package android.content.res;

import android.content.Context;
import android.content.pm.PackageParser;
import android.content.res.Resources;
import android.graphics.Movie;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.util.Log;
import android.util.SparseArray;
import android.util.TypedValue;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import androidx.core.view.ViewCompat;
import androidx.core.view.ViewPropertyAnimatorCompat;
import de.robv.android.xposed.XC_MethodHook;
import de.robv.android.xposed.XposedBridge;
import de.robv.android.xposed.XposedHelpers;
import de.robv.android.xposed.callbacks.XC_LayoutInflated;
import de.robv.android.xposed.callbacks.XCallback;
import java.io.File;
import java.util.Arrays;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.WeakHashMap;
import org.xmlpull.v1.XmlPullParser;
import p.a.a;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class XResources extends a {
    public static final String EXTRA_XML_INSTANCE_DETAILS = "xmlInstanceDetails";
    public boolean mIsObjectInited;
    public String mPackageName;
    public byte[] mReplacementsCache;
    public String mResDir;
    public static final SparseArray<HashMap<String, Object>> sReplacements = new SparseArray<>();
    public static final SparseArray<HashMap<String, ResourceNames>> sResourceNames = new SparseArray<>();
    public static final byte[] sSystemReplacementsCache = new byte[256];
    public static final HashMap<String, byte[]> sReplacementsCacheMap = new HashMap<>();
    public static final SparseArray<ColorStateList> sColorStateListCache = new SparseArray<>(0);
    public static final SparseArray<HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>>> sLayoutCallbacks = new SparseArray<>();
    public static final WeakHashMap<XmlResourceParser, XMLInstanceDetails> sXmlInstanceDetails = new WeakHashMap<>();
    public static final ThreadLocal<LinkedList<XC_MethodHook.MethodHookParam>> sIncludedLayouts = new ThreadLocal<LinkedList<XC_MethodHook.MethodHookParam>>() { // from class: android.content.res.XResources.1
        @Override // java.lang.ThreadLocal
        public LinkedList<XC_MethodHook.MethodHookParam> initialValue() {
            return new LinkedList<>();
        }
    };
    public static final HashMap<String, Long> sResDirLastModified = new HashMap<>();
    public static final HashMap<String, String> sResDirPackageNames = new HashMap<>();
    public static ThreadLocal<Object> sLatestResKey = null;

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public static class DimensionReplacement {
        public final int mUnit;
        public final float mValue;

        public DimensionReplacement(float f2, int i2) {
            this.mValue = f2;
            this.mUnit = i2;
        }

        public float getDimension(DisplayMetrics displayMetrics) {
            return TypedValue.applyDimension(this.mUnit, this.mValue, displayMetrics);
        }

        public int getDimensionPixelOffset(DisplayMetrics displayMetrics) {
            return (int) TypedValue.applyDimension(this.mUnit, this.mValue, displayMetrics);
        }

        public int getDimensionPixelSize(DisplayMetrics displayMetrics) {
            int applyDimension = (int) (TypedValue.applyDimension(this.mUnit, this.mValue, displayMetrics) + 0.5f);
            if (applyDimension != 0) {
                return applyDimension;
            }
            float f2 = this.mValue;
            if (f2 == 0.0f) {
                return 0;
            }
            return f2 > 0.0f ? 1 : -1;
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public static abstract class DrawableLoader {
        public abstract Drawable newDrawable(XResources xResources, int i2) throws Throwable;

        public Drawable newDrawableForDensity(XResources xResources, int i2, int i3) throws Throwable {
            return newDrawable(xResources, i2);
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public static class ResourceNames {
        public final String fullName;
        public final int id;
        public final String name;
        public final String pkg;
        public final String type;

        public boolean equals(String str, String str2, String str3, int i2) {
            return (str == null || str.equals(this.pkg)) && (str2 == null || str2.equals(this.name)) && ((str3 == null || str3.equals(this.type)) && (i2 == 0 || i2 == this.id));
        }

        public ResourceNames(int i2, String str, String str2, String str3) {
            this.id = i2;
            this.pkg = str;
            this.name = str2;
            this.type = str3;
            this.fullName = str + ":" + str3 + "/" + str2;
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public class XMLInstanceDetails {
        public final XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> callbacks;
        public final XResources res;
        public final ResourceNames resNames;
        public final String variant;

        public XMLInstanceDetails(ResourceNames resourceNames, String str, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> copyOnWriteSortedSet) {
            this.res = XResources.this;
            this.resNames = resourceNames;
            this.variant = str;
            this.callbacks = copyOnWriteSortedSet;
        }
    }

    public XResources(ClassLoader classLoader) {
    }

    public static int getFakeResId(String str) {
        return (str.hashCode() & ViewCompat.MEASURED_SIZE_MASK) | ViewPropertyAnimatorCompat.LISTENER_TAG_ID;
    }

    public static String getPackageNameDuringConstruction() {
        Object obj;
        ThreadLocal<Object> threadLocal = sLatestResKey;
        if (threadLocal != null && (obj = threadLocal.get()) != null) {
            return getPackageName((String) XposedHelpers.getObjectField(obj, "mResDir"));
        }
        throw new IllegalStateException("This method can only be called during getTopLevelResources()");
    }

    private ResourceNames getResourceNames(int i2) {
        return new ResourceNames(i2, getResourcePackageName(i2), getResourceTypeName(i2), getResourceEntryName(i2));
    }

    public static ResourceNames getSystemResourceNames(int i2) {
        Resources system = Resources.getSystem();
        return new ResourceNames(i2, system.getResourcePackageName(i2), system.getResourceTypeName(i2), system.getResourceEntryName(i2));
    }

    public static XC_LayoutInflated.Unhook hookLayoutInternal(String str, int i2, ResourceNames resourceNames, XC_LayoutInflated xC_LayoutInflated) {
        HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>> hashMap;
        XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> copyOnWriteSortedSet;
        if (i2 != 0) {
            synchronized (sLayoutCallbacks) {
                hashMap = sLayoutCallbacks.get(i2);
                if (hashMap == null) {
                    hashMap = new HashMap<>();
                    sLayoutCallbacks.put(i2, hashMap);
                }
            }
            synchronized (hashMap) {
                copyOnWriteSortedSet = hashMap.get(str);
                if (copyOnWriteSortedSet == null) {
                    copyOnWriteSortedSet = new XposedBridge.CopyOnWriteSortedSet<>();
                    hashMap.put(str, copyOnWriteSortedSet);
                }
            }
            copyOnWriteSortedSet.add(xC_LayoutInflated);
            putResourceNames(str, resourceNames);
            xC_LayoutInflated.getClass();
            return new XC_LayoutInflated.Unhook(str, i2);
        }
        throw new IllegalArgumentException("id 0 is not an allowed resource identifier");
    }

    public static XC_LayoutInflated.Unhook hookSystemWideLayout(int i2, XC_LayoutInflated xC_LayoutInflated) {
        if (i2 < 2130706432) {
            return hookLayoutInternal(null, i2, getSystemResourceNames(i2), xC_LayoutInflated);
        }
        throw new IllegalArgumentException("ids >= 0x7f000000 are app specific and cannot be set for the framework");
    }

    public static void init(ThreadLocal<Object> threadLocal) throws Exception {
        sLatestResKey = threadLocal;
        XposedHelpers.findAndHookMethod(LayoutInflater.class, "inflate", XmlPullParser.class, ViewGroup.class, Boolean.TYPE, new XC_MethodHook() { // from class: android.content.res.XResources.2
            @Override // de.robv.android.xposed.XC_MethodHook
            public void afterHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) throws Throwable {
                XMLInstanceDetails xMLInstanceDetails;
                if (methodHookParam.hasThrowable()) {
                    return;
                }
                synchronized (XResources.sXmlInstanceDetails) {
                    xMLInstanceDetails = (XMLInstanceDetails) XResources.sXmlInstanceDetails.get(methodHookParam.args[0]);
                }
                if (xMLInstanceDetails != null) {
                    XC_LayoutInflated.LayoutInflatedParam layoutInflatedParam = new XC_LayoutInflated.LayoutInflatedParam(xMLInstanceDetails.callbacks);
                    layoutInflatedParam.view = (View) methodHookParam.getResult();
                    layoutInflatedParam.resNames = xMLInstanceDetails.resNames;
                    layoutInflatedParam.variant = xMLInstanceDetails.variant;
                    layoutInflatedParam.res = xMLInstanceDetails.res;
                    XCallback.callAll(layoutInflatedParam);
                }
            }
        });
        XposedHelpers.findAndHookMethod(LayoutInflater.class, "parseInclude", XmlPullParser.class, Context.class, View.class, AttributeSet.class, new XC_MethodHook() { // from class: android.content.res.XResources.3
            @Override // de.robv.android.xposed.XC_MethodHook
            public void afterHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) throws Throwable {
                XMLInstanceDetails xMLInstanceDetails;
                ((LinkedList) XResources.sIncludedLayouts.get()).pop();
                if (methodHookParam.hasThrowable() || (xMLInstanceDetails = (XMLInstanceDetails) methodHookParam.getObjectExtra(XResources.EXTRA_XML_INSTANCE_DETAILS)) == null) {
                    return;
                }
                XC_LayoutInflated.LayoutInflatedParam layoutInflatedParam = new XC_LayoutInflated.LayoutInflatedParam(xMLInstanceDetails.callbacks);
                ViewGroup viewGroup = (ViewGroup) methodHookParam.args[2];
                layoutInflatedParam.view = viewGroup.getChildAt(viewGroup.getChildCount() - 1);
                layoutInflatedParam.resNames = xMLInstanceDetails.resNames;
                layoutInflatedParam.variant = xMLInstanceDetails.variant;
                layoutInflatedParam.res = xMLInstanceDetails.res;
                XCallback.callAll(layoutInflatedParam);
            }

            @Override // de.robv.android.xposed.XC_MethodHook
            public void beforeHookedMethod(XC_MethodHook.MethodHookParam methodHookParam) throws Throwable {
                ((LinkedList) XResources.sIncludedLayouts.get()).push(methodHookParam);
            }
        });
    }

    public static boolean isXmlCached(Resources resources, int i2) {
        int[] iArr = (int[]) XposedHelpers.getObjectField(XposedHelpers.getObjectField(resources, "mResourcesImpl"), "mCachedXmlBlockCookies");
        synchronized (iArr) {
            for (int i3 : iArr) {
                if (i3 == i2) {
                    return true;
                }
            }
            return false;
        }
    }

    public static void putResourceNames(String str, ResourceNames resourceNames) {
        int i2 = resourceNames.id;
        synchronized (sResourceNames) {
            HashMap<String, ResourceNames> hashMap = sResourceNames.get(i2);
            if (hashMap == null) {
                hashMap = new HashMap<>();
                sResourceNames.put(i2, hashMap);
            }
            synchronized (hashMap) {
                hashMap.put(str, resourceNames);
            }
        }
    }

    public static native void rewriteXmlReferencesNative(long j2, XResources xResources, Resources resources);

    public static void setPackageNameForResDir(String str, String str2) {
        synchronized (sResDirPackageNames) {
            sResDirPackageNames.put(str2, str);
        }
    }

    public static void setSystemWideReplacement(int i2, Object obj) {
        setReplacement(i2, obj, null);
    }

    public static int translateAttrId(String str, XResources xResources) {
        try {
            return xResources.getIdentifier(str, "attr", xResources.mPackageName);
        } catch (Resources.NotFoundException unused) {
            XposedBridge.log("Attribute " + str + " not found in original resources");
            return 0;
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:10:0x0021, code lost:
        if (r4.data != 0) goto L28;
     */
    /* JADX WARN: Removed duplicated region for block: B:21:0x0051 A[Catch: Exception -> 0x0066, TryCatch #2 {Exception -> 0x0066, blocks: (B:2:0x0000, B:4:0x000b, B:7:0x0011, B:9:0x001f, B:16:0x002c, B:18:0x0032, B:21:0x0051, B:23:0x0057, B:25:0x005d), top: B:35:0x0000 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static int translateResId(int i2, XResources xResources, Resources resources) {
        int i3;
        boolean z;
        try {
            String resourceEntryName = resources.getResourceEntryName(i2);
            String resourceTypeName = resources.getResourceTypeName(i2);
            try {
                i3 = xResources.getIdentifier(resourceEntryName, resourceTypeName, xResources.mPackageName);
            } catch (Resources.NotFoundException unused) {
                i3 = 0;
            }
            try {
                TypedValue typedValue = new TypedValue();
                resources.getValue(i2, typedValue, false);
                if (typedValue.type == 18) {
                }
                z = true;
            } catch (Resources.NotFoundException unused2) {
            }
            if (z && i3 == 0 && !resourceTypeName.equals("id")) {
                XposedBridge.log(resourceTypeName + "/" + resourceEntryName + " is neither defined in module nor in original resources");
                return 0;
            }
            if (i3 == 0) {
                i3 = getFakeResId(resources, i2);
            }
            if (z && !resourceTypeName.equals("id")) {
                xResources.setReplacement(i3, new XResForwarder(resources, i2));
            }
            return i3;
            z = false;
            if (z) {
            }
            if (i3 == 0) {
            }
            if (z) {
                xResources.setReplacement(i3, new XResForwarder(resources, i2));
            }
            return i3;
        } catch (Exception e2) {
            XposedBridge.log(e2);
            return i2;
        }
    }

    public static void unhookLayout(String str, int i2, XC_LayoutInflated xC_LayoutInflated) {
        synchronized (sLayoutCallbacks) {
            HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>> hashMap = sLayoutCallbacks.get(i2);
            if (hashMap == null) {
                return;
            }
            synchronized (hashMap) {
                XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> copyOnWriteSortedSet = hashMap.get(str);
                if (copyOnWriteSortedSet == null) {
                    return;
                }
                copyOnWriteSortedSet.remove(xC_LayoutInflated);
            }
        }
    }

    public int addResource(Resources resources, int i2) {
        int fakeResId = getFakeResId(resources, i2);
        synchronized (sReplacements) {
            if (sReplacements.indexOfKey(fakeResId) < 0) {
                setReplacement(fakeResId, new XResForwarder(resources, i2));
            }
        }
        return fakeResId;
    }

    @Override // android.content.res.Resources
    public XmlResourceParser getAnimation(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            Resources resources = xResForwarder.getResources();
            int id = xResForwarder.getId();
            boolean isXmlCached = isXmlCached(resources, id);
            XmlResourceParser animation = resources.getAnimation(id);
            if (!isXmlCached) {
                rewriteXmlReferencesNative(XposedHelpers.getLongField(animation, "mParseState"), this, resources);
            }
            return animation;
        }
        return super.getAnimation(i2);
    }

    @Override // android.content.res.Resources
    public boolean getBoolean(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof Boolean) {
            return ((Boolean) replacement).booleanValue();
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getBoolean(xResForwarder.getId());
        }
        return super.getBoolean(i2);
    }

    @Override // android.content.res.Resources
    public int getColor(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof Integer) {
            return ((Integer) replacement).intValue();
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getColor(xResForwarder.getId());
        }
        return super.getColor(i2);
    }

    @Override // android.content.res.Resources
    public ColorStateList getColorStateList(int i2) throws Resources.NotFoundException {
        ColorStateList colorStateList;
        Object replacement = getReplacement(i2);
        if (replacement instanceof ColorStateList) {
            return (ColorStateList) replacement;
        }
        if (replacement instanceof Integer) {
            int intValue = ((Integer) replacement).intValue();
            synchronized (sColorStateListCache) {
                colorStateList = sColorStateListCache.get(intValue);
                if (colorStateList == null) {
                    colorStateList = ColorStateList.valueOf(intValue);
                    sColorStateListCache.put(intValue, colorStateList);
                }
            }
            return colorStateList;
        } else if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getColorStateList(xResForwarder.getId());
        } else {
            return super.getColorStateList(i2);
        }
    }

    @Override // android.content.res.Resources
    public float getDimension(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof DimensionReplacement) {
            return ((DimensionReplacement) replacement).getDimension(getDisplayMetrics());
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimension(xResForwarder.getId());
        }
        return super.getDimension(i2);
    }

    @Override // android.content.res.Resources
    public int getDimensionPixelOffset(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof DimensionReplacement) {
            return ((DimensionReplacement) replacement).getDimensionPixelOffset(getDisplayMetrics());
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimensionPixelOffset(xResForwarder.getId());
        }
        return super.getDimensionPixelOffset(i2);
    }

    @Override // android.content.res.Resources
    public int getDimensionPixelSize(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof DimensionReplacement) {
            return ((DimensionReplacement) replacement).getDimensionPixelSize(getDisplayMetrics());
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getDimensionPixelSize(xResForwarder.getId());
        }
        return super.getDimensionPixelSize(i2);
    }

    @Override // android.content.res.Resources
    public Drawable getDrawable(int i2) throws Resources.NotFoundException {
        try {
            if (XposedHelpers.incrementMethodDepth("getDrawable") == 1) {
                Object replacement = getReplacement(i2);
                if (replacement instanceof DrawableLoader) {
                    Drawable newDrawable = ((DrawableLoader) replacement).newDrawable(this, i2);
                    if (newDrawable != null) {
                        return newDrawable;
                    }
                } else if (replacement instanceof Integer) {
                    return new ColorDrawable(((Integer) replacement).intValue());
                } else {
                    if (replacement instanceof XResForwarder) {
                        return ((XResForwarder) replacement).getResources().getDrawable(((XResForwarder) replacement).getId());
                    }
                }
            }
            return super.getDrawable(i2);
        } finally {
            XposedHelpers.decrementMethodDepth("getDrawable");
        }
    }

    @Override // android.content.res.Resources
    public Drawable getDrawableForDensity(int i2, int i3) throws Resources.NotFoundException {
        try {
            if (XposedHelpers.incrementMethodDepth("getDrawableForDensity") == 1) {
                Object replacement = getReplacement(i2);
                if (replacement instanceof DrawableLoader) {
                    Drawable newDrawableForDensity = ((DrawableLoader) replacement).newDrawableForDensity(this, i2, i3);
                    if (newDrawableForDensity != null) {
                        return newDrawableForDensity;
                    }
                } else if (replacement instanceof Integer) {
                    return new ColorDrawable(((Integer) replacement).intValue());
                } else {
                    if (replacement instanceof XResForwarder) {
                        return ((XResForwarder) replacement).getResources().getDrawableForDensity(((XResForwarder) replacement).getId(), i3);
                    }
                }
            }
            return super.getDrawableForDensity(i2, i3);
        } finally {
            XposedHelpers.decrementMethodDepth("getDrawableForDensity");
        }
    }

    @Override // android.content.res.Resources
    public float getFraction(int i2, int i3, int i4) {
        Object replacement = getReplacement(i2);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getFraction(xResForwarder.getId(), i3, i4);
        }
        return super.getFraction(i2, i3, i4);
    }

    @Override // android.content.res.Resources
    public int[] getIntArray(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof int[]) {
            return (int[]) replacement;
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getIntArray(xResForwarder.getId());
        }
        return super.getIntArray(i2);
    }

    @Override // android.content.res.Resources
    public int getInteger(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof Integer) {
            return ((Integer) replacement).intValue();
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getInteger(xResForwarder.getId());
        }
        return super.getInteger(i2);
    }

    @Override // android.content.res.Resources
    public XmlResourceParser getLayout(int i2) throws Resources.NotFoundException {
        XmlResourceParser layout;
        HashMap<String, XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated>> hashMap;
        XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> copyOnWriteSortedSet;
        Object replacement = getReplacement(i2);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            Resources resources = xResForwarder.getResources();
            int id = xResForwarder.getId();
            boolean isXmlCached = isXmlCached(resources, id);
            layout = resources.getLayout(id);
            if (!isXmlCached) {
                rewriteXmlReferencesNative(XposedHelpers.getLongField(layout, "mParseState"), this, resources);
            }
        } else {
            layout = super.getLayout(i2);
        }
        synchronized (sLayoutCallbacks) {
            hashMap = sLayoutCallbacks.get(i2);
        }
        if (hashMap != null) {
            synchronized (hashMap) {
                XposedBridge.CopyOnWriteSortedSet<XC_LayoutInflated> copyOnWriteSortedSet2 = hashMap.get(this.mResDir);
                if (copyOnWriteSortedSet2 == null && this.mResDir != null) {
                    copyOnWriteSortedSet2 = hashMap.get(null);
                }
                copyOnWriteSortedSet = copyOnWriteSortedSet2;
            }
            if (copyOnWriteSortedSet != null) {
                String str = "layout";
                TypedValue typedValue = (TypedValue) XposedHelpers.getObjectField(this, "mTmpValue");
                getValue(i2, typedValue, true);
                if (typedValue.type == 3) {
                    String[] split = typedValue.string.toString().split("/", 3);
                    if (split.length == 3) {
                        str = split[1];
                    } else {
                        XposedBridge.log("Unexpected resource path \"" + typedValue.string.toString() + "\" for resource id 0x" + Integer.toHexString(i2));
                    }
                } else {
                    XposedBridge.log(new Resources.NotFoundException("Could not find file name for resource id 0x") + Integer.toHexString(i2));
                }
                String str2 = str;
                synchronized (sXmlInstanceDetails) {
                    synchronized (sResourceNames) {
                        HashMap<String, ResourceNames> hashMap2 = sResourceNames.get(i2);
                        if (hashMap2 != null) {
                            synchronized (hashMap2) {
                                XMLInstanceDetails xMLInstanceDetails = new XMLInstanceDetails(hashMap2.get(this.mResDir), str2, copyOnWriteSortedSet);
                                sXmlInstanceDetails.put(layout, xMLInstanceDetails);
                                XC_MethodHook.MethodHookParam peek = sIncludedLayouts.get().peek();
                                if (peek != null) {
                                    peek.setObjectExtra(EXTRA_XML_INSTANCE_DETAILS, xMLInstanceDetails);
                                }
                            }
                        }
                    }
                }
            }
        }
        return layout;
    }

    @Override // android.content.res.Resources
    public Movie getMovie(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getMovie(xResForwarder.getId());
        }
        return super.getMovie(i2);
    }

    public String getPackageName() {
        return this.mPackageName;
    }

    @Override // android.content.res.Resources
    public CharSequence getQuantityText(int i2, int i3) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getQuantityText(xResForwarder.getId(), i3);
        }
        return super.getQuantityText(i2, i3);
    }

    public Object getReplacement(int i2) {
        HashMap<String, Object> hashMap;
        if (i2 <= 0) {
            return null;
        }
        if (i2 < 2130706432) {
            if ((sSystemReplacementsCache[((i2 & 458752) >> 11) | ((i2 & 248) >> 3)] & (1 << (i2 & 7))) == 0) {
                return null;
            }
        } else if (this.mResDir != null) {
            if ((this.mReplacementsCache[((i2 & 458752) >> 12) | ((i2 & 120) >> 3)] & (1 << (i2 & 7))) == 0) {
                return null;
            }
        }
        synchronized (sReplacements) {
            hashMap = sReplacements.get(i2);
        }
        if (hashMap == null) {
            return null;
        }
        synchronized (hashMap) {
            Object obj = hashMap.get(this.mResDir);
            if (obj == null && this.mResDir != null) {
                return hashMap.get(null);
            }
            return obj;
        }
    }

    @Override // android.content.res.Resources
    public String[] getStringArray(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof String[]) {
            return (String[]) replacement;
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getStringArray(xResForwarder.getId());
        }
        return super.getStringArray(i2);
    }

    @Override // android.content.res.Resources
    public CharSequence getText(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof CharSequence) {
            return (CharSequence) replacement;
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getText(xResForwarder.getId());
        }
        return super.getText(i2);
    }

    @Override // android.content.res.Resources
    public CharSequence[] getTextArray(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof CharSequence[]) {
            return (CharSequence[]) replacement;
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getTextArray(xResForwarder.getId());
        }
        return super.getTextArray(i2);
    }

    @Override // android.content.res.Resources
    public XmlResourceParser getXml(int i2) throws Resources.NotFoundException {
        Object replacement = getReplacement(i2);
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            Resources resources = xResForwarder.getResources();
            int id = xResForwarder.getId();
            boolean isXmlCached = isXmlCached(resources, id);
            XmlResourceParser xml = resources.getXml(id);
            if (!isXmlCached) {
                rewriteXmlReferencesNative(XposedHelpers.getLongField(xml, "mParseState"), this, resources);
            }
            return xml;
        }
        return super.getXml(i2);
    }

    public XC_LayoutInflated.Unhook hookLayout(int i2, XC_LayoutInflated xC_LayoutInflated) {
        return hookLayoutInternal(this.mResDir, i2, getResourceNames(i2), xC_LayoutInflated);
    }

    public void initObject(String str) {
        if (!this.mIsObjectInited) {
            this.mResDir = str;
            this.mPackageName = getPackageName(str);
            if (str != null) {
                synchronized (sReplacementsCacheMap) {
                    byte[] bArr = sReplacementsCacheMap.get(str);
                    this.mReplacementsCache = bArr;
                    if (bArr == null) {
                        byte[] bArr2 = new byte[128];
                        this.mReplacementsCache = bArr2;
                        sReplacementsCacheMap.put(str, bArr2);
                    }
                }
            }
            this.mIsObjectInited = true;
            return;
        }
        throw new IllegalStateException("Object has already been initialized");
    }

    public boolean isFirstLoad() {
        synchronized (sReplacements) {
            if (this.mResDir == null) {
                return false;
            }
            Long valueOf = Long.valueOf(new File(this.mResDir).lastModified());
            Long l2 = sResDirLastModified.get(this.mResDir);
            if (valueOf.equals(l2)) {
                return false;
            }
            sResDirLastModified.put(this.mResDir, valueOf);
            if (l2 == null) {
                return true;
            }
            for (int i2 = 0; i2 < sReplacements.size(); i2++) {
                sReplacements.valueAt(i2).remove(this.mResDir);
            }
            Arrays.fill(this.mReplacementsCache, (byte) 0);
            return true;
        }
    }

    public void setReplacement(int i2, Object obj) {
        setReplacement(i2, obj, this);
    }

    public static int getFakeResId(Resources resources, int i2) {
        return getFakeResId(resources.getResourceName(i2));
    }

    public static String getPackageName(String str) {
        String str2;
        if (str == null) {
            return "android";
        }
        synchronized (sResDirPackageNames) {
            str2 = sResDirPackageNames.get(str);
        }
        if (str2 != null) {
            return str2;
        }
        try {
            PackageParser.PackageLite parsePackageLite = PackageParser.parsePackageLite(new File(str), 0);
            if (parsePackageLite != null && parsePackageLite.packageName != null) {
                Log.w("PineXposed", "Package name for " + str + " had to be retrieved via parser");
                String str3 = parsePackageLite.packageName;
                setPackageNameForResDir(str3, str);
                return str3;
            }
            throw new IllegalStateException("Could not determine package name for " + str);
        } catch (PackageParser.PackageParserException e2) {
            throw new IllegalStateException("Could not determine package name for " + str, e2);
        }
    }

    @Deprecated
    public static void setSystemWideReplacement(String str, Object obj) {
        int identifier = Resources.getSystem().getIdentifier(str, null, null);
        if (identifier != 0) {
            setReplacement(identifier, obj, null);
            return;
        }
        throw new Resources.NotFoundException(str);
    }

    @Deprecated
    public XC_LayoutInflated.Unhook hookLayout(String str, XC_LayoutInflated xC_LayoutInflated) {
        int identifier = getIdentifier(str, null, null);
        if (identifier != 0) {
            return hookLayout(identifier, xC_LayoutInflated);
        }
        throw new Resources.NotFoundException(str);
    }

    @Deprecated
    public void setReplacement(String str, Object obj) {
        int identifier = getIdentifier(str, null, null);
        if (identifier != 0) {
            setReplacement(identifier, obj, this);
            return;
        }
        throw new Resources.NotFoundException(str);
    }

    @Deprecated
    public static XC_LayoutInflated.Unhook hookSystemWideLayout(String str, XC_LayoutInflated xC_LayoutInflated) {
        int identifier = Resources.getSystem().getIdentifier(str, null, null);
        if (identifier != 0) {
            return hookSystemWideLayout(identifier, xC_LayoutInflated);
        }
        throw new Resources.NotFoundException(str);
    }

    public static void setSystemWideReplacement(String str, String str2, String str3, Object obj) {
        int identifier = Resources.getSystem().getIdentifier(str3, str2, str);
        if (identifier != 0) {
            setReplacement(identifier, obj, null);
            return;
        }
        throw new Resources.NotFoundException(str + ":" + str2 + "/" + str3);
    }

    public XC_LayoutInflated.Unhook hookLayout(String str, String str2, String str3, XC_LayoutInflated xC_LayoutInflated) {
        int identifier = getIdentifier(str3, str2, str);
        if (identifier != 0) {
            return hookLayout(identifier, xC_LayoutInflated);
        }
        throw new Resources.NotFoundException(str + ":" + str2 + "/" + str3);
    }

    public void setReplacement(String str, String str2, String str3, Object obj) {
        int identifier = getIdentifier(str3, str2, str);
        if (identifier != 0) {
            setReplacement(identifier, obj, this);
            return;
        }
        throw new Resources.NotFoundException(str + ":" + str2 + "/" + str3);
    }

    public static XC_LayoutInflated.Unhook hookSystemWideLayout(String str, String str2, String str3, XC_LayoutInflated xC_LayoutInflated) {
        int identifier = Resources.getSystem().getIdentifier(str3, str2, str);
        if (identifier != 0) {
            return hookSystemWideLayout(identifier, xC_LayoutInflated);
        }
        throw new Resources.NotFoundException(str + ":" + str2 + "/" + str3);
    }

    public static void setReplacement(int i2, Object obj, XResources xResources) {
        String str = xResources != null ? xResources.mResDir : null;
        if (i2 == 0) {
            throw new IllegalArgumentException("id 0 is not an allowed resource identifier");
        }
        if (str == null && i2 >= 2130706432) {
            throw new IllegalArgumentException("ids >= 0x7f000000 are app specific and cannot be set for the framework");
        }
        if (!(obj instanceof Drawable)) {
            if (i2 < 2130706432) {
                int i3 = ((i2 & 458752) >> 11) | ((i2 & 248) >> 3);
                synchronized (sSystemReplacementsCache) {
                    byte[] bArr = sSystemReplacementsCache;
                    bArr[i3] = (byte) ((1 << (i2 & 7)) | bArr[i3]);
                }
            } else {
                int i4 = ((i2 & 458752) >> 12) | ((i2 & 120) >> 3);
                synchronized (xResources.mReplacementsCache) {
                    byte[] bArr2 = xResources.mReplacementsCache;
                    bArr2[i4] = (byte) ((1 << (i2 & 7)) | bArr2[i4]);
                }
            }
            synchronized (sReplacements) {
                HashMap<String, Object> hashMap = sReplacements.get(i2);
                if (hashMap == null) {
                    hashMap = new HashMap<>();
                    sReplacements.put(i2, hashMap);
                }
                hashMap.put(str, obj);
            }
            return;
        }
        throw new IllegalArgumentException("Drawable replacements are deprecated since Xposed 2.1. Use DrawableLoader instead.");
    }

    @Override // android.content.res.Resources
    public CharSequence getText(int i2, CharSequence charSequence) {
        Object replacement = getReplacement(i2);
        if (replacement instanceof CharSequence) {
            return (CharSequence) replacement;
        }
        if (replacement instanceof XResForwarder) {
            XResForwarder xResForwarder = (XResForwarder) replacement;
            return xResForwarder.getResources().getText(xResForwarder.getId(), charSequence);
        }
        return super.getText(i2, charSequence);
    }

    @Override // android.content.res.Resources
    public Drawable getDrawable(int i2, Resources.Theme theme) throws Resources.NotFoundException {
        try {
            if (XposedHelpers.incrementMethodDepth("getDrawable") == 1) {
                Object replacement = getReplacement(i2);
                if (replacement instanceof DrawableLoader) {
                    Drawable newDrawable = ((DrawableLoader) replacement).newDrawable(this, i2);
                    if (newDrawable != null) {
                        return newDrawable;
                    }
                } else if (replacement instanceof Integer) {
                    return new ColorDrawable(((Integer) replacement).intValue());
                } else {
                    if (replacement instanceof XResForwarder) {
                        return ((XResForwarder) replacement).getResources().getDrawable(((XResForwarder) replacement).getId());
                    }
                }
            }
            return super.getDrawable(i2, theme);
        } finally {
            XposedHelpers.decrementMethodDepth("getDrawable");
        }
    }

    @Override // android.content.res.Resources
    public Drawable getDrawableForDensity(int i2, int i3, Resources.Theme theme) throws Resources.NotFoundException {
        try {
            if (XposedHelpers.incrementMethodDepth("getDrawableForDensity") == 1) {
                Object replacement = getReplacement(i2);
                if (replacement instanceof DrawableLoader) {
                    Drawable newDrawableForDensity = ((DrawableLoader) replacement).newDrawableForDensity(this, i2, i3);
                    if (newDrawableForDensity != null) {
                        return newDrawableForDensity;
                    }
                } else if (replacement instanceof Integer) {
                    return new ColorDrawable(((Integer) replacement).intValue());
                } else {
                    if (replacement instanceof XResForwarder) {
                        return ((XResForwarder) replacement).getResources().getDrawableForDensity(((XResForwarder) replacement).getId(), i3);
                    }
                }
            }
            return super.getDrawableForDensity(i2, i3, theme);
        } finally {
            XposedHelpers.decrementMethodDepth("getDrawableForDensity");
        }
    }
}
