package chongya.canyie.pine;

import android.annotation.SuppressLint;
import android.os.Build;
import android.util.Log;
import chongya.canyie.pine.callback.MethodHook;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.Proxy;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Locale;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
/* compiled from: AAA */
/* loaded from: classes.dex */
public final class Pine {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int ARCH_ARM = 1;
    public static final int ARCH_ARM64 = 2;
    public static final int ARCH_X86 = 3;
    public static final String TAG = "Pine";
    public static int arch;
    public static volatile boolean initialized;
    public static HookListener sHookListener;
    public static final Object[] EMPTY_OBJECT_ARRAY = new Object[0];
    public static final Map<String, Method> sBridgeMethods = new HashMap(8, 2.0f);
    public static final Map<Long, HookRecord> sHookRecords = new ConcurrentHashMap();
    public static final Object sHookLock = new Object();
    public static volatile int hookMode = 0;
    public static HookHandler sHookHandler = new HookHandler() { // from class: chongya.canyie.pine.Pine.1
        @Override // chongya.canyie.pine.Pine.HookHandler
        public MethodHook.Unhook handleHook(HookRecord hookRecord, MethodHook methodHook, int i2, boolean z, boolean z2) {
            if (z) {
                Pine.hookNewMethod(hookRecord, i2, z2);
            }
            if (methodHook == null) {
                return null;
            }
            hookRecord.addCallback(methodHook);
            methodHook.getClass();
            return new MethodHook.Unhook(hookRecord);
        }

        @Override // chongya.canyie.pine.Pine.HookHandler
        public void handleUnhook(HookRecord hookRecord, MethodHook methodHook) {
            hookRecord.removeCallback(methodHook);
        }
    };

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public static class CallFrame {
        public Object[] args;
        public HookRecord hookRecord;
        public final Member method;
        public Object result;
        public boolean returnEarly;
        public Object thisObject;
        public Throwable throwable;

        public CallFrame(HookRecord hookRecord, Object obj, Object[] objArr) {
            this.hookRecord = hookRecord;
            this.method = hookRecord.target;
            this.thisObject = obj;
            this.args = objArr;
        }

        public Object getResult() {
            return this.result;
        }

        public Object getResultOrThrowable() throws Throwable {
            Throwable th = this.throwable;
            if (th == null) {
                return this.result;
            }
            throw th;
        }

        public Throwable getThrowable() {
            return this.throwable;
        }

        public boolean hasThrowable() {
            return this.throwable != null;
        }

        public Object invokeOriginalMethod() throws InvocationTargetException, IllegalAccessException {
            HookRecord hookRecord = this.hookRecord;
            return Pine.callBackupMethod(hookRecord.target, hookRecord.backup, this.thisObject, this.args);
        }

        public void resetResult() {
            this.result = null;
            this.throwable = null;
            this.returnEarly = false;
        }

        public void setResult(Object obj) {
            this.result = obj;
            this.throwable = null;
            this.returnEarly = true;
        }

        public void setResultIfNoException(Object obj) {
            if (this.throwable == null) {
                this.result = obj;
                this.returnEarly = true;
            }
        }

        public void setThrowable(Throwable th) {
            this.throwable = th;
            this.result = null;
            this.returnEarly = true;
        }

        public Object invokeOriginalMethod(Object obj, Object... objArr) throws InvocationTargetException, IllegalAccessException {
            HookRecord hookRecord = this.hookRecord;
            return Pine.callBackupMethod(hookRecord.target, hookRecord.backup, obj, objArr);
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public interface HookHandler {
        MethodHook.Unhook handleHook(HookRecord hookRecord, MethodHook methodHook, int i2, boolean z, boolean z2);

        void handleUnhook(HookRecord hookRecord, MethodHook methodHook);
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public interface HookListener {
        void afterHook(Member member, MethodHook.Unhook unhook);

        void beforeHook(Member member, MethodHook methodHook);
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public interface HookMode {
        public static final int AUTO = 0;
        public static final int INLINE = 1;
        public static final int REPLACEMENT = 2;
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public static final class HookRecord {
        public final long artMethod;
        public Method backup;
        public Set<MethodHook> callbacks = new HashSet();
        public boolean isStatic;
        public int paramNumber;
        public Class<?>[] paramTypes;
        public final Member target;

        public HookRecord(Member member, long j2) {
            this.target = member;
            this.artMethod = j2;
        }

        public synchronized void addCallback(MethodHook methodHook) {
            this.callbacks.add(methodHook);
        }

        public synchronized boolean emptyCallbacks() {
            return this.callbacks.isEmpty();
        }

        public synchronized MethodHook[] getCallbacks() {
            return (MethodHook[]) this.callbacks.toArray(new MethodHook[this.callbacks.size()]);
        }

        public boolean isPending() {
            return this.backup == null;
        }

        public synchronized void removeCallback(MethodHook methodHook) {
            this.callbacks.remove(methodHook);
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public interface LibLoader {
        void loadLib();
    }

    public Pine() {
        throw new RuntimeException("Use static methods");
    }

    public static Object callBackupMethod(Member member, Method method, Object obj, Object[] objArr) throws InvocationTargetException, IllegalAccessException {
        if (PineConfig.sdkLevel >= 24) {
            Class<?> declaringClass = member.getDeclaringClass();
            updateDeclaringClass(member, method);
            Object invoke = method.invoke(obj, objArr);
            declaringClass.getClass();
            return invoke;
        }
        return method.invoke(obj, objArr);
    }

    public static native long cloneExtras(long j2);

    public static boolean compile(Member member) {
        int modifiers = member.getModifiers();
        Class<?> declaringClass = member.getDeclaringClass();
        if (!(member instanceof Method) && !(member instanceof Constructor)) {
            throw new IllegalArgumentException("Only methods and constructors can be compiled: " + member);
        } else if (!Modifier.isAbstract(modifiers)) {
            if (Modifier.isNative(modifiers) || Proxy.isProxyClass(declaringClass)) {
                return false;
            }
            ensureInitialized();
            return compile0(currentArtThread0(), member);
        } else {
            throw new IllegalArgumentException("Cannot compile abstract methods: " + member);
        }
    }

    public static native boolean compile0(long j2, Member member);

    public static native long currentArtThread0();

    public static boolean decompile(Member member, boolean z) {
        int modifiers = member.getModifiers();
        Class<?> declaringClass = member.getDeclaringClass();
        if (!(member instanceof Method) && !(member instanceof Constructor)) {
            throw new IllegalArgumentException("Only methods and constructors can be decompiled: " + member);
        } else if (!Modifier.isAbstract(modifiers)) {
            if (Proxy.isProxyClass(declaringClass)) {
                return false;
            }
            ensureInitialized();
            return decompile0(member, z);
        } else {
            throw new IllegalArgumentException("Cannot decompile abstract methods: " + member);
        }
    }

    public static native boolean decompile0(Member member, boolean z);

    public static void disableHiddenApiPolicy(boolean z, boolean z2) {
        if (initialized) {
            disableHiddenApiPolicy0(z, z2);
            return;
        }
        PineConfig.disableHiddenApiPolicy = z;
        PineConfig.disableHiddenApiPolicyForPlatformDomain = z2;
        ensureInitialized();
    }

    public static native void disableHiddenApiPolicy0(boolean z, boolean z2);

    public static boolean disableJitInline() {
        if (PineConfig.sdkLevel < 24) {
            return false;
        }
        ensureInitialized();
        return disableJitInline0();
    }

    public static native boolean disableJitInline0();

    public static boolean disableProfileSaver() {
        if (PineConfig.sdkLevel < 24) {
            return false;
        }
        ensureInitialized();
        return disableProfileSaver0();
    }

    public static native boolean disableProfileSaver0();

    public static native void enableFastNative();

    public static void ensureInitialized() {
        if (initialized) {
            return;
        }
        synchronized (Pine.class) {
            if (initialized) {
                return;
            }
            initialize();
            initialized = true;
        }
    }

    public static long getAddress(long j2, Object obj) {
        if (obj == null) {
            return 0L;
        }
        return getAddress0(j2, obj);
    }

    public static native long getAddress0(long j2, Object obj);

    public static native void getArgsArm32(int i2, int i3, int[] iArr, int[] iArr2, float[] fArr);

    public static native void getArgsArm64(long j2, long j3, boolean[] zArr, long[] jArr, long[] jArr2, double[] dArr);

    public static native void getArgsX86(int i2, int[] iArr, int i3);

    public static native long getArtMethod(Member member);

    public static HookHandler getHookHandler() {
        return sHookHandler;
    }

    public static HookListener getHookListener() {
        return sHookListener;
    }

    public static HookRecord getHookRecord(long j2) {
        HookRecord hookRecord = sHookRecords.get(Long.valueOf(j2));
        if (hookRecord != null) {
            return hookRecord;
        }
        throw new AssertionError("No HookRecord found for ArtMethod pointer 0x" + Long.toHexString(j2));
    }

    public static Object getObject(long j2, long j3) {
        if (j3 == 0) {
            return null;
        }
        return getObject0(j2, j3);
    }

    public static native Object getObject0(long j2, long j3);

    public static Object handleCall(HookRecord hookRecord, Object obj, Object[] objArr) throws Throwable {
        MethodHook methodHook;
        if (PineConfig.debug) {
            Log.d(TAG, "handleCall for method " + hookRecord.target);
        }
        if (!PineConfig.disableHooks && !hookRecord.emptyCallbacks()) {
            CallFrame callFrame = new CallFrame(hookRecord, obj, objArr);
            MethodHook[] callbacks = hookRecord.getCallbacks();
            int i2 = 0;
            while (true) {
                try {
                    callbacks[i2].beforeCall(callFrame);
                    if (callFrame.returnEarly) {
                        i2++;
                        break;
                    }
                } catch (Throwable th) {
                    Log.e(TAG, "Unexpected exception occurred when calling " + methodHook.getClass().getName() + ".beforeCall()", th);
                    callFrame.resetResult();
                }
                i2++;
                if (i2 >= callbacks.length) {
                    break;
                }
            }
            if (!callFrame.returnEarly) {
                try {
                    callFrame.setResult(callFrame.invokeOriginalMethod());
                } catch (InvocationTargetException e2) {
                    callFrame.setThrowable(e2.getTargetException());
                }
            }
            int i3 = i2 - 1;
            do {
                MethodHook methodHook2 = callbacks[i3];
                Object result = callFrame.getResult();
                Throwable throwable = callFrame.getThrowable();
                try {
                    methodHook2.afterCall(callFrame);
                } catch (Throwable th2) {
                    Log.e(TAG, "Unexpected exception occurred when calling " + methodHook2.getClass().getName() + ".afterCall()", th2);
                    if (throwable == null) {
                        callFrame.setResult(result);
                    } else {
                        callFrame.setThrowable(throwable);
                    }
                }
                i3--;
            } while (i3 >= 0);
            if (!callFrame.hasThrowable()) {
                return callFrame.getResult();
            }
            throw callFrame.getThrowable();
        }
        try {
            return callBackupMethod(hookRecord.target, hookRecord.backup, obj, objArr);
        } catch (InvocationTargetException e3) {
            throw e3.getTargetException();
        }
    }

    public static MethodHook.Unhook hook(Member member, MethodHook methodHook) {
        return hook(member, methodHook, true);
    }

    public static native Method hook0(long j2, Class<?> cls, Member member, Method method, boolean z, boolean z2, boolean z3);

    public static void hookNewMethod(HookRecord hookRecord, int i2, boolean z) {
        boolean z2;
        String str;
        Class<?> returnType;
        Member member = hookRecord.target;
        boolean z3 = false;
        boolean z4 = hookMode != 0 ? hookMode == 1 : PineConfig.sdkLevel < 26;
        long currentArtThread0 = currentArtThread0();
        boolean isStatic = Modifier.isStatic(i2);
        hookRecord.isStatic = isStatic;
        if (isStatic && z) {
            resolve((Method) member);
            if (PineConfig.sdkLevel >= 29) {
                makeClassesVisiblyInitialized(currentArtThread0);
            }
        }
        Class<?> declaringClass = member.getDeclaringClass();
        boolean isNative = Modifier.isNative(i2);
        boolean isProxyClass = Proxy.isProxyClass(declaringClass);
        if (!z4) {
            z2 = z4;
        } else if (isNative || isProxyClass) {
            z2 = false;
        } else {
            if (compile0(currentArtThread0, member)) {
                z3 = z4;
            } else {
                Log.w(TAG, "Cannot compile the target method, force replacement mode.");
            }
            z2 = z3;
        }
        if (member instanceof Method) {
            Method method = (Method) member;
            hookRecord.paramTypes = method.getParameterTypes();
            if (method.getReturnType().isPrimitive()) {
                str = returnType.getName() + "Bridge";
            } else {
                str = "objectBridge";
            }
        } else {
            hookRecord.paramTypes = ((Constructor) member).getParameterTypes();
            str = "voidBridge";
        }
        hookRecord.paramNumber = hookRecord.paramTypes.length;
        Method method2 = sBridgeMethods.get(str);
        if (method2 != null) {
            Method hook0 = hook0(currentArtThread0, declaringClass, member, method2, z2, isNative, isProxyClass);
            if (hook0 != null) {
                hook0.setAccessible(true);
                hookRecord.backup = hook0;
                return;
            }
            throw new RuntimeException("Failed to hook method " + member);
        }
        throw new AssertionError("Cannot find bridge method for " + member);
    }

    public static native void init0(int i2, boolean z, boolean z2, boolean z3, boolean z4, boolean z5);

    public static void initBridgeMethods() {
        String str;
        Class<?>[] clsArr;
        try {
            if (arch == 2) {
                str = "chongya.canyie.pine.entry.Arm64Entry";
                clsArr = new Class[]{Long.TYPE, Long.TYPE, Long.TYPE, Long.TYPE, Long.TYPE, Long.TYPE, Long.TYPE};
            } else if (arch == 1) {
                str = "chongya.canyie.pine.entry.Arm32Entry";
                clsArr = new Class[]{Integer.TYPE, Integer.TYPE, Integer.TYPE};
            } else if (arch != 3) {
                throw new RuntimeException("Unexpected arch " + arch);
            } else {
                str = "chongya.canyie.pine.entry.X86Entry";
                clsArr = new Class[]{Integer.TYPE, Integer.TYPE, Integer.TYPE};
            }
            Class<?> cls = Class.forName(str, true, Pine.class.getClassLoader());
            String[] strArr = {"voidBridge", "intBridge", "longBridge", "doubleBridge", "floatBridge", "booleanBridge", "byteBridge", "charBridge", "shortBridge", "objectBridge"};
            for (int i2 = 0; i2 < 10; i2++) {
                String str2 = strArr[i2];
                Method declaredMethod = cls.getDeclaredMethod(str2, clsArr);
                declaredMethod.setAccessible(true);
                sBridgeMethods.put(str2, declaredMethod);
            }
        } catch (Exception e2) {
            throw new RuntimeException("Failed to init bridge methods", e2);
        }
    }

    @SuppressLint({"ObsoleteSdkInt"})
    public static void initialize() {
        int i2 = PineConfig.sdkLevel;
        if (i2 >= 19) {
            if (i2 > 30) {
                Log.w(TAG, "Android version too high, not tested now...");
                if (i2 >= 32 && isAtLeastPreReleaseCodename("Tiramisu")) {
                    i2 = 33;
                } else if (i2 == 31 && isAtLeastPreReleaseCodename("Sv2")) {
                    i2 = 32;
                }
            }
            String property = System.getProperty("java.vm.version");
            if (property != null && property.startsWith("2")) {
                try {
                    LibLoader libLoader = PineConfig.libLoader;
                    if (libLoader != null) {
                        libLoader.loadLib();
                    }
                    init0(i2, PineConfig.debug, PineConfig.debuggable, PineConfig.antiChecks, PineConfig.disableHiddenApiPolicy, PineConfig.disableHiddenApiPolicyForPlatformDomain);
                    initBridgeMethods();
                    if (!PineConfig.useFastNative || i2 < 21) {
                        return;
                    }
                    enableFastNative();
                    return;
                } catch (Exception e2) {
                    throw new RuntimeException("Pine init error", e2);
                }
            }
            throw new RuntimeException("Only supports ART runtime");
        }
        throw new RuntimeException("Unsupported android sdk level " + i2);
    }

    public static Object invokeOriginalMethod(Member member, Object obj, Object... objArr) throws IllegalAccessException, InvocationTargetException {
        if (member != null) {
            if (member instanceof Method) {
                ((Method) member).setAccessible(true);
            } else if (member instanceof Constructor) {
                ((Constructor) member).setAccessible(true);
            } else {
                throw new IllegalArgumentException("method must be of type Method or Constructor");
            }
            HookRecord hookRecord = sHookRecords.get(Long.valueOf(getArtMethod(member)));
            if (hookRecord == null) {
                if (member instanceof Constructor) {
                    if (obj == null) {
                        try {
                            ((Constructor) member).newInstance(objArr);
                            return null;
                        } catch (InstantiationException e2) {
                            throw new IllegalArgumentException("invalid Constructor", e2);
                        }
                    }
                    throw new IllegalArgumentException("Cannot invoke a not hooked Constructor with a non-null receiver");
                }
                return ((Method) member).invoke(obj, objArr);
            }
            if (hookRecord.backup == null) {
                resolve((Method) member);
            }
            return callBackupMethod(hookRecord.target, hookRecord.backup, obj, objArr);
        }
        throw new NullPointerException("method == null");
    }

    public static boolean is64Bit() {
        ensureInitialized();
        return arch == 2;
    }

    public static boolean isAtLeastPreReleaseCodename(String str) {
        String upperCase = Build.VERSION.CODENAME.toUpperCase(Locale.ROOT);
        return !"REL".equals(upperCase) && upperCase.compareTo(str.toUpperCase(Locale.ROOT)) >= 0;
    }

    public static boolean isHooked(Member member) {
        if (!(member instanceof Method) && !(member instanceof Constructor)) {
            throw new IllegalArgumentException("Only methods and constructors can be hooked: " + member);
        }
        return sHookRecords.containsKey(Long.valueOf(getArtMethod(member)));
    }

    public static boolean isInitialized() {
        return initialized;
    }

    public static void log(String str) {
        if (PineConfig.debug) {
            Log.i(TAG, str);
        }
    }

    public static native void makeClassesVisiblyInitialized(long j2);

    public static void resolve(Method method) {
        try {
            method.invoke(null, method.getParameterTypes().length > 0 ? null : new Object[1]);
            throw new RuntimeException("No IllegalArgumentException thrown when resolve static method.");
        } catch (IllegalArgumentException unused) {
        } catch (Exception e2) {
            throw new RuntimeException("Unknown exception thrown when resolve static method.", e2);
        }
    }

    public static void setDebuggable(boolean z) {
        if (!initialized) {
            synchronized (Pine.class) {
                if (!initialized) {
                    PineConfig.debuggable = z;
                    initialize();
                    initialized = true;
                    return;
                }
            }
        }
        PineConfig.debuggable = z;
        setDebuggable0(z);
    }

    public static native void setDebuggable0(boolean z);

    public static void setHookHandler(HookHandler hookHandler) {
        if (hookHandler != null) {
            sHookHandler = hookHandler;
            return;
        }
        throw new NullPointerException("h == null");
    }

    public static void setHookListener(HookListener hookListener) {
        sHookListener = hookListener;
    }

    public static void setHookMode(int i2) {
        if (i2 >= 0 && i2 <= 2) {
            hookMode = i2;
            return;
        }
        throw new IllegalArgumentException("Illegal hookMode " + i2);
    }

    public static void setJitCompilationAllowed(boolean z) {
        if (PineConfig.sdkLevel < 24) {
            return;
        }
        ensureInitialized();
        setJitCompilationAllowed0(z);
    }

    public static native void setJitCompilationAllowed0(boolean z);

    public static native void updateDeclaringClass(Member member, Method method);

    public static MethodHook.Unhook hook(Member member, MethodHook methodHook, boolean z) {
        HookRecord hookRecord;
        if (PineConfig.debug) {
            Log.d(TAG, "Hooking method " + member + " with callback " + methodHook);
        }
        if (member != null) {
            if (methodHook != null) {
                int modifiers = member.getModifiers();
                boolean z2 = true;
                if (member instanceof Method) {
                    if (!Modifier.isAbstract(modifiers)) {
                        ((Method) member).setAccessible(true);
                    } else {
                        throw new IllegalArgumentException("Cannot hook abstract methods: " + member);
                    }
                } else if (member instanceof Constructor) {
                    if (!Modifier.isStatic(modifiers)) {
                        ((Constructor) member).setAccessible(true);
                    } else {
                        throw new IllegalArgumentException("Cannot hook class initializer: " + member);
                    }
                } else {
                    throw new IllegalArgumentException("Only methods and constructors can be hooked: " + member);
                }
                ensureInitialized();
                HookListener hookListener = sHookListener;
                if (hookListener != null) {
                    hookListener.beforeHook(member, methodHook);
                }
                long artMethod = getArtMethod(member);
                synchronized (sHookLock) {
                    HookRecord hookRecord2 = sHookRecords.get(Long.valueOf(artMethod));
                    if (hookRecord2 == null) {
                        HookRecord hookRecord3 = new HookRecord(member, artMethod);
                        sHookRecords.put(Long.valueOf(artMethod), hookRecord3);
                        hookRecord = hookRecord3;
                    } else {
                        hookRecord = hookRecord2;
                        z2 = false;
                    }
                }
                MethodHook.Unhook handleHook = sHookHandler.handleHook(hookRecord, methodHook, modifiers, z2, z);
                if (hookListener != null) {
                    hookListener.afterHook(member, handleHook);
                }
                return handleHook;
            }
            throw new NullPointerException("callback == null");
        }
        throw new NullPointerException("method == null");
    }

    public static void log(String str, Object... objArr) {
        if (PineConfig.debug) {
            Log.i(TAG, String.format(str, objArr));
        }
    }
}
