package chongya.canyie.pine.utils;

import android.annotation.SuppressLint;
import android.util.Log;
import chongya.canyie.pine.Pine;
import chongya.canyie.pine.entry.Arm64Entry;
import j.l0;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
/* compiled from: AAA */
@SuppressLint({"PrivateApi"})
/* loaded from: classes.dex */
public final class Primitives {
    public static final String TAG = "Primitives";
    public static Field classAccessFlagsField;
    public static Method putObject;
    public static Field shadowKlassField;
    public static Field superClassField;
    public static boolean triedGetShadowKlassField;
    public static Object unsafe;
    public static Class<?> unsafeClass;

    public static int bytes2Int(byte[] bArr) {
        return ((bArr[3] & l0.MAX_VALUE) << 24) | (bArr[0] & l0.MAX_VALUE) | ((bArr[1] & l0.MAX_VALUE) << 8) | ((bArr[2] & l0.MAX_VALUE) << 16);
    }

    public static long currentArtThread() {
        Pine.ensureInitialized();
        return Pine.currentArtThread0();
    }

    public static void ensureUnsafeReady() {
        if (unsafe != null) {
            return;
        }
        try {
            unsafeClass = Class.forName("sun.misc.Unsafe");
            unsafe = getUnsafe();
        } catch (Exception e2) {
            throw new RuntimeException("Unsafe API is unavailable", e2);
        }
    }

    public static int evenUp(int i2) {
        return (i2 & 1) == 1 ? i2 + 1 : i2;
    }

    public static double floats2Double(float f2, float f3) {
        return Double.longBitsToDouble(ints2Long(Float.floatToIntBits(f2), Float.floatToIntBits(f3)));
    }

    public static int getFieldOffset(Field field) throws Exception {
        try {
            Field declaredField = Field.class.getDeclaredField("offset");
            declaredField.setAccessible(true);
            return declaredField.getInt(field);
        } catch (Exception unused) {
            try {
                Method declaredMethod = Field.class.getDeclaredMethod("getOffset", new Class[0]);
                declaredMethod.setAccessible(true);
                return ((Integer) declaredMethod.invoke(field, new Object[0])).intValue();
            } catch (Exception unused2) {
                ensureUnsafeReady();
                Method declaredMethod2 = unsafeClass.getDeclaredMethod("objectFieldOffset", Field.class);
                declaredMethod2.setAccessible(true);
                return ((Integer) declaredMethod2.invoke(unsafe, field)).intValue();
            }
        }
    }

    public static Object getUnsafe() throws Exception {
        Field declaredField;
        try {
            try {
                Method declaredMethod = unsafeClass.getDeclaredMethod("getUnsafe", new Class[0]);
                declaredMethod.setAccessible(true);
                return declaredMethod.invoke(null, new Object[0]);
            } catch (Exception unused) {
                declaredField = unsafeClass.getDeclaredField("theUnsafe");
                declaredField.setAccessible(true);
                return declaredField.get(null);
            }
        } catch (NoSuchFieldException unused2) {
            declaredField = unsafeClass.getDeclaredField("THE_ONE");
            declaredField.setAccessible(true);
            return declaredField.get(null);
        }
    }

    public static byte[] int2Bytes(int i2) {
        return new byte[]{(byte) (i2 & 255), (byte) ((i2 >> 8) & 255), (byte) ((i2 >> 16) & 255), (byte) ((i2 >> 24) & 255)};
    }

    public static double ints2Double(int i2, int i3) {
        return Double.longBitsToDouble(ints2Long(i2, i3));
    }

    public static long ints2Long(int i2, int i3) {
        return (i2 & Arm64Entry.INT_BITS) | (i3 << 32);
    }

    public static void removeClassFinalFlag(Class<?> cls) {
        if (Modifier.isFinal(cls.getModifiers())) {
            if (classAccessFlagsField == null) {
                try {
                    Field declaredField = Class.class.getDeclaredField("accessFlags");
                    classAccessFlagsField = declaredField;
                    declaredField.setAccessible(true);
                } catch (NoSuchFieldException e2) {
                    throw new RuntimeException("Class.accessFlags not found", e2);
                }
            }
            try {
                classAccessFlagsField.setInt(cls, classAccessFlagsField.getInt(cls) & (-17));
            } catch (IllegalAccessException e3) {
                throw new RuntimeException(e3);
            }
        }
    }

    public static void setObjectClass(Object obj, Class<?> cls) {
        if (obj.getClass() == cls) {
            return;
        }
        if (!triedGetShadowKlassField) {
            triedGetShadowKlassField = true;
            try {
                Field declaredField = Object.class.getDeclaredField("shadow$_klass_");
                shadowKlassField = declaredField;
                declaredField.setAccessible(true);
            } catch (NoSuchFieldException e2) {
                Log.w(TAG, "Object.shadow$_klass_ not found, use Unsafe.", e2);
            }
        }
        try {
            if (shadowKlassField != null) {
                shadowKlassField.set(obj, cls);
                return;
            }
            ensureUnsafeReady();
            if (putObject == null) {
                Method declaredMethod = unsafeClass.getDeclaredMethod("putObject", Object.class, Long.TYPE, Object.class);
                putObject = declaredMethod;
                declaredMethod.setAccessible(true);
            }
            putObject.invoke(unsafe, obj, 0L, cls);
        } catch (Exception e3) {
            throw new RuntimeException(e3);
        }
    }

    public static void setSuperClass(Class<?> cls, Class<?> cls2) {
        if (cls.getSuperclass() == cls2) {
            return;
        }
        if (superClassField == null) {
            try {
                Field declaredField = Class.class.getDeclaredField("superClass");
                superClassField = declaredField;
                declaredField.setAccessible(true);
            } catch (NoSuchFieldException e2) {
                throw new RuntimeException("Class.superClass not found", e2);
            }
        }
        try {
            superClassField.set(cls, cls2);
        } catch (IllegalAccessException e3) {
            throw new RuntimeException(e3);
        }
    }
}
