package chongya.haiwai.sandbox.a.dispatcher;

import android.app.job.JobParameters;
import android.app.job.JobService;
import android.content.res.Configuration;
import chongya.haiwai.sandbox.BlackBoxCore;
import chongya.haiwai.sandbox.a.BActivityThread;
import chongya.haiwai.sandbox.bean.JobRecord;
import java.util.HashMap;
import java.util.Map;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class AppJobServiceDispatcher {
    public static final AppJobServiceDispatcher sServiceDispatcher = new AppJobServiceDispatcher();
    public final Map<Integer, JobRecord> mJobRecords = new HashMap();

    public static AppJobServiceDispatcher get() {
        return sServiceDispatcher;
    }

    public JobService getJobService(int i2) {
        synchronized (this.mJobRecords) {
            JobRecord jobRecord = this.mJobRecords.get(Integer.valueOf(i2));
            if (jobRecord != null && jobRecord.mJobService != null) {
                return jobRecord.mJobService;
            }
            JobRecord queryJobRecord = BlackBoxCore.getBJobManager().queryJobRecord(BActivityThread.getAppProcessName(), i2);
            JobService createJobService = BActivityThread.currentActivityThread().createJobService(queryJobRecord.mServiceInfo);
            queryJobRecord.mJobService = createJobService;
            if (createJobService == null) {
                return null;
            }
            this.mJobRecords.put(Integer.valueOf(i2), queryJobRecord);
            return queryJobRecord.mJobService;
        }
    }

    public void onConfigurationChanged(Configuration configuration) {
        for (JobRecord jobRecord : this.mJobRecords.values()) {
            JobService jobService = jobRecord.mJobService;
            if (jobService != null) {
                jobService.onConfigurationChanged(configuration);
            }
        }
    }

    public void onDestroy() {
    }

    public void onLowMemory() {
        for (JobRecord jobRecord : this.mJobRecords.values()) {
            JobService jobService = jobRecord.mJobService;
            if (jobService != null) {
                jobService.onLowMemory();
            }
        }
    }

    public boolean onStartJob(JobParameters jobParameters) {
        try {
            JobService jobService = getJobService(jobParameters.getJobId());
            if (jobService == null) {
                return false;
            }
            return jobService.onStartJob(jobParameters);
        } catch (Exception e2) {
            e2.printStackTrace();
            return false;
        }
    }

    public boolean onStopJob(JobParameters jobParameters) {
        JobService jobService = getJobService(jobParameters.getJobId());
        if (jobService == null) {
            return false;
        }
        boolean onStopJob = jobService.onStopJob(jobParameters);
        jobService.onDestroy();
        synchronized (this.mJobRecords) {
            this.mJobRecords.remove(Integer.valueOf(jobParameters.getJobId()));
        }
        return onStopJob;
    }

    public void onTrimMemory(int i2) {
        for (JobRecord jobRecord : this.mJobRecords.values()) {
            JobService jobService = jobRecord.mJobService;
            if (jobService != null) {
                jobService.onTrimMemory(i2);
            }
        }
    }
}
