package chongya.haiwai.sandbox.d.system.am;

import android.app.ActivityManager;
import android.content.ComponentName;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.ProviderInfo;
import android.content.pm.ResolveInfo;
import android.os.Binder;
import android.os.Bundle;
import android.os.IBinder;
import android.os.RemoteException;
import chongya.haiwai.sandbox.BlackBoxCore;
import chongya.haiwai.sandbox.bean.AppConfig;
import chongya.haiwai.sandbox.bean.IntentSenderData;
import chongya.haiwai.sandbox.bean.UnbindRecord;
import chongya.haiwai.sandbox.bean.am.PendingResultData;
import chongya.haiwai.sandbox.bean.am.ReceiverData;
import chongya.haiwai.sandbox.bean.am.RunningAppProcessInfo;
import chongya.haiwai.sandbox.bean.am.RunningServiceInfo;
import chongya.haiwai.sandbox.d.system.BProcessManagerService;
import chongya.haiwai.sandbox.d.system.ISystemService;
import chongya.haiwai.sandbox.d.system.ProcessRecord;
import chongya.haiwai.sandbox.d.system.am.IBActivityManagerService;
import chongya.haiwai.sandbox.d.system.pm.BPackageManagerService;
import chongya.haiwai.sandbox.utils.Slog;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class BActivityManagerService extends IBActivityManagerService.Stub implements ISystemService {
    public static final String TAG = "BActivityManagerService";
    public static final BActivityManagerService sService = new BActivityManagerService();
    public final Map<Integer, UserSpace> mUserSpace = new HashMap();
    public final BPackageManagerService mPms = BPackageManagerService.get();
    public final Map<IBinder, IntentSenderData> mIntentSenderMap = new HashMap();
    public final BroadcastManager mBroadcastManager = BroadcastManager.startSystem(this, this.mPms);

    public static BActivityManagerService get() {
        return sService;
    }

    private UserSpace getOrCreateSpaceLocked(int i2) {
        synchronized (this.mUserSpace) {
            UserSpace userSpace = this.mUserSpace.get(Integer.valueOf(i2));
            if (userSpace != null) {
                return userSpace;
            }
            UserSpace userSpace2 = new UserSpace();
            this.mUserSpace.put(Integer.valueOf(i2), userSpace2);
            return userSpace2;
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public IBinder acquireContentProviderClient(ProviderInfo providerInfo) throws RemoteException {
        ProcessRecord startProcessLocked = BProcessManagerService.get().startProcessLocked(providerInfo.packageName, providerInfo.processName, BProcessManagerService.get().getUserIdByCallingPid(Binder.getCallingPid()), -1, Binder.getCallingPid());
        if (startProcessLocked != null) {
            try {
                return startProcessLocked.bActivityThread.acquireContentProviderClient(providerInfo);
            } catch (Throwable th) {
                th.printStackTrace();
                return null;
            }
        }
        throw new RuntimeException("Unable to create process " + providerInfo.name);
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void addOrUpdateIntentSender(IntentSenderData intentSenderData, int i2) {
        if (intentSenderData == null || intentSenderData.token == null) {
            return;
        }
        synchronized (this.mIntentSenderMap) {
            IntentSenderData intentSenderData2 = this.mIntentSenderMap.get(intentSenderData.token);
            if (intentSenderData2 == null) {
                this.mIntentSenderMap.put(intentSenderData.token, intentSenderData);
            } else {
                intentSenderData2.replace(intentSenderData);
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public Intent bindService(Intent intent, IBinder iBinder, String str, int i2) throws RemoteException {
        Intent bindService;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            bindService = orCreateSpaceLocked.mActiveServices.bindService(intent, iBinder, str, i2);
        }
        return bindService;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void finishBroadcast(PendingResultData pendingResultData) throws RemoteException {
        this.mBroadcastManager.finishBroadcast(pendingResultData);
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public ComponentName getCallingActivity(IBinder iBinder, int i2) throws RemoteException {
        ComponentName callingActivity;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mStack) {
            callingActivity = orCreateSpaceLocked.mStack.getCallingActivity(iBinder, i2);
        }
        return callingActivity;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public String getCallingPackage(IBinder iBinder, int i2) throws RemoteException {
        String callingPackage;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mStack) {
            callingPackage = orCreateSpaceLocked.mStack.getCallingPackage(iBinder, i2);
        }
        return callingPackage;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void getIntentSender(IBinder iBinder, String str, int i2, int i3) {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i3);
        synchronized (orCreateSpaceLocked.mIntentSenderRecords) {
            PendingIntentRecord pendingIntentRecord = new PendingIntentRecord();
            pendingIntentRecord.uid = i2;
            pendingIntentRecord.packageName = str;
            orCreateSpaceLocked.mIntentSenderRecords.put(iBinder, pendingIntentRecord);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public IntentSenderData getIntentSenderAct(IBinder iBinder, int i2) {
        IntentSenderData intentSenderData;
        if (iBinder != null) {
            synchronized (this.mIntentSenderMap) {
                intentSenderData = this.mIntentSenderMap.get(iBinder);
            }
            return intentSenderData;
        }
        return null;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public String getPackageForIntentSender(IBinder iBinder, int i2) throws RemoteException {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mIntentSenderRecords) {
            PendingIntentRecord pendingIntentRecord = orCreateSpaceLocked.mIntentSenderRecords.get(iBinder);
            if (pendingIntentRecord != null) {
                return pendingIntentRecord.packageName;
            }
            return null;
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public RunningAppProcessInfo getRunningAppProcesses(String str, int i2) throws RemoteException {
        List<ActivityManager.RunningAppProcessInfo> runningAppProcesses = ((ActivityManager) BlackBoxCore.getContext().getSystemService("activity")).getRunningAppProcesses();
        HashMap hashMap = new HashMap();
        for (ActivityManager.RunningAppProcessInfo runningAppProcessInfo : runningAppProcesses) {
            hashMap.put(Integer.valueOf(runningAppProcessInfo.pid), runningAppProcessInfo);
        }
        List<ProcessRecord> packageProcessAsUser = BProcessManagerService.get().getPackageProcessAsUser(str, i2);
        RunningAppProcessInfo runningAppProcessInfo2 = new RunningAppProcessInfo();
        for (ProcessRecord processRecord : packageProcessAsUser) {
            ActivityManager.RunningAppProcessInfo runningAppProcessInfo3 = (ActivityManager.RunningAppProcessInfo) hashMap.get(Integer.valueOf(processRecord.pid));
            if (runningAppProcessInfo3 != null) {
                runningAppProcessInfo3.processName = processRecord.processName;
                runningAppProcessInfo2.mAppProcessInfoList.add(runningAppProcessInfo3);
            }
        }
        return runningAppProcessInfo2;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public RunningServiceInfo getRunningServices(String str, int i2) throws RemoteException {
        RunningServiceInfo runningServiceInfo;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            runningServiceInfo = orCreateSpaceLocked.mActiveServices.getRunningServiceInfo(str, i2);
        }
        return runningServiceInfo;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public int getRunningTaskId(String str, int i2) throws RemoteException {
        int runningTaskId;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mStack) {
            runningTaskId = orCreateSpaceLocked.mStack.getRunningTaskId(str);
        }
        return runningTaskId;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public int getUidForIntentSender(IBinder iBinder, int i2) throws RemoteException {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mIntentSenderRecords) {
            PendingIntentRecord pendingIntentRecord = orCreateSpaceLocked.mIntentSenderRecords.get(iBinder);
            if (pendingIntentRecord != null) {
                return pendingIntentRecord.uid;
            }
            return -1;
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public AppConfig initProcess(String str, String str2, int i2) throws RemoteException {
        ProcessRecord startProcessLocked = BProcessManagerService.get().startProcessLocked(str, str2, i2, -1, Binder.getCallingPid());
        if (startProcessLocked == null) {
            return null;
        }
        return startProcessLocked.getClientConfig();
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void onActivityCreated(int i2, IBinder iBinder, IBinder iBinder2) throws RemoteException {
        ProcessRecord findProcessByPid = BProcessManagerService.get().findProcessByPid(Binder.getCallingPid());
        if (findProcessByPid == null) {
            return;
        }
        ActivityRecord activityRecord = (ActivityRecord) iBinder2;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(findProcessByPid.userId);
        synchronized (orCreateSpaceLocked.mStack) {
            orCreateSpaceLocked.mStack.onActivityCreated(findProcessByPid, i2, iBinder, activityRecord);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void onActivityDestroyed(IBinder iBinder) throws RemoteException {
        ProcessRecord findProcessByPid = BProcessManagerService.get().findProcessByPid(Binder.getCallingPid());
        if (findProcessByPid == null) {
            return;
        }
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(findProcessByPid.userId);
        synchronized (orCreateSpaceLocked.mStack) {
            orCreateSpaceLocked.mStack.onActivityDestroyed(findProcessByPid.userId, iBinder);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void onActivityResumed(IBinder iBinder) throws RemoteException {
        ProcessRecord findProcessByPid = BProcessManagerService.get().findProcessByPid(Binder.getCallingPid());
        if (findProcessByPid == null) {
            return;
        }
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(findProcessByPid.userId);
        synchronized (orCreateSpaceLocked.mStack) {
            orCreateSpaceLocked.mStack.onActivityResumed(findProcessByPid.userId, iBinder);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void onFinishActivity(IBinder iBinder) throws RemoteException {
        ProcessRecord findProcessByPid = BProcessManagerService.get().findProcessByPid(Binder.getCallingPid());
        if (findProcessByPid == null) {
            return;
        }
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(findProcessByPid.userId);
        synchronized (orCreateSpaceLocked.mStack) {
            orCreateSpaceLocked.mStack.onFinishActivity(findProcessByPid.userId, iBinder);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void onServiceDestroy(Intent intent, int i2) throws RemoteException {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            orCreateSpaceLocked.mActiveServices.onServiceDestroy(intent, i2);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public UnbindRecord onServiceUnbind(Intent intent, int i2) throws RemoteException {
        UnbindRecord onServiceUnbind;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            onServiceUnbind = orCreateSpaceLocked.mActiveServices.onServiceUnbind(intent, i2);
        }
        return onServiceUnbind;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void onStartCommand(Intent intent, int i2) throws RemoteException {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            orCreateSpaceLocked.mActiveServices.onStartCommand(intent, i2);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public IBinder peekService(Intent intent, String str, int i2) throws RemoteException {
        IBinder peekService;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            peekService = orCreateSpaceLocked.mActiveServices.peekService(intent, str, i2);
        }
        return peekService;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void removeIntentSender(IBinder iBinder, int i2) {
        if (iBinder != null) {
            synchronized (this.mIntentSenderMap) {
                this.mIntentSenderMap.remove(iBinder);
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void restartProcess(String str, String str2, int i2) throws RemoteException {
        BProcessManagerService.get().restartAppProcess(str, str2, i2);
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void scheduleBroadcastReceiver(Intent intent, PendingResultData pendingResultData, int i2) throws RemoteException {
        List<ResolveInfo> queryBroadcastReceivers = BPackageManagerService.get().queryBroadcastReceivers(intent, 128, null, i2);
        if (queryBroadcastReceivers.isEmpty()) {
            pendingResultData.build().finish();
            Slog.d(TAG, "scheduleBroadcastReceiver empty");
            return;
        }
        this.mBroadcastManager.sendBroadcast(pendingResultData);
        for (ResolveInfo resolveInfo : queryBroadcastReceivers) {
            BProcessManagerService bProcessManagerService = BProcessManagerService.get();
            ActivityInfo activityInfo = resolveInfo.activityInfo;
            ProcessRecord findProcessRecord = bProcessManagerService.findProcessRecord(activityInfo.packageName, activityInfo.processName, i2);
            if (findProcessRecord != null) {
                ReceiverData receiverData = new ReceiverData();
                receiverData.intent = intent;
                receiverData.activityInfo = resolveInfo.activityInfo;
                receiverData.data = pendingResultData;
                findProcessRecord.bActivityThread.scheduleReceiver(receiverData);
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public Intent sendBroadcast(Intent intent, String str, int i2) throws RemoteException {
        for (ResolveInfo resolveInfo : BPackageManagerService.get().queryBroadcastReceivers(intent, 128, str, i2)) {
            BProcessManagerService bProcessManagerService = BProcessManagerService.get();
            ActivityInfo activityInfo = resolveInfo.activityInfo;
            ProcessRecord findProcessRecord = bProcessManagerService.findProcessRecord(activityInfo.packageName, activityInfo.processName, i2);
            if (findProcessRecord != null) {
                try {
                    findProcessRecord.bActivityThread.bindApplication();
                } catch (RemoteException e2) {
                    e2.printStackTrace();
                }
            }
        }
        Intent intent2 = new Intent();
        intent2.setPackage(BlackBoxCore.getHostPkg());
        intent2.setComponent(null);
        intent2.setAction(intent.getAction());
        return intent2;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public int startActivities(int i2, Intent[] intentArr, String[] strArr, IBinder iBinder, Bundle bundle) throws RemoteException {
        int startActivitiesLocked;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mStack) {
            startActivitiesLocked = orCreateSpaceLocked.mStack.startActivitiesLocked(i2, intentArr, strArr, iBinder, bundle);
        }
        return startActivitiesLocked;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void startActivity(Intent intent, int i2) {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mStack) {
            orCreateSpaceLocked.mStack.startActivityLocked(i2, intent, null, null, null, -1, -1, null);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public int startActivityAms(int i2, Intent intent, String str, IBinder iBinder, String str2, int i3, int i4, Bundle bundle) throws RemoteException {
        int startActivityLocked;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mStack) {
            startActivityLocked = orCreateSpaceLocked.mStack.startActivityLocked(i2, intent, str, iBinder, str2, i3, i4, bundle);
        }
        return startActivityLocked;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public ComponentName startService(Intent intent, String str, boolean z, int i2) {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            orCreateSpaceLocked.mActiveServices.startService(intent, str, z, i2);
        }
        return null;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public int stopService(Intent intent, String str, int i2) {
        int stopService;
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            stopService = orCreateSpaceLocked.mActiveServices.stopService(intent, str, i2);
        }
        return stopService;
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void stopServiceToken(ComponentName componentName, IBinder iBinder, int i2) throws RemoteException {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            orCreateSpaceLocked.mActiveServices.stopServiceToken(componentName, iBinder, i2);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.ISystemService
    public void systemReady() {
        this.mBroadcastManager.startup();
    }

    @Override // chongya.haiwai.sandbox.d.system.am.IBActivityManagerService
    public void unbindService(IBinder iBinder, int i2) throws RemoteException {
        UserSpace orCreateSpaceLocked = getOrCreateSpaceLocked(i2);
        synchronized (orCreateSpaceLocked.mActiveServices) {
            orCreateSpaceLocked.mActiveServices.unbindService(iBinder, i2);
        }
    }
}
