package chongya.haiwai.sandbox.d.system.pm;

import android.content.BroadcastReceiver;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.ActivityInfo;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.content.pm.PackageParser;
import android.content.pm.ProviderInfo;
import android.content.pm.ResolveInfo;
import android.content.pm.ServiceInfo;
import android.net.Uri;
import android.os.Binder;
import android.os.RemoteException;
import android.text.TextUtils;
import android.util.ArrayMap;
import android.util.Log;
import chongya.haiwai.sandbox.BlackBoxCore;
import chongya.haiwai.sandbox.bean.pm.InstallOption;
import chongya.haiwai.sandbox.bean.pm.InstallResult;
import chongya.haiwai.sandbox.bean.pm.InstalledPackage;
import chongya.haiwai.sandbox.d.GmsCore;
import chongya.haiwai.sandbox.d.env.BEnvironment;
import chongya.haiwai.sandbox.d.system.BProcessManagerService;
import chongya.haiwai.sandbox.d.system.ISystemService;
import chongya.haiwai.sandbox.d.system.ProcessRecord;
import chongya.haiwai.sandbox.d.system.pm.BPackage;
import chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService;
import chongya.haiwai.sandbox.d.system.user.BUserInfo;
import chongya.haiwai.sandbox.d.system.user.BUserManagerService;
import chongya.haiwai.sandbox.utils.AbiUtils;
import chongya.haiwai.sandbox.utils.FileUtils;
import chongya.haiwai.sandbox.utils.Slog;
import chongya.haiwai.sandbox.utils.compat.BuildCompat;
import chongya.haiwai.sandbox.utils.compat.PackageParserCompat;
import chongya.haiwai.sandbox.utils.compat.XposedParserCompat;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.UUID;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class BPackageManagerService extends IBPackageManagerService.Stub implements ISystemService {
    public static final String TAG = "BPackageManagerService";
    public static BPackageManagerService sService = new BPackageManagerService();
    public static final BUserManagerService sUserManager = BUserManagerService.get();
    public final Settings mSettings = new Settings();
    public final List<PackageMonitor> mPackageMonitors = new ArrayList();
    public final Map<String, BPackageSettings> mPackages = this.mSettings.mPackages;
    public final Object mInstallLock = new Object();
    public final BroadcastReceiver mPackageChangedHandler = new BroadcastReceiver() { // from class: chongya.haiwai.sandbox.d.system.pm.BPackageManagerService.1
        @Override // android.content.BroadcastReceiver
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (TextUtils.isEmpty(action)) {
                return;
            }
            if ("android.intent.action.PACKAGE_ADDED".equals(action) || "android.intent.action.PACKAGE_REMOVED".equals(action)) {
                BPackageManagerService.this.mSettings.scanPackage();
                if (BPackageManagerService.this.mGooglePackages.size() != 0) {
                    if (BPackageManagerService.this.mPackages.containsKey("com.google.android.gms")) {
                        BPackageManagerService.this.removePackagesGoogle();
                    } else {
                        BPackageManagerService.this.mGooglePackages.clear();
                    }
                }
            }
        }
    };
    public final Map<String, BPackageSettings> mGooglePackages = new ArrayMap();
    public final ComponentResolver mComponentResolver = new ComponentResolver();

    public BPackageManagerService() {
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.intent.action.PACKAGE_ADDED");
        intentFilter.addAction("android.intent.action.PACKAGE_REMOVED");
        intentFilter.addDataScheme("package");
        BlackBoxCore.getContext().registerReceiver(this.mPackageChangedHandler, intentFilter);
    }

    private ResolveInfo chooseBestActivity(Intent intent, String str, int i2, List<ResolveInfo> list) {
        if (list != null) {
            int size = list.size();
            if (size == 1) {
                return list.get(0);
            }
            if (size > 1) {
                ResolveInfo resolveInfo = list.get(0);
                ResolveInfo resolveInfo2 = list.get(1);
                if (resolveInfo.priority == resolveInfo2.priority && resolveInfo.preferredOrder == resolveInfo2.preferredOrder && resolveInfo.isDefault == resolveInfo2.isDefault) {
                    return null;
                }
                return list.get(0);
            }
            return null;
        }
        return null;
    }

    public static String fixProcessName(String str, String str2) {
        return str2 == null ? str : str2;
    }

    public static BPackageManagerService get() {
        return sService;
    }

    private ActivityInfo getActivity(ComponentName componentName, int i2, int i3) {
        int updateFlags = updateFlags(i2, i3);
        synchronized (this.mPackages) {
            BPackage.Activity activity = this.mComponentResolver.getActivity(componentName);
            if (activity != null) {
                BPackageSettings bPackageSettings = this.mSettings.mPackages.get(componentName.getPackageName());
                if (bPackageSettings == null) {
                    return null;
                }
                return PackageManagerCompat.generateActivityInfo(activity, updateFlags, bPackageSettings.readUserState(i3), i3);
            }
            return null;
        }
    }

    private List<ApplicationInfo> getInstalledApplicationsListInternal(int i2, int i3, int i4) {
        ArrayList arrayList;
        if (sUserManager.exists(i3)) {
            synchronized (this.mPackages) {
                arrayList = new ArrayList(this.mPackages.size());
                for (BPackageSettings bPackageSettings : this.mPackages.values()) {
                    ApplicationInfo generateApplicationInfo = PackageManagerCompat.generateApplicationInfo(bPackageSettings.pkg, i2, bPackageSettings.readUserState(i3), i3);
                    if (generateApplicationInfo != null) {
                        arrayList.add(generateApplicationInfo);
                    }
                }
            }
            return arrayList;
        }
        return Collections.emptyList();
    }

    private InstallResult installPackageAsUserLocked(String str, InstallOption installOption, int i2) {
        File file;
        InstallResult installError;
        StringBuilder sb;
        Log.w("lxy_install", "installPackageAsUserLocked_1-64" + str);
        long currentTimeMillis = System.currentTimeMillis();
        InstallResult installResult = new InstallResult();
        File file2 = null;
        try {
            if (!sUserManager.exists(i2)) {
                sUserManager.createUser(i2);
            }
            if (installOption.isFlag(8)) {
                Log.w("lxy_install", "installPackageAsUserLocked_2");
                File cacheDir = BEnvironment.getCacheDir();
                file = new File(cacheDir, UUID.randomUUID().toString() + ".apk");
                try {
                    FileUtils.copyFile(BlackBoxCore.getContext().getContentResolver().openInputStream(Uri.parse(str)), file);
                } catch (Throwable th) {
                    th = th;
                    file2 = file;
                    try {
                        th.printStackTrace();
                        return installResult;
                    } finally {
                        if (file2 != null && installOption.isFlag(8)) {
                            FileUtils.deleteDir(file2);
                        }
                        Slog.d(TAG, "install finish: " + (System.currentTimeMillis() - currentTimeMillis) + "ms");
                    }
                }
            } else {
                Log.w("lxy_install", "installPackageAsUserLocked_3");
                file = new File(str);
            }
            File file3 = file;
            Log.w("lxy_install", "installPackageAsUserLocked_4");
            if (installOption.isFlag(4) && i2 != -4) {
                Log.w("lxy_install", "installPackageAsUserLocked_5");
                installError = new InstallResult().installError("Please install the XP module in XP module management");
                if (installOption.isFlag(8)) {
                    FileUtils.deleteDir(file3);
                }
                sb = new StringBuilder();
            } else if (installOption.isFlag(4) && !XposedParserCompat.isXPModule(file3.getAbsolutePath())) {
                Log.w("lxy_install", "installPackageAsUserLocked_6");
                installError = new InstallResult().installError("not a XP module");
                if (installOption.isFlag(8)) {
                    FileUtils.deleteDir(file3);
                }
                sb = new StringBuilder();
            } else {
                PackageParser.Package parserApk = parserApk(file3.getAbsolutePath());
                if (parserApk == null) {
                    Log.w("lxy_install", "installPackageAsUserLocked_9");
                    installError = installResult.installError("parser apk error.");
                    if (installOption.isFlag(8)) {
                        FileUtils.deleteDir(file3);
                    }
                    sb = new StringBuilder();
                } else {
                    boolean isSupport = AbiUtils.isSupport(file3);
                    if (!isSupport) {
                        Log.w("lxy_install", "installPackageAsUserLocked_8_" + isSupport);
                        installError = installResult.installError(parserApk.packageName, BlackBoxCore.is64Bit() ? " not support armeabi-v7a abi" : "not support arm64-v8a abi");
                        if (installOption.isFlag(8)) {
                            FileUtils.deleteDir(file3);
                        }
                        sb = new StringBuilder();
                    } else {
                        installResult.packageName = parserApk.packageName;
                        if (installOption.isFlag(1) && BuildCompat.isOreo()) {
                            Log.w("lxy_install", "installPackageAsUserLocked_10");
                            parserApk.applicationInfo = BlackBoxCore.getPackageManager().getPackageInfo(parserApk.packageName, 0).applicationInfo;
                        }
                        BPackageSettings packageLPw = this.mSettings.getPackageLPw(parserApk.packageName, parserApk, installOption);
                        Log.w("lxy_install", "installPackageAsUserLocked_11");
                        BProcessManagerService.get().killPackageAsUser(parserApk.packageName, i2);
                        if (BPackageInstallerService.get().installPackageAsUser(packageLPw, i2) < 0) {
                            Log.w("lxy_install", "installPackageAsUserLocked_12");
                            installError = installResult.installError("install apk error.");
                            if (installOption.isFlag(8)) {
                                FileUtils.deleteDir(file3);
                            }
                            sb = new StringBuilder();
                        } else {
                            packageLPw.lastUpdateTime = System.currentTimeMillis();
                            synchronized (this.mPackages) {
                                packageLPw.setInstalled(true, i2);
                                packageLPw.save();
                            }
                            Log.w("lxy_install", "installPackageAsUserLocked_13");
                            this.mComponentResolver.removeAllComponents(packageLPw.pkg);
                            this.mComponentResolver.addAllComponents(packageLPw.pkg);
                            this.mSettings.scanPackage(parserApk.packageName);
                            onPackageInstalled(packageLPw.pkg.packageName, i2);
                            Log.w("lxy_install", "installPackageAsUserLocked_14");
                            if (installOption.isFlag(8)) {
                                FileUtils.deleteDir(file3);
                            }
                            Slog.d(TAG, "install finish: " + (System.currentTimeMillis() - currentTimeMillis) + "ms");
                            return installResult;
                        }
                    }
                }
            }
            sb.append("install finish: ");
            sb.append(System.currentTimeMillis() - currentTimeMillis);
            sb.append("ms");
            Slog.d(TAG, sb.toString());
            return installError;
        } catch (Throwable th2) {
            th = th2;
        }
    }

    private PackageParser.Package parserApk(String str) {
        try {
            PackageParser createParser = PackageParserCompat.createParser(new File(str));
            PackageParser.Package parsePackage = PackageParserCompat.parsePackage(createParser, new File(str), 0);
            PackageParserCompat.collectCertificates(createParser, parsePackage, 0);
            return parsePackage;
        } catch (Throwable th) {
            th.printStackTrace();
            return null;
        }
    }

    private List<ResolveInfo> queryIntentActivities(Intent intent, String str, int i2, int i3) {
        List<ResolveInfo> queryActivities;
        ComponentName component = intent.getComponent();
        if (component == null && intent.getSelector() != null) {
            intent = intent.getSelector();
            component = intent.getComponent();
        }
        if (component != null) {
            ArrayList arrayList = new ArrayList(1);
            ActivityInfo activity = getActivity(component, i2, i3);
            if (activity != null) {
                ResolveInfo resolveInfo = new ResolveInfo();
                resolveInfo.activityInfo = activity;
                arrayList.add(resolveInfo);
                return arrayList;
            }
        }
        synchronized (this.mPackages) {
            queryActivities = this.mComponentResolver.queryActivities(intent, str, i2, i3);
        }
        return queryActivities;
    }

    private List<ResolveInfo> queryIntentServicesInternal(Intent intent, String str, int i2, int i3) {
        ComponentName component = intent.getComponent();
        if (component == null && intent.getSelector() != null) {
            intent = intent.getSelector();
            component = intent.getComponent();
        }
        Intent intent2 = intent;
        if (component != null) {
            ArrayList arrayList = new ArrayList(1);
            ServiceInfo serviceInfo = getServiceInfo(component, i2, i3);
            if (serviceInfo != null) {
                ResolveInfo resolveInfo = new ResolveInfo();
                resolveInfo.serviceInfo = serviceInfo;
                arrayList.add(resolveInfo);
            }
            return arrayList;
        }
        synchronized (this.mPackages) {
            String str2 = intent2.getPackage();
            if (str2 != null) {
                BPackageSettings bPackageSettings = this.mPackages.get(str2);
                if (bPackageSettings != null) {
                    return this.mComponentResolver.queryServices(intent2, str, i2, bPackageSettings.pkg.services, i3);
                }
                return Collections.emptyList();
            }
            return this.mComponentResolver.queryServices(intent2, str, i2, i3);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void removePackagesGoogle() {
        if (this.mPackages.containsKey("com.google.android.gms")) {
            BPackageSettings bPackageSettings = this.mPackages.get("com.google.android.gms");
            if (bPackageSettings != null) {
                stopPackage("com.google.android.gms", 0);
                this.mGooglePackages.put("com.google.android.gms", bPackageSettings);
                this.mPackages.remove("com.google.android.gms");
            }
            Log.w("lxy", "clearGoogleInstallInfo === 去掉Google服务" + this.mPackages.containsKey("com.google.android.gms"));
            BPackageSettings bPackageSettings2 = this.mPackages.get(GmsCore.GSF_PKG);
            if (bPackageSettings2 != null) {
                stopPackage(GmsCore.GSF_PKG, 0);
                this.mGooglePackages.put(GmsCore.GSF_PKG, bPackageSettings2);
                this.mPackages.remove(GmsCore.GSF_PKG);
            }
            BPackageSettings bPackageSettings3 = this.mPackages.get("com.android.vending");
            if (bPackageSettings3 != null) {
                stopPackage("com.android.vending", 0);
                this.mGooglePackages.put("com.android.vending", bPackageSettings3);
                this.mPackages.remove("com.android.vending");
            }
        }
    }

    private int updateFlags(int i2, int i3) {
        return (i2 & 786432) != 0 ? i2 : i2 | 786432;
    }

    public void addPackageMonitor(PackageMonitor packageMonitor) {
        this.mPackageMonitors.add(packageMonitor);
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public void clearGoogleInstallInfo(boolean z) {
        Log.w("lxy", "clearGoogleInstallInfo = " + z + " , " + this.mGooglePackages.size() + " , " + this.mPackages.containsKey("com.google.android.gms"));
        if (z) {
            if (this.mGooglePackages.size() == 0 || this.mPackages.containsKey("com.google.android.gms")) {
                return;
            }
            Log.w("lxy", "clearGoogleInstallInfo === 需要Google服务" + this.mPackages.containsKey("com.google.android.gms"));
            BPackageSettings bPackageSettings = this.mGooglePackages.get("com.google.android.gms");
            if (bPackageSettings != null) {
                this.mPackages.put("com.google.android.gms", bPackageSettings);
            }
            BPackageSettings bPackageSettings2 = this.mGooglePackages.get(GmsCore.GSF_PKG);
            if (bPackageSettings2 != null) {
                this.mPackages.put(GmsCore.GSF_PKG, bPackageSettings2);
            }
            BPackageSettings bPackageSettings3 = this.mGooglePackages.get("com.android.vending");
            if (bPackageSettings3 != null) {
                this.mPackages.put("com.android.vending", bPackageSettings3);
            }
            this.mGooglePackages.clear();
            return;
        }
        removePackagesGoogle();
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public void clearPackage(String str, int i2) {
        if (isInstalled(str, i2)) {
            BProcessManagerService.get().killPackageAsUser(str, i2);
            BPackageSettings bPackageSettings = this.mPackages.get(str);
            if (bPackageSettings == null) {
                return;
            }
            BPackageInstallerService.get().clearPackage(bPackageSettings, i2);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public void deleteUser(int i2) throws RemoteException {
        synchronized (this.mPackages) {
            for (BPackageSettings bPackageSettings : this.mPackages.values()) {
                uninstallPackageAsUser(bPackageSettings.pkg.packageName, i2);
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ActivityInfo getActivityInfo(ComponentName componentName, int i2, int i3) {
        if (sUserManager.exists(i3)) {
            synchronized (this.mPackages) {
                BPackage.Activity activity = this.mComponentResolver.getActivity(componentName);
                if (activity != null) {
                    BPackageSettings bPackageSettings = this.mPackages.get(componentName.getPackageName());
                    if (bPackageSettings == null) {
                        return null;
                    }
                    return PackageManagerCompat.generateActivityInfo(activity, i2, bPackageSettings.readUserState(i3), i3);
                }
                return null;
            }
        }
        return null;
    }

    public int getAppId(String str) {
        BPackageSettings bPackageSettings = this.mPackages.get(str);
        if (bPackageSettings != null) {
            return bPackageSettings.appId;
        }
        return -1;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ApplicationInfo getApplicationInfo(String str, int i2, int i3) {
        if (sUserManager.exists(i3)) {
            if (Objects.equals(str, BlackBoxCore.getHostPkg())) {
                try {
                    return BlackBoxCore.getPackageManager().getApplicationInfo(str, i2);
                } catch (PackageManager.NameNotFoundException e2) {
                    e2.printStackTrace();
                    return null;
                }
            }
            int updateFlags = updateFlags(i2, i3);
            synchronized (this.mPackages) {
                BPackageSettings bPackageSettings = this.mPackages.get(str);
                if (bPackageSettings != null) {
                    return PackageManagerCompat.generateApplicationInfo(bPackageSettings.pkg, updateFlags, bPackageSettings.readUserState(i3), i3);
                }
                return null;
            }
        }
        return null;
    }

    public BPackageSettings getBPackageSetting(String str) {
        return this.mPackages.get(str);
    }

    public List<BPackageSettings> getBPackageSettings() {
        return new ArrayList(this.mPackages.values());
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public List<ApplicationInfo> getInstalledApplications(int i2, int i3) {
        return getInstalledApplicationsListInternal(i2, i3, Binder.getCallingUid());
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public List<PackageInfo> getInstalledPackages(int i2, int i3) {
        ArrayList arrayList;
        Binder.getCallingUid();
        if (sUserManager.exists(i3)) {
            synchronized (this.mPackages) {
                ArrayList arrayList2 = new ArrayList(this.mPackages.size());
                for (BPackageSettings bPackageSettings : this.mPackages.values()) {
                    PackageInfo packageInfo = getPackageInfo(bPackageSettings.pkg.packageName, i2, i3);
                    if (packageInfo != null) {
                        arrayList2.add(packageInfo);
                    }
                }
                arrayList = new ArrayList(arrayList2);
            }
            return arrayList;
        }
        return Collections.emptyList();
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public List<InstalledPackage> getInstalledPackagesAsUser(int i2) {
        ArrayList arrayList;
        if (sUserManager.exists(i2)) {
            synchronized (this.mPackages) {
                arrayList = new ArrayList();
                for (BPackageSettings bPackageSettings : this.mPackages.values()) {
                    if (bPackageSettings.getInstalled(i2) && !GmsCore.isGoogleAppOrService(bPackageSettings.pkg.packageName)) {
                        InstalledPackage installedPackage = new InstalledPackage();
                        installedPackage.userId = i2;
                        installedPackage.packageName = bPackageSettings.pkg.packageName;
                        arrayList.add(installedPackage);
                    }
                }
            }
            return arrayList;
        }
        return Collections.emptyList();
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public PackageInfo getPackageInfo(String str, int i2, int i3) {
        BPackageSettings bPackageSettings;
        if (sUserManager.exists(i3)) {
            if (Objects.equals(str, BlackBoxCore.getHostPkg())) {
                try {
                    return BlackBoxCore.getPackageManager().getPackageInfo(str, i2);
                } catch (PackageManager.NameNotFoundException e2) {
                    e2.printStackTrace();
                    return null;
                }
            }
            int updateFlags = updateFlags(i2, i3);
            synchronized (this.mPackages) {
                bPackageSettings = this.mPackages.get(str);
            }
            if (bPackageSettings != null) {
                return PackageManagerCompat.generatePackageInfo(bPackageSettings, updateFlags, bPackageSettings.readUserState(i3), i3);
            }
            return null;
        }
        return null;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public String[] getPackagesForUid(int i2, int i3) throws RemoteException {
        String[] strArr;
        ProcessRecord findProcessByPid;
        if (sUserManager.exists(i3)) {
            synchronized (this.mPackages) {
                ArrayList arrayList = new ArrayList();
                for (BPackageSettings bPackageSettings : this.mPackages.values()) {
                    String str = bPackageSettings.pkg.packageName;
                    if (bPackageSettings.getInstalled(i3) && getAppId(str) == i2) {
                        arrayList.add(str);
                    }
                }
                if (arrayList.isEmpty() && (findProcessByPid = BProcessManagerService.get().findProcessByPid(Binder.getCallingPid())) != null) {
                    arrayList.add(findProcessByPid.getPackageName());
                }
                strArr = (String[]) arrayList.toArray(new String[0]);
            }
            return strArr;
        }
        return new String[0];
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ProviderInfo getProviderInfo(ComponentName componentName, int i2, int i3) {
        if (sUserManager.exists(i3)) {
            synchronized (this.mPackages) {
                BPackage.Provider provider = this.mComponentResolver.getProvider(componentName);
                if (provider != null) {
                    BPackageSettings bPackageSettings = this.mPackages.get(componentName.getPackageName());
                    if (bPackageSettings == null) {
                        return null;
                    }
                    return PackageManagerCompat.generateProviderInfo(provider, i2, bPackageSettings.readUserState(i3), i3);
                }
                return null;
            }
        }
        return null;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ActivityInfo getReceiverInfo(ComponentName componentName, int i2, int i3) {
        if (sUserManager.exists(i3)) {
            synchronized (this.mPackages) {
                BPackage.Activity receiver = this.mComponentResolver.getReceiver(componentName);
                if (receiver != null) {
                    BPackageSettings bPackageSettings = this.mPackages.get(componentName.getPackageName());
                    if (bPackageSettings == null) {
                        return null;
                    }
                    return PackageManagerCompat.generateActivityInfo(receiver, i2, bPackageSettings.readUserState(i3), i3);
                }
                return null;
            }
        }
        return null;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ServiceInfo getServiceInfo(ComponentName componentName, int i2, int i3) {
        if (sUserManager.exists(i3)) {
            synchronized (this.mPackages) {
                BPackage.Service service = this.mComponentResolver.getService(componentName);
                if (service != null) {
                    BPackageSettings bPackageSettings = this.mPackages.get(componentName.getPackageName());
                    if (bPackageSettings == null) {
                        return null;
                    }
                    return PackageManagerCompat.generateServiceInfo(service, i2, bPackageSettings.readUserState(i3), i3);
                }
                return null;
            }
        }
        return null;
    }

    public Settings getSettings() {
        return this.mSettings;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public List<String> getSharedLibraries(String str) {
        synchronized (this.mPackages) {
            BPackageSettings bPackageSettings = this.mPackages.get(str);
            if (bPackageSettings != null) {
                ArrayList arrayList = new ArrayList();
                if (bPackageSettings.pkg.usesLibraries != null) {
                    arrayList.addAll(bPackageSettings.pkg.usesLibraries);
                }
                if (BuildCompat.isS() && bPackageSettings.pkg.usesOptionalLibraries != null) {
                    arrayList.addAll(bPackageSettings.pkg.usesOptionalLibraries);
                }
                return arrayList;
            }
            return null;
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public InstallResult installPackageAsUser(String str, InstallOption installOption, int i2) {
        InstallResult installPackageAsUserLocked;
        synchronized (this.mInstallLock) {
            Log.w("lxy", "installPackageAsUserLocked === 开始安装 ");
            installPackageAsUserLocked = installPackageAsUserLocked(str, installOption, i2);
        }
        return installPackageAsUserLocked;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public boolean isInstalled(String str, int i2) {
        if (sUserManager.exists(i2)) {
            synchronized (this.mPackages) {
                BPackageSettings bPackageSettings = this.mPackages.get(str);
                if (bPackageSettings == null && GmsCore.isGoogleAppOrService(str) && this.mGooglePackages.containsKey(str)) {
                    return true;
                }
                if (bPackageSettings == null) {
                    return false;
                }
                return bPackageSettings.getInstalled(i2);
            }
        }
        return false;
    }

    public void onPackageInstalled(String str, int i2) {
        for (PackageMonitor packageMonitor : this.mPackageMonitors) {
            packageMonitor.onPackageInstalled(str, i2);
        }
        Slog.d(TAG, "onPackageInstalled: " + str + ", userId: " + i2);
    }

    public void onPackageUninstalled(String str, boolean z, int i2) {
        for (PackageMonitor packageMonitor : this.mPackageMonitors) {
            packageMonitor.onPackageUninstalled(str, z, i2);
        }
        Slog.d(TAG, "onPackageUninstalled: " + str + ", userId: " + i2);
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public List<ResolveInfo> queryBroadcastReceivers(Intent intent, int i2, String str, int i3) throws RemoteException {
        if (sUserManager.exists(i3)) {
            ComponentName component = intent.getComponent();
            if (component == null && intent.getSelector() != null) {
                intent = intent.getSelector();
                component = intent.getComponent();
            }
            Intent intent2 = intent;
            if (component != null) {
                ArrayList arrayList = new ArrayList(1);
                ActivityInfo receiverInfo = getReceiverInfo(component, i2, i3);
                if (receiverInfo != null) {
                    ResolveInfo resolveInfo = new ResolveInfo();
                    resolveInfo.activityInfo = receiverInfo;
                    arrayList.add(resolveInfo);
                }
                return arrayList;
            }
            synchronized (this.mPackages) {
                BPackageSettings bPackageSettings = this.mPackages.get(intent2.getPackage());
                if (bPackageSettings != null) {
                    return this.mComponentResolver.queryReceivers(intent2, str, i2, bPackageSettings.pkg.receivers, i3);
                }
                return this.mComponentResolver.queryReceivers(intent2, str, i2, i3);
            }
        }
        return Collections.emptyList();
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public List<ProviderInfo> queryContentProviders(String str, int i2, int i3, int i4) throws RemoteException {
        if (sUserManager.exists(i4)) {
            ArrayList arrayList = new ArrayList();
            if (TextUtils.isEmpty(str)) {
                return arrayList;
            }
            arrayList.addAll(this.mComponentResolver.queryProviders(str, (String) null, i3, i4));
            return arrayList;
        }
        return Collections.emptyList();
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public List<ResolveInfo> queryIntentServices(Intent intent, int i2, int i3) {
        return queryIntentServicesInternal(intent, intent.resolveTypeIfNeeded(BlackBoxCore.getContext().getContentResolver()), i2, i3);
    }

    public void removePackageMonitor(PackageMonitor packageMonitor) {
        this.mPackageMonitors.remove(packageMonitor);
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ResolveInfo resolveActivity(Intent intent, int i2, String str, int i3) {
        if (sUserManager.exists(i3)) {
            return chooseBestActivity(intent, str, i2, queryIntentActivities(intent, str, i2, i3));
        }
        return null;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ProviderInfo resolveContentProvider(String str, int i2, int i3) {
        if (sUserManager.exists(i3)) {
            return this.mComponentResolver.queryProvider(str, i2, i3);
        }
        return null;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ResolveInfo resolveIntent(Intent intent, String str, int i2, int i3) {
        if (sUserManager.exists(i3)) {
            return chooseBestActivity(intent, str, i2, queryIntentActivities(intent, str, i2, i3));
        }
        return null;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public ResolveInfo resolveService(Intent intent, int i2, String str, int i3) {
        synchronized (this.mPackages) {
            if (sUserManager.exists(i3)) {
                List<ResolveInfo> queryIntentServicesInternal = queryIntentServicesInternal(intent, str, i2, i3);
                Log.w("lxy", "bindService -> resolveService = query");
                if (queryIntentServicesInternal != null) {
                    try {
                        Log.w("lxy", "bindService -> resolveService = " + queryIntentServicesInternal.size());
                        if (queryIntentServicesInternal.size() >= 1) {
                            Log.w("lxy", "bindService -> resolveService = " + queryIntentServicesInternal.get(0));
                            return queryIntentServicesInternal.get(0);
                        }
                    } catch (IllegalStateException e2) {
                        Log.w("lxy", "bindService -> resolveService = " + e2);
                    }
                }
                return null;
            }
            return null;
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public void stopPackage(String str, int i2) {
        BProcessManagerService.get().killPackageAsUser(str, i2);
    }

    @Override // chongya.haiwai.sandbox.d.system.ISystemService
    public void systemReady() {
        this.mSettings.scanPackage();
        for (BPackageSettings bPackageSettings : this.mPackages.values()) {
            this.mComponentResolver.removeAllComponents(bPackageSettings.pkg);
            this.mComponentResolver.addAllComponents(bPackageSettings.pkg);
        }
        if (this.mGooglePackages.size() != 0) {
            removePackagesGoogle();
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public InstallResult uninstallPackage(String str) {
        synchronized (this.mInstallLock) {
            synchronized (this.mPackages) {
                InstallResult installResult = new InstallResult();
                installResult.packageName = str;
                BPackageSettings bPackageSettings = this.mPackages.get(str);
                if (bPackageSettings == null) {
                    return installResult;
                }
                BProcessManagerService.get().killAllByPackageName(str);
                if (bPackageSettings.installOption.isFlag(4)) {
                    for (BUserInfo bUserInfo : BUserManagerService.get().getAllUsers()) {
                        if (BPackageInstallerService.get().uninstallPackageAsUser(bPackageSettings, true, bUserInfo.id) >= 0) {
                            onPackageUninstalled(str, true, bUserInfo.id);
                        }
                    }
                } else {
                    for (Integer num : bPackageSettings.getUserIds()) {
                        if (BPackageInstallerService.get().uninstallPackageAsUser(bPackageSettings, true, num.intValue()) >= 0) {
                            onPackageUninstalled(str, true, num.intValue());
                        }
                    }
                }
                this.mSettings.removePackage(str);
                this.mComponentResolver.removeAllComponents(bPackageSettings.pkg);
                return installResult;
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public InstallResult uninstallPackageAsUser(String str, int i2) throws RemoteException {
        synchronized (this.mInstallLock) {
            synchronized (this.mPackages) {
                InstallResult installResult = new InstallResult();
                installResult.packageName = str;
                BPackageSettings bPackageSettings = this.mPackages.get(str);
                if (bPackageSettings == null && GmsCore.isGoogleAppOrService(str) && this.mGooglePackages.containsKey(str)) {
                    bPackageSettings = this.mGooglePackages.get(str);
                    this.mGooglePackages.remove(str);
                }
                if (bPackageSettings == null) {
                    return installResult;
                }
                if (!bPackageSettings.installOption.isFlag(4) || i2 == -4) {
                    if (isInstalled(str, i2)) {
                        boolean z = true;
                        if (bPackageSettings.getUserState().size() > 1) {
                            z = false;
                        }
                        BProcessManagerService.get().killPackageAsUser(str, i2);
                        BPackageInstallerService.get().uninstallPackageAsUser(bPackageSettings, z, i2);
                        if (z) {
                            this.mSettings.removePackage(str);
                            this.mComponentResolver.removeAllComponents(bPackageSettings.pkg);
                        } else {
                            bPackageSettings.removeUser(i2);
                            bPackageSettings.save();
                        }
                        onPackageUninstalled(str, z, i2);
                        return installResult;
                    }
                    return installResult;
                }
                return installResult;
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBPackageManagerService
    public List<ResolveInfo> queryIntentActivities(Intent intent, int i2, String str, int i3) throws RemoteException {
        if (sUserManager.exists(i3)) {
            String str2 = intent.getPackage();
            ComponentName component = intent.getComponent();
            if (component == null && intent.getSelector() != null) {
                intent = intent.getSelector();
                component = intent.getComponent();
            }
            Intent intent2 = intent;
            if (component != null) {
                ArrayList arrayList = new ArrayList(1);
                ActivityInfo activityInfo = getActivityInfo(component, i2, i3);
                if (activityInfo != null) {
                    ResolveInfo resolveInfo = new ResolveInfo();
                    resolveInfo.activityInfo = activityInfo;
                    arrayList.add(resolveInfo);
                }
                return arrayList;
            }
            synchronized (this.mPackages) {
                if (str2 != null) {
                    BPackageSettings bPackageSettings = this.mPackages.get(str2);
                    List<ResolveInfo> list = null;
                    if (bPackageSettings != null) {
                        list = this.mComponentResolver.queryActivities(intent2, str, i2, bPackageSettings.pkg.activities, i3);
                    }
                    if ((list == null || list.size() == 0) && list == null) {
                        list = new ArrayList<>();
                    }
                    return list;
                }
                return Collections.emptyList();
            }
        }
        return Collections.emptyList();
    }
}
