package chongya.haiwai.sandbox.d.system.pm;

import android.os.Parcel;
import android.os.Parcelable;
import android.util.AtomicFile;
import chongya.haiwai.sandbox.bean.pm.InstallOption;
import chongya.haiwai.sandbox.d.env.BEnvironment;
import chongya.haiwai.sandbox.utils.CloseUtils;
import chongya.haiwai.sandbox.utils.FileUtils;
import java.io.FileOutputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class BPackageSettings implements Parcelable {
    public int appId;
    public InstallOption installOption;
    public long lastUpdateTime;
    public BPackage pkg;
    public Map<Integer, BPackageUserState> userState;
    public static final BPackageUserState DEFAULT_USER_STATE = new BPackageUserState();
    public static final Parcelable.Creator<BPackageSettings> CREATOR = new Parcelable.Creator<BPackageSettings>() { // from class: chongya.haiwai.sandbox.d.system.pm.BPackageSettings.1
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // android.os.Parcelable.Creator
        public BPackageSettings createFromParcel(Parcel parcel) {
            return new BPackageSettings(parcel);
        }

        /* JADX WARN: Can't rename method to resolve collision */
        @Override // android.os.Parcelable.Creator
        public BPackageSettings[] newArray(int i2) {
            return new BPackageSettings[i2];
        }
    };

    public BPackageSettings() {
        this.userState = new HashMap();
    }

    private BPackageUserState modifyUserState(int i2) {
        BPackageUserState bPackageUserState = this.userState.get(Integer.valueOf(i2));
        if (bPackageUserState == null) {
            BPackageUserState bPackageUserState2 = new BPackageUserState();
            this.userState.put(Integer.valueOf(i2), bPackageUserState2);
            return bPackageUserState2;
        }
        return bPackageUserState;
    }

    @Override // android.os.Parcelable
    public int describeContents() {
        return 0;
    }

    public boolean getHidden(int i2) {
        return readUserState(i2).hidden;
    }

    public boolean getInstalled(int i2) {
        return readUserState(i2).installed;
    }

    public boolean getStopped(int i2) {
        return readUserState(i2).stopped;
    }

    public List<Integer> getUserIds() {
        return new ArrayList(this.userState.keySet());
    }

    public List<BPackageUserState> getUserState() {
        return new ArrayList(this.userState.values());
    }

    public BPackageUserState readUserState(int i2) {
        BPackageUserState bPackageUserState = this.userState.get(Integer.valueOf(i2));
        if (bPackageUserState == null) {
            bPackageUserState = new BPackageUserState();
        }
        BPackageUserState bPackageUserState2 = new BPackageUserState(bPackageUserState);
        if (this.installOption.isFlag(4) && BXposedManagerService.get().isModuleEnable(this.pkg.packageName) && BXposedManagerService.get().isXPEnable()) {
            bPackageUserState2.installed = true;
        }
        if (i2 == -1) {
            bPackageUserState2.installed = true;
        }
        return bPackageUserState2;
    }

    public void removeUser(int i2) {
        this.userState.remove(Integer.valueOf(i2));
    }

    public boolean save() {
        synchronized (this) {
            Parcel obtain = Parcel.obtain();
            AtomicFile atomicFile = new AtomicFile(BEnvironment.getPackageConf(this.pkg.packageName));
            writeToParcel(obtain, 0);
            obtain.setDataPosition(0);
            FileOutputStream startWrite = atomicFile.startWrite();
            FileUtils.writeParcelToOutput(obtain, startWrite);
            atomicFile.finishWrite(startWrite);
            obtain.recycle();
            CloseUtils.close(startWrite);
        }
        return true;
    }

    public void setHidden(boolean z, int i2) {
        modifyUserState(i2).hidden = z;
    }

    public void setInstalled(boolean z, int i2) {
        modifyUserState(i2).installed = z;
    }

    public void setStopped(boolean z, int i2) {
        modifyUserState(i2).stopped = z;
    }

    @Override // android.os.Parcelable
    public void writeToParcel(Parcel parcel, int i2) {
        parcel.writeParcelable(this.pkg, i2);
        parcel.writeInt(this.appId);
        parcel.writeParcelable(this.installOption, i2);
        parcel.writeInt(this.userState.size());
        for (Map.Entry<Integer, BPackageUserState> entry : this.userState.entrySet()) {
            parcel.writeValue(entry.getKey());
            parcel.writeParcelable(entry.getValue(), i2);
        }
        parcel.writeLong(this.lastUpdateTime);
    }

    public BPackageSettings(Parcel parcel) {
        this.userState = new HashMap();
        this.pkg = (BPackage) parcel.readParcelable(BPackage.class.getClassLoader());
        this.appId = parcel.readInt();
        this.installOption = (InstallOption) parcel.readParcelable(InstallOption.class.getClassLoader());
        int readInt = parcel.readInt();
        this.userState = new HashMap(readInt);
        for (int i2 = 0; i2 < readInt; i2++) {
            this.userState.put((Integer) parcel.readValue(Integer.class.getClassLoader()), (BPackageUserState) parcel.readParcelable(BPackageUserState.class.getClassLoader()));
        }
        this.lastUpdateTime = parcel.readLong();
    }
}
