package chongya.haiwai.sandbox.d.system.pm;

import android.content.pm.ApplicationInfo;
import android.os.Parcel;
import androidx.core.util.AtomicFile;
import chongya.haiwai.sandbox.bean.pm.InstalledModule;
import chongya.haiwai.sandbox.bean.pm.XposedConfig;
import chongya.haiwai.sandbox.d.env.BEnvironment;
import chongya.haiwai.sandbox.d.system.ISystemService;
import chongya.haiwai.sandbox.d.system.pm.IBXposedManagerService;
import chongya.haiwai.sandbox.utils.CloseUtils;
import chongya.haiwai.sandbox.utils.FileUtils;
import chongya.haiwai.sandbox.utils.compat.XposedParserCompat;
import java.io.File;
import java.io.FileOutputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class BXposedManagerService extends IBXposedManagerService.Stub implements ISystemService, PackageMonitor {
    public static final BXposedManagerService sService = new BXposedManagerService();
    public BPackageManagerService mPms;
    public XposedConfig mXposedConfig;
    public final Object mLock = new Object();
    public final Map<String, InstalledModule> mCacheModule = new HashMap();

    public static BXposedManagerService get() {
        return sService;
    }

    private void loadModuleStateLr() {
        File xPModuleConf = BEnvironment.getXPModuleConf();
        if (!xPModuleConf.exists()) {
            this.mXposedConfig = new XposedConfig();
            saveModuleStateLw();
            return;
        }
        Parcel parcel = null;
        try {
            try {
                parcel = FileUtils.readToParcel(xPModuleConf);
                this.mXposedConfig = new XposedConfig(parcel);
                if (parcel == null) {
                    return;
                }
            } catch (Exception e2) {
                e2.printStackTrace();
                if (parcel == null) {
                    return;
                }
            }
            parcel.recycle();
        } catch (Throwable th) {
            if (parcel != null) {
                parcel.recycle();
            }
            throw th;
        }
    }

    private void saveModuleStateLw() {
        Parcel obtain = Parcel.obtain();
        AtomicFile atomicFile = new AtomicFile(BEnvironment.getXPModuleConf());
        FileOutputStream fileOutputStream = null;
        try {
            try {
                this.mXposedConfig.writeToParcel(obtain, 0);
                obtain.setDataPosition(0);
                fileOutputStream = atomicFile.startWrite();
                FileUtils.writeParcelToOutput(obtain, fileOutputStream);
                atomicFile.finishWrite(fileOutputStream);
                obtain.recycle();
                CloseUtils.close(fileOutputStream);
            } catch (Exception unused) {
                atomicFile.failWrite(fileOutputStream);
                obtain.recycle();
                CloseUtils.close(fileOutputStream);
            }
        } catch (Throwable th) {
            obtain.recycle();
            CloseUtils.close(fileOutputStream);
            throw th;
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBXposedManagerService
    public List<InstalledModule> getInstalledModules() {
        ArrayList arrayList;
        InstalledModule parseModule;
        List<ApplicationInfo> installedApplications = this.mPms.getInstalledApplications(128, -4);
        synchronized (this.mCacheModule) {
            for (ApplicationInfo applicationInfo : installedApplications) {
                if (!this.mCacheModule.containsKey(applicationInfo.packageName) && (parseModule = XposedParserCompat.parseModule(applicationInfo)) != null) {
                    this.mCacheModule.put(applicationInfo.packageName, parseModule);
                }
            }
            arrayList = new ArrayList(this.mCacheModule.values());
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                InstalledModule installedModule = (InstalledModule) it.next();
                installedModule.enable = isModuleEnable(installedModule.packageName);
            }
        }
        return arrayList;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBXposedManagerService
    public boolean isModuleEnable(String str) {
        boolean z;
        synchronized (this.mLock) {
            Boolean bool = this.mXposedConfig.moduleState.get(str);
            z = bool != null && bool.booleanValue();
        }
        return z;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBXposedManagerService
    public boolean isXPEnable() {
        boolean z;
        synchronized (this.mLock) {
            z = this.mXposedConfig.enable;
        }
        return z;
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.PackageMonitor
    public void onPackageInstalled(String str, int i2) {
        if (i2 == -4 || i2 == -1) {
            synchronized (this.mCacheModule) {
                this.mCacheModule.remove(str);
            }
            synchronized (this.mLock) {
                this.mXposedConfig.moduleState.put(str, false);
                saveModuleStateLw();
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.PackageMonitor
    public void onPackageUninstalled(String str, boolean z, int i2) {
        if (i2 == -4 || i2 == -1) {
            synchronized (this.mCacheModule) {
                this.mCacheModule.remove(str);
            }
            synchronized (this.mLock) {
                this.mXposedConfig.moduleState.remove(str);
                saveModuleStateLw();
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBXposedManagerService
    public void setModuleEnable(String str, boolean z) {
        synchronized (this.mLock) {
            if (this.mPms.isInstalled(str, -4)) {
                this.mXposedConfig.moduleState.put(str, Boolean.valueOf(z));
                saveModuleStateLw();
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.pm.IBXposedManagerService
    public void setXPEnable(boolean z) {
        synchronized (this.mLock) {
            this.mXposedConfig.enable = z;
            saveModuleStateLw();
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.ISystemService
    public void systemReady() {
        loadModuleStateLr();
        BPackageManagerService bPackageManagerService = BPackageManagerService.get();
        this.mPms = bPackageManagerService;
        bPackageManagerService.addPackageMonitor(this);
    }
}
