package chongya.haiwai.sandbox.d.system.pm;

import android.content.Intent;
import android.content.IntentFilter;
import android.net.Uri;
import android.util.ArrayMap;
import android.util.MutableInt;
import android.util.PrintWriterPrinter;
import chongya.haiwai.sandbox.d.system.pm.BPackage;
import chongya.haiwai.sandbox.d.system.pm.BPackage.IntentInfo;
import chongya.haiwai.sandbox.utils.Slog;
import com.bumptech.glide.load.engine.GlideException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
/* compiled from: AAA */
/* loaded from: classes.dex */
public abstract class IntentResolver<F extends BPackage.IntentInfo, R> {
    public static final boolean DEBUG = false;
    public static final String TAG = "IntentResolver";
    public static final boolean localLOGV = false;
    public static final boolean localVerificationLOGV = false;
    public static final Comparator mResolvePrioritySorter = new Comparator() { // from class: chongya.haiwai.sandbox.d.system.pm.IntentResolver.1
        @Override // java.util.Comparator
        public int compare(Object obj, Object obj2) {
            int priority = ((IntentFilter) obj).getPriority();
            int priority2 = ((IntentFilter) obj2).getPriority();
            if (priority > priority2) {
                return -1;
            }
            return priority < priority2 ? 1 : 0;
        }
    };
    public final HashSet<F> mFilters = new HashSet<>();
    public final ArrayMap<String, F[]> mTypeToFilter = new ArrayMap<>();
    public final ArrayMap<String, F[]> mBaseTypeToFilter = new ArrayMap<>();
    public final ArrayMap<String, F[]> mWildTypeToFilter = new ArrayMap<>();
    public final ArrayMap<String, F[]> mSchemeToFilter = new ArrayMap<>();
    public final ArrayMap<String, F[]> mActionToFilter = new ArrayMap<>();
    public final ArrayMap<String, F[]> mTypedActionToFilter = new ArrayMap<>();

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public class IteratorWrapper implements Iterator<F> {
        public F mCur;
        public final Iterator<F> mI;

        public IteratorWrapper(Iterator<F> it) {
            this.mI = it;
        }

        @Override // java.util.Iterator
        public boolean hasNext() {
            return this.mI.hasNext();
        }

        @Override // java.util.Iterator
        public void remove() {
            F f2 = this.mCur;
            if (f2 != null) {
                IntentResolver.this.removeFilterInternal(f2);
            }
            this.mI.remove();
        }

        @Override // java.util.Iterator
        public F next() {
            F next = this.mI.next();
            this.mCur = next;
            return next;
        }
    }

    private void buildResolveList(Intent intent, FastImmutableArraySet<String> fastImmutableArraySet, boolean z, boolean z2, String str, String str2, F[] fArr, List<R> list, int i2) {
        F f2;
        String str3;
        Uri uri;
        F[] fArr2 = fArr;
        String action = intent.getAction();
        Uri data = intent.getData();
        String str4 = intent.getPackage();
        int length = fArr2 != null ? fArr2.length : 0;
        int i3 = 0;
        boolean z3 = false;
        while (i3 < length && (f2 = fArr2[i3]) != null) {
            if (z) {
                Slog.v(TAG, "Matching against filter " + f2);
            }
            if (str4 == null || isPackageForFilter(str4, f2)) {
                if (allowFilterResult(f2, list)) {
                    str3 = action;
                    uri = data;
                    int match = f2.intentFilter.match(action, str, str2, data, fastImmutableArraySet, TAG);
                    if (match >= 0) {
                        if (z) {
                            Slog.v(TAG, "  Filter matched!  match=0x" + Integer.toHexString(match) + " hasDefault=" + f2.intentFilter.hasCategory("android.intent.category.DEFAULT"));
                        }
                        if (!z2 || f2.intentFilter.hasCategory("android.intent.category.DEFAULT")) {
                            R newResult = newResult(f2, match, i2);
                            if (z) {
                                Slog.v(TAG, "    Created result: " + newResult);
                            }
                            if (newResult != null) {
                                list.add(newResult);
                            }
                        } else {
                            z3 = true;
                        }
                    } else if (z) {
                        String str5 = match != -4 ? match != -3 ? match != -2 ? match != -1 ? "unknown reason" : "type" : "data" : "action" : "category";
                        Slog.v(TAG, "  Filter did not match: " + str5);
                    }
                    i3++;
                    fArr2 = fArr;
                    action = str3;
                    data = uri;
                } else if (z) {
                    Slog.v(TAG, "  Filter's target already added");
                }
            } else if (z) {
                Slog.v(TAG, "  Filter is not from package " + str4 + "; skipping");
            }
            str3 = action;
            uri = data;
            i3++;
            fArr2 = fArr;
            action = str3;
            data = uri;
        }
        if (z && z3) {
            if (list.size() == 0) {
                Slog.v(TAG, "resolveIntent failed: found match, but none with CATEGORY_DEFAULT");
            } else if (list.size() > 1) {
                Slog.v(TAG, "resolveIntent: multiple matches, only some with CATEGORY_DEFAULT");
            }
        }
    }

    private ArrayList<F> collectFilters(F[] fArr, IntentFilter intentFilter) {
        F f2;
        ArrayList<F> arrayList = null;
        if (fArr != null) {
            for (int i2 = 0; i2 < fArr.length && (f2 = fArr[i2]) != null; i2++) {
                if (filterEquals(f2.intentFilter, intentFilter)) {
                    if (arrayList == null) {
                        arrayList = new ArrayList<>();
                    }
                    arrayList.add(f2);
                }
            }
        }
        return arrayList;
    }

    public static boolean filterEquals(IntentFilter intentFilter, IntentFilter intentFilter2) {
        int countActions = intentFilter.countActions();
        if (countActions != intentFilter2.countActions()) {
            return false;
        }
        for (int i2 = 0; i2 < countActions; i2++) {
            if (!intentFilter2.hasAction(intentFilter.getAction(i2))) {
                return false;
            }
        }
        int countCategories = intentFilter.countCategories();
        if (countCategories != intentFilter2.countCategories()) {
            return false;
        }
        for (int i3 = 0; i3 < countCategories; i3++) {
            if (!intentFilter2.hasCategory(intentFilter.getCategory(i3))) {
                return false;
            }
        }
        int countDataSchemes = intentFilter.countDataSchemes();
        if (countDataSchemes != intentFilter2.countDataSchemes()) {
            return false;
        }
        for (int i4 = 0; i4 < countDataSchemes; i4++) {
            if (!intentFilter2.hasDataScheme(intentFilter.getDataScheme(i4))) {
                return false;
            }
        }
        return intentFilter.countDataSchemeSpecificParts() == intentFilter2.countDataSchemeSpecificParts();
    }

    public static FastImmutableArraySet<String> getFastIntentCategories(Intent intent) {
        Set<String> categories = intent.getCategories();
        if (categories == null) {
            return null;
        }
        return new FastImmutableArraySet<>(categories.toArray(new String[categories.size()]));
    }

    private final int register_intent_filter(F f2, Iterator<String> it, ArrayMap<String, F[]> arrayMap, String str) {
        int i2 = 0;
        if (it == null) {
            return 0;
        }
        while (it.hasNext()) {
            i2++;
            addFilter(arrayMap, it.next(), f2);
        }
        return i2;
    }

    private final int register_mime_types(F f2, String str) {
        String str2;
        Iterator<String> typesIterator = f2.intentFilter.typesIterator();
        if (typesIterator == null) {
            return 0;
        }
        int i2 = 0;
        while (typesIterator.hasNext()) {
            String next = typesIterator.next();
            i2++;
            int indexOf = next.indexOf(47);
            if (indexOf > 0) {
                str2 = next.substring(0, indexOf).intern();
            } else {
                str2 = next;
                next = next + "/*";
            }
            addFilter(this.mTypeToFilter, next, f2);
            if (indexOf > 0) {
                addFilter(this.mBaseTypeToFilter, str2, f2);
            } else {
                addFilter(this.mWildTypeToFilter, str2, f2);
            }
        }
        return i2;
    }

    private final void remove_all_objects(ArrayMap<String, F[]> arrayMap, String str, Object obj) {
        F[] fArr = arrayMap.get(str);
        if (fArr != null) {
            int length = fArr.length - 1;
            while (length >= 0 && fArr[length] == null) {
                length--;
            }
            int i2 = length;
            while (length >= 0) {
                if (fArr[length] == obj) {
                    int i3 = i2 - length;
                    if (i3 > 0) {
                        System.arraycopy(fArr, length + 1, fArr, length, i3);
                    }
                    fArr[i2] = null;
                    i2--;
                }
                length--;
            }
            if (i2 < 0) {
                arrayMap.remove(str);
            } else if (i2 < fArr.length / 2) {
                F[] newArray = newArray(i2 + 2);
                System.arraycopy(fArr, 0, newArray, 0, i2 + 1);
                arrayMap.put(str, newArray);
            }
        }
    }

    private final int unregister_intent_filter(F f2, Iterator<String> it, ArrayMap<String, F[]> arrayMap, String str) {
        int i2 = 0;
        if (it == null) {
            return 0;
        }
        while (it.hasNext()) {
            i2++;
            remove_all_objects(arrayMap, it.next(), f2);
        }
        return i2;
    }

    private final int unregister_mime_types(F f2, String str) {
        String str2;
        Iterator<String> typesIterator = f2.intentFilter.typesIterator();
        if (typesIterator == null) {
            return 0;
        }
        int i2 = 0;
        while (typesIterator.hasNext()) {
            String next = typesIterator.next();
            i2++;
            int indexOf = next.indexOf(47);
            if (indexOf > 0) {
                str2 = next.substring(0, indexOf).intern();
            } else {
                str2 = next;
                next = next + "/*";
            }
            remove_all_objects(this.mTypeToFilter, next, f2);
            if (indexOf > 0) {
                remove_all_objects(this.mBaseTypeToFilter, str2, f2);
            } else {
                remove_all_objects(this.mWildTypeToFilter, str2, f2);
            }
        }
        return i2;
    }

    public void addFilter(F f2) {
        this.mFilters.add(f2);
        int register_intent_filter = register_intent_filter(f2, f2.intentFilter.schemesIterator(), this.mSchemeToFilter, "      Scheme: ");
        int register_mime_types = register_mime_types(f2, "      Type: ");
        if (register_intent_filter == 0 && register_mime_types == 0) {
            register_intent_filter(f2, f2.intentFilter.actionsIterator(), this.mActionToFilter, "      Action: ");
        }
        if (register_mime_types != 0) {
            register_intent_filter(f2, f2.intentFilter.actionsIterator(), this.mTypedActionToFilter, "      TypedAction: ");
        }
    }

    public boolean allowFilterResult(F f2, List<R> list) {
        return true;
    }

    public void dumpFilter(PrintWriter printWriter, String str, F f2) {
        printWriter.print(str);
        printWriter.println(f2);
    }

    public void dumpFilterLabel(PrintWriter printWriter, String str, Object obj, int i2) {
        printWriter.print(str);
        printWriter.print(obj);
        printWriter.print(": ");
        printWriter.println(i2);
    }

    public boolean dumpMap(PrintWriter printWriter, String str, String str2, String str3, ArrayMap<String, F[]> arrayMap, String str4, boolean z, boolean z2) {
        boolean z3;
        String str5;
        F f2;
        PrintWriterPrinter printWriterPrinter;
        boolean z4;
        ArrayMap<String, F[]> arrayMap2 = arrayMap;
        String str6 = str3 + GlideException.IndentedAppendable.INDENT;
        String str7 = str3 + "    ";
        ArrayMap arrayMap3 = new ArrayMap();
        String str8 = str2;
        int i2 = 0;
        boolean z5 = false;
        PrintWriterPrinter printWriterPrinter2 = null;
        while (i2 < arrayMap.size()) {
            F[] valueAt = arrayMap2.valueAt(i2);
            int length = valueAt.length;
            if (!z2 || z) {
                z3 = z5;
                str8 = str8;
                printWriterPrinter2 = printWriterPrinter2;
                int i3 = 0;
                boolean z6 = false;
                while (i3 < length) {
                    F f3 = valueAt[i3];
                    if (f3 != null) {
                        if (str4 == null || isPackageForFilter(str4, f3)) {
                            if (str8 != null) {
                                printWriter.print(str);
                                printWriter.println(str8);
                                str8 = null;
                            }
                            if (!z6) {
                                printWriter.print(str6);
                                printWriter.print(arrayMap2.keyAt(i2));
                                printWriter.println(":");
                                z6 = true;
                            }
                            dumpFilter(printWriter, str7, f3);
                            if (z) {
                                if (printWriterPrinter2 == null) {
                                    printWriterPrinter2 = new PrintWriterPrinter(printWriter);
                                }
                                f3.intentFilter.dump(printWriterPrinter2, str7 + GlideException.IndentedAppendable.INDENT);
                            }
                            z3 = true;
                        }
                        i3++;
                        arrayMap2 = arrayMap;
                    }
                }
            } else {
                arrayMap3.clear();
                int i4 = 0;
                while (true) {
                    str5 = str8;
                    if (i4 >= length || (f2 = valueAt[i4]) == null) {
                        break;
                    }
                    if (str4 == null || isPackageForFilter(str4, f2)) {
                        Object filterToLabel = filterToLabel(f2);
                        printWriterPrinter = printWriterPrinter2;
                        int indexOfKey = arrayMap3.indexOfKey(filterToLabel);
                        if (indexOfKey < 0) {
                            z4 = z5;
                            arrayMap3.put(filterToLabel, new MutableInt(1));
                        } else {
                            z4 = z5;
                            ((MutableInt) arrayMap3.valueAt(indexOfKey)).value++;
                        }
                    } else {
                        z4 = z5;
                        printWriterPrinter = printWriterPrinter2;
                    }
                    i4++;
                    str8 = str5;
                    printWriterPrinter2 = printWriterPrinter;
                    z5 = z4;
                }
                z3 = z5;
                PrintWriterPrinter printWriterPrinter3 = printWriterPrinter2;
                str8 = str5;
                int i5 = 0;
                boolean z7 = false;
                while (i5 < arrayMap3.size()) {
                    if (str8 != null) {
                        printWriter.print(str);
                        printWriter.println(str8);
                        str8 = null;
                    }
                    if (!z7) {
                        printWriter.print(str6);
                        printWriter.print(arrayMap2.keyAt(i2));
                        printWriter.println(":");
                        z7 = true;
                    }
                    dumpFilterLabel(printWriter, str7, arrayMap3.keyAt(i5), ((MutableInt) arrayMap3.valueAt(i5)).value);
                    i5++;
                    z3 = true;
                }
                printWriterPrinter2 = printWriterPrinter3;
            }
            z5 = z3;
            i2++;
            arrayMap2 = arrayMap;
        }
        return z5;
    }

    public Iterator<F> filterIterator() {
        return new IteratorWrapper(this.mFilters.iterator());
    }

    public void filterResults(List<R> list) {
    }

    public Set<F> filterSet() {
        return Collections.unmodifiableSet(this.mFilters);
    }

    public Object filterToLabel(F f2) {
        return "IntentFilter";
    }

    public ArrayList<F> findFilters(IntentFilter intentFilter) {
        if (intentFilter.countDataSchemes() == 1) {
            return collectFilters(this.mSchemeToFilter.get(intentFilter.getDataScheme(0)), intentFilter);
        }
        if (intentFilter.countDataTypes() != 0 && intentFilter.countActions() == 1) {
            return collectFilters(this.mTypedActionToFilter.get(intentFilter.getAction(0)), intentFilter);
        }
        if (intentFilter.countDataTypes() == 0 && intentFilter.countDataSchemes() == 0 && intentFilter.countActions() == 1) {
            return collectFilters(this.mActionToFilter.get(intentFilter.getAction(0)), intentFilter);
        }
        ArrayList<F> arrayList = null;
        Iterator<F> it = this.mFilters.iterator();
        while (it.hasNext()) {
            F next = it.next();
            if (filterEquals(next.intentFilter, intentFilter)) {
                if (arrayList == null) {
                    arrayList = new ArrayList<>();
                }
                arrayList.add(next);
            }
        }
        return arrayList;
    }

    public boolean isFilterStopped(F f2, int i2) {
        return false;
    }

    public abstract boolean isPackageForFilter(String str, F f2);

    public abstract F[] newArray(int i2);

    /* JADX WARN: Multi-variable type inference failed */
    public R newResult(F f2, int i2, int i3) {
        return f2;
    }

    /* JADX WARN: Removed duplicated region for block: B:44:0x0165  */
    /* JADX WARN: Removed duplicated region for block: B:48:0x018a  */
    /* JADX WARN: Removed duplicated region for block: B:50:0x018e A[ADDED_TO_REGION] */
    /* JADX WARN: Removed duplicated region for block: B:55:0x01a4  */
    /* JADX WARN: Removed duplicated region for block: B:58:0x01c4  */
    /* JADX WARN: Removed duplicated region for block: B:59:0x01da  */
    /* JADX WARN: Removed duplicated region for block: B:61:0x01dd  */
    /* JADX WARN: Removed duplicated region for block: B:63:0x01f2  */
    /* JADX WARN: Removed duplicated region for block: B:65:0x0208  */
    /* JADX WARN: Removed duplicated region for block: B:68:0x0221  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public List<R> queryIntent(Intent intent, String str, boolean z, int i2) {
        F[] fArr;
        F[] fArr2;
        F[] fArr3;
        F[] fArr4;
        F[] fArr5;
        String str2;
        int indexOf;
        F[] fArr6;
        String scheme = intent.getScheme();
        ArrayList arrayList = new ArrayList();
        boolean z2 = (intent.getFlags() & 8) != 0;
        if (z2) {
            Slog.v(TAG, "Resolving type=" + str + " scheme=" + scheme + " defaultOnly=" + z + " userId=" + i2 + " of " + intent);
        }
        if (str != null && (indexOf = str.indexOf(47)) > 0) {
            String substring = str.substring(0, indexOf);
            if (!substring.equals("*")) {
                if (str.length() == indexOf + 2 && str.charAt(indexOf + 1) == '*') {
                    fArr = this.mBaseTypeToFilter.get(substring);
                    if (z2) {
                        Slog.v(TAG, "First type cut: " + Arrays.toString(fArr));
                    }
                    fArr6 = this.mWildTypeToFilter.get(substring);
                    if (z2) {
                        Slog.v(TAG, "Second type cut: " + Arrays.toString(fArr6));
                    }
                } else {
                    fArr = this.mTypeToFilter.get(str);
                    if (z2) {
                        Slog.v(TAG, "First type cut: " + Arrays.toString(fArr));
                    }
                    fArr6 = this.mWildTypeToFilter.get(substring);
                    if (z2) {
                        Slog.v(TAG, "Second type cut: " + Arrays.toString(fArr6));
                    }
                }
                F[] fArr7 = this.mWildTypeToFilter.get("*");
                if (z2) {
                    Slog.v(TAG, "Third type cut: " + Arrays.toString(fArr7));
                }
                fArr2 = fArr6;
                fArr3 = fArr7;
                if (scheme != null) {
                    F[] fArr8 = this.mSchemeToFilter.get(scheme);
                    if (z2) {
                        Slog.v(TAG, "Scheme list: " + Arrays.toString(fArr8));
                    }
                    fArr4 = fArr8;
                } else {
                    fArr4 = null;
                }
                if (str == null && scheme == null && intent.getAction() != null) {
                    fArr = this.mActionToFilter.get(intent.getAction());
                    if (z2) {
                        Slog.v(TAG, "Action list: " + Arrays.toString(fArr));
                    }
                }
                fArr5 = fArr;
                FastImmutableArraySet<String> fastIntentCategories = getFastIntentCategories(intent);
                if (fArr5 != null) {
                    str2 = TAG;
                    buildResolveList(intent, fastIntentCategories, z2, z, str, scheme, fArr5, arrayList, i2);
                } else {
                    str2 = TAG;
                }
                if (fArr2 != null) {
                    buildResolveList(intent, fastIntentCategories, z2, z, str, scheme, fArr2, arrayList, i2);
                }
                if (fArr3 != null) {
                    buildResolveList(intent, fastIntentCategories, z2, z, str, scheme, fArr3, arrayList, i2);
                }
                if (fArr4 != null) {
                    buildResolveList(intent, fastIntentCategories, z2, z, str, scheme, fArr4, arrayList, i2);
                }
                filterResults(arrayList);
                if (z2) {
                    Slog.v(str2, "Final result list:");
                    for (int i3 = 0; i3 < arrayList.size(); i3++) {
                        Slog.v(str2, GlideException.IndentedAppendable.INDENT + arrayList.get(i3));
                    }
                }
                return arrayList;
            } else if (intent.getAction() != null) {
                fArr = this.mTypedActionToFilter.get(intent.getAction());
                if (z2) {
                    Slog.v(TAG, "Typed Action list: " + Arrays.toString(fArr));
                }
                fArr2 = null;
                fArr3 = null;
                if (scheme != null) {
                }
                if (str == null) {
                    fArr = this.mActionToFilter.get(intent.getAction());
                    if (z2) {
                    }
                }
                fArr5 = fArr;
                FastImmutableArraySet<String> fastIntentCategories2 = getFastIntentCategories(intent);
                if (fArr5 != null) {
                }
                if (fArr2 != null) {
                }
                if (fArr3 != null) {
                }
                if (fArr4 != null) {
                }
                filterResults(arrayList);
                if (z2) {
                }
                return arrayList;
            }
        }
        fArr = null;
        fArr2 = null;
        fArr3 = null;
        if (scheme != null) {
        }
        if (str == null) {
        }
        fArr5 = fArr;
        FastImmutableArraySet<String> fastIntentCategories22 = getFastIntentCategories(intent);
        if (fArr5 != null) {
        }
        if (fArr2 != null) {
        }
        if (fArr3 != null) {
        }
        if (fArr4 != null) {
        }
        filterResults(arrayList);
        if (z2) {
        }
        return arrayList;
    }

    public List<R> queryIntentFromList(Intent intent, String str, boolean z, ArrayList<F[]> arrayList, int i2) {
        ArrayList arrayList2 = new ArrayList();
        boolean z2 = (intent.getFlags() & 8) != 0;
        FastImmutableArraySet<String> fastIntentCategories = getFastIntentCategories(intent);
        String scheme = intent.getScheme();
        int size = arrayList.size();
        for (int i3 = 0; i3 < size; i3++) {
            buildResolveList(intent, fastIntentCategories, z2, z, str, scheme, arrayList.get(i3), arrayList2, i2);
        }
        filterResults(arrayList2);
        return arrayList2;
    }

    public void removeFilter(F f2) {
        removeFilterInternal(f2);
        this.mFilters.remove(f2);
    }

    public void removeFilterInternal(F f2) {
        int unregister_intent_filter = unregister_intent_filter(f2, f2.intentFilter.schemesIterator(), this.mSchemeToFilter, "      Scheme: ");
        int unregister_mime_types = unregister_mime_types(f2, "      Type: ");
        if (unregister_intent_filter == 0 && unregister_mime_types == 0) {
            unregister_intent_filter(f2, f2.intentFilter.actionsIterator(), this.mActionToFilter, "      Action: ");
        }
        if (unregister_mime_types != 0) {
            unregister_intent_filter(f2, f2.intentFilter.actionsIterator(), this.mTypedActionToFilter, "      TypedAction: ");
        }
    }

    public void sortResults(List<R> list) {
        Collections.sort(list, mResolvePrioritySorter);
    }

    private final void addFilter(ArrayMap<String, F[]> arrayMap, String str, F f2) {
        F[] fArr = arrayMap.get(str);
        if (fArr == null) {
            F[] newArray = newArray(2);
            arrayMap.put(str, newArray);
            newArray[0] = f2;
            return;
        }
        int length = fArr.length;
        int i2 = length;
        while (i2 > 0 && fArr[i2 - 1] == null) {
            i2--;
        }
        if (i2 < length) {
            fArr[i2] = f2;
            return;
        }
        F[] newArray2 = newArray((length * 3) / 2);
        System.arraycopy(fArr, 0, newArray2, 0, length);
        newArray2[length] = f2;
        arrayMap.put(str, newArray2);
    }
}
