package chongya.haiwai.sandbox.d.system.user;

import android.os.Parcel;
import android.os.RemoteException;
import androidx.core.util.AtomicFile;
import chongya.haiwai.sandbox.d.env.BEnvironment;
import chongya.haiwai.sandbox.d.system.ISystemService;
import chongya.haiwai.sandbox.d.system.pm.BPackageManagerService;
import chongya.haiwai.sandbox.d.system.user.IBUserManagerService;
import chongya.haiwai.sandbox.utils.CloseUtils;
import chongya.haiwai.sandbox.utils.FileUtils;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class BUserManagerService extends IBUserManagerService.Stub implements ISystemService {
    public static BUserManagerService sService = new BUserManagerService();
    public final HashMap<Integer, BUserInfo> mUsers = new HashMap<>();
    public final Object mUserLock = new Object();

    private BUserInfo createUserLocked(int i2) {
        BUserInfo bUserInfo = new BUserInfo();
        bUserInfo.id = i2;
        bUserInfo.status = BUserStatus.ENABLE;
        this.mUsers.put(Integer.valueOf(i2), bUserInfo);
        synchronized (this.mUsers) {
            saveUserInfoLocked();
        }
        return bUserInfo;
    }

    public static BUserManagerService get() {
        return sService;
    }

    private void saveUserInfoLocked() {
        Parcel obtain = Parcel.obtain();
        AtomicFile atomicFile = new AtomicFile(BEnvironment.getUserInfoConf());
        try {
            obtain.writeTypedList(new ArrayList(this.mUsers.values()));
            FileOutputStream fileOutputStream = null;
            try {
                fileOutputStream = atomicFile.startWrite();
                FileUtils.writeParcelToOutput(obtain, fileOutputStream);
                atomicFile.finishWrite(fileOutputStream);
                CloseUtils.close(fileOutputStream);
            } catch (IOException e2) {
                e2.printStackTrace();
                atomicFile.failWrite(fileOutputStream);
                CloseUtils.close(fileOutputStream);
            }
        } finally {
            obtain.recycle();
        }
    }

    private void scanUserL() {
        Throwable th;
        FileInputStream fileInputStream;
        Exception e2;
        ArrayList createTypedArrayList;
        synchronized (this.mUserLock) {
            Parcel obtain = Parcel.obtain();
            try {
                try {
                } catch (Throwable th2) {
                    th = th2;
                    obtain.recycle();
                    CloseUtils.close(null);
                    throw th;
                }
            } catch (Exception e3) {
                fileInputStream = null;
                e2 = e3;
            } catch (Throwable th3) {
                th = th3;
                obtain.recycle();
                CloseUtils.close(null);
                throw th;
            }
            if (!BEnvironment.getUserInfoConf().exists()) {
                obtain.recycle();
                CloseUtils.close(null);
                return;
            }
            fileInputStream = new FileInputStream(BEnvironment.getUserInfoConf());
            try {
                byte[] byteArray = FileUtils.toByteArray(fileInputStream);
                obtain.unmarshall(byteArray, 0, byteArray.length);
                obtain.setDataPosition(0);
                createTypedArrayList = obtain.createTypedArrayList(BUserInfo.CREATOR);
            } catch (Exception e4) {
                e2 = e4;
                e2.printStackTrace();
                obtain.recycle();
                CloseUtils.close(fileInputStream);
            }
            if (createTypedArrayList == null) {
                obtain.recycle();
                CloseUtils.close(fileInputStream);
                return;
            }
            synchronized (this.mUsers) {
                this.mUsers.clear();
                Iterator it = createTypedArrayList.iterator();
                while (it.hasNext()) {
                    BUserInfo bUserInfo = (BUserInfo) it.next();
                    this.mUsers.put(Integer.valueOf(bUserInfo.id), bUserInfo);
                }
            }
            obtain.recycle();
            CloseUtils.close(fileInputStream);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.user.IBUserManagerService
    public BUserInfo createUser(int i2) throws RemoteException {
        synchronized (this.mUserLock) {
            if (exists(i2)) {
                return getUserInfo(i2);
            }
            return createUserLocked(i2);
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.user.IBUserManagerService
    public void deleteUser(int i2) throws RemoteException {
        synchronized (this.mUserLock) {
            synchronized (this.mUsers) {
                BPackageManagerService.get().deleteUser(i2);
                this.mUsers.remove(Integer.valueOf(i2));
                saveUserInfoLocked();
                FileUtils.deleteDir(BEnvironment.getUserDir(i2));
                FileUtils.deleteDir(BEnvironment.getExternalUserDir(i2));
            }
        }
    }

    @Override // chongya.haiwai.sandbox.d.system.user.IBUserManagerService
    public boolean exists(int i2) {
        boolean z;
        synchronized (this.mUsers) {
            z = this.mUsers.get(Integer.valueOf(i2)) != null;
        }
        return z;
    }

    public List<BUserInfo> getAllUsers() {
        ArrayList arrayList;
        synchronized (this.mUsers) {
            arrayList = new ArrayList(this.mUsers.values());
        }
        return arrayList;
    }

    @Override // chongya.haiwai.sandbox.d.system.user.IBUserManagerService
    public BUserInfo getUserInfo(int i2) {
        BUserInfo bUserInfo;
        synchronized (this.mUserLock) {
            bUserInfo = this.mUsers.get(Integer.valueOf(i2));
        }
        return bUserInfo;
    }

    @Override // chongya.haiwai.sandbox.d.system.user.IBUserManagerService
    public List<BUserInfo> getUsers() {
        ArrayList arrayList;
        synchronized (this.mUsers) {
            arrayList = new ArrayList();
            for (BUserInfo bUserInfo : this.mUsers.values()) {
                if (bUserInfo.id >= 0) {
                    arrayList.add(bUserInfo);
                }
            }
        }
        return arrayList;
    }

    @Override // chongya.haiwai.sandbox.d.system.ISystemService
    public void systemReady() {
        scanUserL();
    }
}
