package chongya.haiwai.sandbox.f.service;

import android.content.ComponentName;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.ResolveInfo;
import android.net.Uri;
import android.os.Bundle;
import android.os.IBinder;
import chongya.haiwai.sandbox.BlackBoxCore;
import chongya.haiwai.sandbox.a.BActivityThread;
import chongya.haiwai.sandbox.f.hook.MethodHook;
import chongya.haiwai.sandbox.f.hook.ProxyMethod;
import chongya.haiwai.sandbox.f.provider.FileProviderHandler;
import chongya.haiwai.sandbox.utils.ComponentUtils;
import chongya.haiwai.sandbox.utils.MethodParameterUtils;
import chongya.haiwai.sandbox.utils.Slog;
import chongya.haiwai.sandbox.utils.compat.BuildCompat;
import chongya.haiwai.sandbox.utils.compat.StartActivityCompat;
import java.lang.reflect.Method;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class ActivityManagerCommonProxy {
    public static final String TAG = "CommonStub";

    /* compiled from: AAA */
    @ProxyMethod("activityDestroyed")
    /* loaded from: classes.dex */
    public static class ActivityDestroyed extends MethodHook {
        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            BlackBoxCore.getBActivityManager().onActivityDestroyed((IBinder) objArr[0]);
            return method.invoke(obj, objArr);
        }
    }

    /* compiled from: AAA */
    @ProxyMethod("activityResumed")
    /* loaded from: classes.dex */
    public static class ActivityResumed extends MethodHook {
        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            BlackBoxCore.getBActivityManager().onActivityResumed((IBinder) objArr[0]);
            return method.invoke(obj, objArr);
        }
    }

    /* compiled from: AAA */
    @ProxyMethod("finishActivity")
    /* loaded from: classes.dex */
    public static class FinishActivity extends MethodHook {
        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            BlackBoxCore.getBActivityManager().onFinishActivity((IBinder) objArr[0]);
            return method.invoke(obj, objArr);
        }
    }

    /* compiled from: AAA */
    @ProxyMethod("getAppTasks")
    /* loaded from: classes.dex */
    public static class GetAppTasks extends MethodHook {
        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            MethodParameterUtils.replaceFirstAppPkg(objArr);
            return method.invoke(obj, objArr);
        }
    }

    /* compiled from: AAA */
    @ProxyMethod("startActivities")
    /* loaded from: classes.dex */
    public static class StartActivities extends MethodHook {
        public int getIntents() {
            return BuildCompat.isR() ? 3 : 2;
        }

        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            int intents = getIntents();
            int i2 = intents + 1;
            Intent[] intentArr = (Intent[]) objArr[intents];
            int i3 = i2 + 1;
            String[] strArr = (String[]) objArr[i2];
            IBinder iBinder = (IBinder) objArr[i3];
            Bundle bundle = (Bundle) objArr[i3 + 1];
            if (!ComponentUtils.isSelf(intentArr)) {
                return method.invoke(obj, objArr);
            }
            for (Intent intent : intentArr) {
                intent.setExtrasClassLoader(obj.getClass().getClassLoader());
            }
            return Integer.valueOf(BlackBoxCore.getBActivityManager().startActivities(BActivityThread.getUserId(), intentArr, strArr, iBinder, bundle));
        }
    }

    /* compiled from: AAA */
    @ProxyMethod("startActivity")
    /* loaded from: classes.dex */
    public static class StartActivity extends MethodHook {
        public static final /* synthetic */ boolean $assertionsDisabled = false;

        private Intent getIntent(Object[] objArr) {
            char c2 = BuildCompat.isR() ? (char) 3 : (char) 2;
            if (objArr[c2] instanceof Intent) {
                return (Intent) objArr[c2];
            }
            for (Object obj : objArr) {
                if (obj instanceof Intent) {
                    return (Intent) obj;
                }
            }
            return null;
        }

        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            MethodParameterUtils.replaceFirstAppPkg(objArr);
            Intent intent = getIntent(objArr);
            Slog.d(ActivityManagerCommonProxy.TAG, "Hook in : " + intent);
            if (intent.getParcelableExtra("_B_|_target_") != null) {
                Slog.d(ActivityManagerCommonProxy.TAG, "Hook in1 : " + intent);
                return method.invoke(obj, objArr);
            } else if (ComponentUtils.isRequestInstall(intent)) {
                if (BlackBoxCore.get().requestInstallPackage(FileProviderHandler.convertFile(BActivityThread.getApplication(), intent.getData()))) {
                    Slog.d(ActivityManagerCommonProxy.TAG, "Hook in2 : " + intent);
                    return 0;
                }
                intent.setData(FileProviderHandler.convertFileUri(BActivityThread.getApplication(), intent.getData()));
                Slog.d(ActivityManagerCommonProxy.TAG, "Hook in3 : " + intent);
                return method.invoke(obj, objArr);
            } else {
                String dataString = intent.getDataString();
                if (dataString != null) {
                    if (dataString.equals("package:" + BActivityThread.getAppPackageName())) {
                        Slog.d(ActivityManagerCommonProxy.TAG, "Hook in6 : " + dataString);
                        intent.setData(Uri.parse("package:" + BlackBoxCore.getHostPkg()));
                    }
                }
                ResolveInfo resolveActivity = BlackBoxCore.getBPackageManager().resolveActivity(intent, 128, StartActivityCompat.getResolvedType(objArr), BActivityThread.getUserId());
                if (resolveActivity == null) {
                    String str = intent.getPackage();
                    if (intent.getPackage() == null && intent.getComponent() == null) {
                        Slog.d(ActivityManagerCommonProxy.TAG, "Hook in7 : " + BActivityThread.getAppPackageName());
                        intent.setPackage(BActivityThread.getAppPackageName());
                    } else {
                        str = intent.getPackage();
                    }
                    ResolveInfo resolveActivity2 = BlackBoxCore.getBPackageManager().resolveActivity(intent, 128, StartActivityCompat.getResolvedType(objArr), BActivityThread.getUserId());
                    if (resolveActivity2 == null) {
                        if ("com.taptap.sdk.action".equals(intent.getAction())) {
                            intent.setPackage(BActivityThread.getAppPackageName());
                        } else {
                            intent.setPackage(str);
                        }
                        Slog.d(ActivityManagerCommonProxy.TAG, "Hook in4 : " + intent);
                        return method.invoke(obj, objArr);
                    }
                    resolveActivity = resolveActivity2;
                }
                intent.setExtrasClassLoader(obj.getClass().getClassLoader());
                ActivityInfo activityInfo = resolveActivity.activityInfo;
                intent.setComponent(new ComponentName(activityInfo.packageName, activityInfo.name));
                BlackBoxCore.getBActivityManager().startActivityAms(BActivityThread.getUserId(), StartActivityCompat.getIntent(objArr), StartActivityCompat.getResolvedType(objArr), StartActivityCompat.getResultTo(objArr), StartActivityCompat.getResultWho(objArr), StartActivityCompat.getRequestCode(objArr), StartActivityCompat.getFlags(objArr), StartActivityCompat.getOptions(objArr));
                Slog.d(ActivityManagerCommonProxy.TAG, "Hook in5 : " + intent.getPackage() + " , " + intent.getAction() + " , " + intent.getScheme() + " , " + intent.getComponent());
                return 0;
            }
        }
    }

    /* compiled from: AAA */
    @ProxyMethod("startIntentSenderForResult")
    /* loaded from: classes.dex */
    public static class StartIntentSenderForResult extends MethodHook {
        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            return method.invoke(obj, objArr);
        }
    }

    /* compiled from: AAA */
    @ProxyMethod("getCallingActivity")
    /* loaded from: classes.dex */
    public static class getCallingActivity extends MethodHook {
        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            return BlackBoxCore.getBActivityManager().getCallingActivity((IBinder) objArr[0], BActivityThread.getUserId());
        }
    }

    /* compiled from: AAA */
    @ProxyMethod("getCallingPackage")
    /* loaded from: classes.dex */
    public static class getCallingPackage extends MethodHook {
        @Override // chongya.haiwai.sandbox.f.hook.MethodHook
        public Object hook(Object obj, Method method, Object[] objArr) throws Throwable {
            return BlackBoxCore.getBActivityManager().getCallingPackage((IBinder) objArr[0], BActivityThread.getUserId());
        }
    }
}
