package chongya.haiwai.sandbox.f.service;

import android.content.ComponentName;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.ServiceInfo;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import androidx.annotation.NonNull;
import chongya.haiwai.sandbox.BlackBoxCore;
import chongya.haiwai.sandbox.a.BActivityThread;
import chongya.haiwai.sandbox.f.hook.IInjectHook;
import chongya.haiwai.sandbox.hook.HookManifest;
import chongya.haiwai.sandbox.hook.record.ProxyActivityRecord;
import chongya.haiwai.sandbox.utils.Slog;
import chongya.haiwai.sandbox.utils.compat.BuildCompat;
import java.lang.reflect.Proxy;
import java.util.concurrent.atomic.AtomicBoolean;
import joke.android.app.ActivityThreadActivityClientRecordContext;
import joke.android.app.BRActivityClient;
import joke.android.app.BRActivityClientActivityClientControllerSingleton;
import joke.android.app.BRActivityManagerNative;
import joke.android.app.BRActivityThread;
import joke.android.app.BRActivityThreadActivityClientRecord;
import joke.android.app.BRActivityThreadCreateServiceData;
import joke.android.app.BRActivityThreadH;
import joke.android.app.BRIActivityManager;
import joke.android.app.servertransaction.BRClientTransaction;
import joke.android.app.servertransaction.BRLaunchActivityItem;
import joke.android.app.servertransaction.LaunchActivityItemContext;
import joke.android.os.BRHandler;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class HCallbackProxy implements IInjectHook, Handler.Callback {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final String TAG = "HCallbackStub";
    public AtomicBoolean mBeing = new AtomicBoolean(false);
    public Handler.Callback mOtherCallback;

    private void checkActivityClient() {
        try {
            Object activityClientController = BRActivityClient.get().getActivityClientController();
            if (activityClientController instanceof Proxy) {
                return;
            }
            IActivityClientProxy iActivityClientProxy = new IActivityClientProxy(activityClientController);
            iActivityClientProxy.onlyProxy(true);
            iActivityClientProxy.injectHook();
            BRActivityClientActivityClientControllerSingleton.get(BRActivityClient.get(BRActivityClient.get().getInstance()).INTERFACE_SINGLETON())._set_mKnownInstance(iActivityClientProxy.getProxyInvocation());
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private Handler getH() {
        return BRActivityThread.get(BlackBoxCore.mainThread()).mH();
    }

    private Handler.Callback getHCallback() {
        return BRHandler.get(getH()).mCallback();
    }

    private Object getLaunchActivityItem(Object obj) {
        for (Object obj2 : BRClientTransaction.get(obj).mActivityCallbacks()) {
            if (BRLaunchActivityItem.getRealClass().getName().equals(obj2.getClass().getCanonicalName())) {
                return obj2;
            }
        }
        return null;
    }

    private boolean handleCreateService(Object obj) {
        if (BActivityThread.getAppConfig() != null) {
            String appPackageName = BActivityThread.getAppPackageName();
            ServiceInfo info = BRActivityThreadCreateServiceData.get(obj).info();
            if (!info.name.equals(HookManifest.getProxyService(BActivityThread.getAppPid())) && !info.name.equals(HookManifest.getProxyJobService(BActivityThread.getAppPid()))) {
                Slog.d(TAG, "handleCreateService: " + obj);
                Intent intent = new Intent();
                intent.setComponent(new ComponentName(appPackageName, info.name));
                BlackBoxCore.getBActivityManager().startService(intent, null, false, BActivityThread.getUserId());
                return true;
            }
        }
        return false;
    }

    private boolean handleLaunchActivity(Object obj) {
        Intent intent;
        IBinder iBinder;
        ProxyActivityRecord create;
        ActivityInfo activityInfo;
        Object launchActivityItem = BuildCompat.isPie() ? getLaunchActivityItem(obj) : obj;
        if (launchActivityItem == null) {
            return false;
        }
        if (BuildCompat.isPie()) {
            intent = BRLaunchActivityItem.get(launchActivityItem).mIntent();
            iBinder = BRClientTransaction.get(obj).mActivityToken();
        } else {
            ActivityThreadActivityClientRecordContext activityThreadActivityClientRecordContext = BRActivityThreadActivityClientRecord.get(launchActivityItem);
            intent = activityThreadActivityClientRecordContext.intent();
            iBinder = activityThreadActivityClientRecordContext.token();
        }
        if (intent != null && (activityInfo = (create = ProxyActivityRecord.create(intent)).mActivityInfo) != null) {
            if (BActivityThread.getAppConfig() == null) {
                BlackBoxCore.getBActivityManager().restartProcess(activityInfo.packageName, activityInfo.processName, create.mUserId);
                Intent launchIntentForPackage = BlackBoxCore.getBPackageManager().getLaunchIntentForPackage(activityInfo.packageName, create.mUserId);
                intent.setExtrasClassLoader(HCallbackProxy.class.getClassLoader());
                ProxyActivityRecord.saveStub(intent, launchIntentForPackage, create.mActivityInfo, create.mActivityRecord, create.mUserId);
                if (BuildCompat.isPie()) {
                    LaunchActivityItemContext launchActivityItemContext = BRLaunchActivityItem.get(launchActivityItem);
                    launchActivityItemContext._set_mIntent(intent);
                    launchActivityItemContext._set_mInfo(activityInfo);
                } else {
                    ActivityThreadActivityClientRecordContext activityThreadActivityClientRecordContext2 = BRActivityThreadActivityClientRecord.get(launchActivityItem);
                    activityThreadActivityClientRecordContext2._set_intent(intent);
                    activityThreadActivityClientRecordContext2._set_activityInfo(activityInfo);
                }
                return true;
            } else if (!BActivityThread.currentActivityThread().isInit()) {
                BActivityThread.currentActivityThread().bindApplication(activityInfo.packageName, activityInfo.processName);
                return true;
            } else {
                BlackBoxCore.getBActivityManager().onActivityCreated(BRIActivityManager.get(BRActivityManagerNative.get().getDefault()).getTaskForActivity(iBinder, false).intValue(), iBinder, create.mActivityRecord);
                if (BuildCompat.isT()) {
                    LaunchActivityItemContext launchActivityItemContext2 = BRLaunchActivityItem.get(launchActivityItem);
                    launchActivityItemContext2._set_mIntent(create.mTarget);
                    launchActivityItemContext2._set_mInfo(activityInfo);
                    checkActivityClient();
                } else if (BuildCompat.isS()) {
                    ActivityThreadActivityClientRecordContext activityThreadActivityClientRecordContext3 = BRActivityThreadActivityClientRecord.get(BRActivityThread.get(BlackBoxCore.mainThread()).getLaunchingActivity(iBinder));
                    activityThreadActivityClientRecordContext3._set_intent(create.mTarget);
                    activityThreadActivityClientRecordContext3._set_activityInfo(activityInfo);
                    activityThreadActivityClientRecordContext3._set_packageInfo(BActivityThread.currentActivityThread().getPackageInfo());
                    checkActivityClient();
                } else if (BuildCompat.isPie()) {
                    LaunchActivityItemContext launchActivityItemContext3 = BRLaunchActivityItem.get(launchActivityItem);
                    launchActivityItemContext3._set_mIntent(create.mTarget);
                    launchActivityItemContext3._set_mInfo(activityInfo);
                } else {
                    ActivityThreadActivityClientRecordContext activityThreadActivityClientRecordContext4 = BRActivityThreadActivityClientRecord.get(launchActivityItem);
                    activityThreadActivityClientRecordContext4._set_intent(create.mTarget);
                    activityThreadActivityClientRecordContext4._set_activityInfo(activityInfo);
                }
            }
        }
        return false;
    }

    /* JADX WARN: Removed duplicated region for block: B:20:0x006d A[Catch: all -> 0x008a, TRY_LEAVE, TryCatch #0 {all -> 0x008a, blocks: (B:4:0x000a, B:6:0x0010, B:8:0x0020, B:10:0x0028, B:18:0x005d, B:20:0x006d, B:23:0x0079, B:25:0x007d, B:13:0x0039, B:15:0x0049, B:17:0x0051), top: B:33:0x000a }] */
    /* JADX WARN: Removed duplicated region for block: B:23:0x0079 A[Catch: all -> 0x008a, TRY_ENTER, TryCatch #0 {all -> 0x008a, blocks: (B:4:0x000a, B:6:0x0010, B:8:0x0020, B:10:0x0028, B:18:0x005d, B:20:0x006d, B:23:0x0079, B:25:0x007d, B:13:0x0039, B:15:0x0049, B:17:0x0051), top: B:33:0x000a }] */
    @Override // android.os.Handler.Callback
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean handleMessage(@NonNull Message message) {
        boolean handleMessage;
        if (this.mBeing.getAndSet(true)) {
            return false;
        }
        try {
            if (BuildCompat.isPie()) {
                if (message.what == BRActivityThreadH.get().EXECUTE_TRANSACTION().intValue() && handleLaunchActivity(message.obj)) {
                    getH().sendMessageAtFrontOfQueue(Message.obtain(message));
                    return true;
                }
                if (message.what != BRActivityThreadH.get().CREATE_SERVICE().intValue()) {
                    handleMessage = handleCreateService(message.obj);
                } else if (this.mOtherCallback == null) {
                    return false;
                } else {
                    handleMessage = this.mOtherCallback.handleMessage(message);
                }
                return handleMessage;
            }
            if (message.what == BRActivityThreadH.get().LAUNCH_ACTIVITY().intValue() && handleLaunchActivity(message.obj)) {
                getH().sendMessageAtFrontOfQueue(Message.obtain(message));
                return true;
            }
            if (message.what != BRActivityThreadH.get().CREATE_SERVICE().intValue()) {
            }
            return handleMessage;
        } finally {
            this.mBeing.set(false);
        }
    }

    @Override // chongya.haiwai.sandbox.f.hook.IInjectHook
    public void injectHook() {
        Handler.Callback hCallback = getHCallback();
        this.mOtherCallback = hCallback;
        if (hCallback != null && (hCallback == this || hCallback.getClass().getName().equals(HCallbackProxy.class.getName()))) {
            this.mOtherCallback = null;
        }
        BRHandler.get(getH())._set_mCallback(this);
    }

    @Override // chongya.haiwai.sandbox.f.hook.IInjectHook
    public boolean isBadEnv() {
        Handler.Callback hCallback = getHCallback();
        return (hCallback == null || hCallback == this) ? false : true;
    }
}
