package chongya.haiwai.sandbox.utils;

import android.content.ComponentName;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.ComponentInfo;
import android.content.pm.ProviderInfo;
import android.os.Build;
import chongya.haiwai.sandbox.BlackBoxCore;
import chongya.haiwai.sandbox.a.BActivityThread;
import chongya.haiwai.sandbox.d.system.user.BUserHandle;
import chongya.haiwai.sandbox.hook.HookNewPendingActivity;
import chongya.haiwai.sandbox.utils.compat.IntentCompat;
import com.ss.android.downloadad.api.constant.AdBaseConstants;
import com.ss.android.socialbase.downloader.utils.DownloadExpSwitchCode;
import java.util.Objects;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class ComponentUtils {
    public static void clearVAData(Intent intent) {
        if (intent.hasExtra("_VA_|_intent_")) {
            intent.removeExtra("_VA_|_intent_");
        }
        if (intent.hasExtra("_VA_|_userId_")) {
            intent.removeExtra("_VA_|_userId_");
        }
    }

    public static String getFirstAuthority(ProviderInfo providerInfo) {
        if (providerInfo == null) {
            return null;
        }
        String[] split = providerInfo.authority.split(";");
        return split.length == 0 ? providerInfo.authority : split[0];
    }

    public static Intent getIntentForIntentSender(Intent intent) {
        return (Intent) intent.getParcelableExtra("_VA_|_intent_");
    }

    public static String getProcessName(ComponentInfo componentInfo) {
        String str = componentInfo.processName;
        if (str == null) {
            String str2 = componentInfo.packageName;
            componentInfo.processName = str2;
            return str2;
        }
        return str;
    }

    public static String getTaskAffinity(ActivityInfo activityInfo) {
        if (activityInfo.launchMode == 3) {
            return "-SingleInstance-" + activityInfo.packageName + "/" + activityInfo.name;
        } else if (activityInfo.taskAffinity == null && activityInfo.applicationInfo.taskAffinity == null) {
            return activityInfo.packageName;
        } else {
            String str = activityInfo.taskAffinity;
            return str != null ? str : activityInfo.applicationInfo.taskAffinity;
        }
    }

    public static int getUserIdForIntentSender(Intent intent) {
        return intent.getIntExtra("_VA_|_userId_", -1);
    }

    public static boolean intentFilterEquals(Intent intent, Intent intent2) {
        if (intent == null || intent2 == null) {
            return true;
        }
        if (Objects.equals(intent.getAction(), intent2.getAction()) && Objects.equals(intent.getData(), intent2.getData()) && Objects.equals(intent.getType(), intent2.getType())) {
            String str = intent.getPackage();
            if (str == null && intent.getComponent() != null) {
                str = intent.getComponent().getPackageName();
            }
            String str2 = intent2.getPackage();
            if (str2 == null && intent2.getComponent() != null) {
                str2 = intent2.getComponent().getPackageName();
            }
            return Objects.equals(str, str2) && Objects.equals(intent.getComponent(), intent2.getComponent()) && Objects.equals(intent.getCategories(), intent2.getCategories());
        }
        return false;
    }

    public static boolean isRequestInstall(Intent intent) {
        return AdBaseConstants.MIME_APK.equals(intent.getType());
    }

    public static boolean isSameComponent(ComponentInfo componentInfo, ComponentInfo componentInfo2) {
        if (componentInfo == null || componentInfo2 == null) {
            return false;
        }
        String str = componentInfo.packageName + "";
        String str2 = componentInfo2.packageName + "";
        String str3 = componentInfo.name + "";
        StringBuilder sb = new StringBuilder();
        sb.append(componentInfo2.name);
        sb.append("");
        return str.equals(str2) && str3.equals(sb.toString());
    }

    public static boolean isSelf(Intent intent) {
        ComponentName component = intent.getComponent();
        if (component == null || BActivityThread.getAppPackageName() == null) {
            return false;
        }
        return component.getPackageName().equals(BActivityThread.getAppPackageName());
    }

    public static Intent redirectIntentSender(int i2, String str, Intent intent) {
        if (i2 == 3) {
            return null;
        }
        Intent intent2 = new Intent();
        intent2.setSourceBounds(intent.getSourceBounds());
        if (Build.VERSION.SDK_INT >= 16) {
            intent2.setClipData(intent.getClipData());
        }
        intent2.addFlags(intent.getFlags() & IntentCompat.IMMUTABLE_FLAGS);
        String type = intent2.getType();
        ComponentName component = intent2.getComponent();
        if (type != null) {
            str = type + ":" + str;
        }
        if (component != null) {
            str = str + ":" + component.flattenToString();
        }
        if (intent.getAction() != null) {
            intent2.setAction(intent.getAction());
        }
        if (intent.getCategories() != null) {
            for (String str2 : intent.getCategories()) {
                intent2.addCategory(str2);
            }
        }
        intent2.setDataAndType(intent.getData(), str);
        String hostPkg = BlackBoxCore.getHostPkg();
        if (i2 != 2) {
            return null;
        }
        intent2.addFlags(DownloadExpSwitchCode.BUGFIX_GETPACKAGEINFO_BY_UNZIP);
        intent2.setClassName(hostPkg, HookNewPendingActivity.class.getName());
        intent2.putExtra("_VA_|_intent_", intent);
        intent2.putExtra("_VA_|_userId_", BUserHandle.myUserId());
        return intent2;
    }

    public static ComponentName toComponentName(ComponentInfo componentInfo) {
        return new ComponentName(componentInfo.packageName, componentInfo.name);
    }

    public static boolean isSelf(Intent[] intentArr) {
        for (Intent intent : intentArr) {
            if (!isSelf(intent)) {
                return false;
            }
        }
        return true;
    }
}
