package chongya.haiwai.sandbox.utils;

import e.b.a.a.f.b;
import java.io.PrintStream;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import okhttp3.HttpUrl;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class ReflectionClass {
    public static void print(String str) {
        try {
            Class<?> cls = Class.forName(str);
            Class<? super Object> superclass = cls.getSuperclass();
            Class<?>[] interfaces = cls.getInterfaces();
            String modifier = Modifier.toString(cls.getModifiers());
            if (modifier.length() > 0) {
                System.out.print(modifier);
            }
            if (!cls.isInterface()) {
                System.out.print(" class ");
            }
            printType(cls);
            if (superclass != null && superclass != Object.class) {
                System.out.print(" extends ");
                printType(superclass);
            }
            if (interfaces.length > 0) {
                System.out.print(" implements ");
                for (int i2 = 0; i2 < interfaces.length; i2++) {
                    if (i2 > 0) {
                        System.out.print(", ");
                    }
                    printType(interfaces[i2]);
                }
            }
            System.out.print(" {\n");
            printConstructors(cls);
            System.out.println();
            printMethods(cls);
            System.out.println();
            printFields(cls);
            System.out.println("}");
            printExtendsChain(cls);
        } catch (ClassNotFoundException e2) {
            e2.printStackTrace();
        }
    }

    public static void printConstructors(Class cls) {
        Constructor<?>[] declaredConstructors;
        for (Constructor<?> constructor : cls.getDeclaredConstructors()) {
            String name = constructor.getName();
            System.out.print("    ");
            String modifier = Modifier.toString(constructor.getModifiers());
            if (modifier.length() > 0) {
                System.out.print(modifier + " ");
            }
            System.out.print(name.substring(name.lastIndexOf(b.DOT) + 1) + " (");
            Class<?>[] parameterTypes = constructor.getParameterTypes();
            for (int i2 = 0; i2 < parameterTypes.length; i2++) {
                if (i2 > 0) {
                    System.out.print(", ");
                }
                printType(parameterTypes[i2]);
            }
            System.out.print(")");
            Class<?>[] exceptionTypes = constructor.getExceptionTypes();
            if (exceptionTypes.length > 0) {
                System.out.print(" throws ");
                for (int i3 = 0; i3 < exceptionTypes.length; i3++) {
                    if (i3 > 0) {
                        System.out.print(", ");
                    }
                    printType(exceptionTypes[i3]);
                }
            }
            System.out.println(";");
        }
    }

    public static void printExtendsChain(Class cls) {
        System.out.print("\n\nExtends chain:\n    ");
        printType(cls);
        Class superclass = cls.getSuperclass();
        while (superclass != Object.class) {
            System.out.print(" --> ");
            printType(superclass);
            superclass = superclass.getSuperclass();
        }
        System.out.print(" --> ");
        printType(superclass);
    }

    public static void printFields(Class cls) {
        Field[] declaredFields;
        for (Field field : cls.getDeclaredFields()) {
            Class<?> type = field.getType();
            String name = field.getName();
            System.out.print("    ");
            String modifier = Modifier.toString(field.getModifiers());
            if (modifier.length() > 0) {
                System.out.print(modifier + " ");
            }
            printType(type);
            System.out.println(" " + name + ";");
        }
    }

    public static void printMethods(Class cls) {
        Method[] declaredMethods;
        for (Method method : cls.getDeclaredMethods()) {
            Class<?> returnType = method.getReturnType();
            String name = method.getName();
            System.out.print("    ");
            String modifier = Modifier.toString(method.getModifiers());
            if (modifier.length() > 0) {
                System.out.print(modifier + " ");
            }
            printType(returnType);
            System.out.print(" " + name + "(");
            Class<?>[] parameterTypes = method.getParameterTypes();
            for (int i2 = 0; i2 < parameterTypes.length; i2++) {
                if (i2 > 0) {
                    System.out.print(", ");
                }
                printType(parameterTypes[i2]);
            }
            System.out.print(")");
            Class<?>[] exceptionTypes = method.getExceptionTypes();
            if (exceptionTypes.length > 0) {
                System.out.print(" throws ");
                for (int i3 = 0; i3 < exceptionTypes.length; i3++) {
                    if (i3 > 0) {
                        System.out.print(", ");
                    }
                    printType(exceptionTypes[i3]);
                }
            }
            System.out.println(";");
        }
    }

    public static void printType(Class cls) {
        String name = cls.getName();
        if (name.startsWith("[")) {
            if (name.startsWith("[C")) {
                System.out.print("char[]");
                return;
            } else if (name.startsWith("[B")) {
                System.out.print("byte[]");
                return;
            } else if (name.startsWith("[S")) {
                System.out.print("short[]");
                return;
            } else if (name.startsWith("[I")) {
                System.out.print("int[]");
                return;
            } else if (name.startsWith("[J")) {
                System.out.print("long[]");
                return;
            } else if (name.startsWith("[F")) {
                System.out.print("float[]");
                return;
            } else if (name.startsWith("[D")) {
                System.out.print("double[]");
                return;
            } else if (name.startsWith("[Z")) {
                System.out.print("boolean[]");
                return;
            } else if (name.startsWith("[L")) {
                PrintStream printStream = System.out;
                printStream.print(name.substring(name.lastIndexOf(b.DOT) + 1, name.length() - 1) + HttpUrl.PATH_SEGMENT_ENCODE_SET_URI);
                return;
            } else {
                return;
            }
        }
        System.out.print(name.substring(name.lastIndexOf(b.DOT) + 1));
    }
}
