package chongya.haiwai.sandbox.utils;

import java.util.LinkedList;
import java.util.List;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class TrieTree {
    public final TrieNode root = new TrieNode();

    public void add(String str) {
        TrieNode trieNode = this.root;
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            sb.append(charAt);
            TrieNode trieNode2 = new TrieNode(charAt, sb.toString());
            if (trieNode.children.contains(trieNode2)) {
                trieNode = trieNode.nextNode(charAt);
            } else {
                trieNode.children.add(trieNode2);
                trieNode = trieNode2;
            }
            if (i2 == str.length() - 1) {
                trieNode.isEnd = true;
            }
        }
    }

    public void addAll(List<String> list) {
        for (String str : list) {
            add(str);
        }
    }

    public String search(String str) {
        TrieNode trieNode = this.root;
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            if (!trieNode.children.contains(new TrieNode(charAt, null))) {
                break;
            }
            trieNode = trieNode.nextNode(charAt);
            if (trieNode.isEnd) {
                return trieNode.word;
            }
        }
        return null;
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public static class TrieNode {
        public char content;
        public String word;
        public boolean isEnd = false;
        public List<TrieNode> children = new LinkedList();

        public TrieNode() {
        }

        public boolean equals(Object obj) {
            return (obj instanceof TrieNode) && ((TrieNode) obj).content == this.content;
        }

        public TrieNode nextNode(char c2) {
            for (TrieNode trieNode : this.children) {
                if (trieNode.content == c2) {
                    return trieNode;
                }
            }
            return null;
        }

        public TrieNode(char c2, String str) {
            this.content = c2;
            this.word = str;
        }
    }
}
