package chongya.haiwai.sandbox.utils.compat;

import android.os.Build;
import com.google.android.material.internal.ManufacturerUtils;
import com.joke.chongya.sandbox.utils.RomUtil;
import e.f.a.h0;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class BuildCompat {
    public static final String HARMONY_OS = "harmony";
    public static int harmonyOS = -1;
    public static ROMType sRomType;

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public enum ROMType {
        EMUI,
        MIUI,
        FLYME,
        COLOR_OS,
        LETV,
        VIVO,
        _360,
        SAMSUNG,
        OTHER
    }

    public static int getPreviewSDKInt() {
        if (Build.VERSION.SDK_INT >= 23) {
            try {
                return Build.VERSION.PREVIEW_SDK_INT;
            } catch (Throwable unused) {
                return 0;
            }
        }
        return 0;
    }

    public static ROMType getROMType() {
        if (sRomType == null) {
            if (isEMUI()) {
                sRomType = ROMType.EMUI;
            } else if (isMIUI()) {
                sRomType = ROMType.MIUI;
            } else if (isFlyme()) {
                sRomType = ROMType.FLYME;
            } else if (isColorOS()) {
                sRomType = ROMType.COLOR_OS;
            } else if (is360UI()) {
                sRomType = ROMType._360;
            } else if (isLetv()) {
                sRomType = ROMType.LETV;
            } else if (isVivo()) {
                sRomType = ROMType.VIVO;
            } else if (isSamsung()) {
                sRomType = ROMType.SAMSUNG;
            } else {
                sRomType = ROMType.OTHER;
            }
        }
        return sRomType;
    }

    public static boolean is360UI() {
        String str = SystemPropertiesCompat.get(h0.VERSION_PROPERTY_360);
        return str != null && str.toUpperCase().contains("360UI");
    }

    public static boolean isColorOS() {
        return SystemPropertiesCompat.isExist("ro.build.version.opporom") || SystemPropertiesCompat.isExist("ro.rom.different.version");
    }

    public static boolean isEMUI() {
        if (Build.DISPLAY.toUpperCase().startsWith("EMUI")) {
            return true;
        }
        String str = SystemPropertiesCompat.get("ro.build.version.emui");
        return str != null && str.contains("EmotionUI");
    }

    public static boolean isFlyme() {
        return Build.DISPLAY.toLowerCase().contains(RomUtil.RomConstant.MEIZU);
    }

    public static boolean isHarmonyOS() {
        int i2 = harmonyOS;
        if (i2 != -1) {
            return i2 != 0;
        }
        try {
            Class<?> cls = Class.forName("com.huawei.system.BuildEx");
            int i3 = HARMONY_OS.equals(cls.getMethod("getOsBrand", new Class[0]).invoke(cls, new Object[0])) ? 1 : 0;
            harmonyOS = i3;
            return i3 == 1;
        } catch (ClassNotFoundException | NoSuchMethodException | Exception unused) {
            harmonyOS = 0;
            return false;
        }
    }

    public static boolean isL() {
        return Build.VERSION.SDK_INT >= 21;
    }

    public static boolean isLetv() {
        return Build.MANUFACTURER.equalsIgnoreCase("Letv");
    }

    public static boolean isM() {
        return Build.VERSION.SDK_INT >= 23;
    }

    public static boolean isMIUI() {
        return SystemPropertiesCompat.getInt("ro.miui.ui.version.code", 0) > 0;
    }

    public static boolean isN() {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 < 24) {
            return i2 >= 23 && Build.VERSION.PREVIEW_SDK_INT == 1;
        }
        return true;
    }

    public static boolean isN_MR1() {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 < 25) {
            return i2 >= 24 && Build.VERSION.PREVIEW_SDK_INT == 1;
        }
        return true;
    }

    public static boolean isOreo() {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 < 26) {
            return i2 >= 25 && Build.VERSION.PREVIEW_SDK_INT == 1;
        }
        return true;
    }

    public static boolean isPie() {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 < 28) {
            return i2 >= 27 && Build.VERSION.PREVIEW_SDK_INT == 1;
        }
        return true;
    }

    public static boolean isQ() {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 < 29) {
            return i2 >= 28 && Build.VERSION.PREVIEW_SDK_INT == 1;
        }
        return true;
    }

    public static boolean isR() {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 < 30) {
            return i2 >= 29 && Build.VERSION.PREVIEW_SDK_INT == 1;
        }
        return true;
    }

    public static boolean isS() {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 < 31) {
            return i2 >= 30 && Build.VERSION.PREVIEW_SDK_INT == 1;
        }
        return true;
    }

    public static boolean isSamsung() {
        return ManufacturerUtils.SAMSUNG.equalsIgnoreCase(Build.BRAND) || ManufacturerUtils.SAMSUNG.equalsIgnoreCase(Build.MANUFACTURER);
    }

    public static boolean isT() {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 < 33) {
            return i2 >= 32 && Build.VERSION.PREVIEW_SDK_INT == 1;
        }
        return true;
    }

    public static boolean isVivo() {
        return SystemPropertiesCompat.isExist(h0.VERSION_PROPERTY_VIVO);
    }
}
