package chongya.haiwai.sandbox.utils.compat;

import android.content.ContentProviderClient;
import android.content.Context;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.RemoteException;
import android.os.SystemClock;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class ContentProviderCompat {
    public static ContentProviderClient acquireContentProviderClient(Context context, Uri uri) {
        try {
            if (Build.VERSION.SDK_INT >= 16) {
                return context.getContentResolver().acquireUnstableContentProviderClient(uri);
            }
            return context.getContentResolver().acquireContentProviderClient(uri);
        } catch (SecurityException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public static ContentProviderClient acquireContentProviderClientRetry(Context context, Uri uri, int i2) {
        ContentProviderClient acquireContentProviderClient = acquireContentProviderClient(context, uri);
        if (acquireContentProviderClient == null) {
            int i3 = 0;
            while (i3 < i2 && acquireContentProviderClient == null) {
                SystemClock.sleep(400L);
                i3++;
                acquireContentProviderClient = acquireContentProviderClient(context, uri);
            }
        }
        return acquireContentProviderClient;
    }

    public static Bundle call(Context context, Uri uri, String str, String str2, Bundle bundle, int i2) throws IllegalAccessException {
        if (Build.VERSION.SDK_INT < 17) {
            return context.getContentResolver().call(uri, str, str2, bundle);
        }
        ContentProviderClient acquireContentProviderClientRetry = acquireContentProviderClientRetry(context, uri, i2);
        try {
            try {
                if (acquireContentProviderClientRetry != null) {
                    return acquireContentProviderClientRetry.call(str, str2, bundle);
                }
                throw new IllegalAccessException();
            } catch (RemoteException e2) {
                throw new IllegalAccessException(e2.getMessage());
            }
        } finally {
            releaseQuietly(acquireContentProviderClientRetry);
        }
    }

    public static void releaseQuietly(ContentProviderClient contentProviderClient) {
        if (contentProviderClient != null) {
            try {
                if (Build.VERSION.SDK_INT >= 24) {
                    contentProviderClient.close();
                } else {
                    contentProviderClient.release();
                }
            } catch (Exception unused) {
            }
        }
    }

    public static ContentProviderClient acquireContentProviderClientRetry(Context context, String str, int i2) {
        ContentProviderClient acquireContentProviderClient = acquireContentProviderClient(context, str);
        if (acquireContentProviderClient == null) {
            int i3 = 0;
            while (i3 < i2 && acquireContentProviderClient == null) {
                SystemClock.sleep(400L);
                i3++;
                acquireContentProviderClient = acquireContentProviderClient(context, str);
            }
        }
        return acquireContentProviderClient;
    }

    public static ContentProviderClient acquireContentProviderClient(Context context, String str) {
        if (Build.VERSION.SDK_INT >= 16) {
            return context.getContentResolver().acquireUnstableContentProviderClient(str);
        }
        return context.getContentResolver().acquireContentProviderClient(str);
    }
}
