package com.alibaba.sdk.android.oss.common.utils;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Build;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import android.util.Base64;
import android.webkit.MimeTypeMap;
import e.b.b.a.a.f.f;
import e.b.b.a.a.f.g.a;
import e.b.b.a.a.f.g.e;
import e.b.b.a.a.f.h.b;
import e.b.b.a.a.f.h.c;
import e.b.b.a.a.f.h.d;
import e.b.b.a.a.g.g;
import e.b.b.a.a.h.c0;
import e.b.b.a.a.h.e0;
import e.b.b.a.a.h.f0;
import e.b.b.a.a.h.i;
import e.b.b.a.a.h.k;
import e.b.b.a.a.h.p;
import e.b.b.a.a.h.x;
import j.y1.y;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import org.json.JSONObject;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class OSSUtils {
    public static final String NEW_LINE = "\n";
    public static final List<String> SIGNED_PARAMTERS = Arrays.asList(f.SUBRESOURCE_ACL, f.SUBRESOURCE_UPLOADS, f.SUBRESOURCE_LOCATION, f.SUBRESOURCE_CORS, f.SUBRESOURCE_LOGGING, f.SUBRESOURCE_WEBSITE, f.SUBRESOURCE_REFERER, f.SUBRESOURCE_LIFECYCLE, f.SUBRESOURCE_DELETE, f.SUBRESOURCE_APPEND, f.UPLOAD_ID, f.PART_NUMBER, f.SECURITY_TOKEN, f.POSITION, f.RESPONSE_HEADER_CACHE_CONTROL, f.RESPONSE_HEADER_CONTENT_DISPOSITION, f.RESPONSE_HEADER_CONTENT_ENCODING, f.RESPONSE_HEADER_CONTENT_LANGUAGE, f.RESPONSE_HEADER_CONTENT_TYPE, f.RESPONSE_HEADER_EXPIRES, f.X_OSS_PROCESS);

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public enum MetadataDirective {
        COPY("COPY"),
        REPLACE("REPLACE");
        
        public final String directiveAsString;

        MetadataDirective(String str) {
            this.directiveAsString = str;
        }

        @Override // java.lang.Enum
        public String toString() {
            return this.directiveAsString;
        }
    }

    public static void addDateHeader(Map<String, String> map, String str, Date date) {
        if (date != null) {
            map.put(str, b.formatRfc822Date(date));
        }
    }

    public static void addHeader(Map<String, String> map, String str, String str2) {
        if (str2 != null) {
            map.put(str, str2);
        }
    }

    public static void addStringListHeader(Map<String, String> map, String str, List<String> list) {
        if (list == null || list.isEmpty()) {
            return;
        }
        map.put(str, join(list));
    }

    public static void assertTrue(boolean z, String str) {
        if (!z) {
            throw new IllegalArgumentException(str);
        }
    }

    public static String buildBaseLogInfo(Context context) {
        StringBuilder sb = new StringBuilder();
        sb.append("=====[device info]=====\n");
        sb.append("[INFO]: android_version：" + Build.VERSION.RELEASE + "\n");
        sb.append("[INFO]: mobile_model：" + Build.MODEL + "\n");
        String operatorName = getOperatorName(context);
        if (!TextUtils.isEmpty(operatorName)) {
            sb.append("[INFO]: operator_name：" + operatorName + "\n");
        }
        NetworkInfo activeNetworkInfo = ((ConnectivityManager) context.getSystemService("connectivity")).getActiveNetworkInfo();
        String str = (activeNetworkInfo == null || activeNetworkInfo.getState() != NetworkInfo.State.CONNECTED) ? "unconnected" : "connected";
        sb.append("[INFO]: network_state：" + str + "\n");
        String typeName = activeNetworkInfo != null ? activeNetworkInfo.getTypeName() : "unknown";
        sb.append("[INFO]: network_type：" + typeName);
        return sb.toString();
    }

    public static String buildCanonicalString(g gVar) {
        StringBuilder sb = new StringBuilder();
        sb.append(gVar.getMethod().toString() + "\n");
        Map<String, String> headers = gVar.getHeaders();
        TreeMap treeMap = new TreeMap();
        if (headers != null) {
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                if (entry.getKey() != null) {
                    String lowerCase = entry.getKey().toLowerCase();
                    if (lowerCase.equals("Content-Type".toLowerCase()) || lowerCase.equals(c.CONTENT_MD5.toLowerCase()) || lowerCase.equals(c.DATE.toLowerCase()) || lowerCase.startsWith(e.b.b.a.a.f.c.OSS_PREFIX)) {
                        treeMap.put(lowerCase, entry.getValue().trim());
                    }
                }
            }
        }
        if (!treeMap.containsKey("Content-Type".toLowerCase())) {
            treeMap.put("Content-Type".toLowerCase(), "");
        }
        if (!treeMap.containsKey(c.CONTENT_MD5.toLowerCase())) {
            treeMap.put(c.CONTENT_MD5.toLowerCase(), "");
        }
        for (Map.Entry entry2 : treeMap.entrySet()) {
            String str = (String) entry2.getKey();
            Object value = entry2.getValue();
            if (str.startsWith(e.b.b.a.a.f.c.OSS_PREFIX)) {
                sb.append(str);
                sb.append(':');
                sb.append(value);
            } else {
                sb.append(value);
            }
            sb.append("\n");
        }
        sb.append(buildCanonicalizedResource(gVar.getBucketName(), gVar.getObjectKey(), gVar.getParameters()));
        return sb.toString();
    }

    public static String buildCanonicalizedResource(String str, String str2, Map<String, String> map) {
        String str3 = "/";
        if (str != null || str2 != null) {
            if (str2 == null) {
                str3 = "/" + str + "/";
            } else {
                str3 = "/" + str + "/" + str2;
            }
        }
        return buildCanonicalizedResource(str3, map);
    }

    public static String buildXMLFromPartEtagList(List<f0> list) {
        StringBuilder sb = new StringBuilder();
        sb.append("<CompleteMultipartUpload>\n");
        for (f0 f0Var : list) {
            sb.append("<Part>\n");
            sb.append("<PartNumber>" + f0Var.getPartNumber() + "</PartNumber>\n");
            sb.append("<ETag>" + f0Var.getETag() + "</ETag>\n");
            sb.append("</Part>\n");
        }
        sb.append("</CompleteMultipartUpload>\n");
        return sb.toString();
    }

    public static boolean checkParamRange(long j2, long j3, boolean z, long j4, boolean z2) {
        return (z && z2) ? j3 <= j2 && j2 <= j4 : (!z || z2) ? (z || z2) ? j3 < j2 && j2 <= j4 : j3 < j2 && j2 < j4 : j3 <= j2 && j2 < j4;
    }

    public static String determineContentType(String str, String str2, String str3) {
        String mimeTypeFromExtension;
        String mimeTypeFromExtension2;
        if (str != null) {
            return str;
        }
        MimeTypeMap singleton = MimeTypeMap.getSingleton();
        return (str2 == null || (mimeTypeFromExtension2 = singleton.getMimeTypeFromExtension(str2.substring(str2.lastIndexOf(46) + 1))) == null) ? (str3 == null || (mimeTypeFromExtension = singleton.getMimeTypeFromExtension(str3.substring(str3.lastIndexOf(46) + 1))) == null) ? e.b.b.a.a.f.b.DEFAULT_OBJECT_CONTENT_TYPE : mimeTypeFromExtension : mimeTypeFromExtension2;
    }

    public static boolean doesRequestNeedObjectKey(c0 c0Var) {
        return ((c0Var instanceof x) || (c0Var instanceof i) || (c0Var instanceof k) || (c0Var instanceof p)) ? false : true;
    }

    public static void ensureBucketNameValid(String str) {
        if (!validateBucketName(str)) {
            throw new IllegalArgumentException("The bucket name is invalid. \nA bucket name must: \n1) be comprised of lower-case characters, numbers or dash(-); \n2) start with lower case or numbers; \n3) be between 3-63 characters long. ");
        }
    }

    public static void ensureObjectKeyValid(String str) {
        if (!validateObjectKey(str)) {
            throw new IllegalArgumentException("The object key is invalid. \nAn object name should be: \n1) between 1 - 1023 bytes long when encoded as UTF-8 \n2) cannot contain LF or CR or unsupported chars in XML1.0, \n3) cannot begin with \"/\" or \"\\\".");
        }
    }

    public static void ensureRequestValid(c0 c0Var, g gVar) {
        ensureBucketNameValid(gVar.getBucketName());
        if (doesRequestNeedObjectKey(c0Var)) {
            ensureObjectKeyValid(gVar.getObjectKey());
        }
        if (c0Var instanceof e.b.b.a.a.h.g) {
            ensureObjectKeyValid(((e.b.b.a.a.h.g) c0Var).getDestinationKey());
        }
    }

    public static String getOperatorName(Context context) {
        String simOperator = ((TelephonyManager) context.getSystemService("phone")).getSimOperator();
        if (simOperator != null) {
            if (simOperator.equals("46000") || simOperator.equals("46002")) {
                return "CMCC";
            }
            if (simOperator.equals("46001")) {
                return "CUCC";
            }
            if (simOperator.equals("46003")) {
                return "CTCC";
            }
        }
        return "";
    }

    public static boolean isCname(String str) {
        for (String str2 : e.b.b.a.a.f.b.DEFAULT_CNAME_EXCLUDE_LIST) {
            if (str.toLowerCase().endsWith(str2)) {
                return false;
            }
        }
        return true;
    }

    public static boolean isEmptyString(String str) {
        return TextUtils.isEmpty(str);
    }

    public static boolean isInCustomCnameExcludeList(String str, List<String> list) {
        for (String str2 : list) {
            if (str.endsWith(str2.toLowerCase())) {
                return true;
            }
        }
        return false;
    }

    public static String join(List<String> list) {
        StringBuilder sb = new StringBuilder();
        boolean z = true;
        for (String str : list) {
            if (!z) {
                sb.append(", ");
            }
            sb.append(str);
            z = false;
        }
        return sb.toString();
    }

    public static String paramToQueryString(Map<String, String> map, String str) {
        if (map == null || map.isEmpty()) {
            return null;
        }
        StringBuilder sb = new StringBuilder();
        boolean z = true;
        for (Map.Entry<String, String> entry : map.entrySet()) {
            String key = entry.getKey();
            String value = entry.getValue();
            if (!z) {
                sb.append(e.h.a.j.g.e.b.PARAMETER_SEPARATOR);
            }
            sb.append(d.urlEncode(key, str));
            if (!isEmptyString(value)) {
                sb.append(e.h.a.j.g.e.b.NAME_VALUE_SEPARATOR);
                sb.append(d.urlEncode(value, str));
            }
            z = false;
        }
        return sb.toString();
    }

    public static void populateCopyObjectHeaders(e.b.b.a.a.h.g gVar, Map<String, String> map) {
        map.put(e.b.b.a.a.f.c.COPY_OBJECT_SOURCE, "/" + gVar.getSourceBucketName() + "/" + d.urlEncode(gVar.getSourceKey(), "utf-8"));
        addDateHeader(map, e.b.b.a.a.f.c.COPY_OBJECT_SOURCE_IF_MODIFIED_SINCE, gVar.getModifiedSinceConstraint());
        addDateHeader(map, e.b.b.a.a.f.c.COPY_OBJECT_SOURCE_IF_UNMODIFIED_SINCE, gVar.getUnmodifiedSinceConstraint());
        addStringListHeader(map, e.b.b.a.a.f.c.COPY_OBJECT_SOURCE_IF_MATCH, gVar.getMatchingETagConstraints());
        addStringListHeader(map, e.b.b.a.a.f.c.COPY_OBJECT_SOURCE_IF_NONE_MATCH, gVar.getNonmatchingEtagConstraints());
        addHeader(map, e.b.b.a.a.f.c.OSS_SERVER_SIDE_ENCRYPTION, gVar.getServerSideEncryption());
        e0 newObjectMetadata = gVar.getNewObjectMetadata();
        if (newObjectMetadata != null) {
            map.put(e.b.b.a.a.f.c.COPY_OBJECT_METADATA_DIRECTIVE, MetadataDirective.REPLACE.toString());
            populateRequestMetadata(map, newObjectMetadata);
        }
        removeHeader(map, "Content-Length");
    }

    public static void populateListObjectsRequestParameters(x xVar, Map<String, String> map) {
        if (xVar.getPrefix() != null) {
            map.put(f.PREFIX, xVar.getPrefix());
        }
        if (xVar.getMarker() != null) {
            map.put(f.MARKER, xVar.getMarker());
        }
        if (xVar.getDelimiter() != null) {
            map.put(f.DELIMITER, xVar.getDelimiter());
        }
        if (xVar.getMaxKeys() != null) {
            map.put(f.MAX_KEYS, Integer.toString(xVar.getMaxKeys().intValue()));
        }
        if (xVar.getEncodingType() != null) {
            map.put(f.ENCODING_TYPE, xVar.getEncodingType());
        }
    }

    public static String populateMapToBase64JsonString(Map<String, String> map) {
        return Base64.encodeToString(new JSONObject(map).toString().getBytes(), 2);
    }

    public static void populateRequestMetadata(Map<String, String> map, e0 e0Var) {
        if (e0Var == null) {
            return;
        }
        Map<String, Object> rawMetadata = e0Var.getRawMetadata();
        if (rawMetadata != null) {
            for (Map.Entry<String, Object> entry : rawMetadata.entrySet()) {
                map.put(entry.getKey(), entry.getValue().toString());
            }
        }
        Map<String, String> userMetadata = e0Var.getUserMetadata();
        if (userMetadata != null) {
            for (Map.Entry<String, String> entry2 : userMetadata.entrySet()) {
                String key = entry2.getKey();
                String value = entry2.getValue();
                if (key != null) {
                    key = key.trim();
                }
                if (value != null) {
                    value = value.trim();
                }
                map.put(key, value);
            }
        }
    }

    public static void removeHeader(Map<String, String> map, String str) {
        if (str == null || !map.containsKey(str)) {
            return;
        }
        map.remove(str);
    }

    public static String sign(String str, String str2, String str3) {
        try {
            String trim = new a().computeSignature(str2, str3).trim();
            return "OSS " + str + ":" + trim;
        } catch (Exception e2) {
            throw new IllegalStateException("Compute signature failed!", e2);
        }
    }

    public static void signRequest(g gVar) throws IOException {
        String sign;
        if (gVar.isAuthorizationRequired()) {
            if (gVar.getCredentialProvider() != null) {
                e.b.b.a.a.f.g.b credentialProvider = gVar.getCredentialProvider();
                e eVar = null;
                boolean z = credentialProvider instanceof e.b.b.a.a.f.g.d;
                if (z) {
                    eVar = ((e.b.b.a.a.f.g.d) credentialProvider).getValidFederationToken();
                    if (eVar != null) {
                        gVar.getHeaders().put(e.b.b.a.a.f.c.OSS_SECURITY_TOKEN, eVar.getSecurityToken());
                    } else {
                        e.b.b.a.a.f.d.logError("Can't get a federation token");
                        throw new IOException("Can't get a federation token");
                    }
                } else if (credentialProvider instanceof e.b.b.a.a.f.g.g) {
                    eVar = ((e.b.b.a.a.f.g.g) credentialProvider).getFederationToken();
                    gVar.getHeaders().put(e.b.b.a.a.f.c.OSS_SECURITY_TOKEN, eVar.getSecurityToken());
                }
                String buildCanonicalString = buildCanonicalString(gVar);
                if (!z && !(credentialProvider instanceof e.b.b.a.a.f.g.g)) {
                    if (credentialProvider instanceof e.b.b.a.a.f.g.f) {
                        e.b.b.a.a.f.g.f fVar = (e.b.b.a.a.f.g.f) credentialProvider;
                        sign = sign(fVar.getAccessKeyId(), fVar.getAccessKeySecret(), buildCanonicalString);
                    } else {
                        sign = credentialProvider instanceof e.b.b.a.a.f.g.c ? ((e.b.b.a.a.f.g.c) credentialProvider).signContent(buildCanonicalString) : "---initValue---";
                    }
                } else {
                    sign = sign(eVar.getTempAK(), eVar.getTempSK(), buildCanonicalString);
                }
                e.b.b.a.a.f.d.logDebug("signed content: " + buildCanonicalString + "   \n ---------   signature: " + sign, false);
                gVar.getHeaders().put(c.AUTHORIZATION, sign);
                return;
            }
            throw new IllegalStateException("当前CredentialProvider为空！！！\n1. 请检查您是否在初始化OSSService时设置CredentialProvider;\n2. 如果您bucket为公共权限，请确认获取到Bucket后已经调用Bucket中接口声明ACL;");
        }
    }

    public static boolean validateBucketName(String str) {
        if (str == null) {
            return false;
        }
        return str.matches("^[a-z0-9][a-z0-9_\\-]{2,62}$");
    }

    public static boolean validateObjectKey(String str) {
        if (str != null && str.length() > 0 && str.length() <= 1023) {
            try {
                str.getBytes("utf-8");
                char[] charArray = str.toCharArray();
                char c2 = charArray[0];
                if (c2 != '/' && c2 != '\\') {
                    for (char c3 : charArray) {
                        if (c3 != '\t' && c3 < ' ') {
                            return false;
                        }
                    }
                    return true;
                }
            } catch (UnsupportedEncodingException unused) {
            }
        }
        return false;
    }

    public static String buildCanonicalizedResource(String str, Map<String, String> map) {
        StringBuilder sb = new StringBuilder();
        sb.append(str);
        if (map != null) {
            String[] strArr = (String[]) map.keySet().toArray(new String[map.size()]);
            Arrays.sort(strArr);
            char c2 = '?';
            for (String str2 : strArr) {
                if (SIGNED_PARAMTERS.contains(str2)) {
                    sb.append(c2);
                    sb.append(str2);
                    String str3 = map.get(str2);
                    if (!isEmptyString(str3)) {
                        sb.append(e.h.a.j.g.e.b.NAME_VALUE_SEPARATOR);
                        sb.append(str3);
                    }
                    c2 = y.amp;
                }
            }
        }
        return sb.toString();
    }
}
