package com.efs.sdk.base;

import android.app.Application;
import android.content.Context;
import android.os.Message;
import android.text.TextUtils;
import android.util.Pair;
import android.webkit.ValueCallback;
import androidx.annotation.NonNull;
import com.efs.sdk.base.core.b.a;
import com.efs.sdk.base.core.b.e;
import com.efs.sdk.base.core.c.d;
import com.efs.sdk.base.core.config.GlobalEnvStruct;
import com.efs.sdk.base.core.config.a.c;
import com.efs.sdk.base.core.controller.ControllerCenter;
import com.efs.sdk.base.core.util.Log;
import com.efs.sdk.base.core.util.a;
import com.efs.sdk.base.http.HttpResponse;
import com.efs.sdk.base.observer.IConfigCallback;
import com.efs.sdk.base.observer.IEfsReporterObserver;
import com.efs.sdk.base.processor.action.ILogEncryptAction;
import com.efs.sdk.base.protocol.ILogProtocol;
import java.io.File;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
/* compiled from: AAA */
/* loaded from: classes2.dex */
public class EfsReporter {
    public static ControllerCenter sControllerCenter;

    /* compiled from: AAA */
    /* loaded from: classes2.dex */
    public static class Builder {
        public static Map<String, EfsReporter> sInstanceMap = new ConcurrentHashMap();
        public static boolean sUseAppContext = true;
        public final String TAG;
        public GlobalEnvStruct mGlobalEnvStruct;

        /* compiled from: AAA */
        /* loaded from: classes2.dex */
        public interface IPublicParams {
            Map<String, String> getRecordHeaders();
        }

        public Builder(@NonNull Application application, @NonNull String str, @NonNull String str2) {
            this(application.getApplicationContext(), str, str2);
        }

        public static Context checkContext(Context context) {
            if (context != null) {
                if (!sUseAppContext || (context instanceof Application) || ((context = context.getApplicationContext()) != null && (context instanceof Application))) {
                    return context;
                }
                Log.e("Can not get Application context from given context!");
                throw new IllegalArgumentException("Can not get Application context from given context!");
            }
            Log.e("context can not be null!");
            throw null;
        }

        private void checkParam(String str) {
            GlobalEnvStruct globalEnvStruct = sInstanceMap.get(str).getGlobalEnvStruct();
            if (globalEnvStruct.mAppContext.equals(getGlobalEnvStruct().mAppContext)) {
                if (!TextUtils.isEmpty(globalEnvStruct.getSecret()) && !globalEnvStruct.getSecret().equals(getGlobalEnvStruct().getSecret())) {
                    throw new RuntimeException("efs-core: duplicate init, but secret is different");
                } else if (globalEnvStruct.isIntl() == getGlobalEnvStruct().isIntl()) {
                    if (!TextUtils.isEmpty(getGlobalEnvStruct().getUid()) && !getGlobalEnvStruct().getUid().equals(globalEnvStruct.getUid())) {
                        Log.w("efs.reporter.builder", "efs-core: duplicate init, but  uid is different");
                    }
                    if (getGlobalEnvStruct().getPublicParamMap() == null || getGlobalEnvStruct().getPublicParamMap().size() <= 0) {
                        return;
                    }
                    globalEnvStruct.addPublicParams(getGlobalEnvStruct().getPublicParamMap());
                    return;
                } else {
                    throw new RuntimeException("efs-core: duplicate init, but intl setting is different");
                }
            }
            throw new RuntimeException("efs-core: duplicate init, but application context is different");
        }

        public Builder addEfsReporterObserver(IEfsReporterObserver iEfsReporterObserver) {
            this.mGlobalEnvStruct.addConfigObserver(iEfsReporterObserver);
            return this;
        }

        public EfsReporter build() {
            String appid = getGlobalEnvStruct().getAppid();
            if (!sInstanceMap.containsKey(appid)) {
                synchronized (EfsReporter.class) {
                    if (!sInstanceMap.containsKey(appid)) {
                        EfsReporter efsReporter = new EfsReporter(this);
                        sInstanceMap.put(appid, efsReporter);
                        return efsReporter;
                    }
                }
            }
            Log.w("efs.reporter.builder", "efs-core: duplicate init");
            checkParam(appid);
            return sInstanceMap.get(appid);
        }

        public Builder configRefreshAction(@NonNull IConfigRefreshAction iConfigRefreshAction) {
            c.a().b = iConfigRefreshAction;
            return this;
        }

        public Builder configRefreshDelayMills(long j2) {
            this.mGlobalEnvStruct.configRefreshDelayMills = j2;
            return this;
        }

        public Builder debug(boolean z) {
            this.mGlobalEnvStruct.setDebug(z);
            return this;
        }

        public Builder efsDirRootName(String str) {
            a.a(str);
            return this;
        }

        public Builder enableSendLog(boolean z) {
            this.mGlobalEnvStruct.setEnableSendLog(z);
            return this;
        }

        public Builder enableWaStat(boolean z) {
            this.mGlobalEnvStruct.setEnableWaStat(z);
            return this;
        }

        public GlobalEnvStruct getGlobalEnvStruct() {
            return this.mGlobalEnvStruct;
        }

        public Builder intl(boolean z) {
            this.mGlobalEnvStruct.setIsIntl(z);
            return this;
        }

        public Builder logEncryptAction(ILogEncryptAction iLogEncryptAction) {
            this.mGlobalEnvStruct.setLogEncryptAction(iLogEncryptAction);
            return this;
        }

        public Builder maxConcurrentUploadCnt(int i2) {
            d.a().a = i2;
            return this;
        }

        public Builder printLogDetail(boolean z) {
            this.mGlobalEnvStruct.setPrintLogDetail(z);
            return this;
        }

        public Builder publicParams(@NonNull IPublicParams iPublicParams) {
            if (iPublicParams.getRecordHeaders() != null && iPublicParams.getRecordHeaders().size() > 0) {
                this.mGlobalEnvStruct.addPublicParams(iPublicParams.getRecordHeaders());
            }
            return this;
        }

        public Builder uid(String str) {
            this.mGlobalEnvStruct.setUid(str);
            return this;
        }

        public Builder(@NonNull Context context, @NonNull String str, @NonNull String str2) {
            this.TAG = "efs.reporter.builder";
            Context checkContext = checkContext(context);
            if (!TextUtils.isEmpty(str)) {
                if (!TextUtils.isEmpty(str2)) {
                    GlobalEnvStruct globalEnvStruct = new GlobalEnvStruct();
                    this.mGlobalEnvStruct = globalEnvStruct;
                    globalEnvStruct.mAppContext = checkContext;
                    globalEnvStruct.setAppid(str);
                    this.mGlobalEnvStruct.setSecret(str2);
                    return;
                }
                throw new RuntimeException("EfsReporter init, secret is empty");
            }
            throw new RuntimeException("EfsReporter init, appid is empty");
        }

        public Builder publicParams(@NonNull Map<String, String> map) {
            if (map.size() > 0) {
                this.mGlobalEnvStruct.addPublicParams(map);
            }
            return this;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    @NonNull
    public GlobalEnvStruct getGlobalEnvStruct() {
        return ControllerCenter.getGlobalEnvStruct();
    }

    public void addPublicParams(@NonNull Map<String, String> map) {
        if (map.size() > 0) {
            getGlobalEnvStruct().addPublicParams(map);
        }
    }

    public void flushRecordLogImmediately(String str) {
        e a = a.b.a().f993c.a((byte) 1);
        if (a != null) {
            a.a(str);
        }
    }

    public Map<String, String> getAllConfig() {
        return c.a().c();
    }

    public void getAllSdkConfig(String[] strArr, IConfigCallback iConfigCallback) {
        c a = c.a();
        a.f1026e.put(iConfigCallback, strArr);
        if (a.f1025d.f1022f.isEmpty()) {
            return;
        }
        a.d();
    }

    public void refreshConfig(String str) {
        c.a().a(str);
    }

    public void registerCallback(int i2, ValueCallback<Pair<Message, Message>> valueCallback) {
        getGlobalEnvStruct().registerCallback(i2, valueCallback);
    }

    public void send(ILogProtocol iLogProtocol) {
        sControllerCenter.send(iLogProtocol);
    }

    public HttpResponse sendSyncImediatelly(String str, int i2, String str2, File file) {
        return sendSyncImediatelly(str, i2, str2, true, file);
    }

    public void setEnableRefreshConfigFromRemote(boolean z) {
        c.a().f1024c = z;
    }

    public EfsReporter(Builder builder) {
        sControllerCenter = new ControllerCenter(builder);
    }

    public HttpResponse sendSyncImediatelly(String str, int i2, String str2, boolean z, File file) {
        return sControllerCenter.sendSyncImmediately(str, i2, str2, z, file);
    }

    public Map<String, Object> getAllSdkConfig() {
        return new HashMap(c.a().f1025d.f1022f);
    }
}
