package com.efs.sdk.pa;

import android.content.Context;
import android.util.Log;
import com.efs.sdk.base.EfsReporter;
import com.efs.sdk.pa.config.ConfigManager;
import com.efs.sdk.pa.config.IEfsReporter;
import com.efs.sdk.pa.config.PackageLevel;
import java.util.HashMap;
/* compiled from: AAA */
/* loaded from: classes2.dex */
public class PAFactory {
    public static final long DEFAULT_TIME_OUT_TIME = 2000;
    public static final long INVALID_TIME_OUT_TIME = 0;
    public static final long MAX_TIME_OUT_TIME = 4000;
    public static final String TAG = "pafactory";
    public static final ThreadLocal<PA> sThreadLocal = new ThreadLocal<>();
    public ConfigManager mConfigManager;
    public Context mContext;
    public HashMap<String, String> mExtend;
    public EfsReporter mReporter;
    public IEfsReporter mReporterFactory;
    public String mSerial;
    public String mSver;
    public long mTimeOutTime;
    public PATraceListener mTraceListener;

    /* compiled from: AAA */
    /* loaded from: classes2.dex */
    public static class Builder {
        public PackageLevel a;
        public IEfsReporter b;

        /* renamed from: c  reason: collision with root package name */
        public boolean f1147c;

        /* renamed from: d  reason: collision with root package name */
        public Context f1148d;

        /* renamed from: e  reason: collision with root package name */
        public String f1149e;

        /* renamed from: f  reason: collision with root package name */
        public HashMap<String, String> f1150f;

        /* renamed from: g  reason: collision with root package name */
        public String f1151g;

        /* renamed from: h  reason: collision with root package name */
        public long f1152h = 2000;

        /* renamed from: i  reason: collision with root package name */
        public PATraceListener f1153i;

        public Builder(Context context, IEfsReporter iEfsReporter) {
            if (context == null) {
                throw new RuntimeException("context Should Not null");
            }
            if (iEfsReporter != null) {
                this.b = iEfsReporter;
                this.f1148d = context;
                return;
            }
            throw new RuntimeException("reporter Should Not Empty");
        }

        public PAFactory build() {
            if (this.a != null) {
                return new PAFactory(this.f1148d, this.a, this.b, this.f1147c, this.f1149e, this.f1150f, this.f1151g, this.f1152h, this.f1153i);
            }
            throw new RuntimeException(String.format("%s Should Not Null", ""));
        }

        public Builder extendLogInfo(HashMap<String, String> hashMap) {
            this.f1150f = hashMap;
            return this;
        }

        public Builder isNewInstall(boolean z) {
            this.f1147c = z;
            return this;
        }

        public Builder packageLevel(PackageLevel packageLevel) {
            this.a = packageLevel;
            return this;
        }

        public Builder serial(String str) {
            this.f1149e = str;
            return this;
        }

        public Builder sver(String str) {
            this.f1151g = str;
            return this;
        }

        public Builder timeoutTime(long j2) {
            if (j2 <= 0) {
                Log.w(PAFactory.TAG, "Timeout time is invalid, and the default value 2s will be used");
                this.f1152h = 2000L;
            } else if (j2 > 4000) {
                Log.w(PAFactory.TAG, "Timeout time over 4s is not recommended, and the default value 2s will be used");
                this.f1152h = 2000L;
                return this;
            } else {
                this.f1152h = j2;
            }
            return this;
        }

        public Builder traceListener(PATraceListener pATraceListener) {
            this.f1153i = pATraceListener;
            return this;
        }
    }

    public ConfigManager getConfigManager() {
        return this.mConfigManager;
    }

    public HashMap<String, String> getExtend() {
        return this.mExtend;
    }

    public synchronized PA getPaInstance() {
        PA pa;
        pa = sThreadLocal.get();
        if (pa == null) {
            pa = new com.efs.sdk.pa.a.c(this.mConfigManager.enableTracer());
            pa.registerPAANRListener(this.mContext, new a(this), this.mTimeOutTime);
            sThreadLocal.set(pa);
        }
        return pa;
    }

    public EfsReporter getReporter() {
        if (this.mReporter == null) {
            IEfsReporter iEfsReporter = this.mReporterFactory;
            this.mReporter = iEfsReporter != null ? iEfsReporter.getReporter() : null;
        }
        return this.mReporter;
    }

    public String getSerial() {
        return this.mSerial;
    }

    public String getSver() {
        return this.mSver;
    }

    public PATraceListener getTraceListener() {
        return this.mTraceListener;
    }

    public PAFactory(Context context, PackageLevel packageLevel, IEfsReporter iEfsReporter, boolean z, String str, HashMap<String, String> hashMap, String str2, long j2, PATraceListener pATraceListener) {
        this.mReporterFactory = iEfsReporter;
        this.mSerial = str;
        this.mExtend = hashMap;
        this.mSver = str2;
        this.mContext = context;
        this.mTraceListener = pATraceListener;
        this.mTimeOutTime = j2;
        this.mConfigManager = new ConfigManager(context, packageLevel, iEfsReporter, z);
    }
}
