package com.joke.chongya.sandbox.widget;

import android.animation.ValueAnimator;
import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Point;
import android.os.Bundle;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.view.View;
import android.view.animation.LinearInterpolator;
import android.widget.Checkable;
import com.joke.chongya.sandbox.R;
import e.g.a.f.i.z;
/* compiled from: AAA */
/* loaded from: classes2.dex */
public class SmoothCheckBox extends View implements Checkable {
    public static final int COLOR_CHECKED = Color.parseColor("#FB4846");
    public static final int COLOR_FLOOR_UNCHECKED = Color.parseColor("#FFDB26");
    public static final int COLOR_TICK = -1;
    public static final int COLOR_UNCHECKED = -1;
    public static final int DEF_ANIM_DURATION = 300;
    public static final int DEF_DRAW_SIZE = 15;
    public static final String KEY_INSTANCE_STATE = "InstanceState";
    public int mAnimDuration;
    public Point mCenterPoint;
    public boolean mChecked;
    public int mCheckedColor;
    public float mDrewDistance;
    public int mFloorColor;
    public Paint mFloorPaint;
    public float mFloorScale;
    public int mFloorUnCheckedColor;
    public float mLeftLineDistance;
    public OnCheckedChangeListener mListener;
    public Paint mPaint;
    public float mRightLineDistance;
    public float mScaleVal;
    public int mStrokeWidth;
    public boolean mTickDrawing;
    public Paint mTickPaint;
    public Path mTickPath;
    public Point[] mTickPoints;
    public int mUnCheckedColor;
    public int mWidth;

    /* compiled from: AAA */
    /* loaded from: classes2.dex */
    public interface OnCheckedChangeListener {
        void onCheckedChanged(SmoothCheckBox smoothCheckBox, boolean z);
    }

    public SmoothCheckBox(Context context) {
        this(context, null);
    }

    private void drawBorder(Canvas canvas) {
        this.mFloorPaint.setColor(this.mFloorColor);
        Point point = this.mCenterPoint;
        int i2 = point.x;
        canvas.drawCircle(i2, point.y, i2 * this.mFloorScale, this.mFloorPaint);
    }

    private void drawCenter(Canvas canvas) {
        this.mPaint.setColor(this.mUnCheckedColor);
        Point point = this.mCenterPoint;
        int i2 = point.x;
        canvas.drawCircle(i2, point.y, (i2 - this.mStrokeWidth) * this.mScaleVal, this.mPaint);
    }

    private void drawTick(Canvas canvas) {
        if (this.mTickDrawing && isChecked()) {
            drawTickPath(canvas);
        }
    }

    private void drawTickDelayed() {
        postDelayed(new Runnable() { // from class: com.joke.chongya.sandbox.widget.SmoothCheckBox.7
            @Override // java.lang.Runnable
            public void run() {
                SmoothCheckBox.this.mTickDrawing = true;
                SmoothCheckBox.this.postInvalidate();
            }
        }, this.mAnimDuration);
    }

    private void drawTickPath(Canvas canvas) {
        int i2;
        this.mTickPath.reset();
        if (this.mDrewDistance < this.mLeftLineDistance) {
            int i3 = this.mWidth;
            float f2 = this.mDrewDistance + (((float) i3) / 20.0f >= 3.0f ? i3 / 20.0f : 3.0f);
            this.mDrewDistance = f2;
            Point[] pointArr = this.mTickPoints;
            float f3 = this.mLeftLineDistance;
            this.mTickPath.moveTo(pointArr[0].x, pointArr[0].y);
            this.mTickPath.lineTo(pointArr[0].x + (((pointArr[1].x - pointArr[0].x) * f2) / f3), pointArr[0].y + (((pointArr[1].y - pointArr[0].y) * f2) / f3));
            canvas.drawPath(this.mTickPath, this.mTickPaint);
            float f4 = this.mDrewDistance;
            float f5 = this.mLeftLineDistance;
            if (f4 > f5) {
                this.mDrewDistance = f5;
            }
        } else {
            Path path = this.mTickPath;
            Point[] pointArr2 = this.mTickPoints;
            path.moveTo(pointArr2[0].x, pointArr2[0].y);
            Path path2 = this.mTickPath;
            Point[] pointArr3 = this.mTickPoints;
            path2.lineTo(pointArr3[1].x, pointArr3[1].y);
            canvas.drawPath(this.mTickPath, this.mTickPaint);
            float f6 = this.mDrewDistance;
            float f7 = this.mLeftLineDistance;
            float f8 = this.mRightLineDistance;
            if (f6 < f7 + f8) {
                Point[] pointArr4 = this.mTickPoints;
                this.mTickPath.reset();
                Path path3 = this.mTickPath;
                Point[] pointArr5 = this.mTickPoints;
                path3.moveTo(pointArr5[1].x, pointArr5[1].y);
                this.mTickPath.lineTo(pointArr4[1].x + (((pointArr4[2].x - pointArr4[1].x) * (f6 - f7)) / f8), pointArr4[1].y - (((pointArr4[1].y - pointArr4[2].y) * (f6 - f7)) / f8));
                canvas.drawPath(this.mTickPath, this.mTickPaint);
                this.mDrewDistance += this.mWidth / 20 >= 3 ? i2 / 20 : 3.0f;
            } else {
                this.mTickPath.reset();
                Path path4 = this.mTickPath;
                Point[] pointArr6 = this.mTickPoints;
                path4.moveTo(pointArr6[1].x, pointArr6[1].y);
                Path path5 = this.mTickPath;
                Point[] pointArr7 = this.mTickPoints;
                path5.lineTo(pointArr7[2].x, pointArr7[2].y);
                canvas.drawPath(this.mTickPath, this.mTickPaint);
            }
        }
        if (this.mDrewDistance < this.mLeftLineDistance + this.mRightLineDistance) {
            postDelayed(new Runnable() { // from class: com.joke.chongya.sandbox.widget.SmoothCheckBox.2
                @Override // java.lang.Runnable
                public void run() {
                    SmoothCheckBox.this.postInvalidate();
                }
            }, 10L);
        }
    }

    public static int getGradientColor(int i2, int i3, float f2) {
        int alpha = Color.alpha(i2);
        int red = Color.red(i2);
        int green = Color.green(i2);
        int blue = Color.blue(i2);
        float f3 = 1.0f - f2;
        return Color.argb((int) ((alpha * f3) + (Color.alpha(i3) * f2)), (int) ((red * f3) + (Color.red(i3) * f2)), (int) ((green * f3) + (Color.green(i3) * f2)), (int) ((blue * f3) + (Color.blue(i3) * f2)));
    }

    private void init(AttributeSet attributeSet) {
        TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attributeSet, R.styleable.SmoothCheckBox);
        int color = obtainStyledAttributes.getColor(R.styleable.SmoothCheckBox_color_tick, -1);
        this.mAnimDuration = obtainStyledAttributes.getInt(R.styleable.SmoothCheckBox_duration, 300);
        this.mFloorColor = obtainStyledAttributes.getColor(R.styleable.SmoothCheckBox_color_unchecked_stroke, COLOR_FLOOR_UNCHECKED);
        this.mCheckedColor = obtainStyledAttributes.getColor(R.styleable.SmoothCheckBox_color_checked, COLOR_CHECKED);
        this.mUnCheckedColor = obtainStyledAttributes.getColor(R.styleable.SmoothCheckBox_color_unchecked, -1);
        this.mStrokeWidth = obtainStyledAttributes.getDimensionPixelSize(R.styleable.SmoothCheckBox_stroke_width, z.INSTANCE.dp2px(getContext(), 0.0f));
        obtainStyledAttributes.recycle();
        this.mFloorUnCheckedColor = this.mFloorColor;
        Paint paint = new Paint(1);
        this.mTickPaint = paint;
        paint.setStyle(Paint.Style.STROKE);
        this.mTickPaint.setStrokeCap(Paint.Cap.ROUND);
        this.mTickPaint.setColor(color);
        Paint paint2 = new Paint(1);
        this.mFloorPaint = paint2;
        paint2.setStyle(Paint.Style.FILL);
        this.mFloorPaint.setColor(this.mFloorColor);
        Paint paint3 = new Paint(1);
        this.mPaint = paint3;
        paint3.setStyle(Paint.Style.FILL);
        this.mPaint.setColor(this.mCheckedColor);
        this.mTickPath = new Path();
        this.mCenterPoint = new Point();
        Point[] pointArr = new Point[3];
        this.mTickPoints = pointArr;
        pointArr[0] = new Point();
        this.mTickPoints[1] = new Point();
        this.mTickPoints[2] = new Point();
        setOnClickListener(new View.OnClickListener() { // from class: com.joke.chongya.sandbox.widget.SmoothCheckBox.1
            @Override // android.view.View.OnClickListener
            public void onClick(View view) {
                SmoothCheckBox.this.toggle();
                SmoothCheckBox.this.mTickDrawing = false;
                SmoothCheckBox.this.mDrewDistance = 0.0f;
                if (SmoothCheckBox.this.isChecked()) {
                    SmoothCheckBox.this.startCheckedAnimation();
                } else {
                    SmoothCheckBox.this.startUnCheckedAnimation();
                }
            }
        });
    }

    private int measureSize(int i2) {
        int dp2px = z.INSTANCE.dp2px(getContext(), 15.0f);
        int size = View.MeasureSpec.getSize(i2);
        int mode = View.MeasureSpec.getMode(i2);
        if (mode == Integer.MIN_VALUE || mode == 0) {
            return Math.min(dp2px, size);
        }
        if (mode != 1073741824) {
            return 0;
        }
        return size;
    }

    private void reset() {
        this.mTickDrawing = true;
        this.mFloorScale = 1.0f;
        this.mScaleVal = isChecked() ? 0.0f : 1.0f;
        this.mFloorColor = isChecked() ? this.mCheckedColor : this.mFloorUnCheckedColor;
        this.mDrewDistance = isChecked() ? this.mLeftLineDistance + this.mRightLineDistance : 0.0f;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void startCheckedAnimation() {
        ValueAnimator ofFloat = ValueAnimator.ofFloat(1.0f, 0.0f);
        ofFloat.setDuration((this.mAnimDuration / 3) * 2);
        ofFloat.setInterpolator(new LinearInterpolator());
        ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.joke.chongya.sandbox.widget.SmoothCheckBox.3
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                SmoothCheckBox.this.mScaleVal = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                SmoothCheckBox smoothCheckBox = SmoothCheckBox.this;
                smoothCheckBox.mFloorColor = SmoothCheckBox.getGradientColor(smoothCheckBox.mUnCheckedColor, SmoothCheckBox.this.mCheckedColor, 1.0f - SmoothCheckBox.this.mScaleVal);
                SmoothCheckBox.this.postInvalidate();
            }
        });
        ofFloat.start();
        ValueAnimator ofFloat2 = ValueAnimator.ofFloat(1.0f, 0.8f, 1.0f);
        ofFloat2.setDuration(this.mAnimDuration);
        ofFloat2.setInterpolator(new LinearInterpolator());
        ofFloat2.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.joke.chongya.sandbox.widget.SmoothCheckBox.4
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                SmoothCheckBox.this.mFloorScale = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                SmoothCheckBox.this.postInvalidate();
            }
        });
        ofFloat2.start();
        drawTickDelayed();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void startUnCheckedAnimation() {
        ValueAnimator ofFloat = ValueAnimator.ofFloat(0.0f, 1.0f);
        ofFloat.setDuration(this.mAnimDuration);
        ofFloat.setInterpolator(new LinearInterpolator());
        ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.joke.chongya.sandbox.widget.SmoothCheckBox.5
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                SmoothCheckBox.this.mScaleVal = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                SmoothCheckBox smoothCheckBox = SmoothCheckBox.this;
                smoothCheckBox.mFloorColor = SmoothCheckBox.getGradientColor(smoothCheckBox.mCheckedColor, SmoothCheckBox.this.mFloorUnCheckedColor, SmoothCheckBox.this.mScaleVal);
                SmoothCheckBox.this.postInvalidate();
            }
        });
        ofFloat.start();
        ValueAnimator ofFloat2 = ValueAnimator.ofFloat(1.0f, 0.8f, 1.0f);
        ofFloat2.setDuration(this.mAnimDuration);
        ofFloat2.setInterpolator(new LinearInterpolator());
        ofFloat2.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.joke.chongya.sandbox.widget.SmoothCheckBox.6
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                SmoothCheckBox.this.mFloorScale = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                SmoothCheckBox.this.postInvalidate();
            }
        });
        ofFloat2.start();
    }

    @Override // android.widget.Checkable
    public boolean isChecked() {
        return this.mChecked;
    }

    @Override // android.view.View
    public void onDraw(Canvas canvas) {
        drawBorder(canvas);
        drawCenter(canvas);
        drawTick(canvas);
    }

    @Override // android.view.View
    public void onLayout(boolean z, int i2, int i3, int i4, int i5) {
        this.mWidth = getMeasuredWidth();
        int i6 = this.mStrokeWidth;
        if (i6 == 0) {
            i6 = getMeasuredWidth() / 10;
        }
        this.mStrokeWidth = i6;
        int measuredWidth = i6 > getMeasuredWidth() / 5 ? getMeasuredWidth() / 5 : this.mStrokeWidth;
        this.mStrokeWidth = measuredWidth;
        if (measuredWidth < 3) {
            measuredWidth = 3;
        }
        this.mStrokeWidth = measuredWidth;
        Point point = this.mCenterPoint;
        point.x = this.mWidth / 2;
        point.y = getMeasuredHeight() / 2;
        this.mTickPoints[0].x = Math.round((getMeasuredWidth() / 30.0f) * 7.0f);
        this.mTickPoints[0].y = Math.round((getMeasuredHeight() / 30.0f) * 14.0f);
        this.mTickPoints[1].x = Math.round((getMeasuredWidth() / 30.0f) * 13.0f);
        this.mTickPoints[1].y = Math.round((getMeasuredHeight() / 30.0f) * 20.0f);
        this.mTickPoints[2].x = Math.round((getMeasuredWidth() / 30.0f) * 22.0f);
        this.mTickPoints[2].y = Math.round((getMeasuredHeight() / 30.0f) * 10.0f);
        Point[] pointArr = this.mTickPoints;
        double pow = Math.pow(pointArr[1].x - pointArr[0].x, 2.0d);
        Point[] pointArr2 = this.mTickPoints;
        this.mLeftLineDistance = (float) Math.sqrt(pow + Math.pow(pointArr2[1].y - pointArr2[0].y, 2.0d));
        Point[] pointArr3 = this.mTickPoints;
        double pow2 = Math.pow(pointArr3[2].x - pointArr3[1].x, 2.0d);
        Point[] pointArr4 = this.mTickPoints;
        this.mRightLineDistance = (float) Math.sqrt(pow2 + Math.pow(pointArr4[2].y - pointArr4[1].y, 2.0d));
        this.mTickPaint.setStrokeWidth(this.mStrokeWidth);
    }

    @Override // android.view.View
    public void onMeasure(int i2, int i3) {
        super.onMeasure(i2, i3);
        setMeasuredDimension(measureSize(i2), measureSize(i3));
    }

    @Override // android.view.View
    public void onRestoreInstanceState(Parcelable parcelable) {
        if (parcelable instanceof Bundle) {
            Bundle bundle = (Bundle) parcelable;
            setChecked(bundle.getBoolean(KEY_INSTANCE_STATE));
            super.onRestoreInstanceState(bundle.getParcelable(KEY_INSTANCE_STATE));
            return;
        }
        super.onRestoreInstanceState(parcelable);
    }

    @Override // android.view.View
    public Parcelable onSaveInstanceState() {
        Bundle bundle = new Bundle();
        bundle.putParcelable(KEY_INSTANCE_STATE, super.onSaveInstanceState());
        bundle.putBoolean(KEY_INSTANCE_STATE, isChecked());
        return bundle;
    }

    @Override // android.widget.Checkable
    public void setChecked(boolean z) {
        this.mChecked = z;
        reset();
        invalidate();
        OnCheckedChangeListener onCheckedChangeListener = this.mListener;
        if (onCheckedChangeListener != null) {
            onCheckedChangeListener.onCheckedChanged(this, this.mChecked);
        }
    }

    public void setOnCheckedChangeListener(OnCheckedChangeListener onCheckedChangeListener) {
        this.mListener = onCheckedChangeListener;
    }

    @Override // android.widget.Checkable
    public void toggle() {
        setChecked(!isChecked());
    }

    public SmoothCheckBox(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public SmoothCheckBox(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mScaleVal = 1.0f;
        this.mFloorScale = 1.0f;
        init(attributeSet);
    }

    @TargetApi(21)
    public SmoothCheckBox(Context context, AttributeSet attributeSet, int i2, int i3) {
        super(context, attributeSet, i2, i3);
        this.mScaleVal = 1.0f;
        this.mFloorScale = 1.0f;
        init(attributeSet);
    }

    public void setChecked(boolean z, boolean z2) {
        if (z2) {
            this.mTickDrawing = false;
            this.mChecked = z;
            this.mDrewDistance = 0.0f;
            if (z) {
                startCheckedAnimation();
            } else {
                startUnCheckedAnimation();
            }
            OnCheckedChangeListener onCheckedChangeListener = this.mListener;
            if (onCheckedChangeListener != null) {
                onCheckedChangeListener.onCheckedChanged(this, this.mChecked);
                return;
            }
            return;
        }
        setChecked(z);
    }
}
