package com.kingja.loadsir.core;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import com.kingja.loadsir.callback.Callback;
import com.kingja.loadsir.callback.SuccessCallback;
import com.kingja.loadsir.core.LoadSir;
import java.util.List;
/* compiled from: AAA */
/* loaded from: classes2.dex */
public class LoadService<T> {
    public Convertor<T> convertor;
    public LoadLayout loadLayout;

    public LoadService(Convertor<T> convertor, TargetContext targetContext, Callback.OnReloadListener onReloadListener, LoadSir.Builder builder) {
        this.convertor = convertor;
        Context context = targetContext.getContext();
        View oldContent = targetContext.getOldContent();
        ViewGroup.LayoutParams layoutParams = oldContent.getLayoutParams();
        LoadLayout loadLayout = new LoadLayout(context, onReloadListener);
        this.loadLayout = loadLayout;
        loadLayout.setupSuccessLayout(new SuccessCallback(oldContent, context, onReloadListener));
        if (targetContext.getParentView() != null) {
            targetContext.getParentView().addView(this.loadLayout, targetContext.getChildIndex(), layoutParams);
        }
        initCallback(builder);
    }

    private void initCallback(LoadSir.Builder builder) {
        List<Callback> callbacks = builder.getCallbacks();
        Class<? extends Callback> defaultCallback = builder.getDefaultCallback();
        if (callbacks != null && callbacks.size() > 0) {
            for (Callback callback : callbacks) {
                this.loadLayout.setupCallback(callback);
            }
        }
        if (defaultCallback != null) {
            this.loadLayout.showCallback(defaultCallback);
        }
    }

    public Class<? extends Callback> getCurrentCallback() {
        return this.loadLayout.getCurrentCallback();
    }

    public LoadLayout getLoadLayout() {
        return this.loadLayout;
    }

    public LinearLayout getTitleLoadLayout(Context context, ViewGroup viewGroup, View view) {
        LinearLayout linearLayout = new LinearLayout(context);
        linearLayout.setOrientation(1);
        LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(-1, -1);
        linearLayout.setLayoutParams(layoutParams);
        viewGroup.removeView(view);
        linearLayout.addView(view);
        linearLayout.addView(this.loadLayout, layoutParams);
        return linearLayout;
    }

    public LoadService<T> setCallBack(Class<? extends Callback> cls, Transport transport) {
        this.loadLayout.setCallBack(cls, transport);
        return this;
    }

    public void showCallback(Class<? extends Callback> cls) {
        this.loadLayout.showCallback(cls);
    }

    public void showSuccess() {
        this.loadLayout.showCallback(SuccessCallback.class);
    }

    public void showWithConvertor(T t) {
        Convertor<T> convertor = this.convertor;
        if (convertor != null) {
            this.loadLayout.showCallback(convertor.map(t));
            return;
        }
        throw new IllegalArgumentException("You haven't set the Convertor.");
    }
}
