package com.kwad.sdk.core.imageloader.cache.memory.impl;

import com.kwad.sdk.core.imageloader.cache.memory.MemoryCache;
import com.kwad.sdk.core.imageloader.core.decode.DecodedResult;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class LimitedAgeMemoryCache implements MemoryCache {
    public final MemoryCache cache;
    public final Map<String, Long> loadingDates = Collections.synchronizedMap(new HashMap());
    public final long maxAge;

    public LimitedAgeMemoryCache(MemoryCache memoryCache, long j2) {
        this.cache = memoryCache;
        this.maxAge = j2 * 1000;
    }

    @Override // com.kwad.sdk.core.imageloader.cache.memory.MemoryCache
    public void clear() {
        this.cache.clear();
        this.loadingDates.clear();
    }

    @Override // com.kwad.sdk.core.imageloader.cache.memory.MemoryCache
    public DecodedResult get(String str) {
        Long l2 = this.loadingDates.get(str);
        if (l2 != null && System.currentTimeMillis() - l2.longValue() > this.maxAge) {
            this.cache.remove(str);
            this.loadingDates.remove(str);
        }
        return this.cache.get(str);
    }

    @Override // com.kwad.sdk.core.imageloader.cache.memory.MemoryCache
    public Collection<String> keys() {
        return this.cache.keys();
    }

    @Override // com.kwad.sdk.core.imageloader.cache.memory.MemoryCache
    public boolean put(String str, DecodedResult decodedResult) {
        boolean put = this.cache.put(str, decodedResult);
        if (put) {
            this.loadingDates.put(str, Long.valueOf(System.currentTimeMillis()));
        }
        return put;
    }

    @Override // com.kwad.sdk.core.imageloader.cache.memory.MemoryCache
    public DecodedResult remove(String str) {
        this.loadingDates.remove(str);
        return this.cache.remove(str);
    }
}
