package com.kwad.sdk.widget;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.LinearGradient;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import android.os.SystemClock;
import android.util.AttributeSet;
import android.view.View;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.TooltipCompatHandler;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class DownloadProgressBar extends View {
    public Runnable Dm;
    public Paint aLG;
    public Paint aLH;
    public Paint aLI;
    public String aLJ;
    public float aLK;
    public Rect aLL;
    public LinearGradient aLM;
    public LinearGradient aLN;
    public LinearGradient aLO;
    public Matrix mMatrix;
    public Path mPath;
    public RectF mRectF;
    public long mStartTime;

    public DownloadProgressBar(Context context) {
        this(context, null, 0);
    }

    public DownloadProgressBar(Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public DownloadProgressBar(Context context, @Nullable AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.Dm = new Runnable() { // from class: com.kwad.sdk.widget.DownloadProgressBar.1
            @Override // java.lang.Runnable
            public final void run() {
                DownloadProgressBar.this.invalidate();
                if (DownloadProgressBar.this.getWindowVisibility() == 0) {
                    DownloadProgressBar.this.postDelayed(this, 34L);
                }
            }
        };
        this.aLG = new Paint(1);
        this.aLH = new Paint(1);
        this.mRectF = new RectF();
        Paint paint = new Paint(1);
        this.aLI = paint;
        paint.setTextSize(com.kwad.sdk.d.a.a.a(context, 16.0f));
        this.aLI.setColor(-1);
        this.aLI.setTextAlign(Paint.Align.CENTER);
        this.aLL = new Rect();
        this.mMatrix = new Matrix();
        this.mPath = new Path();
    }

    @Override // android.view.View
    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        removeCallbacks(this.Dm);
    }

    @Override // android.view.View
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        canvas.clipPath(this.mPath);
        this.aLG.setShader(this.aLM);
        canvas.drawRect(this.mRectF, this.aLG);
        this.aLG.setShader(this.aLN);
        canvas.drawRect(0.0f, 0.0f, (getWidth() * this.aLK) / 100.0f, getHeight(), this.aLG);
        float f2 = this.aLK;
        float f3 = 0.0f;
        if (f2 > 0.0f && f2 < 100.0f) {
            long elapsedRealtime = (SystemClock.elapsedRealtime() - this.mStartTime) % TooltipCompatHandler.LONG_CLICK_HIDE_TIMEOUT_MS;
            float f4 = elapsedRealtime >= 1500 ? 0.0f : ((float) elapsedRealtime) / 1500.0f;
            this.mMatrix.reset();
            this.mMatrix.setScale(1.0f, f4);
            this.aLO.setLocalMatrix(this.mMatrix);
            this.aLH.setShader(this.aLO);
            canvas.drawRect(0.0f, 0.0f, ((getWidth() * this.aLK) / 100.0f) * f4, getHeight(), this.aLH);
            if (elapsedRealtime > 500 && elapsedRealtime <= 1500) {
                f3 = ((float) (elapsedRealtime - 500)) / 1000.0f;
            }
            float width = ((getWidth() * this.aLK) / 100.0f) * f3;
            this.mMatrix.reset();
            this.mMatrix.setScale(1.0f, f4);
            this.aLO.setLocalMatrix(this.mMatrix);
            this.aLH.setShader(this.aLO);
            canvas.drawRect(0.0f, 0.0f, width, getHeight(), this.aLH);
        }
        String str = this.aLJ;
        if (str != null) {
            this.aLI.getTextBounds(str, 0, str.length(), this.aLL);
            Rect rect = this.aLL;
            canvas.drawText(this.aLJ, getWidth() / 2.0f, (getHeight() / 2.0f) - ((rect.top + rect.bottom) / 2.0f), this.aLI);
        }
    }

    @Override // android.view.View
    public void onSizeChanged(int i2, int i3, int i4, int i5) {
        super.onSizeChanged(i2, i3, i4, i5);
        this.aLM = new LinearGradient(0.0f, 0.0f, getMeasuredWidth(), 0.0f, new int[]{1291525714, 1291569420}, new float[]{0.0f, 1.0f}, Shader.TileMode.CLAMP);
        this.aLN = new LinearGradient(0.0f, 0.0f, getMeasuredWidth(), 0.0f, new int[]{-319918, -276212}, new float[]{0.0f, 1.0f}, Shader.TileMode.CLAMP);
        this.aLG.setShader(this.aLM);
        LinearGradient linearGradient = new LinearGradient(0.0f, 0.0f, getMeasuredWidth(), 0.0f, new int[]{16501004, -276212}, new float[]{0.0f, 1.0f}, Shader.TileMode.CLAMP);
        this.aLO = linearGradient;
        this.aLH.setShader(linearGradient);
        float f2 = i2;
        this.mRectF.set(0.0f, 0.0f, f2, i3);
        this.mPath.reset();
        float f3 = f2 / 2.0f;
        this.mPath.addRoundRect(this.mRectF, f3, f3, Path.Direction.CW);
    }

    @Override // android.view.View
    public void onVisibilityChanged(@NonNull View view, int i2) {
        super.onVisibilityChanged(view, i2);
    }

    @Override // android.view.View
    public void onWindowVisibilityChanged(int i2) {
        super.onWindowVisibilityChanged(i2);
        if (i2 != 0) {
            removeCallbacks(this.Dm);
            return;
        }
        float f2 = this.aLK;
        if (f2 <= 0.0f || f2 >= 100.0f) {
            return;
        }
        this.mStartTime = SystemClock.elapsedRealtime();
        post(this.Dm);
    }

    public void setProgress(float f2) {
        this.aLK = f2;
        invalidate();
        if (f2 == 0.0f || f2 == 100.0f) {
            removeCallbacks(this.Dm);
        } else if (getWindowVisibility() == 0 && this.mStartTime == 0) {
            post(this.Dm);
        }
    }

    public void setText(String str) {
        this.aLJ = str;
        invalidate();
    }
}
