package com.lidroid.xutils.http.client;

import e.h.a.j.b;
import e.h.a.j.f.e;
import e.h.a.j.g.e.a;
import e.h.a.l.d;
import e.h.a.l.f;
import java.net.URI;
import java.net.URISyntaxException;
import java.nio.charset.Charset;
import java.util.List;
import org.apache.http.Header;
import org.apache.http.HttpEntity;
import org.apache.http.HttpEntityEnclosingRequest;
import org.apache.http.NameValuePair;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.client.utils.CloneUtils;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class HttpRequest extends HttpRequestBase implements HttpEntityEnclosingRequest {
    public HttpEntity entity;
    public HttpMethod method;
    public a uriBuilder;
    public Charset uriCharset;

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public enum HttpMethod {
        GET("GET"),
        POST("POST"),
        PUT("PUT"),
        HEAD("HEAD"),
        MOVE("MOVE"),
        COPY("COPY"),
        DELETE("DELETE"),
        OPTIONS("OPTIONS"),
        TRACE("TRACE"),
        CONNECT("CONNECT");
        
        public final String value;

        HttpMethod(String str) {
            this.value = str;
        }

        @Override // java.lang.Enum
        public String toString() {
            return this.value;
        }
    }

    public HttpRequest(HttpMethod httpMethod) {
        this.method = httpMethod;
    }

    public HttpRequest addQueryStringParameter(String str, String str2) {
        this.uriBuilder.addParameter(str, str2);
        return this;
    }

    public HttpRequest addQueryStringParams(List<NameValuePair> list) {
        if (list != null) {
            for (NameValuePair nameValuePair : list) {
                this.uriBuilder.addParameter(nameValuePair.getName(), nameValuePair.getValue());
            }
        }
        return this;
    }

    public Object clone() throws CloneNotSupportedException {
        HttpRequest httpRequest = (HttpRequest) super.clone();
        HttpEntity httpEntity = this.entity;
        if (httpEntity != null) {
            httpRequest.entity = (HttpEntity) CloneUtils.clone(httpEntity);
        }
        return httpRequest;
    }

    public boolean expectContinue() {
        Header firstHeader = getFirstHeader("Expect");
        return firstHeader != null && "100-continue".equalsIgnoreCase(firstHeader.getValue());
    }

    public HttpEntity getEntity() {
        return this.entity;
    }

    public String getMethod() {
        return this.method.toString();
    }

    public URI getURI() {
        try {
            if (this.uriCharset == null) {
                this.uriCharset = f.getCharsetFromHttpRequest(this);
            }
            if (this.uriCharset == null) {
                this.uriCharset = Charset.forName("UTF-8");
            }
            return this.uriBuilder.build(this.uriCharset);
        } catch (URISyntaxException e2) {
            d.e(e2.getMessage(), e2);
            return null;
        }
    }

    public void setEntity(HttpEntity httpEntity) {
        this.entity = httpEntity;
    }

    public void setRequestParams(b bVar) {
        if (bVar != null) {
            if (this.uriCharset == null) {
                this.uriCharset = Charset.forName(bVar.getCharset());
            }
            List<b.a> headers = bVar.getHeaders();
            if (headers != null) {
                for (b.a aVar : headers) {
                    if (aVar.overwrite) {
                        setHeader(aVar.header);
                    } else {
                        addHeader(aVar.header);
                    }
                }
            }
            addQueryStringParams(bVar.getQueryStringParams());
            setEntity(bVar.getEntity());
        }
    }

    public void setURI(URI uri) {
        this.uriBuilder = new a(uri);
    }

    public HttpRequest addQueryStringParameter(NameValuePair nameValuePair) {
        this.uriBuilder.addParameter(nameValuePair.getName(), nameValuePair.getValue());
        return this;
    }

    public void setURI(String str) {
        this.uriBuilder = new a(str);
    }

    public HttpRequest(HttpMethod httpMethod, String str) {
        this.method = httpMethod;
        setURI(str);
    }

    public HttpRequest(HttpMethod httpMethod, URI uri) {
        this.method = httpMethod;
        setURI(uri);
    }

    public void setRequestParams(b bVar, e eVar) {
        if (bVar != null) {
            if (this.uriCharset == null) {
                this.uriCharset = Charset.forName(bVar.getCharset());
            }
            List<b.a> headers = bVar.getHeaders();
            if (headers != null) {
                for (b.a aVar : headers) {
                    if (aVar.overwrite) {
                        setHeader(aVar.header);
                    } else {
                        addHeader(aVar.header);
                    }
                }
            }
            addQueryStringParams(bVar.getQueryStringParams());
            e.h.a.j.g.c.f entity = bVar.getEntity();
            if (entity != null) {
                if (entity instanceof e.h.a.j.g.c.f) {
                    entity.setCallBackHandler(eVar);
                }
                setEntity(entity);
            }
        }
    }
}
