package com.lidroid.xutils.task;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.lang.reflect.Array;
import java.util.AbstractQueue;
import java.util.Collection;
import java.util.Iterator;
import java.util.NoSuchElementException;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.ReentrantLock;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class PriorityObjectBlockingQueue<E> extends AbstractQueue<E> implements BlockingQueue<E>, Serializable {
    public static final long serialVersionUID = -6903933977591709194L;
    public final int capacity;
    public final AtomicInteger count;
    public transient e.h.a.k.a<E> head;
    public transient e.h.a.k.a<E> last;
    public final Condition notEmpty;
    public final Condition notFull;
    public final ReentrantLock putLock;
    public final ReentrantLock takeLock;

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class a implements Iterator<E> {
        public e.h.a.k.a<E> current;
        public E currentElement;
        public e.h.a.k.a<E> lastRet;

        public a() {
            PriorityObjectBlockingQueue.this.fullyLock();
            try {
                e.h.a.k.a<E> aVar = PriorityObjectBlockingQueue.this.head.next;
                this.current = aVar;
                if (aVar != null) {
                    this.currentElement = aVar.getValue();
                }
            } finally {
                PriorityObjectBlockingQueue.this.fullyUnlock();
            }
        }

        private e.h.a.k.a<E> nextNode(e.h.a.k.a<E> aVar) {
            e.h.a.k.a<E> aVar2;
            while (true) {
                aVar2 = aVar.next;
                if (aVar2 == aVar) {
                    return PriorityObjectBlockingQueue.this.head.next;
                }
                if (aVar2 == null || aVar2.getValue() != null) {
                    break;
                }
                aVar = aVar2;
            }
            return aVar2;
        }

        @Override // java.util.Iterator
        public boolean hasNext() {
            return this.current != null;
        }

        @Override // java.util.Iterator
        public E next() {
            PriorityObjectBlockingQueue.this.fullyLock();
            try {
                if (this.current != null) {
                    E e2 = this.currentElement;
                    this.lastRet = this.current;
                    e.h.a.k.a<E> nextNode = nextNode(this.current);
                    this.current = nextNode;
                    this.currentElement = nextNode == null ? null : nextNode.getValue();
                    return e2;
                }
                throw new NoSuchElementException();
            } finally {
                PriorityObjectBlockingQueue.this.fullyUnlock();
            }
        }

        /* JADX WARN: Code restructure failed: missing block: B:9:0x001b, code lost:
            r4.this$0.unlink(r1, r2);
         */
        @Override // java.util.Iterator
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public void remove() {
            if (this.lastRet != null) {
                PriorityObjectBlockingQueue.this.fullyLock();
                try {
                    e.h.a.k.a<E> aVar = this.lastRet;
                    this.lastRet = null;
                    e.h.a.k.a<E> aVar2 = PriorityObjectBlockingQueue.this.head;
                    e.h.a.k.a<E> aVar3 = aVar2.next;
                    while (true) {
                        e.h.a.k.a<E> aVar4 = aVar3;
                        e.h.a.k.a<E> aVar5 = aVar2;
                        aVar2 = aVar4;
                        if (aVar2 == null) {
                            break;
                        } else if (aVar2 == aVar) {
                            break;
                        } else {
                            aVar3 = aVar2.next;
                        }
                    }
                    return;
                } finally {
                    PriorityObjectBlockingQueue.this.fullyUnlock();
                }
            }
            throw new IllegalStateException();
        }
    }

    public PriorityObjectBlockingQueue() {
        this(Integer.MAX_VALUE);
    }

    private E _dequeue() {
        e.h.a.k.a aVar = (e.h.a.k.a<E>) this.head;
        e.h.a.k.a<E> aVar2 = (e.h.a.k.a<E>) aVar.next;
        aVar.next = aVar;
        this.head = aVar2;
        E value = aVar2.getValue();
        aVar2.setValue(null);
        return value;
    }

    /* JADX WARN: Multi-variable type inference failed */
    private void _enqueue(e.h.a.k.a<E> aVar) {
        boolean z;
        e.h.a.k.a aVar2 = this.head;
        while (true) {
            e.h.a.k.a<T> aVar3 = aVar2.next;
            if (aVar3 == 0) {
                z = false;
                break;
            } else if (aVar3.getPriority().ordinal() > aVar.getPriority().ordinal()) {
                aVar2.next = aVar;
                aVar.next = aVar3;
                z = true;
                break;
            } else {
                aVar2 = aVar2.next;
            }
        }
        if (z) {
            return;
        }
        this.last.next = aVar;
        this.last = aVar;
    }

    private synchronized E opQueue(e.h.a.k.a<E> aVar) {
        if (aVar == null) {
            return _dequeue();
        }
        _enqueue(aVar);
        return null;
    }

    /* JADX WARN: Multi-variable type inference failed */
    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        objectInputStream.defaultReadObject();
        this.count.set(0);
        e.h.a.k.a<E> aVar = new e.h.a.k.a<>(null);
        this.head = aVar;
        this.last = aVar;
        while (true) {
            Object readObject = objectInputStream.readObject();
            if (readObject == null) {
                return;
            }
            add(readObject);
        }
    }

    private void signalNotEmpty() {
        ReentrantLock reentrantLock = this.takeLock;
        reentrantLock.lock();
        try {
            this.notEmpty.signal();
        } finally {
            reentrantLock.unlock();
        }
    }

    private void signalNotFull() {
        ReentrantLock reentrantLock = this.putLock;
        reentrantLock.lock();
        try {
            this.notFull.signal();
        } finally {
            reentrantLock.unlock();
        }
    }

    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        fullyLock();
        try {
            objectOutputStream.defaultWriteObject();
            e.h.a.k.a aVar = this.head;
            while (true) {
                aVar = aVar.next;
                if (aVar != null) {
                    objectOutputStream.writeObject(aVar.getValue());
                } else {
                    objectOutputStream.writeObject(null);
                    return;
                }
            }
        } finally {
            fullyUnlock();
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // java.util.AbstractQueue, java.util.AbstractCollection, java.util.Collection
    public void clear() {
        fullyLock();
        try {
            e.h.a.k.a aVar = (e.h.a.k.a<E>) this.head;
            while (true) {
                e.h.a.k.a aVar2 = aVar.next;
                if (aVar2 == null) {
                    break;
                }
                aVar.next = aVar;
                aVar2.setValue(null);
                aVar = (e.h.a.k.a<E>) aVar2;
            }
            this.head = this.last;
            if (this.count.getAndSet(0) == this.capacity) {
                this.notFull.signal();
            }
        } finally {
            fullyUnlock();
        }
    }

    @Override // java.util.AbstractCollection, java.util.Collection, java.util.concurrent.BlockingQueue
    public boolean contains(Object obj) {
        if (obj == null) {
            return false;
        }
        fullyLock();
        try {
            e.h.a.k.a aVar = this.head;
            do {
                aVar = aVar.next;
                if (aVar == null) {
                    return false;
                }
            } while (!obj.equals(aVar.getValue()));
            return true;
        } finally {
            fullyUnlock();
        }
    }

    @Override // java.util.concurrent.BlockingQueue
    public int drainTo(Collection<? super E> collection) {
        return drainTo(collection, Integer.MAX_VALUE);
    }

    public void fullyLock() {
        this.putLock.lock();
        this.takeLock.lock();
    }

    public void fullyUnlock() {
        this.takeLock.unlock();
        this.putLock.unlock();
    }

    @Override // java.util.AbstractCollection, java.util.Collection, java.lang.Iterable
    public Iterator<E> iterator() {
        return new a();
    }

    @Override // java.util.concurrent.BlockingQueue
    public boolean offer(E e2, long j2, TimeUnit timeUnit) throws InterruptedException {
        if (e2 != null) {
            long nanos = timeUnit.toNanos(j2);
            ReentrantLock reentrantLock = this.putLock;
            AtomicInteger atomicInteger = this.count;
            reentrantLock.lockInterruptibly();
            while (atomicInteger.get() == this.capacity) {
                try {
                    if (nanos <= 0) {
                        return false;
                    }
                    nanos = this.notFull.awaitNanos(nanos);
                } finally {
                    reentrantLock.unlock();
                }
            }
            opQueue(new e.h.a.k.a<>(e2));
            int andIncrement = atomicInteger.getAndIncrement();
            if (andIncrement + 1 < this.capacity) {
                this.notFull.signal();
            }
            if (andIncrement == 0) {
                signalNotEmpty();
                return true;
            }
            return true;
        }
        throw null;
    }

    @Override // java.util.Queue
    public E peek() {
        if (this.count.get() == 0) {
            return null;
        }
        ReentrantLock reentrantLock = this.takeLock;
        reentrantLock.lock();
        try {
            e.h.a.k.a<E> aVar = this.head.next;
            if (aVar == null) {
                return null;
            }
            return aVar.getValue();
        } finally {
            reentrantLock.unlock();
        }
    }

    @Override // java.util.concurrent.BlockingQueue
    public E poll(long j2, TimeUnit timeUnit) throws InterruptedException {
        long nanos = timeUnit.toNanos(j2);
        AtomicInteger atomicInteger = this.count;
        ReentrantLock reentrantLock = this.takeLock;
        reentrantLock.lockInterruptibly();
        while (atomicInteger.get() == 0) {
            try {
                if (nanos <= 0) {
                    return null;
                }
                nanos = this.notEmpty.awaitNanos(nanos);
            } finally {
                reentrantLock.unlock();
            }
        }
        E opQueue = opQueue(null);
        int andDecrement = atomicInteger.getAndDecrement();
        if (andDecrement > 1) {
            this.notEmpty.signal();
        }
        reentrantLock.unlock();
        if (andDecrement == this.capacity) {
            signalNotFull();
        }
        return opQueue;
    }

    @Override // java.util.concurrent.BlockingQueue
    public void put(E e2) throws InterruptedException {
        if (e2 == null) {
            throw null;
        }
        e.h.a.k.a<E> aVar = new e.h.a.k.a<>(e2);
        ReentrantLock reentrantLock = this.putLock;
        AtomicInteger atomicInteger = this.count;
        reentrantLock.lockInterruptibly();
        while (atomicInteger.get() == this.capacity) {
            try {
                this.notFull.await();
            } finally {
                reentrantLock.unlock();
            }
        }
        opQueue(aVar);
        int andIncrement = atomicInteger.getAndIncrement();
        if (andIncrement + 1 < this.capacity) {
            this.notFull.signal();
        }
        if (andIncrement == 0) {
            signalNotEmpty();
        }
    }

    @Override // java.util.concurrent.BlockingQueue
    public int remainingCapacity() {
        return this.capacity - this.count.get();
    }

    @Override // java.util.AbstractCollection, java.util.Collection, java.util.concurrent.BlockingQueue
    public boolean remove(Object obj) {
        if (obj == null) {
            return false;
        }
        fullyLock();
        try {
            e.h.a.k.a<E> aVar = this.head;
            e.h.a.k.a<E> aVar2 = aVar.next;
            while (true) {
                e.h.a.k.a<E> aVar3 = aVar2;
                e.h.a.k.a<E> aVar4 = aVar;
                aVar = aVar3;
                if (aVar == null) {
                    return false;
                }
                if (obj.equals(aVar.getValue())) {
                    unlink(aVar, aVar4);
                    return true;
                }
                aVar2 = aVar.next;
            }
        } finally {
            fullyUnlock();
        }
    }

    @Override // java.util.AbstractCollection, java.util.Collection
    public int size() {
        return this.count.get();
    }

    @Override // java.util.concurrent.BlockingQueue
    public E take() throws InterruptedException {
        AtomicInteger atomicInteger = this.count;
        ReentrantLock reentrantLock = this.takeLock;
        reentrantLock.lockInterruptibly();
        while (atomicInteger.get() == 0) {
            try {
                this.notEmpty.await();
            } catch (Throwable th) {
                reentrantLock.unlock();
                throw th;
            }
        }
        E opQueue = opQueue(null);
        int andDecrement = atomicInteger.getAndDecrement();
        if (andDecrement > 1) {
            this.notEmpty.signal();
        }
        reentrantLock.unlock();
        if (andDecrement == this.capacity) {
            signalNotFull();
        }
        return opQueue;
    }

    @Override // java.util.AbstractCollection, java.util.Collection
    public Object[] toArray() {
        fullyLock();
        try {
            Object[] objArr = new Object[this.count.get()];
            int i2 = 0;
            e.h.a.k.a aVar = this.head.next;
            while (aVar != null) {
                int i3 = i2 + 1;
                objArr[i2] = aVar.getValue();
                aVar = aVar.next;
                i2 = i3;
            }
            return objArr;
        } finally {
            fullyUnlock();
        }
    }

    public void unlink(e.h.a.k.a<E> aVar, e.h.a.k.a<E> aVar2) {
        aVar.setValue(null);
        aVar2.next = (e.h.a.k.a<E>) aVar.next;
        if (this.last == aVar) {
            this.last = aVar2;
        }
        if (this.count.getAndDecrement() == this.capacity) {
            this.notFull.signal();
        }
    }

    public PriorityObjectBlockingQueue(int i2) {
        this.count = new AtomicInteger();
        ReentrantLock reentrantLock = new ReentrantLock();
        this.takeLock = reentrantLock;
        this.notEmpty = reentrantLock.newCondition();
        ReentrantLock reentrantLock2 = new ReentrantLock();
        this.putLock = reentrantLock2;
        this.notFull = reentrantLock2.newCondition();
        if (i2 > 0) {
            this.capacity = i2;
            e.h.a.k.a<E> aVar = new e.h.a.k.a<>(null);
            this.head = aVar;
            this.last = aVar;
            return;
        }
        throw new IllegalArgumentException();
    }

    @Override // java.util.concurrent.BlockingQueue
    public int drainTo(Collection<? super E> collection, int i2) {
        if (collection != null) {
            if (collection != this) {
                boolean z = false;
                if (i2 <= 0) {
                    return 0;
                }
                ReentrantLock reentrantLock = this.takeLock;
                reentrantLock.lock();
                try {
                    int min = Math.min(i2, this.count.get());
                    e.h.a.k.a<E> aVar = this.head;
                    int i3 = 0;
                    while (i3 < min) {
                        e.h.a.k.a<E> aVar2 = aVar.next;
                        collection.add((Object) aVar2.getValue());
                        aVar2.setValue(null);
                        aVar.next = (e.h.a.k.a<T>) aVar;
                        i3++;
                        aVar = aVar2;
                    }
                    if (i3 > 0) {
                        this.head = aVar;
                        if (this.count.getAndAdd(-i3) == this.capacity) {
                            z = true;
                        }
                    }
                    return min;
                } finally {
                    reentrantLock.unlock();
                    if (0 != 0) {
                        signalNotFull();
                    }
                }
            }
            throw new IllegalArgumentException();
        }
        throw null;
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // java.util.AbstractCollection, java.util.Collection
    public <T> T[] toArray(T[] tArr) {
        fullyLock();
        try {
            int i2 = this.count.get();
            if (tArr.length < i2) {
                tArr = (T[]) ((Object[]) Array.newInstance(tArr.getClass().getComponentType(), i2));
            }
            int i3 = 0;
            e.h.a.k.a aVar = this.head.next;
            while (aVar != null) {
                tArr[i3] = aVar.getValue();
                aVar = aVar.next;
                i3++;
            }
            if (tArr.length > i3) {
                tArr[i3] = null;
            }
            return tArr;
        } finally {
            fullyUnlock();
        }
    }

    public PriorityObjectBlockingQueue(Collection<? extends E> collection) {
        this(Integer.MAX_VALUE);
        ReentrantLock reentrantLock = this.putLock;
        reentrantLock.lock();
        int i2 = 0;
        try {
            for (E e2 : collection) {
                if (e2 != null) {
                    if (i2 != this.capacity) {
                        opQueue(new e.h.a.k.a<>(e2));
                        i2++;
                    } else {
                        throw new IllegalStateException("Queue full");
                    }
                } else {
                    throw new NullPointerException();
                }
            }
            this.count.set(i2);
        } finally {
            reentrantLock.unlock();
        }
    }

    @Override // java.util.Queue
    public E poll() {
        AtomicInteger atomicInteger = this.count;
        E e2 = null;
        if (atomicInteger.get() == 0) {
            return null;
        }
        int i2 = -1;
        ReentrantLock reentrantLock = this.takeLock;
        reentrantLock.lock();
        try {
            if (atomicInteger.get() > 0) {
                e2 = opQueue(null);
                i2 = atomicInteger.getAndDecrement();
                if (i2 > 1) {
                    this.notEmpty.signal();
                }
            }
            reentrantLock.unlock();
            if (i2 == this.capacity) {
                signalNotFull();
            }
            return e2;
        } catch (Throwable th) {
            reentrantLock.unlock();
            throw th;
        }
    }

    @Override // java.util.Queue, java.util.concurrent.BlockingQueue
    public boolean offer(E e2) {
        if (e2 != null) {
            AtomicInteger atomicInteger = this.count;
            if (atomicInteger.get() == this.capacity) {
                return false;
            }
            int i2 = -1;
            e.h.a.k.a<E> aVar = new e.h.a.k.a<>(e2);
            ReentrantLock reentrantLock = this.putLock;
            reentrantLock.lock();
            try {
                if (atomicInteger.get() < this.capacity) {
                    opQueue(aVar);
                    i2 = atomicInteger.getAndIncrement();
                    if (i2 + 1 < this.capacity) {
                        this.notFull.signal();
                    }
                }
                if (i2 == 0) {
                    signalNotEmpty();
                }
                return i2 >= 0;
            } finally {
                reentrantLock.unlock();
            }
        }
        throw null;
    }
}
