package com.scwang.smartrefresh.layout;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.ValueAnimator;
import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.os.Build;
import android.os.Handler;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.animation.AnimationUtils;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.Interpolator;
import android.widget.Scroller;
import android.widget.TextView;
import android.widget.Toast;
import androidx.annotation.ColorInt;
import androidx.annotation.ColorRes;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.core.content.ContextCompat;
import androidx.core.view.NestedScrollingChildHelper;
import androidx.core.view.NestedScrollingParent;
import androidx.core.view.NestedScrollingParentHelper;
import com.scwang.smartrefresh.layout.constant.DimensionStatus;
import com.scwang.smartrefresh.layout.constant.RefreshState;
import com.scwang.smartrefresh.layout.constant.SpinnerStyle;
import com.scwang.smartrefresh.layout.footer.BallPulseFooter;
import com.scwang.smartrefresh.layout.header.BezierRadarHeader;
import java.io.PrintStream;
/* compiled from: AAA */
@SuppressLint({"RestrictedApi"})
/* loaded from: classes3.dex */
public class SmartRefreshLayout extends ViewGroup implements e.l.a.a.b.j, NestedScrollingParent {
    public static ViewGroup.MarginLayoutParams sDefaultMarginLP = new ViewGroup.MarginLayoutParams(-1, -1);
    public static e.l.a.a.b.a sFooterCreator;
    public static e.l.a.a.b.b sHeaderCreator;
    public static e.l.a.a.b.c sRefreshInitializer;
    public Runnable animationRunnable;
    public int mCurrentVelocity;
    public boolean mDisableContentWhenLoading;
    public boolean mDisableContentWhenRefresh;
    public char mDragDirection;
    public float mDragRate;
    public boolean mEnableAutoLoadMore;
    public boolean mEnableClipFooterWhenFixedBehind;
    public boolean mEnableClipHeaderWhenFixedBehind;
    public boolean mEnableFooterFollowWhenNoMoreData;
    public boolean mEnableFooterTranslationContent;
    public boolean mEnableHeaderTranslationContent;
    public boolean mEnableLoadMore;
    public boolean mEnableLoadMoreWhenContentNotFull;
    public boolean mEnableNestedScrolling;
    public boolean mEnableOverScrollBounce;
    public boolean mEnableOverScrollDrag;
    public boolean mEnablePreviewInEditMode;
    public boolean mEnablePureScrollMode;
    public boolean mEnableRefresh;
    public boolean mEnableScrollContentWhenLoaded;
    public boolean mEnableScrollContentWhenRefreshed;
    public MotionEvent mFalsifyEvent;
    public int mFixedFooterViewId;
    public int mFixedHeaderViewId;
    public int mFloorDuration;
    public int mFooterBackgroundColor;
    public int mFooterHeight;
    public DimensionStatus mFooterHeightStatus;
    public int mFooterInsetStart;
    public boolean mFooterLocked;
    public float mFooterMaxDragRate;
    public boolean mFooterNeedTouchEventWhenLoading;
    public boolean mFooterNoMoreData;
    public int mFooterTranslationViewId;
    public float mFooterTriggerRate;
    public int mHeaderBackgroundColor;
    public int mHeaderHeight;
    public DimensionStatus mHeaderHeightStatus;
    public int mHeaderInsetStart;
    public float mHeaderMaxDragRate;
    public boolean mHeaderNeedTouchEventWhenRefreshing;
    public int mHeaderTranslationViewId;
    public float mHeaderTriggerRate;
    public boolean mIsBeingDragged;
    public e.l.a.a.b.i mKernel;
    public long mLastOpenTime;
    public int mLastSpinner;
    public float mLastTouchX;
    public float mLastTouchY;
    public e.l.a.a.e.b mLoadMoreListener;
    public boolean mManualFooterTranslationContent;
    public boolean mManualHeaderTranslationContent;
    public boolean mManualLoadMore;
    public int mMaximumVelocity;
    public int mMinimumVelocity;
    public NestedScrollingChildHelper mNestedChild;
    public boolean mNestedInProgress;
    public NestedScrollingParentHelper mNestedParent;
    public e.l.a.a.e.c mOnMultiPurposeListener;
    public Paint mPaint;
    public int[] mParentOffsetInWindow;
    public int[] mPrimaryColors;
    public int mReboundDuration;
    public Interpolator mReboundInterpolator;
    public e.l.a.a.b.e mRefreshContent;
    public e.l.a.a.b.h mRefreshFooter;
    public e.l.a.a.b.h mRefreshHeader;
    public e.l.a.a.e.d mRefreshListener;
    public int mScreenHeightPixels;
    public e.l.a.a.b.k mScrollBoundaryDecider;
    public Scroller mScroller;
    public int mSpinner;
    public RefreshState mState;
    public boolean mSuperDispatchTouchEvent;
    public int mTotalUnconsumed;
    public int mTouchSlop;
    public int mTouchSpinner;
    public float mTouchX;
    public float mTouchY;
    public VelocityTracker mVelocityTracker;
    public boolean mVerticalPermit;
    public RefreshState mViceState;
    public ValueAnimator reboundAnimator;

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public static /* synthetic */ class a {
        public static final /* synthetic */ int[] $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState;

        static {
            int[] iArr = new int[RefreshState.values().length];
            $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState = iArr;
            try {
                iArr[RefreshState.None.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.PullDownToRefresh.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.PullUpToLoad.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.PullDownCanceled.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.PullUpCanceled.ordinal()] = 5;
            } catch (NoSuchFieldError unused5) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.ReleaseToRefresh.ordinal()] = 6;
            } catch (NoSuchFieldError unused6) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.ReleaseToLoad.ordinal()] = 7;
            } catch (NoSuchFieldError unused7) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.ReleaseToTwoLevel.ordinal()] = 8;
            } catch (NoSuchFieldError unused8) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.RefreshReleased.ordinal()] = 9;
            } catch (NoSuchFieldError unused9) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.LoadReleased.ordinal()] = 10;
            } catch (NoSuchFieldError unused10) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.Refreshing.ordinal()] = 11;
            } catch (NoSuchFieldError unused11) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.Loading.ordinal()] = 12;
            } catch (NoSuchFieldError unused12) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.RefreshFinish.ordinal()] = 13;
            } catch (NoSuchFieldError unused13) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.LoadFinish.ordinal()] = 14;
            } catch (NoSuchFieldError unused14) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.TwoLevelReleased.ordinal()] = 15;
            } catch (NoSuchFieldError unused15) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.TwoLevelFinish.ordinal()] = 16;
            } catch (NoSuchFieldError unused16) {
            }
            try {
                $SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[RefreshState.TwoLevel.ordinal()] = 17;
            } catch (NoSuchFieldError unused17) {
            }
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class b extends AnimatorListenerAdapter {
        public final /* synthetic */ boolean val$notify;

        public b(boolean z) {
            this.val$notify = z;
        }

        @Override // android.animation.AnimatorListenerAdapter, android.animation.Animator.AnimatorListener
        public void onAnimationEnd(Animator animator) {
            SmartRefreshLayout.this.setStateDirectLoading(this.val$notify);
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class c extends AnimatorListenerAdapter {
        public final /* synthetic */ boolean val$notify;

        public c(boolean z) {
            this.val$notify = z;
        }

        @Override // android.animation.AnimatorListenerAdapter, android.animation.Animator.AnimatorListener
        public void onAnimationEnd(Animator animator) {
            SmartRefreshLayout.this.mLastOpenTime = System.currentTimeMillis();
            SmartRefreshLayout.this.notifyStateChanged(RefreshState.Refreshing);
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            e.l.a.a.e.d dVar = smartRefreshLayout.mRefreshListener;
            if (dVar != null) {
                if (this.val$notify) {
                    dVar.onRefresh(smartRefreshLayout);
                }
            } else if (smartRefreshLayout.mOnMultiPurposeListener == null) {
                smartRefreshLayout.finishRefresh(3000);
            }
            SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
            e.l.a.a.b.h hVar = smartRefreshLayout2.mRefreshHeader;
            if (hVar != null) {
                int i2 = smartRefreshLayout2.mHeaderHeight;
                hVar.onStartAnimator(smartRefreshLayout2, i2, (int) (smartRefreshLayout2.mHeaderMaxDragRate * i2));
            }
            SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
            e.l.a.a.e.c cVar = smartRefreshLayout3.mOnMultiPurposeListener;
            if (cVar == null || !(smartRefreshLayout3.mRefreshHeader instanceof e.l.a.a.b.g)) {
                return;
            }
            if (this.val$notify) {
                cVar.onRefresh(smartRefreshLayout3);
            }
            SmartRefreshLayout smartRefreshLayout4 = SmartRefreshLayout.this;
            int i3 = smartRefreshLayout4.mHeaderHeight;
            smartRefreshLayout4.mOnMultiPurposeListener.onHeaderStartAnimator((e.l.a.a.b.g) smartRefreshLayout4.mRefreshHeader, i3, (int) (smartRefreshLayout4.mHeaderMaxDragRate * i3));
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class d extends AnimatorListenerAdapter {
        public d() {
        }

        @Override // android.animation.AnimatorListenerAdapter, android.animation.Animator.AnimatorListener
        public void onAnimationEnd(Animator animator) {
            RefreshState refreshState;
            RefreshState refreshState2;
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            smartRefreshLayout.reboundAnimator = null;
            if (smartRefreshLayout.mSpinner == 0 && (refreshState = smartRefreshLayout.mState) != (refreshState2 = RefreshState.None) && !refreshState.isOpening && !refreshState.isDragging) {
                smartRefreshLayout.notifyStateChanged(refreshState2);
                return;
            }
            SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
            RefreshState refreshState3 = smartRefreshLayout2.mState;
            if (refreshState3 != smartRefreshLayout2.mViceState) {
                smartRefreshLayout2.setViceState(refreshState3);
            }
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class e implements ValueAnimator.AnimatorUpdateListener {
        public e() {
        }

        @Override // android.animation.ValueAnimator.AnimatorUpdateListener
        public void onAnimationUpdate(ValueAnimator valueAnimator) {
            SmartRefreshLayout.this.mKernel.moveSpinner(((Integer) valueAnimator.getAnimatedValue()).intValue(), false);
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class f implements Runnable {
        public f() {
        }

        @Override // java.lang.Runnable
        public void run() {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            e.l.a.a.e.b bVar = smartRefreshLayout.mLoadMoreListener;
            if (bVar != null) {
                bVar.onLoadMore(smartRefreshLayout);
            } else if (smartRefreshLayout.mOnMultiPurposeListener == null) {
                smartRefreshLayout.finishLoadMore(2000);
            }
            SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
            e.l.a.a.e.c cVar = smartRefreshLayout2.mOnMultiPurposeListener;
            if (cVar != null) {
                cVar.onLoadMore(smartRefreshLayout2);
            }
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class g implements Runnable {
        public final /* synthetic */ Boolean val$noMoreData;
        public final /* synthetic */ boolean val$success;

        public g(Boolean bool, boolean z) {
            this.val$noMoreData = bool;
            this.val$success = z;
        }

        @Override // java.lang.Runnable
        public void run() {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            if (smartRefreshLayout.mState == RefreshState.Refreshing && smartRefreshLayout.mRefreshHeader != null && smartRefreshLayout.mRefreshContent != null) {
                Boolean bool = this.val$noMoreData;
                if (bool != null) {
                    smartRefreshLayout.setNoMoreData(bool == Boolean.TRUE);
                }
                SmartRefreshLayout.this.notifyStateChanged(RefreshState.RefreshFinish);
                SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                int onFinish = smartRefreshLayout2.mRefreshHeader.onFinish(smartRefreshLayout2, this.val$success);
                SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
                e.l.a.a.e.c cVar = smartRefreshLayout3.mOnMultiPurposeListener;
                if (cVar != null) {
                    e.l.a.a.b.h hVar = smartRefreshLayout3.mRefreshHeader;
                    if (hVar instanceof e.l.a.a.b.g) {
                        cVar.onHeaderFinish((e.l.a.a.b.g) hVar, this.val$success);
                    }
                }
                if (onFinish < Integer.MAX_VALUE) {
                    SmartRefreshLayout smartRefreshLayout4 = SmartRefreshLayout.this;
                    if (smartRefreshLayout4.mIsBeingDragged || smartRefreshLayout4.mNestedInProgress) {
                        long currentTimeMillis = System.currentTimeMillis();
                        SmartRefreshLayout smartRefreshLayout5 = SmartRefreshLayout.this;
                        if (smartRefreshLayout5.mIsBeingDragged) {
                            float f2 = smartRefreshLayout5.mLastTouchY;
                            smartRefreshLayout5.mTouchY = f2;
                            smartRefreshLayout5.mTouchSpinner = 0;
                            smartRefreshLayout5.mIsBeingDragged = false;
                            SmartRefreshLayout.super.dispatchTouchEvent(MotionEvent.obtain(currentTimeMillis, currentTimeMillis, 0, smartRefreshLayout5.mLastTouchX, (f2 + smartRefreshLayout5.mSpinner) - (smartRefreshLayout5.mTouchSlop * 2), 0));
                            SmartRefreshLayout smartRefreshLayout6 = SmartRefreshLayout.this;
                            SmartRefreshLayout.super.dispatchTouchEvent(MotionEvent.obtain(currentTimeMillis, currentTimeMillis, 2, smartRefreshLayout6.mLastTouchX, smartRefreshLayout6.mLastTouchY + smartRefreshLayout6.mSpinner, 0));
                        }
                        SmartRefreshLayout smartRefreshLayout7 = SmartRefreshLayout.this;
                        if (smartRefreshLayout7.mNestedInProgress) {
                            smartRefreshLayout7.mTotalUnconsumed = 0;
                            SmartRefreshLayout.super.dispatchTouchEvent(MotionEvent.obtain(currentTimeMillis, currentTimeMillis, 1, smartRefreshLayout7.mLastTouchX, smartRefreshLayout7.mLastTouchY, 0));
                            SmartRefreshLayout smartRefreshLayout8 = SmartRefreshLayout.this;
                            smartRefreshLayout8.mNestedInProgress = false;
                            smartRefreshLayout8.mTouchSpinner = 0;
                        }
                    }
                    SmartRefreshLayout smartRefreshLayout9 = SmartRefreshLayout.this;
                    int i2 = smartRefreshLayout9.mSpinner;
                    if (i2 <= 0) {
                        if (i2 < 0) {
                            smartRefreshLayout9.animSpinner(0, onFinish, smartRefreshLayout9.mReboundInterpolator, smartRefreshLayout9.mReboundDuration);
                            return;
                        }
                        smartRefreshLayout9.mKernel.moveSpinner(0, false);
                        SmartRefreshLayout.this.mKernel.setState(RefreshState.None);
                        return;
                    }
                    ValueAnimator animSpinner = smartRefreshLayout9.animSpinner(0, onFinish, smartRefreshLayout9.mReboundInterpolator, smartRefreshLayout9.mReboundDuration);
                    SmartRefreshLayout smartRefreshLayout10 = SmartRefreshLayout.this;
                    ValueAnimator.AnimatorUpdateListener scrollContentWhenFinished = smartRefreshLayout10.mEnableScrollContentWhenRefreshed ? smartRefreshLayout10.mRefreshContent.scrollContentWhenFinished(smartRefreshLayout10.mSpinner) : null;
                    if (animSpinner == null || scrollContentWhenFinished == null) {
                        return;
                    }
                    animSpinner.addUpdateListener(scrollContentWhenFinished);
                    return;
                }
                return;
            }
            SmartRefreshLayout smartRefreshLayout11 = SmartRefreshLayout.this;
            if (smartRefreshLayout11.mState == RefreshState.None && smartRefreshLayout11.mViceState == RefreshState.Refreshing) {
                smartRefreshLayout11.mViceState = RefreshState.None;
                return;
            }
            SmartRefreshLayout smartRefreshLayout12 = SmartRefreshLayout.this;
            if (smartRefreshLayout12.reboundAnimator != null) {
                RefreshState refreshState = smartRefreshLayout12.mState;
                if (refreshState.isHeader) {
                    if (refreshState.isDragging || refreshState == RefreshState.RefreshReleased) {
                        SmartRefreshLayout smartRefreshLayout13 = SmartRefreshLayout.this;
                        ValueAnimator valueAnimator = smartRefreshLayout13.reboundAnimator;
                        smartRefreshLayout13.reboundAnimator = null;
                        valueAnimator.cancel();
                        SmartRefreshLayout.this.mKernel.setState(RefreshState.None);
                    }
                }
            }
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class h implements Runnable {
        public final /* synthetic */ boolean val$noMoreData;
        public final /* synthetic */ boolean val$success;

        /* compiled from: AAA */
        /* loaded from: classes3.dex */
        public class a implements Runnable {
            public final /* synthetic */ int val$offset;

            /* compiled from: AAA */
            /* renamed from: com.scwang.smartrefresh.layout.SmartRefreshLayout$h$a$a  reason: collision with other inner class name */
            /* loaded from: classes3.dex */
            public class C0195a extends AnimatorListenerAdapter {
                public C0195a() {
                }

                @Override // android.animation.AnimatorListenerAdapter, android.animation.Animator.AnimatorListener
                public void onAnimationEnd(Animator animator) {
                    h hVar = h.this;
                    SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                    smartRefreshLayout.mFooterLocked = false;
                    if (hVar.val$noMoreData) {
                        smartRefreshLayout.setNoMoreData(true);
                    }
                    SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                    if (smartRefreshLayout2.mState == RefreshState.LoadFinish) {
                        smartRefreshLayout2.notifyStateChanged(RefreshState.None);
                    }
                }
            }

            public a(int i2) {
                this.val$offset = i2;
            }

            @Override // java.lang.Runnable
            public void run() {
                ValueAnimator valueAnimator;
                SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                ValueAnimator.AnimatorUpdateListener scrollContentWhenFinished = (!smartRefreshLayout.mEnableScrollContentWhenLoaded || this.val$offset >= 0) ? null : smartRefreshLayout.mRefreshContent.scrollContentWhenFinished(smartRefreshLayout.mSpinner);
                if (scrollContentWhenFinished != null) {
                    scrollContentWhenFinished.onAnimationUpdate(ValueAnimator.ofInt(0, 0));
                }
                C0195a c0195a = new C0195a();
                h hVar = h.this;
                SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                int i2 = smartRefreshLayout2.mSpinner;
                if (i2 > 0) {
                    valueAnimator = smartRefreshLayout2.mKernel.animSpinner(0);
                } else {
                    if (scrollContentWhenFinished == null && i2 != 0) {
                        if (hVar.val$noMoreData && smartRefreshLayout2.mEnableFooterFollowWhenNoMoreData) {
                            int i3 = smartRefreshLayout2.mFooterHeight;
                            if (i2 >= (-i3)) {
                                smartRefreshLayout2.notifyStateChanged(RefreshState.None);
                            } else {
                                valueAnimator = smartRefreshLayout2.mKernel.animSpinner(-i3);
                            }
                        } else {
                            valueAnimator = SmartRefreshLayout.this.mKernel.animSpinner(0);
                        }
                    } else {
                        ValueAnimator valueAnimator2 = SmartRefreshLayout.this.reboundAnimator;
                        if (valueAnimator2 != null) {
                            valueAnimator2.cancel();
                            SmartRefreshLayout.this.reboundAnimator = null;
                        }
                        SmartRefreshLayout.this.mKernel.moveSpinner(0, false);
                        SmartRefreshLayout.this.mKernel.setState(RefreshState.None);
                    }
                    valueAnimator = null;
                }
                if (valueAnimator != null) {
                    valueAnimator.addListener(c0195a);
                } else {
                    c0195a.onAnimationEnd(null);
                }
            }
        }

        public h(boolean z, boolean z2) {
            this.val$success = z;
            this.val$noMoreData = z2;
        }

        /* JADX WARN: Code restructure failed: missing block: B:22:0x004d, code lost:
            if (r1.mRefreshContent.canLoadMore() != false) goto L22;
         */
        @Override // java.lang.Runnable
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public void run() {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            boolean z = true;
            if (smartRefreshLayout.mState == RefreshState.Loading && smartRefreshLayout.mRefreshFooter != null && smartRefreshLayout.mRefreshContent != null) {
                smartRefreshLayout.notifyStateChanged(RefreshState.LoadFinish);
                SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                int onFinish = smartRefreshLayout2.mRefreshFooter.onFinish(smartRefreshLayout2, this.val$success);
                SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
                e.l.a.a.e.c cVar = smartRefreshLayout3.mOnMultiPurposeListener;
                if (cVar != null) {
                    e.l.a.a.b.h hVar = smartRefreshLayout3.mRefreshFooter;
                    if (hVar instanceof e.l.a.a.b.f) {
                        cVar.onFooterFinish((e.l.a.a.b.f) hVar, this.val$success);
                    }
                }
                if (onFinish < Integer.MAX_VALUE) {
                    if (this.val$noMoreData) {
                        SmartRefreshLayout smartRefreshLayout4 = SmartRefreshLayout.this;
                        if (smartRefreshLayout4.mEnableFooterFollowWhenNoMoreData) {
                            if (smartRefreshLayout4.mSpinner < 0) {
                            }
                        }
                    }
                    z = false;
                    SmartRefreshLayout smartRefreshLayout5 = SmartRefreshLayout.this;
                    int i2 = smartRefreshLayout5.mSpinner;
                    int max = i2 - (z ? Math.max(i2, -smartRefreshLayout5.mFooterHeight) : 0);
                    SmartRefreshLayout smartRefreshLayout6 = SmartRefreshLayout.this;
                    if (smartRefreshLayout6.mIsBeingDragged || smartRefreshLayout6.mNestedInProgress) {
                        long currentTimeMillis = System.currentTimeMillis();
                        SmartRefreshLayout smartRefreshLayout7 = SmartRefreshLayout.this;
                        if (smartRefreshLayout7.mIsBeingDragged) {
                            smartRefreshLayout7.mTouchY = smartRefreshLayout7.mLastTouchY;
                            smartRefreshLayout7.mTouchSpinner = smartRefreshLayout7.mSpinner - max;
                            smartRefreshLayout7.mIsBeingDragged = false;
                            int i3 = smartRefreshLayout7.mEnableFooterTranslationContent ? max : 0;
                            SmartRefreshLayout smartRefreshLayout8 = SmartRefreshLayout.this;
                            float f2 = i3;
                            SmartRefreshLayout.super.dispatchTouchEvent(MotionEvent.obtain(currentTimeMillis, currentTimeMillis, 0, smartRefreshLayout8.mLastTouchX, smartRefreshLayout8.mLastTouchY + f2 + (smartRefreshLayout8.mTouchSlop * 2), 0));
                            SmartRefreshLayout smartRefreshLayout9 = SmartRefreshLayout.this;
                            SmartRefreshLayout.super.dispatchTouchEvent(MotionEvent.obtain(currentTimeMillis, currentTimeMillis, 2, smartRefreshLayout9.mLastTouchX, smartRefreshLayout9.mLastTouchY + f2, 0));
                        }
                        SmartRefreshLayout smartRefreshLayout10 = SmartRefreshLayout.this;
                        if (smartRefreshLayout10.mNestedInProgress) {
                            smartRefreshLayout10.mTotalUnconsumed = 0;
                            SmartRefreshLayout.super.dispatchTouchEvent(MotionEvent.obtain(currentTimeMillis, currentTimeMillis, 1, smartRefreshLayout10.mLastTouchX, smartRefreshLayout10.mLastTouchY, 0));
                            SmartRefreshLayout smartRefreshLayout11 = SmartRefreshLayout.this;
                            smartRefreshLayout11.mNestedInProgress = false;
                            smartRefreshLayout11.mTouchSpinner = 0;
                        }
                    }
                    SmartRefreshLayout.this.postDelayed(new a(max), SmartRefreshLayout.this.mSpinner < 0 ? onFinish : 0L);
                    return;
                }
                return;
            }
            SmartRefreshLayout smartRefreshLayout12 = SmartRefreshLayout.this;
            if (smartRefreshLayout12.mState == RefreshState.None && smartRefreshLayout12.mViceState == RefreshState.Loading) {
                smartRefreshLayout12.mViceState = RefreshState.None;
            } else {
                SmartRefreshLayout smartRefreshLayout13 = SmartRefreshLayout.this;
                if (smartRefreshLayout13.reboundAnimator != null) {
                    RefreshState refreshState = smartRefreshLayout13.mState;
                    if (refreshState.isDragging || refreshState == RefreshState.LoadReleased) {
                        SmartRefreshLayout smartRefreshLayout14 = SmartRefreshLayout.this;
                        if (smartRefreshLayout14.mState.isFooter) {
                            ValueAnimator valueAnimator = smartRefreshLayout14.reboundAnimator;
                            smartRefreshLayout14.reboundAnimator = null;
                            valueAnimator.cancel();
                            SmartRefreshLayout.this.mKernel.setState(RefreshState.None);
                        }
                    }
                }
            }
            if (this.val$noMoreData) {
                SmartRefreshLayout.this.setNoMoreData(true);
            }
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class i implements Runnable {
        public final /* synthetic */ boolean val$animationOnly;
        public final /* synthetic */ float val$dragRate;
        public final /* synthetic */ int val$duration;

        /* compiled from: AAA */
        /* loaded from: classes3.dex */
        public class a implements ValueAnimator.AnimatorUpdateListener {
            public a() {
            }

            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                if (smartRefreshLayout.reboundAnimator != null) {
                    smartRefreshLayout.mKernel.moveSpinner(((Integer) valueAnimator.getAnimatedValue()).intValue(), true);
                }
            }
        }

        /* compiled from: AAA */
        /* loaded from: classes3.dex */
        public class b extends AnimatorListenerAdapter {
            public b() {
            }

            @Override // android.animation.AnimatorListenerAdapter, android.animation.Animator.AnimatorListener
            public void onAnimationEnd(Animator animator) {
                SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                if (smartRefreshLayout.reboundAnimator != null) {
                    smartRefreshLayout.reboundAnimator = null;
                    RefreshState refreshState = smartRefreshLayout.mState;
                    RefreshState refreshState2 = RefreshState.ReleaseToRefresh;
                    if (refreshState != refreshState2) {
                        smartRefreshLayout.mKernel.setState(refreshState2);
                    }
                    i iVar = i.this;
                    SmartRefreshLayout.this.setStateRefreshing(!iVar.val$animationOnly);
                }
            }
        }

        public i(float f2, int i2, boolean z) {
            this.val$dragRate = f2;
            this.val$duration = i2;
            this.val$animationOnly = z;
        }

        @Override // java.lang.Runnable
        public void run() {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            if (smartRefreshLayout.mViceState != RefreshState.Refreshing) {
                return;
            }
            ValueAnimator valueAnimator = smartRefreshLayout.reboundAnimator;
            if (valueAnimator != null) {
                valueAnimator.cancel();
            }
            SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
            smartRefreshLayout2.mLastTouchX = smartRefreshLayout2.getMeasuredWidth() / 2.0f;
            SmartRefreshLayout.this.mKernel.setState(RefreshState.PullDownToRefresh);
            SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
            smartRefreshLayout3.reboundAnimator = ValueAnimator.ofInt(smartRefreshLayout3.mSpinner, (int) (smartRefreshLayout3.mHeaderHeight * this.val$dragRate));
            SmartRefreshLayout.this.reboundAnimator.setDuration(this.val$duration);
            SmartRefreshLayout.this.reboundAnimator.setInterpolator(new DecelerateInterpolator());
            SmartRefreshLayout.this.reboundAnimator.addUpdateListener(new a());
            SmartRefreshLayout.this.reboundAnimator.addListener(new b());
            SmartRefreshLayout.this.reboundAnimator.start();
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class j implements Runnable {
        public final /* synthetic */ boolean val$animationOnly;
        public final /* synthetic */ float val$dragRate;
        public final /* synthetic */ int val$duration;

        /* compiled from: AAA */
        /* loaded from: classes3.dex */
        public class a implements ValueAnimator.AnimatorUpdateListener {
            public a() {
            }

            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                if (smartRefreshLayout.reboundAnimator != null) {
                    smartRefreshLayout.mKernel.moveSpinner(((Integer) valueAnimator.getAnimatedValue()).intValue(), true);
                }
            }
        }

        /* compiled from: AAA */
        /* loaded from: classes3.dex */
        public class b extends AnimatorListenerAdapter {
            public b() {
            }

            @Override // android.animation.AnimatorListenerAdapter, android.animation.Animator.AnimatorListener
            public void onAnimationEnd(Animator animator) {
                SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                if (smartRefreshLayout.reboundAnimator != null) {
                    smartRefreshLayout.reboundAnimator = null;
                    RefreshState refreshState = smartRefreshLayout.mState;
                    RefreshState refreshState2 = RefreshState.ReleaseToLoad;
                    if (refreshState != refreshState2) {
                        smartRefreshLayout.mKernel.setState(refreshState2);
                    }
                    j jVar = j.this;
                    SmartRefreshLayout.this.setStateLoading(!jVar.val$animationOnly);
                }
            }
        }

        public j(float f2, int i2, boolean z) {
            this.val$dragRate = f2;
            this.val$duration = i2;
            this.val$animationOnly = z;
        }

        @Override // java.lang.Runnable
        public void run() {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            if (smartRefreshLayout.mViceState != RefreshState.Loading) {
                return;
            }
            ValueAnimator valueAnimator = smartRefreshLayout.reboundAnimator;
            if (valueAnimator != null) {
                valueAnimator.cancel();
            }
            SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
            smartRefreshLayout2.mLastTouchX = smartRefreshLayout2.getMeasuredWidth() / 2.0f;
            SmartRefreshLayout.this.mKernel.setState(RefreshState.PullUpToLoad);
            SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
            smartRefreshLayout3.reboundAnimator = ValueAnimator.ofInt(smartRefreshLayout3.mSpinner, -((int) (smartRefreshLayout3.mFooterHeight * this.val$dragRate)));
            SmartRefreshLayout.this.reboundAnimator.setDuration(this.val$duration);
            SmartRefreshLayout.this.reboundAnimator.setInterpolator(new DecelerateInterpolator());
            SmartRefreshLayout.this.reboundAnimator.addUpdateListener(new a());
            SmartRefreshLayout.this.reboundAnimator.addListener(new b());
            SmartRefreshLayout.this.reboundAnimator.start();
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class k implements Runnable {
        public int mSmoothDistance;
        public float mVelocity;
        public int mFrame = 0;
        public int mFrameDelay = 10;
        public float mOffset = 0.0f;
        public long mLastTime = AnimationUtils.currentAnimationTimeMillis();

        public k(float f2, int i2) {
            this.mVelocity = f2;
            this.mSmoothDistance = i2;
            SmartRefreshLayout.this.postDelayed(this, this.mFrameDelay);
            if (f2 > 0.0f) {
                SmartRefreshLayout.this.mKernel.setState(RefreshState.PullDownToRefresh);
            } else {
                SmartRefreshLayout.this.mKernel.setState(RefreshState.PullUpToLoad);
            }
        }

        @Override // java.lang.Runnable
        public void run() {
            int i2;
            int i3;
            int i4;
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            if (smartRefreshLayout.animationRunnable != this || smartRefreshLayout.mState.isFinishing) {
                return;
            }
            if (Math.abs(smartRefreshLayout.mSpinner) >= Math.abs(this.mSmoothDistance)) {
                if (this.mSmoothDistance != 0) {
                    double d2 = this.mVelocity;
                    this.mFrame = this.mFrame + 1;
                    double pow = Math.pow(0.44999998807907104d, i4 * 2);
                    Double.isNaN(d2);
                    this.mVelocity = (float) (d2 * pow);
                } else {
                    double d3 = this.mVelocity;
                    this.mFrame = this.mFrame + 1;
                    double pow2 = Math.pow(0.8500000238418579d, i3 * 2);
                    Double.isNaN(d3);
                    this.mVelocity = (float) (d3 * pow2);
                }
            } else {
                double d4 = this.mVelocity;
                this.mFrame = this.mFrame + 1;
                double pow3 = Math.pow(0.949999988079071d, i2 * 2);
                Double.isNaN(d4);
                this.mVelocity = (float) (d4 * pow3);
            }
            long currentAnimationTimeMillis = AnimationUtils.currentAnimationTimeMillis();
            float f2 = this.mVelocity * ((((float) (currentAnimationTimeMillis - this.mLastTime)) * 1.0f) / 1000.0f);
            if (Math.abs(f2) >= 1.0f) {
                this.mLastTime = currentAnimationTimeMillis;
                float f3 = this.mOffset + f2;
                this.mOffset = f3;
                SmartRefreshLayout.this.moveSpinnerInfinitely(f3);
                SmartRefreshLayout.this.postDelayed(this, this.mFrameDelay);
                return;
            }
            SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
            RefreshState refreshState = smartRefreshLayout2.mViceState;
            if (refreshState.isDragging && refreshState.isHeader) {
                smartRefreshLayout2.mKernel.setState(RefreshState.PullDownCanceled);
            } else {
                SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
                RefreshState refreshState2 = smartRefreshLayout3.mViceState;
                if (refreshState2.isDragging && refreshState2.isFooter) {
                    smartRefreshLayout3.mKernel.setState(RefreshState.PullUpCanceled);
                }
            }
            SmartRefreshLayout smartRefreshLayout4 = SmartRefreshLayout.this;
            smartRefreshLayout4.animationRunnable = null;
            if (Math.abs(smartRefreshLayout4.mSpinner) >= Math.abs(this.mSmoothDistance)) {
                SmartRefreshLayout smartRefreshLayout5 = SmartRefreshLayout.this;
                smartRefreshLayout5.animSpinner(this.mSmoothDistance, 0, smartRefreshLayout5.mReboundInterpolator, Math.min(Math.max((int) e.l.a.a.f.a.px2dp(Math.abs(SmartRefreshLayout.this.mSpinner - this.mSmoothDistance)), 30), 100) * 10);
            }
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class l implements Runnable {
        public int mOffset;
        public float mVelocity;
        public int mFrame = 0;
        public int mFrameDelay = 10;
        public float mDamping = 0.98f;
        public long mStartTime = 0;
        public long mLastTime = AnimationUtils.currentAnimationTimeMillis();

        public l(float f2) {
            this.mVelocity = f2;
            this.mOffset = SmartRefreshLayout.this.mSpinner;
        }

        @Override // java.lang.Runnable
        public void run() {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            if (smartRefreshLayout.animationRunnable != this || smartRefreshLayout.mState.isFinishing) {
                return;
            }
            long currentAnimationTimeMillis = AnimationUtils.currentAnimationTimeMillis();
            double d2 = this.mVelocity;
            double pow = Math.pow(this.mDamping, ((float) (currentAnimationTimeMillis - this.mStartTime)) / (1000.0f / this.mFrameDelay));
            Double.isNaN(d2);
            float f2 = (float) (d2 * pow);
            this.mVelocity = f2;
            float f3 = f2 * ((((float) (currentAnimationTimeMillis - this.mLastTime)) * 1.0f) / 1000.0f);
            if (Math.abs(f3) > 1.0f) {
                this.mLastTime = currentAnimationTimeMillis;
                int i2 = (int) (this.mOffset + f3);
                this.mOffset = i2;
                SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                if (smartRefreshLayout2.mSpinner * i2 > 0) {
                    smartRefreshLayout2.mKernel.moveSpinner(i2, true);
                    SmartRefreshLayout.this.postDelayed(this, this.mFrameDelay);
                    return;
                }
                smartRefreshLayout2.animationRunnable = null;
                smartRefreshLayout2.mKernel.moveSpinner(0, true);
                e.l.a.a.f.d.fling(SmartRefreshLayout.this.mRefreshContent.getScrollableView(), (int) (-this.mVelocity));
                SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
                if (!smartRefreshLayout3.mFooterLocked || f3 <= 0.0f) {
                    return;
                }
                smartRefreshLayout3.mFooterLocked = false;
                return;
            }
            SmartRefreshLayout.this.animationRunnable = null;
        }

        /* JADX WARN: Code restructure failed: missing block: B:24:0x0041, code lost:
            if (r0.mSpinner >= (-r0.mFooterHeight)) goto L42;
         */
        /* JADX WARN: Code restructure failed: missing block: B:28:0x004f, code lost:
            if (r0.mSpinner > r0.mHeaderHeight) goto L15;
         */
        /* JADX WARN: Code restructure failed: missing block: B:43:0x00a5, code lost:
            if (r4 < (-r0.mFooterHeight)) goto L32;
         */
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public Runnable start() {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            RefreshState refreshState = smartRefreshLayout.mState;
            if (refreshState.isFinishing) {
                return null;
            }
            if (smartRefreshLayout.mSpinner != 0) {
                if (refreshState.isOpening || (smartRefreshLayout.mFooterNoMoreData && smartRefreshLayout.mEnableFooterFollowWhenNoMoreData && smartRefreshLayout.isEnableRefreshOrLoadMore(smartRefreshLayout.mEnableLoadMore))) {
                    SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                    if (smartRefreshLayout2.mState == RefreshState.Loading || (smartRefreshLayout2.mFooterNoMoreData && smartRefreshLayout2.mEnableFooterFollowWhenNoMoreData && smartRefreshLayout2.isEnableRefreshOrLoadMore(smartRefreshLayout2.mEnableLoadMore))) {
                        SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
                    }
                    SmartRefreshLayout smartRefreshLayout4 = SmartRefreshLayout.this;
                    if (smartRefreshLayout4.mState == RefreshState.Refreshing) {
                    }
                }
                int i2 = 0;
                int i3 = SmartRefreshLayout.this.mSpinner;
                float f2 = this.mVelocity;
                int i4 = i3;
                while (true) {
                    if (i3 * i4 <= 0) {
                        break;
                    }
                    double d2 = f2;
                    i2++;
                    double pow = Math.pow(this.mDamping, (this.mFrameDelay * i2) / 10.0f);
                    Double.isNaN(d2);
                    f2 = (float) (d2 * pow);
                    float f3 = ((this.mFrameDelay * 1.0f) / 1000.0f) * f2;
                    if (Math.abs(f3) < 1.0f) {
                        SmartRefreshLayout smartRefreshLayout5 = SmartRefreshLayout.this;
                        RefreshState refreshState2 = smartRefreshLayout5.mState;
                        if (refreshState2.isOpening && (refreshState2 != RefreshState.Refreshing || i4 <= smartRefreshLayout5.mHeaderHeight)) {
                            SmartRefreshLayout smartRefreshLayout6 = SmartRefreshLayout.this;
                            if (smartRefreshLayout6.mState != RefreshState.Refreshing) {
                            }
                        }
                        return null;
                    }
                    i4 = (int) (i4 + f3);
                }
            }
            this.mStartTime = AnimationUtils.currentAnimationTimeMillis();
            SmartRefreshLayout.this.postDelayed(this, this.mFrameDelay);
            return this;
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class m implements e.l.a.a.b.i {

        /* compiled from: AAA */
        /* loaded from: classes3.dex */
        public class a extends AnimatorListenerAdapter {
            public a() {
            }

            @Override // android.animation.AnimatorListenerAdapter, android.animation.Animator.AnimatorListener
            public void onAnimationEnd(Animator animator) {
                SmartRefreshLayout.this.mKernel.setState(RefreshState.TwoLevel);
            }
        }

        public m() {
        }

        @Override // e.l.a.a.b.i
        public ValueAnimator animSpinner(int i2) {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            return smartRefreshLayout.animSpinner(i2, 0, smartRefreshLayout.mReboundInterpolator, smartRefreshLayout.mReboundDuration);
        }

        @Override // e.l.a.a.b.i
        public e.l.a.a.b.i finishTwoLevel() {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            if (smartRefreshLayout.mState == RefreshState.TwoLevel) {
                smartRefreshLayout.mKernel.setState(RefreshState.TwoLevelFinish);
                if (SmartRefreshLayout.this.mSpinner == 0) {
                    moveSpinner(0, false);
                    SmartRefreshLayout.this.notifyStateChanged(RefreshState.None);
                } else {
                    animSpinner(0).setDuration(SmartRefreshLayout.this.mFloorDuration);
                }
            }
            return this;
        }

        @Override // e.l.a.a.b.i
        @NonNull
        public e.l.a.a.b.e getRefreshContent() {
            return SmartRefreshLayout.this.mRefreshContent;
        }

        @Override // e.l.a.a.b.i
        @NonNull
        public e.l.a.a.b.j getRefreshLayout() {
            return SmartRefreshLayout.this;
        }

        /* JADX WARN: Removed duplicated region for block: B:54:0x00b8  */
        /* JADX WARN: Removed duplicated region for block: B:56:0x00bb  */
        /* JADX WARN: Removed duplicated region for block: B:59:0x00c1  */
        @Override // e.l.a.a.b.i
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public e.l.a.a.b.i moveSpinner(int i2, boolean z) {
            e.l.a.a.e.c cVar;
            e.l.a.a.e.c cVar2;
            int i3;
            boolean z2;
            e.l.a.a.b.h hVar;
            e.l.a.a.b.h hVar2;
            SmartRefreshLayout smartRefreshLayout;
            e.l.a.a.b.h hVar3;
            e.l.a.a.b.h hVar4;
            e.l.a.a.b.h hVar5;
            e.l.a.a.b.h hVar6;
            SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
            if (smartRefreshLayout2.mSpinner != i2 || (((hVar5 = smartRefreshLayout2.mRefreshHeader) != null && hVar5.isSupportHorizontalDrag()) || ((hVar6 = SmartRefreshLayout.this.mRefreshFooter) != null && hVar6.isSupportHorizontalDrag()))) {
                SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
                int i4 = smartRefreshLayout3.mSpinner;
                smartRefreshLayout3.mSpinner = i2;
                if (z) {
                    RefreshState refreshState = smartRefreshLayout3.mViceState;
                    if (refreshState.isDragging || refreshState.isOpening) {
                        SmartRefreshLayout smartRefreshLayout4 = SmartRefreshLayout.this;
                        int i5 = smartRefreshLayout4.mSpinner;
                        if (i5 > smartRefreshLayout4.mHeaderHeight * smartRefreshLayout4.mHeaderTriggerRate) {
                            if (smartRefreshLayout4.mState != RefreshState.ReleaseToTwoLevel) {
                                smartRefreshLayout4.mKernel.setState(RefreshState.ReleaseToRefresh);
                            }
                        } else if ((-i5) > smartRefreshLayout4.mFooterHeight * smartRefreshLayout4.mFooterTriggerRate && !smartRefreshLayout4.mFooterNoMoreData) {
                            smartRefreshLayout4.mKernel.setState(RefreshState.ReleaseToLoad);
                        } else {
                            SmartRefreshLayout smartRefreshLayout5 = SmartRefreshLayout.this;
                            if (smartRefreshLayout5.mSpinner < 0 && !smartRefreshLayout5.mFooterNoMoreData) {
                                smartRefreshLayout5.mKernel.setState(RefreshState.PullUpToLoad);
                            } else {
                                SmartRefreshLayout smartRefreshLayout6 = SmartRefreshLayout.this;
                                if (smartRefreshLayout6.mSpinner > 0) {
                                    smartRefreshLayout6.mKernel.setState(RefreshState.PullDownToRefresh);
                                }
                            }
                        }
                    }
                }
                SmartRefreshLayout smartRefreshLayout7 = SmartRefreshLayout.this;
                if (smartRefreshLayout7.mRefreshContent != null) {
                    if (i2 >= 0 && (hVar4 = smartRefreshLayout7.mRefreshHeader) != null) {
                        if (smartRefreshLayout7.isEnableTranslationContent(smartRefreshLayout7.mEnableHeaderTranslationContent, hVar4)) {
                            i3 = i2;
                        } else {
                            i3 = i4 < 0 ? 0 : 0;
                        }
                        z2 = true;
                        if (i2 <= 0 && (hVar3 = (smartRefreshLayout = SmartRefreshLayout.this).mRefreshFooter) != null) {
                            if (smartRefreshLayout.isEnableTranslationContent(smartRefreshLayout.mEnableFooterTranslationContent, hVar3)) {
                                i3 = i4 > 0 ? 0 : 0;
                            } else {
                                i3 = i2;
                            }
                            z2 = true;
                        }
                        if (z2) {
                            SmartRefreshLayout smartRefreshLayout8 = SmartRefreshLayout.this;
                            smartRefreshLayout8.mRefreshContent.moveSpinner(i3, smartRefreshLayout8.mHeaderTranslationViewId, smartRefreshLayout8.mFooterTranslationViewId);
                            SmartRefreshLayout smartRefreshLayout9 = SmartRefreshLayout.this;
                            boolean z3 = (smartRefreshLayout9.mEnableClipHeaderWhenFixedBehind && (hVar2 = smartRefreshLayout9.mRefreshHeader) != null && hVar2.getSpinnerStyle() == SpinnerStyle.FixedBehind) || SmartRefreshLayout.this.mHeaderBackgroundColor != 0;
                            SmartRefreshLayout smartRefreshLayout10 = SmartRefreshLayout.this;
                            boolean z4 = (smartRefreshLayout10.mEnableClipFooterWhenFixedBehind && (hVar = smartRefreshLayout10.mRefreshFooter) != null && hVar.getSpinnerStyle() == SpinnerStyle.FixedBehind) || SmartRefreshLayout.this.mFooterBackgroundColor != 0;
                            if ((z3 && (i3 >= 0 || i4 > 0)) || (z4 && (i3 <= 0 || i4 < 0))) {
                                smartRefreshLayout3.invalidate();
                            }
                        }
                    }
                    i3 = 0;
                    z2 = false;
                    if (i2 <= 0) {
                        if (smartRefreshLayout.isEnableTranslationContent(smartRefreshLayout.mEnableFooterTranslationContent, hVar3)) {
                        }
                        z2 = true;
                    }
                    if (z2) {
                    }
                }
                if ((i2 >= 0 || i4 > 0) && SmartRefreshLayout.this.mRefreshHeader != null) {
                    int max = Math.max(i2, 0);
                    SmartRefreshLayout smartRefreshLayout11 = SmartRefreshLayout.this;
                    int i6 = smartRefreshLayout11.mHeaderHeight;
                    int i7 = (int) (i6 * smartRefreshLayout11.mHeaderMaxDragRate);
                    float f2 = (max * 1.0f) / (i6 == 0 ? 1 : i6);
                    SmartRefreshLayout smartRefreshLayout12 = SmartRefreshLayout.this;
                    if (smartRefreshLayout12.isEnableRefreshOrLoadMore(smartRefreshLayout12.mEnableRefresh) || (SmartRefreshLayout.this.mState == RefreshState.RefreshFinish && !z)) {
                        SmartRefreshLayout smartRefreshLayout13 = SmartRefreshLayout.this;
                        if (i4 != smartRefreshLayout13.mSpinner) {
                            if (smartRefreshLayout13.mRefreshHeader.getSpinnerStyle() == SpinnerStyle.Translate) {
                                SmartRefreshLayout.this.mRefreshHeader.getView().setTranslationY(SmartRefreshLayout.this.mSpinner);
                                SmartRefreshLayout smartRefreshLayout14 = SmartRefreshLayout.this;
                                if (smartRefreshLayout14.mHeaderBackgroundColor != 0 && smartRefreshLayout14.mPaint != null && !smartRefreshLayout14.isEnableTranslationContent(smartRefreshLayout14.mEnableHeaderTranslationContent, smartRefreshLayout14.mRefreshHeader)) {
                                    smartRefreshLayout3.invalidate();
                                }
                            } else if (SmartRefreshLayout.this.mRefreshHeader.getSpinnerStyle() == SpinnerStyle.Scale) {
                                SmartRefreshLayout.this.mRefreshHeader.getView().requestLayout();
                            }
                            SmartRefreshLayout.this.mRefreshHeader.onMoving(z, f2, max, i6, i7);
                        }
                        if (z && SmartRefreshLayout.this.mRefreshHeader.isSupportHorizontalDrag()) {
                            int i8 = (int) SmartRefreshLayout.this.mLastTouchX;
                            int width = smartRefreshLayout3.getWidth();
                            SmartRefreshLayout.this.mRefreshHeader.onHorizontalDrag(SmartRefreshLayout.this.mLastTouchX / (width == 0 ? 1 : width), i8, width);
                        }
                    }
                    SmartRefreshLayout smartRefreshLayout15 = SmartRefreshLayout.this;
                    if (i4 != smartRefreshLayout15.mSpinner && (cVar = smartRefreshLayout15.mOnMultiPurposeListener) != null) {
                        e.l.a.a.b.h hVar7 = smartRefreshLayout15.mRefreshHeader;
                        if (hVar7 instanceof e.l.a.a.b.g) {
                            cVar.onHeaderMoving((e.l.a.a.b.g) hVar7, z, f2, max, i6, i7);
                        }
                    }
                }
                if ((i2 <= 0 || i4 < 0) && SmartRefreshLayout.this.mRefreshFooter != null) {
                    int i9 = -Math.min(i2, 0);
                    SmartRefreshLayout smartRefreshLayout16 = SmartRefreshLayout.this;
                    int i10 = smartRefreshLayout16.mFooterHeight;
                    int i11 = (int) (i10 * smartRefreshLayout16.mFooterMaxDragRate);
                    float f3 = (i9 * 1.0f) / (i10 == 0 ? 1 : i10);
                    SmartRefreshLayout smartRefreshLayout17 = SmartRefreshLayout.this;
                    if (smartRefreshLayout17.isEnableRefreshOrLoadMore(smartRefreshLayout17.mEnableLoadMore) || (SmartRefreshLayout.this.mState == RefreshState.LoadFinish && !z)) {
                        SmartRefreshLayout smartRefreshLayout18 = SmartRefreshLayout.this;
                        if (i4 != smartRefreshLayout18.mSpinner) {
                            if (smartRefreshLayout18.mRefreshFooter.getSpinnerStyle() == SpinnerStyle.Translate) {
                                SmartRefreshLayout.this.mRefreshFooter.getView().setTranslationY(SmartRefreshLayout.this.mSpinner);
                                SmartRefreshLayout smartRefreshLayout19 = SmartRefreshLayout.this;
                                if (smartRefreshLayout19.mFooterBackgroundColor != 0 && smartRefreshLayout19.mPaint != null && !smartRefreshLayout19.isEnableTranslationContent(smartRefreshLayout19.mEnableFooterTranslationContent, smartRefreshLayout19.mRefreshFooter)) {
                                    smartRefreshLayout3.invalidate();
                                }
                            } else if (SmartRefreshLayout.this.mRefreshFooter.getSpinnerStyle() == SpinnerStyle.Scale) {
                                SmartRefreshLayout.this.mRefreshFooter.getView().requestLayout();
                            }
                            SmartRefreshLayout.this.mRefreshFooter.onMoving(z, f3, i9, i10, i11);
                        }
                        if (z && SmartRefreshLayout.this.mRefreshFooter.isSupportHorizontalDrag()) {
                            int i12 = (int) SmartRefreshLayout.this.mLastTouchX;
                            int width2 = smartRefreshLayout3.getWidth();
                            SmartRefreshLayout.this.mRefreshFooter.onHorizontalDrag(SmartRefreshLayout.this.mLastTouchX / (width2 != 0 ? width2 : 1), i12, width2);
                        }
                    }
                    SmartRefreshLayout smartRefreshLayout20 = SmartRefreshLayout.this;
                    if (i4 != smartRefreshLayout20.mSpinner && (cVar2 = smartRefreshLayout20.mOnMultiPurposeListener) != null) {
                        e.l.a.a.b.h hVar8 = smartRefreshLayout20.mRefreshFooter;
                        if (hVar8 instanceof e.l.a.a.b.f) {
                            cVar2.onFooterMoving((e.l.a.a.b.f) hVar8, z, f3, i9, i10, i11);
                        }
                    }
                }
                return this;
            }
            return this;
        }

        @Override // e.l.a.a.b.i
        public e.l.a.a.b.i requestDefaultTranslationContentFor(@NonNull e.l.a.a.b.h hVar, boolean z) {
            if (hVar.equals(SmartRefreshLayout.this.mRefreshHeader)) {
                SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                if (!smartRefreshLayout.mManualHeaderTranslationContent) {
                    smartRefreshLayout.mManualHeaderTranslationContent = true;
                    smartRefreshLayout.mEnableHeaderTranslationContent = z;
                }
            } else if (hVar.equals(SmartRefreshLayout.this.mRefreshFooter)) {
                SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                if (!smartRefreshLayout2.mManualFooterTranslationContent) {
                    smartRefreshLayout2.mManualFooterTranslationContent = true;
                    smartRefreshLayout2.mEnableFooterTranslationContent = z;
                }
            }
            return this;
        }

        @Override // e.l.a.a.b.i
        public e.l.a.a.b.i requestDrawBackgroundFor(@NonNull e.l.a.a.b.h hVar, int i2) {
            SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
            if (smartRefreshLayout.mPaint == null && i2 != 0) {
                smartRefreshLayout.mPaint = new Paint();
            }
            if (hVar.equals(SmartRefreshLayout.this.mRefreshHeader)) {
                SmartRefreshLayout.this.mHeaderBackgroundColor = i2;
            } else if (hVar.equals(SmartRefreshLayout.this.mRefreshFooter)) {
                SmartRefreshLayout.this.mFooterBackgroundColor = i2;
            }
            return this;
        }

        @Override // e.l.a.a.b.i
        public e.l.a.a.b.i requestFloorDuration(int i2) {
            SmartRefreshLayout.this.mFloorDuration = i2;
            return this;
        }

        @Override // e.l.a.a.b.i
        public e.l.a.a.b.i requestNeedTouchEventFor(@NonNull e.l.a.a.b.h hVar, boolean z) {
            if (hVar.equals(SmartRefreshLayout.this.mRefreshHeader)) {
                SmartRefreshLayout.this.mHeaderNeedTouchEventWhenRefreshing = z;
            } else if (hVar.equals(SmartRefreshLayout.this.mRefreshFooter)) {
                SmartRefreshLayout.this.mFooterNeedTouchEventWhenLoading = z;
            }
            return this;
        }

        @Override // e.l.a.a.b.i
        public e.l.a.a.b.i requestRemeasureHeightFor(@NonNull e.l.a.a.b.h hVar) {
            if (hVar.equals(SmartRefreshLayout.this.mRefreshHeader)) {
                SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                DimensionStatus dimensionStatus = smartRefreshLayout.mHeaderHeightStatus;
                if (dimensionStatus.notified) {
                    smartRefreshLayout.mHeaderHeightStatus = dimensionStatus.unNotify();
                }
            } else if (hVar.equals(SmartRefreshLayout.this.mRefreshFooter)) {
                SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                DimensionStatus dimensionStatus2 = smartRefreshLayout2.mFooterHeightStatus;
                if (dimensionStatus2.notified) {
                    smartRefreshLayout2.mFooterHeightStatus = dimensionStatus2.unNotify();
                }
            }
            return this;
        }

        @Override // e.l.a.a.b.i
        public e.l.a.a.b.i setState(@NonNull RefreshState refreshState) {
            switch (a.$SwitchMap$com$scwang$smartrefresh$layout$constant$RefreshState[refreshState.ordinal()]) {
                case 1:
                    SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                    RefreshState refreshState2 = smartRefreshLayout.mState;
                    RefreshState refreshState3 = RefreshState.None;
                    if (refreshState2 != refreshState3 && smartRefreshLayout.mSpinner == 0) {
                        smartRefreshLayout.notifyStateChanged(refreshState3);
                        return null;
                    } else if (SmartRefreshLayout.this.mSpinner != 0) {
                        animSpinner(0);
                        return null;
                    } else {
                        return null;
                    }
                case 2:
                    SmartRefreshLayout smartRefreshLayout2 = SmartRefreshLayout.this;
                    if (!smartRefreshLayout2.mState.isOpening && smartRefreshLayout2.isEnableRefreshOrLoadMore(smartRefreshLayout2.mEnableRefresh)) {
                        SmartRefreshLayout.this.notifyStateChanged(RefreshState.PullDownToRefresh);
                        return null;
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.PullDownToRefresh);
                    return null;
                case 3:
                    SmartRefreshLayout smartRefreshLayout3 = SmartRefreshLayout.this;
                    if (smartRefreshLayout3.isEnableRefreshOrLoadMore(smartRefreshLayout3.mEnableLoadMore)) {
                        SmartRefreshLayout smartRefreshLayout4 = SmartRefreshLayout.this;
                        RefreshState refreshState4 = smartRefreshLayout4.mState;
                        if (!refreshState4.isOpening && !refreshState4.isFinishing && (!smartRefreshLayout4.mFooterNoMoreData || !smartRefreshLayout4.mEnableFooterFollowWhenNoMoreData)) {
                            SmartRefreshLayout.this.notifyStateChanged(RefreshState.PullUpToLoad);
                            return null;
                        }
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.PullUpToLoad);
                    return null;
                case 4:
                    SmartRefreshLayout smartRefreshLayout5 = SmartRefreshLayout.this;
                    if (!smartRefreshLayout5.mState.isOpening && smartRefreshLayout5.isEnableRefreshOrLoadMore(smartRefreshLayout5.mEnableRefresh)) {
                        SmartRefreshLayout.this.notifyStateChanged(RefreshState.PullDownCanceled);
                        setState(RefreshState.None);
                        return null;
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.PullDownCanceled);
                    return null;
                case 5:
                    SmartRefreshLayout smartRefreshLayout6 = SmartRefreshLayout.this;
                    if (smartRefreshLayout6.isEnableRefreshOrLoadMore(smartRefreshLayout6.mEnableLoadMore)) {
                        SmartRefreshLayout smartRefreshLayout7 = SmartRefreshLayout.this;
                        if (!smartRefreshLayout7.mState.isOpening && (!smartRefreshLayout7.mFooterNoMoreData || !smartRefreshLayout7.mEnableFooterFollowWhenNoMoreData)) {
                            SmartRefreshLayout.this.notifyStateChanged(RefreshState.PullUpCanceled);
                            setState(RefreshState.None);
                            return null;
                        }
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.PullUpCanceled);
                    return null;
                case 6:
                    SmartRefreshLayout smartRefreshLayout8 = SmartRefreshLayout.this;
                    if (!smartRefreshLayout8.mState.isOpening && smartRefreshLayout8.isEnableRefreshOrLoadMore(smartRefreshLayout8.mEnableRefresh)) {
                        SmartRefreshLayout.this.notifyStateChanged(RefreshState.ReleaseToRefresh);
                        return null;
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.ReleaseToRefresh);
                    return null;
                case 7:
                    SmartRefreshLayout smartRefreshLayout9 = SmartRefreshLayout.this;
                    if (smartRefreshLayout9.isEnableRefreshOrLoadMore(smartRefreshLayout9.mEnableLoadMore)) {
                        SmartRefreshLayout smartRefreshLayout10 = SmartRefreshLayout.this;
                        RefreshState refreshState5 = smartRefreshLayout10.mState;
                        if (!refreshState5.isOpening && !refreshState5.isFinishing && (!smartRefreshLayout10.mFooterNoMoreData || !smartRefreshLayout10.mEnableFooterFollowWhenNoMoreData)) {
                            SmartRefreshLayout.this.notifyStateChanged(RefreshState.ReleaseToLoad);
                            return null;
                        }
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.ReleaseToLoad);
                    return null;
                case 8:
                    SmartRefreshLayout smartRefreshLayout11 = SmartRefreshLayout.this;
                    if (!smartRefreshLayout11.mState.isOpening && smartRefreshLayout11.isEnableRefreshOrLoadMore(smartRefreshLayout11.mEnableRefresh)) {
                        SmartRefreshLayout.this.notifyStateChanged(RefreshState.ReleaseToTwoLevel);
                        return null;
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.ReleaseToTwoLevel);
                    return null;
                case 9:
                    SmartRefreshLayout smartRefreshLayout12 = SmartRefreshLayout.this;
                    if (!smartRefreshLayout12.mState.isOpening && smartRefreshLayout12.isEnableRefreshOrLoadMore(smartRefreshLayout12.mEnableRefresh)) {
                        SmartRefreshLayout.this.notifyStateChanged(RefreshState.RefreshReleased);
                        return null;
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.RefreshReleased);
                    return null;
                case 10:
                    SmartRefreshLayout smartRefreshLayout13 = SmartRefreshLayout.this;
                    if (!smartRefreshLayout13.mState.isOpening && smartRefreshLayout13.isEnableRefreshOrLoadMore(smartRefreshLayout13.mEnableLoadMore)) {
                        SmartRefreshLayout.this.notifyStateChanged(RefreshState.LoadReleased);
                        return null;
                    }
                    SmartRefreshLayout.this.setViceState(RefreshState.LoadReleased);
                    return null;
                case 11:
                    SmartRefreshLayout.this.setStateRefreshing(true);
                    return null;
                case 12:
                    SmartRefreshLayout.this.setStateLoading(true);
                    return null;
                case 13:
                    SmartRefreshLayout smartRefreshLayout14 = SmartRefreshLayout.this;
                    if (smartRefreshLayout14.mState == RefreshState.Refreshing) {
                        smartRefreshLayout14.notifyStateChanged(RefreshState.RefreshFinish);
                        return null;
                    }
                    return null;
                case 14:
                    SmartRefreshLayout smartRefreshLayout15 = SmartRefreshLayout.this;
                    if (smartRefreshLayout15.mState == RefreshState.Loading) {
                        smartRefreshLayout15.notifyStateChanged(RefreshState.LoadFinish);
                        return null;
                    }
                    return null;
                case 15:
                    SmartRefreshLayout.this.notifyStateChanged(RefreshState.TwoLevelReleased);
                    return null;
                case 16:
                    SmartRefreshLayout.this.notifyStateChanged(RefreshState.TwoLevelFinish);
                    return null;
                case 17:
                    SmartRefreshLayout.this.notifyStateChanged(RefreshState.TwoLevel);
                    return null;
                default:
                    return null;
            }
        }

        @Override // e.l.a.a.b.i
        public e.l.a.a.b.i startTwoLevel(boolean z) {
            if (z) {
                a aVar = new a();
                ValueAnimator animSpinner = animSpinner(SmartRefreshLayout.this.getMeasuredHeight());
                if (animSpinner != null) {
                    SmartRefreshLayout smartRefreshLayout = SmartRefreshLayout.this;
                    if (animSpinner == smartRefreshLayout.reboundAnimator) {
                        animSpinner.setDuration(smartRefreshLayout.mFloorDuration);
                        animSpinner.addListener(aVar);
                    }
                }
                aVar.onAnimationEnd(null);
            } else if (animSpinner(0) == null) {
                SmartRefreshLayout.this.notifyStateChanged(RefreshState.None);
            }
            return this;
        }
    }

    public SmartRefreshLayout(Context context) {
        this(context, null);
    }

    public static void setDefaultRefreshFooterCreator(@NonNull e.l.a.a.b.a aVar) {
        sFooterCreator = aVar;
    }

    public static void setDefaultRefreshHeaderCreator(@NonNull e.l.a.a.b.b bVar) {
        sHeaderCreator = bVar;
    }

    public static void setDefaultRefreshInitializer(@NonNull e.l.a.a.b.c cVar) {
        sRefreshInitializer = cVar;
    }

    public ValueAnimator animSpinner(int i2, int i3, Interpolator interpolator, int i4) {
        if (this.mSpinner != i2) {
            ValueAnimator valueAnimator = this.reboundAnimator;
            if (valueAnimator != null) {
                valueAnimator.cancel();
            }
            this.animationRunnable = null;
            ValueAnimator ofInt = ValueAnimator.ofInt(this.mSpinner, i2);
            this.reboundAnimator = ofInt;
            ofInt.setDuration(i4);
            this.reboundAnimator.setInterpolator(interpolator);
            this.reboundAnimator.addListener(new d());
            this.reboundAnimator.addUpdateListener(new e());
            this.reboundAnimator.setStartDelay(i3);
            this.reboundAnimator.start();
            return this.reboundAnimator;
        }
        return null;
    }

    public void animSpinnerBounce(float f2) {
        RefreshState refreshState;
        if (this.reboundAnimator == null) {
            if (f2 > 0.0f && ((refreshState = this.mState) == RefreshState.Refreshing || refreshState == RefreshState.TwoLevel)) {
                this.animationRunnable = new k(f2, this.mHeaderHeight);
            } else if (f2 < 0.0f && (this.mState == RefreshState.Loading || ((this.mEnableFooterFollowWhenNoMoreData && this.mFooterNoMoreData && isEnableRefreshOrLoadMore(this.mEnableLoadMore)) || (this.mEnableAutoLoadMore && !this.mFooterNoMoreData && isEnableRefreshOrLoadMore(this.mEnableLoadMore) && this.mState != RefreshState.Refreshing)))) {
                this.animationRunnable = new k(f2, -this.mFooterHeight);
            } else if (this.mSpinner == 0 && this.mEnableOverScrollBounce) {
                this.animationRunnable = new k(f2, 0);
            }
        }
    }

    @Override // e.l.a.a.b.j
    public boolean autoLoadMore() {
        int i2 = this.mReboundDuration;
        int i3 = this.mFooterHeight;
        float f2 = i3 * ((this.mFooterMaxDragRate / 2.0f) + 0.5f) * 1.0f;
        if (i3 == 0) {
            i3 = 1;
        }
        return autoLoadMore(0, i2, f2 / i3, false);
    }

    @Override // e.l.a.a.b.j
    public boolean autoLoadMoreAnimationOnly() {
        int i2 = this.mReboundDuration;
        int i3 = this.mFooterHeight;
        float f2 = i3 * ((this.mFooterMaxDragRate / 2.0f) + 0.5f) * 1.0f;
        if (i3 == 0) {
            i3 = 1;
        }
        return autoLoadMore(0, i2, f2 / i3, true);
    }

    @Override // e.l.a.a.b.j
    public boolean autoRefresh() {
        int i2 = getHandler() == null ? 400 : 0;
        int i3 = this.mReboundDuration;
        int i4 = this.mHeaderHeight;
        float f2 = ((this.mHeaderMaxDragRate / 2.0f) + 0.5f) * i4 * 1.0f;
        if (i4 == 0) {
            i4 = 1;
        }
        return autoRefresh(i2, i3, f2 / i4, false);
    }

    @Override // e.l.a.a.b.j
    public boolean autoRefreshAnimationOnly() {
        int i2 = getHandler() == null ? 400 : 0;
        int i3 = this.mReboundDuration;
        int i4 = this.mHeaderHeight;
        float f2 = ((this.mHeaderMaxDragRate / 2.0f) + 0.5f) * i4 * 1.0f;
        if (i4 == 0) {
            i4 = 1;
        }
        return autoRefresh(i2, i3, f2 / i4, true);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j closeHeaderOrFooter() {
        RefreshState refreshState = this.mState;
        if (refreshState == RefreshState.Refreshing) {
            finishRefresh();
        } else if (refreshState == RefreshState.Loading) {
            finishLoadMore();
        } else if (this.mSpinner != 0) {
            animSpinner(0, 0, this.mReboundInterpolator, this.mReboundDuration);
        }
        return this;
    }

    @Override // android.view.View
    public void computeScroll() {
        float currY;
        this.mScroller.getCurrY();
        if (this.mScroller.computeScrollOffset()) {
            int finalY = this.mScroller.getFinalY();
            if ((finalY < 0 && ((this.mEnableRefresh || this.mEnableOverScrollDrag) && this.mRefreshContent.canRefresh())) || (finalY > 0 && ((this.mEnableLoadMore || this.mEnableOverScrollDrag) && this.mRefreshContent.canLoadMore()))) {
                if (this.mVerticalPermit) {
                    if (Build.VERSION.SDK_INT >= 14) {
                        currY = finalY > 0 ? -this.mScroller.getCurrVelocity() : this.mScroller.getCurrVelocity();
                    } else {
                        currY = ((this.mScroller.getCurrY() - finalY) * 1.0f) / Math.max(this.mScroller.getDuration() - this.mScroller.timePassed(), 1);
                    }
                    animSpinnerBounce(currY);
                }
                this.mScroller.forceFinished(true);
                return;
            }
            this.mVerticalPermit = true;
            invalidate();
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:63:0x00c2, code lost:
        if (r4.isFinishing == false) goto L62;
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x00c8, code lost:
        if (r22.mState.isHeader == false) goto L62;
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x00d6, code lost:
        if (r4.isFinishing == false) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:73:0x00dc, code lost:
        if (r22.mState.isFooter == false) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:94:0x010a, code lost:
        if (r6 != 3) goto L96;
     */
    @Override // android.view.ViewGroup, android.view.View
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean dispatchTouchEvent(MotionEvent motionEvent) {
        char c2;
        e.l.a.a.b.h hVar;
        e.l.a.a.b.h hVar2;
        int actionMasked = motionEvent.getActionMasked();
        int i2 = 0;
        boolean z = actionMasked == 6;
        int actionIndex = z ? motionEvent.getActionIndex() : -1;
        int pointerCount = motionEvent.getPointerCount();
        float f2 = 0.0f;
        float f3 = 0.0f;
        for (int i3 = 0; i3 < pointerCount; i3++) {
            if (actionIndex != i3) {
                f2 += motionEvent.getX(i3);
                f3 += motionEvent.getY(i3);
            }
        }
        if (z) {
            pointerCount--;
        }
        float f4 = pointerCount;
        float f5 = f2 / f4;
        float f6 = f3 / f4;
        if ((actionMasked == 6 || actionMasked == 5) && this.mIsBeingDragged) {
            this.mTouchY += f6 - this.mLastTouchY;
        }
        this.mLastTouchX = f5;
        this.mLastTouchY = f6;
        if (this.mNestedInProgress) {
            int i4 = this.mTotalUnconsumed;
            boolean dispatchTouchEvent = super.dispatchTouchEvent(motionEvent);
            if (actionMasked == 2 && i4 == this.mTotalUnconsumed) {
                int i5 = (int) this.mLastTouchX;
                int width = getWidth();
                float f7 = this.mLastTouchX / (width != 0 ? width : 1);
                if (isEnableRefreshOrLoadMore(this.mEnableRefresh) && this.mSpinner > 0 && (hVar2 = this.mRefreshHeader) != null && hVar2.isSupportHorizontalDrag()) {
                    this.mRefreshHeader.onHorizontalDrag(f7, i5, width);
                } else if (isEnableRefreshOrLoadMore(this.mEnableLoadMore) && this.mSpinner < 0 && (hVar = this.mRefreshFooter) != null && hVar.isSupportHorizontalDrag()) {
                    this.mRefreshFooter.onHorizontalDrag(f7, i5, width);
                }
            }
            return dispatchTouchEvent;
        }
        if (isEnabled() && (this.mEnableRefresh || this.mEnableLoadMore)) {
            if (this.mHeaderNeedTouchEventWhenRefreshing) {
                RefreshState refreshState = this.mState;
                if (!refreshState.isOpening) {
                }
            }
            if (this.mFooterNeedTouchEventWhenLoading) {
                RefreshState refreshState2 = this.mState;
                if (!refreshState2.isOpening) {
                }
            }
            if (!interceptAnimatorByAction(actionMasked)) {
                RefreshState refreshState3 = this.mState;
                if (!refreshState3.isFinishing && ((refreshState3 != RefreshState.Loading || !this.mDisableContentWhenLoading) && (this.mState != RefreshState.Refreshing || !this.mDisableContentWhenRefresh))) {
                    if (actionMasked != 0) {
                        if (actionMasked == 1) {
                            this.mVelocityTracker.addMovement(motionEvent);
                            this.mVelocityTracker.computeCurrentVelocity(1000, this.mMaximumVelocity);
                            this.mCurrentVelocity = (int) this.mVelocityTracker.getYVelocity();
                            startFlingIfNeed(0.0f);
                        } else {
                            if (actionMasked == 2) {
                                float f8 = f5 - this.mTouchX;
                                float f9 = f6 - this.mTouchY;
                                this.mVelocityTracker.addMovement(motionEvent);
                                if (!this.mIsBeingDragged && (c2 = this.mDragDirection) != 'h' && this.mRefreshContent != null) {
                                    if (c2 != 'v' && (Math.abs(f9) < this.mTouchSlop || Math.abs(f8) >= Math.abs(f9))) {
                                        if (Math.abs(f8) >= this.mTouchSlop && Math.abs(f8) > Math.abs(f9) && this.mDragDirection != 'v') {
                                            this.mDragDirection = 'h';
                                        }
                                    } else {
                                        this.mDragDirection = 'v';
                                        if (f9 > 0.0f && (this.mSpinner < 0 || ((this.mEnableOverScrollDrag || this.mEnableRefresh) && this.mRefreshContent.canRefresh()))) {
                                            this.mIsBeingDragged = true;
                                            this.mTouchY = f6 - this.mTouchSlop;
                                        } else if (f9 < 0.0f && (this.mSpinner > 0 || ((this.mEnableOverScrollDrag || this.mEnableLoadMore) && ((this.mState == RefreshState.Loading && this.mFooterLocked) || this.mRefreshContent.canLoadMore())))) {
                                            this.mIsBeingDragged = true;
                                            this.mTouchY = this.mTouchSlop + f6;
                                        }
                                        if (this.mIsBeingDragged) {
                                            f9 = f6 - this.mTouchY;
                                            if (this.mSuperDispatchTouchEvent) {
                                                motionEvent.setAction(3);
                                                super.dispatchTouchEvent(motionEvent);
                                            }
                                            e.l.a.a.b.i iVar = this.mKernel;
                                            int i6 = this.mSpinner;
                                            iVar.setState((i6 > 0 || (i6 == 0 && f9 > 0.0f)) ? RefreshState.PullDownToRefresh : RefreshState.PullUpToLoad);
                                            ViewParent parent = getParent();
                                            if (parent != null) {
                                                parent.requestDisallowInterceptTouchEvent(true);
                                            }
                                        }
                                    }
                                }
                                if (this.mIsBeingDragged) {
                                    int i7 = ((int) f9) + this.mTouchSpinner;
                                    if ((this.mViceState.isHeader && (i7 < 0 || this.mLastSpinner < 0)) || (this.mViceState.isFooter && (i7 > 0 || this.mLastSpinner > 0))) {
                                        this.mLastSpinner = i7;
                                        long eventTime = motionEvent.getEventTime();
                                        if (this.mFalsifyEvent == null) {
                                            MotionEvent obtain = MotionEvent.obtain(eventTime, eventTime, 0, this.mTouchX + f8, this.mTouchY, 0);
                                            this.mFalsifyEvent = obtain;
                                            super.dispatchTouchEvent(obtain);
                                        }
                                        MotionEvent obtain2 = MotionEvent.obtain(eventTime, eventTime, 2, this.mTouchX + f8, this.mTouchY + i7, 0);
                                        super.dispatchTouchEvent(obtain2);
                                        if (this.mFooterLocked && f9 > this.mTouchSlop && this.mSpinner < 0) {
                                            this.mFooterLocked = false;
                                        }
                                        if (i7 > 0 && ((this.mEnableOverScrollDrag || this.mEnableRefresh) && this.mRefreshContent.canRefresh())) {
                                            this.mLastTouchY = f6;
                                            this.mTouchY = f6;
                                            this.mTouchSpinner = 0;
                                            this.mKernel.setState(RefreshState.PullDownToRefresh);
                                        } else if (i7 >= 0 || !((this.mEnableOverScrollDrag || this.mEnableLoadMore) && this.mRefreshContent.canLoadMore())) {
                                            i2 = i7;
                                        } else {
                                            this.mLastTouchY = f6;
                                            this.mTouchY = f6;
                                            this.mTouchSpinner = 0;
                                            this.mKernel.setState(RefreshState.PullUpToLoad);
                                        }
                                        if ((this.mViceState.isHeader && i2 < 0) || (this.mViceState.isFooter && i2 > 0)) {
                                            if (this.mSpinner != 0) {
                                                moveSpinnerInfinitely(0.0f);
                                            }
                                            return true;
                                        }
                                        if (this.mFalsifyEvent != null) {
                                            this.mFalsifyEvent = null;
                                            obtain2.setAction(3);
                                            super.dispatchTouchEvent(obtain2);
                                        }
                                        obtain2.recycle();
                                        i7 = i2;
                                    }
                                    moveSpinnerInfinitely(i7);
                                    return true;
                                } else if (this.mFooterLocked && f9 > this.mTouchSlop && this.mSpinner < 0) {
                                    this.mFooterLocked = false;
                                }
                            }
                            return super.dispatchTouchEvent(motionEvent);
                        }
                        this.mVelocityTracker.clear();
                        this.mDragDirection = 'n';
                        MotionEvent motionEvent2 = this.mFalsifyEvent;
                        if (motionEvent2 != null) {
                            motionEvent2.recycle();
                            this.mFalsifyEvent = null;
                            long eventTime2 = motionEvent.getEventTime();
                            MotionEvent obtain3 = MotionEvent.obtain(eventTime2, eventTime2, actionMasked, this.mTouchX, f6, 0);
                            super.dispatchTouchEvent(obtain3);
                            obtain3.recycle();
                        }
                        overSpinner();
                        if (this.mIsBeingDragged) {
                            this.mIsBeingDragged = false;
                            return true;
                        }
                        return super.dispatchTouchEvent(motionEvent);
                    }
                    this.mCurrentVelocity = 0;
                    this.mVelocityTracker.addMovement(motionEvent);
                    this.mScroller.forceFinished(true);
                    this.mTouchX = f5;
                    this.mTouchY = f6;
                    this.mLastSpinner = 0;
                    this.mTouchSpinner = this.mSpinner;
                    this.mIsBeingDragged = false;
                    this.mSuperDispatchTouchEvent = super.dispatchTouchEvent(motionEvent);
                    if (this.mState == RefreshState.TwoLevel && this.mTouchY < (getMeasuredHeight() * 5) / 6) {
                        this.mDragDirection = 'h';
                        return this.mSuperDispatchTouchEvent;
                    }
                    e.l.a.a.b.e eVar = this.mRefreshContent;
                    if (eVar != null) {
                        eVar.onActionDown(motionEvent);
                    }
                    return true;
                }
            }
            return false;
        }
        return super.dispatchTouchEvent(motionEvent);
    }

    @Override // android.view.ViewGroup
    public boolean drawChild(Canvas canvas, View view, long j2) {
        Paint paint;
        Paint paint2;
        e.l.a.a.b.e eVar = this.mRefreshContent;
        View view2 = eVar != null ? eVar.getView() : null;
        e.l.a.a.b.h hVar = this.mRefreshHeader;
        if (hVar != null && hVar.getView() == view) {
            if (!isEnableRefreshOrLoadMore(this.mEnableRefresh) || (!this.mEnablePreviewInEditMode && isInEditMode())) {
                return true;
            }
            if (view2 != null) {
                int max = Math.max(view2.getTop() + view2.getPaddingTop() + this.mSpinner, view.getTop());
                int i2 = this.mHeaderBackgroundColor;
                if (i2 != 0 && (paint2 = this.mPaint) != null) {
                    paint2.setColor(i2);
                    if (this.mRefreshHeader.getSpinnerStyle() == SpinnerStyle.Scale) {
                        max = view.getBottom();
                    } else if (this.mRefreshHeader.getSpinnerStyle() == SpinnerStyle.Translate) {
                        max = view.getBottom() + this.mSpinner;
                    }
                    canvas.drawRect(0.0f, view.getTop(), getWidth(), max, this.mPaint);
                }
                if (this.mEnableClipHeaderWhenFixedBehind && this.mRefreshHeader.getSpinnerStyle() == SpinnerStyle.FixedBehind) {
                    canvas.save();
                    canvas.clipRect(view.getLeft(), view.getTop(), view.getRight(), max);
                    boolean drawChild = super.drawChild(canvas, view, j2);
                    canvas.restore();
                    return drawChild;
                }
            }
        }
        e.l.a.a.b.h hVar2 = this.mRefreshFooter;
        if (hVar2 != null && hVar2.getView() == view) {
            if (!isEnableRefreshOrLoadMore(this.mEnableLoadMore) || (!this.mEnablePreviewInEditMode && isInEditMode())) {
                return true;
            }
            if (view2 != null) {
                int min = Math.min((view2.getBottom() - view2.getPaddingBottom()) + this.mSpinner, view.getBottom());
                int i3 = this.mFooterBackgroundColor;
                if (i3 != 0 && (paint = this.mPaint) != null) {
                    paint.setColor(i3);
                    if (this.mRefreshFooter.getSpinnerStyle() == SpinnerStyle.Scale) {
                        min = view.getTop();
                    } else if (this.mRefreshFooter.getSpinnerStyle() == SpinnerStyle.Translate) {
                        min = view.getTop() + this.mSpinner;
                    }
                    canvas.drawRect(0.0f, min, getWidth(), view.getBottom(), this.mPaint);
                }
                if (this.mEnableClipFooterWhenFixedBehind && this.mRefreshFooter.getSpinnerStyle() == SpinnerStyle.FixedBehind) {
                    canvas.save();
                    canvas.clipRect(view.getLeft(), min, view.getRight(), view.getBottom());
                    boolean drawChild2 = super.drawChild(canvas, view, j2);
                    canvas.restore();
                    return drawChild2;
                }
            }
        }
        return super.drawChild(canvas, view, j2);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishLoadMore() {
        return finishLoadMore(Math.min(Math.max(0, 300 - ((int) (System.currentTimeMillis() - this.mLastOpenTime))), 300));
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishLoadMoreWithNoMoreData() {
        return finishLoadMore(Math.min(Math.max(0, 300 - ((int) (System.currentTimeMillis() - this.mLastOpenTime))), 300), true, true);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishRefresh() {
        return finishRefresh(Math.min(Math.max(0, 300 - ((int) (System.currentTimeMillis() - this.mLastOpenTime))), 300));
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishRefreshWithNoMoreData() {
        return finishRefresh(Math.min(Math.max(0, 300 - ((int) (System.currentTimeMillis() - this.mLastOpenTime))), 300), true, Boolean.TRUE);
    }

    @Override // android.view.ViewGroup
    public ViewGroup.LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        return new LayoutParams(getContext(), attributeSet);
    }

    @Override // e.l.a.a.b.j
    @NonNull
    public ViewGroup getLayout() {
        return this;
    }

    @Override // android.view.ViewGroup, androidx.core.view.NestedScrollingParent
    public int getNestedScrollAxes() {
        return this.mNestedParent.getNestedScrollAxes();
    }

    @Override // e.l.a.a.b.j
    @Nullable
    public e.l.a.a.b.f getRefreshFooter() {
        e.l.a.a.b.h hVar = this.mRefreshFooter;
        if (hVar instanceof e.l.a.a.b.f) {
            return (e.l.a.a.b.f) hVar;
        }
        return null;
    }

    @Override // e.l.a.a.b.j
    @Nullable
    public e.l.a.a.b.g getRefreshHeader() {
        e.l.a.a.b.h hVar = this.mRefreshHeader;
        if (hVar instanceof e.l.a.a.b.g) {
            return (e.l.a.a.b.g) hVar;
        }
        return null;
    }

    @Override // e.l.a.a.b.j
    @NonNull
    public RefreshState getState() {
        return this.mState;
    }

    public boolean interceptAnimatorByAction(int i2) {
        if (i2 == 0) {
            if (this.reboundAnimator != null) {
                RefreshState refreshState = this.mState;
                if (refreshState.isFinishing || refreshState == RefreshState.TwoLevelReleased) {
                    return true;
                }
                if (refreshState == RefreshState.PullDownCanceled) {
                    this.mKernel.setState(RefreshState.PullDownToRefresh);
                } else if (refreshState == RefreshState.PullUpCanceled) {
                    this.mKernel.setState(RefreshState.PullUpToLoad);
                }
                this.reboundAnimator.cancel();
                this.reboundAnimator = null;
            }
            this.animationRunnable = null;
        }
        return this.reboundAnimator != null;
    }

    public boolean isEnableRefreshOrLoadMore(boolean z) {
        return z && !this.mEnablePureScrollMode;
    }

    public boolean isEnableTranslationContent(boolean z, e.l.a.a.b.h hVar) {
        return z || this.mEnablePureScrollMode || hVar == null || hVar.getSpinnerStyle() == SpinnerStyle.FixedBehind;
    }

    @Override // android.view.View
    public boolean isNestedScrollingEnabled() {
        return this.mEnableNestedScrolling;
    }

    public void moveSpinnerInfinitely(float f2) {
        RefreshState refreshState;
        float f3 = (!this.mNestedInProgress || this.mEnableLoadMoreWhenContentNotFull || f2 >= 0.0f || this.mRefreshContent.canLoadMore()) ? f2 : 0.0f;
        if (f3 > this.mScreenHeightPixels * 3 && getTag() == null) {
            Toast.makeText(getContext(), "不要再往下拉了", 0).show();
            setTag("不要再往下拉了");
        }
        if (this.mState == RefreshState.TwoLevel && f3 > 0.0f) {
            this.mKernel.moveSpinner(Math.min((int) f3, getMeasuredHeight()), true);
        } else if (this.mState == RefreshState.Refreshing && f3 >= 0.0f) {
            int i2 = this.mHeaderHeight;
            if (f3 < i2) {
                this.mKernel.moveSpinner((int) f3, true);
            } else {
                double d2 = (this.mHeaderMaxDragRate - 1.0f) * i2;
                int max = Math.max((this.mScreenHeightPixels * 4) / 3, getHeight());
                int i3 = this.mHeaderHeight;
                double d3 = max - i3;
                double max2 = Math.max(0.0f, (f3 - i3) * this.mDragRate);
                Double.isNaN(max2);
                double d4 = -max2;
                if (d3 == 0.0d) {
                    d3 = 1.0d;
                }
                Double.isNaN(d2);
                this.mKernel.moveSpinner(((int) Math.min(d2 * (1.0d - Math.pow(100.0d, d4 / d3)), max2)) + this.mHeaderHeight, true);
            }
        } else if (f3 < 0.0f && (this.mState == RefreshState.Loading || ((this.mEnableFooterFollowWhenNoMoreData && this.mFooterNoMoreData && isEnableRefreshOrLoadMore(this.mEnableLoadMore)) || (this.mEnableAutoLoadMore && !this.mFooterNoMoreData && isEnableRefreshOrLoadMore(this.mEnableLoadMore))))) {
            int i4 = this.mFooterHeight;
            if (f3 > (-i4)) {
                this.mKernel.moveSpinner((int) f3, true);
            } else {
                double d5 = (this.mFooterMaxDragRate - 1.0f) * i4;
                int max3 = Math.max((this.mScreenHeightPixels * 4) / 3, getHeight());
                int i5 = this.mFooterHeight;
                double d6 = max3 - i5;
                double d7 = -Math.min(0.0f, (i5 + f3) * this.mDragRate);
                Double.isNaN(d7);
                double d8 = -d7;
                if (d6 == 0.0d) {
                    d6 = 1.0d;
                }
                Double.isNaN(d5);
                this.mKernel.moveSpinner(((int) (-Math.min(d5 * (1.0d - Math.pow(100.0d, d8 / d6)), d7))) - this.mFooterHeight, true);
            }
        } else if (f3 >= 0.0f) {
            double d9 = this.mHeaderMaxDragRate * this.mHeaderHeight;
            double max4 = Math.max(this.mScreenHeightPixels / 2, getHeight());
            double max5 = Math.max(0.0f, this.mDragRate * f3);
            Double.isNaN(max5);
            double d10 = -max5;
            if (max4 == 0.0d) {
                max4 = 1.0d;
            }
            Double.isNaN(d9);
            this.mKernel.moveSpinner((int) Math.min(d9 * (1.0d - Math.pow(100.0d, d10 / max4)), max5), true);
        } else {
            double d11 = this.mFooterMaxDragRate * this.mFooterHeight;
            double max6 = Math.max(this.mScreenHeightPixels / 2, getHeight());
            double d12 = -Math.min(0.0f, this.mDragRate * f3);
            Double.isNaN(d12);
            double d13 = -d12;
            if (max6 == 0.0d) {
                max6 = 1.0d;
            }
            Double.isNaN(d11);
            this.mKernel.moveSpinner((int) (-Math.min(d11 * (1.0d - Math.pow(100.0d, d13 / max6)), d12)), true);
        }
        if (!this.mEnableAutoLoadMore || this.mFooterNoMoreData || !isEnableRefreshOrLoadMore(this.mEnableLoadMore) || f3 >= 0.0f || (refreshState = this.mState) == RefreshState.Refreshing || refreshState == RefreshState.Loading || refreshState == RefreshState.LoadFinish) {
            return;
        }
        if (this.mDisableContentWhenLoading) {
            this.animationRunnable = null;
            this.mKernel.animSpinner(-this.mFooterHeight);
        }
        setStateDirectLoading(false);
        postDelayed(new f(), this.mReboundDuration);
    }

    public void notifyStateChanged(RefreshState refreshState) {
        RefreshState refreshState2 = this.mState;
        if (refreshState2 != refreshState) {
            this.mState = refreshState;
            this.mViceState = refreshState;
            e.l.a.a.b.h hVar = this.mRefreshHeader;
            e.l.a.a.b.h hVar2 = this.mRefreshFooter;
            e.l.a.a.e.c cVar = this.mOnMultiPurposeListener;
            if (hVar != null) {
                hVar.onStateChanged(this, refreshState2, refreshState);
            }
            if (hVar2 != null) {
                hVar2.onStateChanged(this, refreshState2, refreshState);
            }
            if (cVar != null) {
                cVar.onStateChanged(this, refreshState2, refreshState);
            }
            if (refreshState == RefreshState.LoadFinish) {
                this.mFooterLocked = false;
            }
        } else if (this.mViceState != refreshState2) {
            this.mViceState = refreshState2;
        }
    }

    @Override // android.view.ViewGroup, android.view.View
    public void onAttachedToWindow() {
        e.l.a.a.b.h hVar;
        super.onAttachedToWindow();
        if (!isInEditMode()) {
            if (this.mRefreshHeader == null) {
                e.l.a.a.b.b bVar = sHeaderCreator;
                if (bVar != null) {
                    setRefreshHeader(bVar.createRefreshHeader(getContext(), this));
                } else {
                    setRefreshHeader(new BezierRadarHeader(getContext()));
                }
            }
            if (this.mRefreshFooter == null) {
                e.l.a.a.b.a aVar = sFooterCreator;
                if (aVar != null) {
                    setRefreshFooter(aVar.createRefreshFooter(getContext(), this));
                } else {
                    boolean z = this.mEnableLoadMore;
                    setRefreshFooter(new BallPulseFooter(getContext()));
                    this.mEnableLoadMore = z;
                }
            } else {
                this.mEnableLoadMore = this.mEnableLoadMore || !this.mManualLoadMore;
            }
            if (this.mRefreshContent == null) {
                int childCount = getChildCount();
                for (int i2 = 0; i2 < childCount; i2++) {
                    View childAt = getChildAt(i2);
                    e.l.a.a.b.h hVar2 = this.mRefreshHeader;
                    if ((hVar2 == null || childAt != hVar2.getView()) && ((hVar = this.mRefreshFooter) == null || childAt != hVar.getView())) {
                        this.mRefreshContent = new e.l.a.a.c.a(childAt);
                    }
                }
            }
            if (this.mRefreshContent == null) {
                int dp2px = e.l.a.a.f.a.dp2px(20.0f);
                TextView textView = new TextView(getContext());
                textView.setTextColor(-39424);
                textView.setGravity(17);
                textView.setTextSize(20.0f);
                textView.setText(R.string.srl_content_empty);
                super.addView(textView, -1, -1);
                e.l.a.a.c.a aVar2 = new e.l.a.a.c.a(textView);
                this.mRefreshContent = aVar2;
                aVar2.getView().setPadding(dp2px, dp2px, dp2px, dp2px);
            }
            int i3 = this.mFixedHeaderViewId;
            View findViewById = i3 > 0 ? findViewById(i3) : null;
            int i4 = this.mFixedFooterViewId;
            View findViewById2 = i4 > 0 ? findViewById(i4) : null;
            this.mRefreshContent.setScrollBoundaryDecider(this.mScrollBoundaryDecider);
            this.mRefreshContent.setEnableLoadMoreWhenContentNotFull(this.mEnableLoadMoreWhenContentNotFull);
            this.mRefreshContent.setUpComponent(this.mKernel, findViewById, findViewById2);
            if (this.mSpinner != 0) {
                notifyStateChanged(RefreshState.None);
                e.l.a.a.b.e eVar = this.mRefreshContent;
                this.mSpinner = 0;
                eVar.moveSpinner(0, this.mHeaderTranslationViewId, this.mFooterTranslationViewId);
            }
        }
        int[] iArr = this.mPrimaryColors;
        if (iArr != null) {
            e.l.a.a.b.h hVar3 = this.mRefreshHeader;
            if (hVar3 != null) {
                hVar3.setPrimaryColors(iArr);
            }
            e.l.a.a.b.h hVar4 = this.mRefreshFooter;
            if (hVar4 != null) {
                hVar4.setPrimaryColors(this.mPrimaryColors);
            }
        }
        e.l.a.a.b.e eVar2 = this.mRefreshContent;
        if (eVar2 != null) {
            super.bringChildToFront(eVar2.getView());
        }
        e.l.a.a.b.h hVar5 = this.mRefreshHeader;
        if (hVar5 != null && hVar5.getSpinnerStyle() != SpinnerStyle.FixedBehind) {
            super.bringChildToFront(this.mRefreshHeader.getView());
        }
        e.l.a.a.b.h hVar6 = this.mRefreshFooter;
        if (hVar6 == null || hVar6.getSpinnerStyle() == SpinnerStyle.FixedBehind) {
            return;
        }
        super.bringChildToFront(this.mRefreshFooter.getView());
    }

    @Override // android.view.ViewGroup, android.view.View
    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        this.mKernel.moveSpinner(0, true);
        notifyStateChanged(RefreshState.None);
        Handler handler = getHandler();
        if (handler != null) {
            handler.removeCallbacksAndMessages(null);
        }
        this.mManualLoadMore = true;
        this.animationRunnable = null;
        ValueAnimator valueAnimator = this.reboundAnimator;
        if (valueAnimator != null) {
            valueAnimator.removeAllListeners();
            this.reboundAnimator.removeAllUpdateListeners();
            this.reboundAnimator.cancel();
            this.reboundAnimator = null;
        }
        this.mFooterLocked = false;
    }

    /* JADX WARN: Removed duplicated region for block: B:32:0x0052  */
    @Override // android.view.View
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void onFinishInflate() {
        int i2;
        int i3;
        int i4;
        super.onFinishInflate();
        int childCount = super.getChildCount();
        if (childCount > 3) {
            throw new RuntimeException("最多只支持3个子View，Most only support three sub view");
        }
        int i5 = 0;
        int i6 = -1;
        char c2 = 0;
        while (true) {
            i2 = 2;
            if (i5 >= childCount) {
                break;
            }
            View childAt = super.getChildAt(i5);
            if (e.l.a.a.f.d.isContentView(childAt) && (c2 < 2 || i5 == 1)) {
                i6 = i5;
                c2 = 2;
            } else if (!(childAt instanceof e.l.a.a.b.h) && c2 < 1) {
                c2 = i5 > 0 ? (char) 1 : (char) 0;
                i6 = i5;
            }
            i5++;
        }
        if (i6 >= 0) {
            this.mRefreshContent = new e.l.a.a.c.a(super.getChildAt(i6));
            if (i6 == 1) {
                if (childCount == 3) {
                    i3 = 0;
                } else {
                    i3 = 0;
                    i2 = -1;
                }
            } else if (childCount == 2) {
                i3 = -1;
                i2 = 1;
            }
            for (i4 = 0; i4 < childCount; i4++) {
                View childAt2 = super.getChildAt(i4);
                if (i4 != i3 && (i4 == i2 || i3 != -1 || this.mRefreshHeader != null || !(childAt2 instanceof e.l.a.a.b.g))) {
                    if (i4 == i2 || (i2 == -1 && (childAt2 instanceof e.l.a.a.b.f))) {
                        this.mEnableLoadMore = this.mEnableLoadMore || !this.mManualLoadMore;
                        this.mRefreshFooter = childAt2 instanceof e.l.a.a.b.f ? (e.l.a.a.b.f) childAt2 : new e.l.a.a.c.b(childAt2);
                    }
                } else {
                    this.mRefreshHeader = childAt2 instanceof e.l.a.a.b.g ? (e.l.a.a.b.g) childAt2 : new e.l.a.a.c.c(childAt2);
                }
            }
        }
        i3 = -1;
        i2 = -1;
        while (i4 < childCount) {
        }
    }

    @Override // android.view.ViewGroup, android.view.View
    public void onLayout(boolean z, int i2, int i3, int i4, int i5) {
        int i6;
        int paddingLeft = getPaddingLeft();
        int paddingTop = getPaddingTop();
        getPaddingBottom();
        int childCount = super.getChildCount();
        for (int i7 = 0; i7 < childCount; i7++) {
            View childAt = super.getChildAt(i7);
            if (childAt.getVisibility() != 8 && childAt.getTag(R.string.srl_component_falsify) != childAt) {
                e.l.a.a.b.e eVar = this.mRefreshContent;
                boolean z2 = true;
                if (eVar != null && eVar.getView() == childAt) {
                    boolean z3 = isInEditMode() && this.mEnablePreviewInEditMode && isEnableRefreshOrLoadMore(this.mEnableRefresh) && this.mRefreshHeader != null;
                    View view = this.mRefreshContent.getView();
                    ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
                    ViewGroup.MarginLayoutParams marginLayoutParams = layoutParams instanceof ViewGroup.MarginLayoutParams ? (ViewGroup.MarginLayoutParams) layoutParams : sDefaultMarginLP;
                    int i8 = marginLayoutParams.leftMargin + paddingLeft;
                    int i9 = marginLayoutParams.topMargin + paddingTop;
                    int measuredWidth = view.getMeasuredWidth() + i8;
                    int measuredHeight = view.getMeasuredHeight() + i9;
                    if (z3 && isEnableTranslationContent(this.mEnableHeaderTranslationContent, this.mRefreshHeader)) {
                        int i10 = this.mHeaderHeight;
                        i9 += i10;
                        measuredHeight += i10;
                    }
                    view.layout(i8, i9, measuredWidth, measuredHeight);
                }
                e.l.a.a.b.h hVar = this.mRefreshHeader;
                if (hVar != null && hVar.getView() == childAt) {
                    boolean z4 = isInEditMode() && this.mEnablePreviewInEditMode && isEnableRefreshOrLoadMore(this.mEnableRefresh);
                    View view2 = this.mRefreshHeader.getView();
                    ViewGroup.LayoutParams layoutParams2 = view2.getLayoutParams();
                    ViewGroup.MarginLayoutParams marginLayoutParams2 = layoutParams2 instanceof ViewGroup.MarginLayoutParams ? (ViewGroup.MarginLayoutParams) layoutParams2 : sDefaultMarginLP;
                    int i11 = marginLayoutParams2.leftMargin;
                    int i12 = marginLayoutParams2.topMargin + this.mHeaderInsetStart;
                    int measuredWidth2 = view2.getMeasuredWidth() + i11;
                    int measuredHeight2 = view2.getMeasuredHeight() + i12;
                    if (!z4 && this.mRefreshHeader.getSpinnerStyle() == SpinnerStyle.Translate) {
                        int i13 = this.mHeaderHeight;
                        i12 -= i13;
                        measuredHeight2 -= i13;
                    }
                    view2.layout(i11, i12, measuredWidth2, measuredHeight2);
                }
                e.l.a.a.b.h hVar2 = this.mRefreshFooter;
                if (hVar2 != null && hVar2.getView() == childAt) {
                    z2 = (isInEditMode() && this.mEnablePreviewInEditMode && isEnableRefreshOrLoadMore(this.mEnableLoadMore)) ? false : false;
                    View view3 = this.mRefreshFooter.getView();
                    ViewGroup.LayoutParams layoutParams3 = view3.getLayoutParams();
                    ViewGroup.MarginLayoutParams marginLayoutParams3 = layoutParams3 instanceof ViewGroup.MarginLayoutParams ? (ViewGroup.MarginLayoutParams) layoutParams3 : sDefaultMarginLP;
                    SpinnerStyle spinnerStyle = this.mRefreshFooter.getSpinnerStyle();
                    int i14 = marginLayoutParams3.leftMargin;
                    int measuredHeight3 = marginLayoutParams3.topMargin + getMeasuredHeight();
                    int i15 = this.mFooterInsetStart;
                    int i16 = measuredHeight3 - i15;
                    if (spinnerStyle == SpinnerStyle.MatchLayout) {
                        i16 = marginLayoutParams3.topMargin - i15;
                    } else {
                        if (!z2 && spinnerStyle != SpinnerStyle.FixedFront && spinnerStyle != SpinnerStyle.FixedBehind) {
                            if (spinnerStyle == SpinnerStyle.Scale && this.mSpinner < 0) {
                                i6 = Math.max(isEnableRefreshOrLoadMore(this.mEnableLoadMore) ? -this.mSpinner : 0, 0);
                            }
                        } else {
                            i6 = this.mFooterHeight;
                        }
                        i16 -= i6;
                    }
                    view3.layout(i14, i16, view3.getMeasuredWidth() + i14, view3.getMeasuredHeight() + i16);
                }
            }
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:107:0x0220  */
    /* JADX WARN: Removed duplicated region for block: B:110:0x0239  */
    /* JADX WARN: Removed duplicated region for block: B:112:0x0250  */
    /* JADX WARN: Removed duplicated region for block: B:95:0x01f9  */
    /* JADX WARN: Removed duplicated region for block: B:97:0x01ff  */
    @Override // android.view.View
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void onMeasure(int i2, int i3) {
        int i4;
        int i5;
        DimensionStatus dimensionStatus;
        int i6;
        int i7;
        boolean z = isInEditMode() && this.mEnablePreviewInEditMode;
        int childCount = super.getChildCount();
        int i8 = 0;
        for (int i9 = 0; i9 < childCount; i9++) {
            View childAt = super.getChildAt(i9);
            if (childAt.getVisibility() != 8 && childAt.getTag(R.string.srl_component_falsify) != childAt) {
                e.l.a.a.b.h hVar = this.mRefreshHeader;
                if (hVar != null && hVar.getView() == childAt) {
                    View view = this.mRefreshHeader.getView();
                    ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
                    ViewGroup.MarginLayoutParams marginLayoutParams = layoutParams instanceof ViewGroup.MarginLayoutParams ? (ViewGroup.MarginLayoutParams) layoutParams : sDefaultMarginLP;
                    int childMeasureSpec = ViewGroup.getChildMeasureSpec(i2, marginLayoutParams.leftMargin + marginLayoutParams.rightMargin, layoutParams.width);
                    int i10 = this.mHeaderHeight;
                    if (this.mHeaderHeightStatus.ordinal() < DimensionStatus.XmlLayoutUnNotify.ordinal()) {
                        int i11 = layoutParams.height;
                        if (i11 > 0) {
                            int i12 = i11 + marginLayoutParams.bottomMargin + marginLayoutParams.topMargin;
                            if (this.mHeaderHeightStatus.canReplaceWith(DimensionStatus.XmlExactUnNotify)) {
                                this.mHeaderHeight = layoutParams.height + marginLayoutParams.bottomMargin + marginLayoutParams.topMargin;
                                this.mHeaderHeightStatus = DimensionStatus.XmlExactUnNotify;
                            }
                            i10 = i12;
                        } else if (i11 == -2 && (this.mRefreshHeader.getSpinnerStyle() != SpinnerStyle.MatchLayout || !this.mHeaderHeightStatus.notified)) {
                            int max = Math.max((View.MeasureSpec.getSize(i3) - marginLayoutParams.bottomMargin) - marginLayoutParams.topMargin, 0);
                            view.measure(childMeasureSpec, View.MeasureSpec.makeMeasureSpec(max, Integer.MIN_VALUE));
                            int measuredHeight = view.getMeasuredHeight();
                            if (measuredHeight > 0) {
                                if (measuredHeight != max && this.mHeaderHeightStatus.canReplaceWith(DimensionStatus.XmlWrapUnNotify)) {
                                    this.mHeaderHeight = measuredHeight + marginLayoutParams.bottomMargin + marginLayoutParams.topMargin;
                                    this.mHeaderHeightStatus = DimensionStatus.XmlWrapUnNotify;
                                }
                                i10 = -1;
                            }
                        }
                    }
                    if (this.mRefreshHeader.getSpinnerStyle() == SpinnerStyle.MatchLayout) {
                        i10 = View.MeasureSpec.getSize(i3);
                        i7 = -1;
                        i6 = 0;
                    } else {
                        if (this.mRefreshHeader.getSpinnerStyle() != SpinnerStyle.Scale || z) {
                            i6 = 0;
                        } else {
                            i6 = 0;
                            i10 = Math.max(0, isEnableRefreshOrLoadMore(this.mEnableRefresh) ? this.mSpinner : 0);
                        }
                        i7 = -1;
                    }
                    if (i10 != i7) {
                        view.measure(childMeasureSpec, View.MeasureSpec.makeMeasureSpec(Math.max((i10 - marginLayoutParams.bottomMargin) - marginLayoutParams.topMargin, i6), 1073741824));
                    }
                    DimensionStatus dimensionStatus2 = this.mHeaderHeightStatus;
                    if (!dimensionStatus2.notified) {
                        this.mHeaderHeightStatus = dimensionStatus2.notified();
                        e.l.a.a.b.h hVar2 = this.mRefreshHeader;
                        e.l.a.a.b.i iVar = this.mKernel;
                        int i13 = this.mHeaderHeight;
                        hVar2.onInitialized(iVar, i13, (int) (this.mHeaderMaxDragRate * i13));
                    }
                    if (z && isEnableRefreshOrLoadMore(this.mEnableRefresh)) {
                        i8 += view.getMeasuredHeight();
                    }
                }
                e.l.a.a.b.h hVar3 = this.mRefreshFooter;
                if (hVar3 != null && hVar3.getView() == childAt) {
                    View view2 = this.mRefreshFooter.getView();
                    ViewGroup.LayoutParams layoutParams2 = view2.getLayoutParams();
                    ViewGroup.MarginLayoutParams marginLayoutParams2 = layoutParams2 instanceof ViewGroup.MarginLayoutParams ? (ViewGroup.MarginLayoutParams) layoutParams2 : sDefaultMarginLP;
                    int childMeasureSpec2 = ViewGroup.getChildMeasureSpec(i2, marginLayoutParams2.leftMargin + marginLayoutParams2.rightMargin, layoutParams2.width);
                    int i14 = this.mFooterHeight;
                    if (this.mFooterHeightStatus.ordinal() < DimensionStatus.XmlLayoutUnNotify.ordinal()) {
                        int i15 = layoutParams2.height;
                        if (i15 > 0) {
                            i14 = marginLayoutParams2.bottomMargin + i15 + marginLayoutParams2.topMargin;
                            if (this.mFooterHeightStatus.canReplaceWith(DimensionStatus.XmlExactUnNotify)) {
                                this.mFooterHeight = layoutParams2.height + marginLayoutParams2.topMargin + marginLayoutParams2.bottomMargin;
                                this.mFooterHeightStatus = DimensionStatus.XmlExactUnNotify;
                            }
                        } else if (i15 == -2 && (this.mRefreshFooter.getSpinnerStyle() != SpinnerStyle.MatchLayout || !this.mFooterHeightStatus.notified)) {
                            int max2 = Math.max((View.MeasureSpec.getSize(i3) - marginLayoutParams2.bottomMargin) - marginLayoutParams2.topMargin, 0);
                            view2.measure(childMeasureSpec2, View.MeasureSpec.makeMeasureSpec(max2, Integer.MIN_VALUE));
                            int measuredHeight2 = view2.getMeasuredHeight();
                            if (measuredHeight2 > 0) {
                                if (measuredHeight2 != max2 && this.mFooterHeightStatus.canReplaceWith(DimensionStatus.XmlWrapUnNotify)) {
                                    this.mFooterHeight = measuredHeight2 + marginLayoutParams2.topMargin + marginLayoutParams2.bottomMargin;
                                    this.mFooterHeightStatus = DimensionStatus.XmlWrapUnNotify;
                                }
                                i4 = -1;
                                if (this.mRefreshFooter.getSpinnerStyle() != SpinnerStyle.MatchLayout) {
                                    i4 = View.MeasureSpec.getSize(i3);
                                } else if (this.mRefreshFooter.getSpinnerStyle() == SpinnerStyle.Scale && !z) {
                                    i5 = 0;
                                    i4 = Math.max(0, isEnableRefreshOrLoadMore(this.mEnableLoadMore) ? -this.mSpinner : 0);
                                    if (i4 != -1) {
                                        view2.measure(childMeasureSpec2, View.MeasureSpec.makeMeasureSpec(Math.max((i4 - marginLayoutParams2.bottomMargin) - marginLayoutParams2.topMargin, i5), 1073741824));
                                    }
                                    dimensionStatus = this.mFooterHeightStatus;
                                    if (!dimensionStatus.notified) {
                                        this.mFooterHeightStatus = dimensionStatus.notified();
                                        e.l.a.a.b.h hVar4 = this.mRefreshFooter;
                                        e.l.a.a.b.i iVar2 = this.mKernel;
                                        int i16 = this.mFooterHeight;
                                        hVar4.onInitialized(iVar2, i16, (int) (this.mFooterMaxDragRate * i16));
                                    }
                                    if (z && isEnableRefreshOrLoadMore(this.mEnableLoadMore)) {
                                        i8 += view2.getMeasuredHeight();
                                    }
                                }
                                i5 = 0;
                                if (i4 != -1) {
                                }
                                dimensionStatus = this.mFooterHeightStatus;
                                if (!dimensionStatus.notified) {
                                }
                                if (z) {
                                    i8 += view2.getMeasuredHeight();
                                }
                            }
                        }
                    }
                    i4 = i14;
                    if (this.mRefreshFooter.getSpinnerStyle() != SpinnerStyle.MatchLayout) {
                    }
                    i5 = 0;
                    if (i4 != -1) {
                    }
                    dimensionStatus = this.mFooterHeightStatus;
                    if (!dimensionStatus.notified) {
                    }
                    if (z) {
                    }
                }
                e.l.a.a.b.e eVar = this.mRefreshContent;
                if (eVar != null && eVar.getView() == childAt) {
                    View view3 = this.mRefreshContent.getView();
                    ViewGroup.LayoutParams layoutParams3 = view3.getLayoutParams();
                    ViewGroup.MarginLayoutParams marginLayoutParams3 = layoutParams3 instanceof ViewGroup.MarginLayoutParams ? (ViewGroup.MarginLayoutParams) layoutParams3 : sDefaultMarginLP;
                    view3.measure(ViewGroup.getChildMeasureSpec(i2, getPaddingLeft() + getPaddingRight() + marginLayoutParams3.leftMargin + marginLayoutParams3.rightMargin, layoutParams3.width), ViewGroup.getChildMeasureSpec(i3, getPaddingTop() + getPaddingBottom() + marginLayoutParams3.topMargin + marginLayoutParams3.bottomMargin + ((z && (this.mRefreshHeader != null && isEnableRefreshOrLoadMore(this.mEnableRefresh) && isEnableTranslationContent(this.mEnableHeaderTranslationContent, this.mRefreshHeader))) ? this.mHeaderHeight : 0) + ((z && (this.mRefreshFooter != null && isEnableRefreshOrLoadMore(this.mEnableLoadMore) && isEnableTranslationContent(this.mEnableFooterTranslationContent, this.mRefreshFooter))) ? this.mFooterHeight : 0), layoutParams3.height));
                    i8 += view3.getMeasuredHeight();
                }
            }
        }
        super.setMeasuredDimension(View.resolveSize(super.getSuggestedMinimumWidth(), i2), View.resolveSize(i8, i3));
        this.mLastTouchX = getMeasuredWidth() / 2.0f;
    }

    @Override // android.view.ViewGroup, android.view.ViewParent, androidx.core.view.NestedScrollingParent
    public boolean onNestedFling(@NonNull View view, float f2, float f3, boolean z) {
        return this.mNestedChild.dispatchNestedFling(f2, f3, z);
    }

    @Override // android.view.ViewGroup, android.view.ViewParent, androidx.core.view.NestedScrollingParent
    public boolean onNestedPreFling(@NonNull View view, float f2, float f3) {
        return (this.mFooterLocked && f3 > 0.0f) || startFlingIfNeed(-f3) || this.mNestedChild.dispatchNestedPreFling(f2, f3);
    }

    @Override // android.view.ViewGroup, android.view.ViewParent, androidx.core.view.NestedScrollingParent
    public void onNestedPreScroll(@NonNull View view, int i2, int i3, @NonNull int[] iArr) {
        int i4 = this.mTotalUnconsumed;
        int i5 = 0;
        if (i3 * i4 > 0) {
            if (Math.abs(i3) > Math.abs(this.mTotalUnconsumed)) {
                int i6 = this.mTotalUnconsumed;
                this.mTotalUnconsumed = 0;
                i5 = i6;
            } else {
                this.mTotalUnconsumed -= i3;
                i5 = i3;
            }
            moveSpinnerInfinitely(this.mTotalUnconsumed);
        } else if (i3 > 0 && this.mFooterLocked) {
            int i7 = i4 - i3;
            this.mTotalUnconsumed = i7;
            moveSpinnerInfinitely(i7);
            i5 = i3;
        }
        this.mNestedChild.dispatchNestedPreScroll(i2, i3 - i5, iArr, null);
        iArr[1] = iArr[1] + i5;
    }

    @Override // android.view.ViewGroup, android.view.ViewParent, androidx.core.view.NestedScrollingParent
    public void onNestedScroll(@NonNull View view, int i2, int i3, int i4, int i5) {
        this.mNestedChild.dispatchNestedScroll(i2, i3, i4, i5, this.mParentOffsetInWindow);
        int i6 = i5 + this.mParentOffsetInWindow[1];
        if ((i6 < 0 && (this.mEnableRefresh || this.mEnableOverScrollDrag)) || (i6 > 0 && (this.mEnableLoadMore || this.mEnableOverScrollDrag))) {
            RefreshState refreshState = this.mViceState;
            if (refreshState == RefreshState.None || refreshState.isOpening) {
                this.mKernel.setState(i6 > 0 ? RefreshState.PullUpToLoad : RefreshState.PullDownToRefresh);
            }
            int i7 = this.mTotalUnconsumed - i6;
            this.mTotalUnconsumed = i7;
            moveSpinnerInfinitely(i7);
        }
        if (!this.mFooterLocked || i3 >= 0) {
            return;
        }
        this.mFooterLocked = false;
    }

    @Override // android.view.ViewGroup, android.view.ViewParent, androidx.core.view.NestedScrollingParent
    public void onNestedScrollAccepted(@NonNull View view, @NonNull View view2, int i2) {
        this.mNestedParent.onNestedScrollAccepted(view, view2, i2);
        this.mNestedChild.startNestedScroll(i2 & 2);
        this.mTotalUnconsumed = this.mSpinner;
        this.mNestedInProgress = true;
        interceptAnimatorByAction(0);
    }

    @Override // android.view.ViewGroup, android.view.ViewParent, androidx.core.view.NestedScrollingParent
    public boolean onStartNestedScroll(@NonNull View view, @NonNull View view2, int i2) {
        return (isEnabled() && isNestedScrollingEnabled() && (i2 & 2) != 0) && (this.mEnableOverScrollDrag || this.mEnableRefresh || this.mEnableLoadMore);
    }

    @Override // android.view.ViewGroup, android.view.ViewParent, androidx.core.view.NestedScrollingParent
    public void onStopNestedScroll(@NonNull View view) {
        this.mNestedParent.onStopNestedScroll(view);
        this.mNestedInProgress = false;
        this.mTotalUnconsumed = 0;
        overSpinner();
        this.mNestedChild.stopNestedScroll();
    }

    public void overSpinner() {
        RefreshState refreshState = this.mState;
        if (refreshState == RefreshState.TwoLevel) {
            if (this.mCurrentVelocity > -1000 && this.mSpinner > getMeasuredHeight() / 2) {
                ValueAnimator animSpinner = this.mKernel.animSpinner(getMeasuredHeight());
                if (animSpinner != null) {
                    animSpinner.setDuration(this.mFloorDuration);
                }
            } else if (this.mIsBeingDragged) {
                this.mKernel.finishTwoLevel();
            }
        } else if (refreshState != RefreshState.Loading && (!this.mEnableFooterFollowWhenNoMoreData || !this.mFooterNoMoreData || this.mSpinner >= 0 || !isEnableRefreshOrLoadMore(this.mEnableLoadMore))) {
            RefreshState refreshState2 = this.mState;
            if (refreshState2 == RefreshState.Refreshing) {
                int i2 = this.mSpinner;
                int i3 = this.mHeaderHeight;
                if (i2 > i3) {
                    this.mKernel.animSpinner(i3);
                } else if (i2 < 0) {
                    this.mKernel.animSpinner(0);
                }
            } else if (refreshState2 == RefreshState.PullDownToRefresh) {
                this.mKernel.setState(RefreshState.PullDownCanceled);
            } else if (refreshState2 == RefreshState.PullUpToLoad) {
                this.mKernel.setState(RefreshState.PullUpCanceled);
            } else if (refreshState2 == RefreshState.ReleaseToRefresh) {
                this.mKernel.setState(RefreshState.Refreshing);
            } else if (refreshState2 == RefreshState.ReleaseToLoad) {
                this.mKernel.setState(RefreshState.Loading);
            } else if (refreshState2 == RefreshState.ReleaseToTwoLevel) {
                this.mKernel.setState(RefreshState.TwoLevelReleased);
            } else if (refreshState2 == RefreshState.RefreshReleased) {
                if (this.reboundAnimator == null) {
                    this.mKernel.animSpinner(this.mHeaderHeight);
                }
            } else if (refreshState2 == RefreshState.LoadReleased) {
                if (this.reboundAnimator == null) {
                    this.mKernel.animSpinner(-this.mFooterHeight);
                }
            } else if (this.mSpinner != 0) {
                this.mKernel.animSpinner(0);
            }
        } else {
            int i4 = this.mSpinner;
            int i5 = this.mFooterHeight;
            if (i4 < (-i5)) {
                this.mKernel.animSpinner(-i5);
            } else if (i4 > 0) {
                this.mKernel.animSpinner(0);
            }
        }
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j resetNoMoreData() {
        this.mFooterNoMoreData = false;
        e.l.a.a.b.h hVar = this.mRefreshFooter;
        if ((hVar instanceof e.l.a.a.b.f) && !((e.l.a.a.b.f) hVar).setNoMoreData(false)) {
            PrintStream printStream = System.out;
            printStream.println("Footer:" + this.mRefreshFooter + " NoMoreData is not supported.(不支持NoMoreData，请使用ClassicsFooter或者自定义)");
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setDisableContentWhenLoading(boolean z) {
        this.mDisableContentWhenLoading = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setDisableContentWhenRefresh(boolean z) {
        this.mDisableContentWhenRefresh = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setDragRate(float f2) {
        this.mDragRate = f2;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableAutoLoadMore(boolean z) {
        this.mEnableAutoLoadMore = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableClipFooterWhenFixedBehind(boolean z) {
        this.mEnableClipFooterWhenFixedBehind = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableClipHeaderWhenFixedBehind(boolean z) {
        this.mEnableClipHeaderWhenFixedBehind = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    @Deprecated
    public e.l.a.a.b.j setEnableFooterFollowWhenLoadFinished(boolean z) {
        this.mEnableFooterFollowWhenNoMoreData = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableFooterFollowWhenNoMoreData(boolean z) {
        this.mEnableFooterFollowWhenNoMoreData = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableFooterTranslationContent(boolean z) {
        this.mEnableFooterTranslationContent = z;
        this.mManualFooterTranslationContent = true;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableHeaderTranslationContent(boolean z) {
        this.mEnableHeaderTranslationContent = z;
        this.mManualHeaderTranslationContent = true;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableLoadMore(boolean z) {
        this.mManualLoadMore = true;
        this.mEnableLoadMore = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableLoadMoreWhenContentNotFull(boolean z) {
        this.mEnableLoadMoreWhenContentNotFull = z;
        e.l.a.a.b.e eVar = this.mRefreshContent;
        if (eVar != null) {
            eVar.setEnableLoadMoreWhenContentNotFull(z);
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableNestedScroll(boolean z) {
        setNestedScrollingEnabled(z);
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableOverScrollBounce(boolean z) {
        this.mEnableOverScrollBounce = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableOverScrollDrag(boolean z) {
        this.mEnableOverScrollDrag = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnablePureScrollMode(boolean z) {
        this.mEnablePureScrollMode = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableRefresh(boolean z) {
        this.mEnableRefresh = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableScrollContentWhenLoaded(boolean z) {
        this.mEnableScrollContentWhenLoaded = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setEnableScrollContentWhenRefreshed(boolean z) {
        this.mEnableScrollContentWhenRefreshed = z;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setFooterHeight(float f2) {
        if (this.mFooterHeightStatus.canReplaceWith(DimensionStatus.CodeExact)) {
            this.mFooterHeight = e.l.a.a.f.a.dp2px(f2);
            this.mFooterHeightStatus = DimensionStatus.CodeExactUnNotify;
            e.l.a.a.b.h hVar = this.mRefreshFooter;
            if (hVar != null) {
                hVar.getView().requestLayout();
            }
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setFooterInsetStart(float f2) {
        this.mFooterInsetStart = e.l.a.a.f.a.dp2px(f2);
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setFooterMaxDragRate(float f2) {
        this.mFooterMaxDragRate = f2;
        if (this.mRefreshFooter != null && getHandler() != null) {
            e.l.a.a.b.h hVar = this.mRefreshFooter;
            e.l.a.a.b.i iVar = this.mKernel;
            int i2 = this.mFooterHeight;
            hVar.onInitialized(iVar, i2, (int) (i2 * this.mFooterMaxDragRate));
        } else {
            this.mFooterHeightStatus = this.mFooterHeightStatus.unNotify();
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setFooterTriggerRate(float f2) {
        this.mFooterTriggerRate = f2;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setHeaderHeight(float f2) {
        if (this.mHeaderHeightStatus.canReplaceWith(DimensionStatus.CodeExact)) {
            this.mHeaderHeight = e.l.a.a.f.a.dp2px(f2);
            this.mHeaderHeightStatus = DimensionStatus.CodeExactUnNotify;
            e.l.a.a.b.h hVar = this.mRefreshHeader;
            if (hVar != null) {
                hVar.getView().requestLayout();
            }
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setHeaderInsetStart(float f2) {
        this.mHeaderInsetStart = e.l.a.a.f.a.dp2px(f2);
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setHeaderMaxDragRate(float f2) {
        this.mHeaderMaxDragRate = f2;
        if (this.mRefreshHeader != null && getHandler() != null) {
            e.l.a.a.b.h hVar = this.mRefreshHeader;
            e.l.a.a.b.i iVar = this.mKernel;
            int i2 = this.mHeaderHeight;
            hVar.onInitialized(iVar, i2, (int) (this.mHeaderMaxDragRate * i2));
        } else {
            this.mHeaderHeightStatus = this.mHeaderHeightStatus.unNotify();
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setHeaderTriggerRate(float f2) {
        this.mHeaderTriggerRate = f2;
        return this;
    }

    @Override // android.view.View
    public void setNestedScrollingEnabled(boolean z) {
        this.mEnableNestedScrolling = z;
        this.mNestedChild.setNestedScrollingEnabled(z);
    }

    @Override // e.l.a.a.b.j
    @Deprecated
    public e.l.a.a.b.j setNoMoreData(boolean z) {
        if (this.mState == RefreshState.Loading && z) {
            finishLoadMoreWithNoMoreData();
            return this;
        }
        this.mFooterNoMoreData = z;
        e.l.a.a.b.h hVar = this.mRefreshFooter;
        if ((hVar instanceof e.l.a.a.b.f) && !((e.l.a.a.b.f) hVar).setNoMoreData(z)) {
            PrintStream printStream = System.out;
            printStream.println("Footer:" + this.mRefreshFooter + " NoMoreData is not supported.(不支持NoMoreData，请使用ClassicsFooter或者自定义)");
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setOnLoadMoreListener(e.l.a.a.e.b bVar) {
        this.mLoadMoreListener = bVar;
        this.mEnableLoadMore = this.mEnableLoadMore || !(this.mManualLoadMore || bVar == null);
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setOnMultiPurposeListener(e.l.a.a.e.c cVar) {
        this.mOnMultiPurposeListener = cVar;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setOnRefreshListener(e.l.a.a.e.d dVar) {
        this.mRefreshListener = dVar;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setOnRefreshLoadMoreListener(e.l.a.a.e.e eVar) {
        this.mRefreshListener = eVar;
        this.mLoadMoreListener = eVar;
        this.mEnableLoadMore = this.mEnableLoadMore || !(this.mManualLoadMore || eVar == null);
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setPrimaryColors(@ColorInt int... iArr) {
        e.l.a.a.b.h hVar = this.mRefreshHeader;
        if (hVar != null) {
            hVar.setPrimaryColors(iArr);
        }
        e.l.a.a.b.h hVar2 = this.mRefreshFooter;
        if (hVar2 != null) {
            hVar2.setPrimaryColors(iArr);
        }
        this.mPrimaryColors = iArr;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setPrimaryColorsId(@ColorRes int... iArr) {
        int[] iArr2 = new int[iArr.length];
        for (int i2 = 0; i2 < iArr.length; i2++) {
            iArr2[i2] = ContextCompat.getColor(getContext(), iArr[i2]);
        }
        setPrimaryColors(iArr2);
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setReboundDuration(int i2) {
        this.mReboundDuration = i2;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setReboundInterpolator(@NonNull Interpolator interpolator) {
        this.mReboundInterpolator = interpolator;
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setRefreshContent(@NonNull View view) {
        return setRefreshContent(view, -1, -1);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setRefreshFooter(@NonNull e.l.a.a.b.f fVar) {
        return setRefreshFooter(fVar, -1, -2);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setRefreshHeader(@NonNull e.l.a.a.b.g gVar) {
        return setRefreshHeader(gVar, -1, -2);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setScrollBoundaryDecider(e.l.a.a.b.k kVar) {
        this.mScrollBoundaryDecider = kVar;
        e.l.a.a.b.e eVar = this.mRefreshContent;
        if (eVar != null) {
            eVar.setScrollBoundaryDecider(kVar);
        }
        return this;
    }

    public void setStateDirectLoading(boolean z) {
        if (this.mState != RefreshState.Loading) {
            this.mLastOpenTime = System.currentTimeMillis();
            this.mFooterLocked = true;
            notifyStateChanged(RefreshState.Loading);
            e.l.a.a.e.b bVar = this.mLoadMoreListener;
            if (bVar != null) {
                if (z) {
                    bVar.onLoadMore(this);
                }
            } else if (this.mOnMultiPurposeListener == null) {
                finishLoadMore(2000);
            }
            e.l.a.a.b.h hVar = this.mRefreshFooter;
            if (hVar != null) {
                int i2 = this.mFooterHeight;
                hVar.onStartAnimator(this, i2, (int) (this.mFooterMaxDragRate * i2));
            }
            e.l.a.a.e.c cVar = this.mOnMultiPurposeListener;
            if (cVar == null || !(this.mRefreshFooter instanceof e.l.a.a.b.f)) {
                return;
            }
            if (z) {
                cVar.onLoadMore(this);
            }
            int i3 = this.mFooterHeight;
            this.mOnMultiPurposeListener.onFooterStartAnimator((e.l.a.a.b.f) this.mRefreshFooter, i3, (int) (this.mFooterMaxDragRate * i3));
        }
    }

    public void setStateLoading(boolean z) {
        b bVar = new b(z);
        notifyStateChanged(RefreshState.LoadReleased);
        ValueAnimator animSpinner = this.mKernel.animSpinner(-this.mFooterHeight);
        if (animSpinner != null) {
            animSpinner.addListener(bVar);
        }
        e.l.a.a.b.h hVar = this.mRefreshFooter;
        if (hVar != null) {
            int i2 = this.mFooterHeight;
            hVar.onReleased(this, i2, (int) (this.mFooterMaxDragRate * i2));
        }
        e.l.a.a.e.c cVar = this.mOnMultiPurposeListener;
        if (cVar != null) {
            e.l.a.a.b.h hVar2 = this.mRefreshFooter;
            if (hVar2 instanceof e.l.a.a.b.f) {
                int i3 = this.mFooterHeight;
                cVar.onFooterReleased((e.l.a.a.b.f) hVar2, i3, (int) (this.mFooterMaxDragRate * i3));
            }
        }
        if (animSpinner == null) {
            bVar.onAnimationEnd(null);
        }
    }

    public void setStateRefreshing(boolean z) {
        c cVar = new c(z);
        notifyStateChanged(RefreshState.RefreshReleased);
        ValueAnimator animSpinner = this.mKernel.animSpinner(this.mHeaderHeight);
        if (animSpinner != null) {
            animSpinner.addListener(cVar);
        }
        e.l.a.a.b.h hVar = this.mRefreshHeader;
        if (hVar != null) {
            int i2 = this.mHeaderHeight;
            hVar.onReleased(this, i2, (int) (this.mHeaderMaxDragRate * i2));
        }
        e.l.a.a.e.c cVar2 = this.mOnMultiPurposeListener;
        if (cVar2 != null) {
            e.l.a.a.b.h hVar2 = this.mRefreshHeader;
            if (hVar2 instanceof e.l.a.a.b.g) {
                int i3 = this.mHeaderHeight;
                cVar2.onHeaderReleased((e.l.a.a.b.g) hVar2, i3, (int) (this.mHeaderMaxDragRate * i3));
            }
        }
        if (animSpinner == null) {
            cVar.onAnimationEnd(null);
        }
    }

    public void setViceState(RefreshState refreshState) {
        RefreshState refreshState2 = this.mState;
        if (refreshState2.isDragging && refreshState2.isHeader != refreshState.isHeader) {
            notifyStateChanged(RefreshState.None);
        }
        if (this.mViceState != refreshState) {
            this.mViceState = refreshState;
        }
    }

    public boolean startFlingIfNeed(float f2) {
        if (f2 == 0.0f) {
            f2 = this.mCurrentVelocity;
        }
        if (Math.abs(f2) > this.mMinimumVelocity) {
            int i2 = this.mSpinner;
            if (i2 * f2 < 0.0f) {
                RefreshState refreshState = this.mState;
                if (refreshState != RefreshState.Refreshing && refreshState != RefreshState.Loading && (i2 >= 0 || !this.mFooterNoMoreData)) {
                    if (this.mState.isReleaseToOpening) {
                        return true;
                    }
                } else {
                    this.animationRunnable = new l(f2).start();
                    return true;
                }
            }
            if ((f2 < 0.0f && ((this.mEnableOverScrollBounce && (this.mEnableLoadMore || this.mEnableOverScrollDrag)) || ((this.mState == RefreshState.Loading && this.mSpinner >= 0) || (this.mEnableAutoLoadMore && isEnableRefreshOrLoadMore(this.mEnableLoadMore))))) || (f2 > 0.0f && ((this.mEnableOverScrollBounce && this.mEnableRefresh) || this.mEnableOverScrollDrag || (this.mState == RefreshState.Refreshing && this.mSpinner <= 0)))) {
                this.mVerticalPermit = false;
                this.mScroller.fling(0, 0, 0, (int) (-f2), 0, 0, -2147483647, Integer.MAX_VALUE);
                this.mScroller.computeScrollOffset();
                invalidate();
            }
        }
        return false;
    }

    public SmartRefreshLayout(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    @Override // e.l.a.a.b.j
    public boolean autoLoadMore(int i2, int i3, float f2, boolean z) {
        if (this.mState == RefreshState.None && isEnableRefreshOrLoadMore(this.mEnableLoadMore) && !this.mFooterNoMoreData) {
            j jVar = new j(f2, i3, z);
            setViceState(RefreshState.Loading);
            if (i2 > 0) {
                postDelayed(jVar, i2);
                return true;
            }
            jVar.run();
            return true;
        }
        return false;
    }

    @Override // e.l.a.a.b.j
    @Deprecated
    public boolean autoRefresh(int i2) {
        int i3 = this.mReboundDuration;
        int i4 = this.mHeaderHeight;
        float f2 = ((this.mHeaderMaxDragRate / 2.0f) + 0.5f) * i4 * 1.0f;
        if (i4 == 0) {
            i4 = 1;
        }
        return autoRefresh(i2, i3, f2 / i4, false);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setRefreshContent(@NonNull View view, int i2, int i3) {
        e.l.a.a.b.e eVar = this.mRefreshContent;
        if (eVar != null) {
            super.removeView(eVar.getView());
        }
        super.addView(view, 0, new LayoutParams(i2, i3));
        e.l.a.a.b.h hVar = this.mRefreshHeader;
        if (hVar != null && hVar.getSpinnerStyle() == SpinnerStyle.FixedBehind) {
            super.bringChildToFront(view);
            e.l.a.a.b.h hVar2 = this.mRefreshFooter;
            if (hVar2 != null && hVar2.getSpinnerStyle() != SpinnerStyle.FixedBehind) {
                super.bringChildToFront(this.mRefreshFooter.getView());
            }
        } else {
            e.l.a.a.b.h hVar3 = this.mRefreshFooter;
            if (hVar3 != null && hVar3.getSpinnerStyle() == SpinnerStyle.FixedBehind) {
                super.bringChildToFront(view);
                e.l.a.a.b.h hVar4 = this.mRefreshHeader;
                if (hVar4 != null && hVar4.getSpinnerStyle() == SpinnerStyle.FixedBehind) {
                    super.bringChildToFront(this.mRefreshHeader.getView());
                }
            }
        }
        this.mRefreshContent = new e.l.a.a.c.a(view);
        if (getHandler() != null) {
            int i4 = this.mFixedHeaderViewId;
            View findViewById = i4 > 0 ? findViewById(i4) : null;
            int i5 = this.mFixedFooterViewId;
            View findViewById2 = i5 > 0 ? findViewById(i5) : null;
            this.mRefreshContent.setScrollBoundaryDecider(this.mScrollBoundaryDecider);
            this.mRefreshContent.setEnableLoadMoreWhenContentNotFull(this.mEnableLoadMoreWhenContentNotFull);
            this.mRefreshContent.setUpComponent(this.mKernel, findViewById, findViewById2);
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setRefreshFooter(@NonNull e.l.a.a.b.f fVar, int i2, int i3) {
        e.l.a.a.b.h hVar = this.mRefreshFooter;
        if (hVar != null) {
            super.removeView(hVar.getView());
        }
        this.mRefreshFooter = fVar;
        this.mFooterBackgroundColor = 0;
        this.mFooterNeedTouchEventWhenLoading = false;
        this.mFooterHeightStatus = this.mFooterHeightStatus.unNotify();
        this.mEnableLoadMore = !this.mManualLoadMore || this.mEnableLoadMore;
        if (this.mRefreshFooter.getSpinnerStyle() == SpinnerStyle.FixedBehind) {
            super.addView(this.mRefreshFooter.getView(), 0, new LayoutParams(i2, i3));
        } else {
            super.addView(this.mRefreshFooter.getView(), i2, i3);
        }
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j setRefreshHeader(@NonNull e.l.a.a.b.g gVar, int i2, int i3) {
        e.l.a.a.b.h hVar = this.mRefreshHeader;
        if (hVar != null) {
            super.removeView(hVar.getView());
        }
        this.mRefreshHeader = gVar;
        this.mHeaderBackgroundColor = 0;
        this.mHeaderNeedTouchEventWhenRefreshing = false;
        this.mHeaderHeightStatus = this.mHeaderHeightStatus.unNotify();
        if (this.mRefreshHeader.getSpinnerStyle() == SpinnerStyle.FixedBehind) {
            super.addView(this.mRefreshHeader.getView(), 0, new LayoutParams(i2, i3));
        } else {
            super.addView(this.mRefreshHeader.getView(), i2, i3);
        }
        return this;
    }

    public SmartRefreshLayout(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mFloorDuration = 250;
        this.mReboundDuration = 250;
        this.mDragRate = 0.5f;
        this.mDragDirection = 'n';
        this.mFixedHeaderViewId = -1;
        this.mFixedFooterViewId = -1;
        this.mHeaderTranslationViewId = -1;
        this.mFooterTranslationViewId = -1;
        this.mEnableRefresh = true;
        this.mEnableLoadMore = false;
        this.mEnableClipHeaderWhenFixedBehind = true;
        this.mEnableClipFooterWhenFixedBehind = true;
        this.mEnableHeaderTranslationContent = true;
        this.mEnableFooterTranslationContent = true;
        this.mEnableFooterFollowWhenNoMoreData = false;
        this.mEnablePreviewInEditMode = true;
        this.mEnableOverScrollBounce = true;
        this.mEnableOverScrollDrag = false;
        this.mEnableAutoLoadMore = true;
        this.mEnablePureScrollMode = false;
        this.mEnableScrollContentWhenLoaded = true;
        this.mEnableScrollContentWhenRefreshed = true;
        this.mEnableLoadMoreWhenContentNotFull = true;
        this.mEnableNestedScrolling = true;
        this.mDisableContentWhenRefresh = false;
        this.mDisableContentWhenLoading = false;
        this.mFooterNoMoreData = false;
        this.mManualLoadMore = false;
        this.mManualHeaderTranslationContent = false;
        this.mManualFooterTranslationContent = false;
        this.mParentOffsetInWindow = new int[2];
        this.mNestedChild = new NestedScrollingChildHelper(this);
        this.mNestedParent = new NestedScrollingParentHelper(this);
        DimensionStatus dimensionStatus = DimensionStatus.DefaultUnNotify;
        this.mHeaderHeightStatus = dimensionStatus;
        this.mFooterHeightStatus = dimensionStatus;
        this.mHeaderMaxDragRate = 2.5f;
        this.mFooterMaxDragRate = 2.5f;
        this.mHeaderTriggerRate = 1.0f;
        this.mFooterTriggerRate = 1.0f;
        this.mKernel = new m();
        RefreshState refreshState = RefreshState.None;
        this.mState = refreshState;
        this.mViceState = refreshState;
        this.mLastOpenTime = 0L;
        this.mHeaderBackgroundColor = 0;
        this.mFooterBackgroundColor = 0;
        this.mFooterLocked = false;
        this.mVerticalPermit = false;
        this.mFalsifyEvent = null;
        super.setClipToPadding(false);
        e.l.a.a.f.a aVar = new e.l.a.a.f.a();
        ViewConfiguration viewConfiguration = ViewConfiguration.get(context);
        this.mScroller = new Scroller(context);
        this.mVelocityTracker = VelocityTracker.obtain();
        this.mScreenHeightPixels = context.getResources().getDisplayMetrics().heightPixels;
        this.mReboundInterpolator = new e.l.a.a.f.e();
        this.mTouchSlop = viewConfiguration.getScaledTouchSlop();
        this.mMinimumVelocity = viewConfiguration.getScaledMinimumFlingVelocity();
        this.mMaximumVelocity = viewConfiguration.getScaledMaximumFlingVelocity();
        this.mFooterHeight = aVar.dip2px(60.0f);
        this.mHeaderHeight = aVar.dip2px(100.0f);
        e.l.a.a.b.c cVar = sRefreshInitializer;
        if (cVar != null) {
            cVar.initialize(context, this);
        }
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.SmartRefreshLayout);
        this.mDragRate = obtainStyledAttributes.getFloat(R.styleable.SmartRefreshLayout_srlDragRate, this.mDragRate);
        this.mHeaderMaxDragRate = obtainStyledAttributes.getFloat(R.styleable.SmartRefreshLayout_srlHeaderMaxDragRate, this.mHeaderMaxDragRate);
        this.mFooterMaxDragRate = obtainStyledAttributes.getFloat(R.styleable.SmartRefreshLayout_srlFooterMaxDragRate, this.mFooterMaxDragRate);
        this.mHeaderTriggerRate = obtainStyledAttributes.getFloat(R.styleable.SmartRefreshLayout_srlHeaderTriggerRate, this.mHeaderTriggerRate);
        this.mFooterTriggerRate = obtainStyledAttributes.getFloat(R.styleable.SmartRefreshLayout_srlFooterTriggerRate, this.mFooterTriggerRate);
        this.mEnableRefresh = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableRefresh, this.mEnableRefresh);
        this.mReboundDuration = obtainStyledAttributes.getInt(R.styleable.SmartRefreshLayout_srlReboundDuration, this.mReboundDuration);
        this.mEnableLoadMore = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableLoadMore, this.mEnableLoadMore);
        this.mHeaderHeight = obtainStyledAttributes.getDimensionPixelOffset(R.styleable.SmartRefreshLayout_srlHeaderHeight, this.mHeaderHeight);
        this.mFooterHeight = obtainStyledAttributes.getDimensionPixelOffset(R.styleable.SmartRefreshLayout_srlFooterHeight, this.mFooterHeight);
        this.mHeaderInsetStart = obtainStyledAttributes.getDimensionPixelOffset(R.styleable.SmartRefreshLayout_srlHeaderInsetStart, this.mHeaderInsetStart);
        this.mFooterInsetStart = obtainStyledAttributes.getDimensionPixelOffset(R.styleable.SmartRefreshLayout_srlFooterInsetStart, this.mFooterInsetStart);
        this.mDisableContentWhenRefresh = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlDisableContentWhenRefresh, this.mDisableContentWhenRefresh);
        this.mDisableContentWhenLoading = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlDisableContentWhenLoading, this.mDisableContentWhenLoading);
        this.mEnableHeaderTranslationContent = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableHeaderTranslationContent, this.mEnableHeaderTranslationContent);
        this.mEnableFooterTranslationContent = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableFooterTranslationContent, this.mEnableFooterTranslationContent);
        this.mEnablePreviewInEditMode = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnablePreviewInEditMode, this.mEnablePreviewInEditMode);
        this.mEnableAutoLoadMore = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableAutoLoadMore, this.mEnableAutoLoadMore);
        this.mEnableOverScrollBounce = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableOverScrollBounce, this.mEnableOverScrollBounce);
        this.mEnablePureScrollMode = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnablePureScrollMode, this.mEnablePureScrollMode);
        this.mEnableScrollContentWhenLoaded = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableScrollContentWhenLoaded, this.mEnableScrollContentWhenLoaded);
        this.mEnableScrollContentWhenRefreshed = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableScrollContentWhenRefreshed, this.mEnableScrollContentWhenRefreshed);
        this.mEnableLoadMoreWhenContentNotFull = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableLoadMoreWhenContentNotFull, this.mEnableLoadMoreWhenContentNotFull);
        boolean z = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableFooterFollowWhenLoadFinished, this.mEnableFooterFollowWhenNoMoreData);
        this.mEnableFooterFollowWhenNoMoreData = z;
        this.mEnableFooterFollowWhenNoMoreData = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableFooterFollowWhenNoMoreData, z);
        this.mEnableClipHeaderWhenFixedBehind = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableClipHeaderWhenFixedBehind, this.mEnableClipHeaderWhenFixedBehind);
        this.mEnableClipFooterWhenFixedBehind = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableClipFooterWhenFixedBehind, this.mEnableClipFooterWhenFixedBehind);
        this.mEnableOverScrollDrag = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableOverScrollDrag, this.mEnableOverScrollDrag);
        this.mFixedHeaderViewId = obtainStyledAttributes.getResourceId(R.styleable.SmartRefreshLayout_srlFixedHeaderViewId, this.mFixedHeaderViewId);
        this.mFixedFooterViewId = obtainStyledAttributes.getResourceId(R.styleable.SmartRefreshLayout_srlFixedFooterViewId, this.mFixedFooterViewId);
        this.mHeaderTranslationViewId = obtainStyledAttributes.getResourceId(R.styleable.SmartRefreshLayout_srlHeaderTranslationViewId, this.mHeaderTranslationViewId);
        this.mFooterTranslationViewId = obtainStyledAttributes.getResourceId(R.styleable.SmartRefreshLayout_srlFooterTranslationViewId, this.mFooterTranslationViewId);
        boolean z2 = obtainStyledAttributes.getBoolean(R.styleable.SmartRefreshLayout_srlEnableNestedScrolling, this.mEnableNestedScrolling);
        this.mEnableNestedScrolling = z2;
        this.mNestedChild.setNestedScrollingEnabled(z2);
        this.mManualLoadMore = this.mManualLoadMore || obtainStyledAttributes.hasValue(R.styleable.SmartRefreshLayout_srlEnableLoadMore);
        this.mManualHeaderTranslationContent = this.mManualHeaderTranslationContent || obtainStyledAttributes.hasValue(R.styleable.SmartRefreshLayout_srlEnableHeaderTranslationContent);
        this.mManualFooterTranslationContent = this.mManualFooterTranslationContent || obtainStyledAttributes.hasValue(R.styleable.SmartRefreshLayout_srlEnableFooterTranslationContent);
        this.mHeaderHeightStatus = obtainStyledAttributes.hasValue(R.styleable.SmartRefreshLayout_srlHeaderHeight) ? DimensionStatus.XmlLayoutUnNotify : this.mHeaderHeightStatus;
        this.mFooterHeightStatus = obtainStyledAttributes.hasValue(R.styleable.SmartRefreshLayout_srlFooterHeight) ? DimensionStatus.XmlLayoutUnNotify : this.mFooterHeightStatus;
        int color = obtainStyledAttributes.getColor(R.styleable.SmartRefreshLayout_srlAccentColor, 0);
        int color2 = obtainStyledAttributes.getColor(R.styleable.SmartRefreshLayout_srlPrimaryColor, 0);
        if (color2 != 0) {
            if (color != 0) {
                this.mPrimaryColors = new int[]{color2, color};
            } else {
                this.mPrimaryColors = new int[]{color2};
            }
        } else if (color != 0) {
            this.mPrimaryColors = new int[]{0, color};
        }
        if (this.mEnablePureScrollMode && !this.mManualLoadMore && !this.mEnableLoadMore) {
            this.mEnableLoadMore = true;
        }
        obtainStyledAttributes.recycle();
    }

    @Override // e.l.a.a.b.j
    public boolean autoRefresh(int i2, int i3, float f2, boolean z) {
        if (this.mState == RefreshState.None && isEnableRefreshOrLoadMore(this.mEnableRefresh)) {
            i iVar = new i(f2, i3, z);
            setViceState(RefreshState.Refreshing);
            if (i2 > 0) {
                postDelayed(iVar, i2);
                return true;
            }
            iVar.run();
            return true;
        }
        return false;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishLoadMore(int i2) {
        return finishLoadMore(i2, true, false);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishRefresh(int i2) {
        return finishRefresh(i2, true, Boolean.FALSE);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishLoadMore(boolean z) {
        return finishLoadMore(z ? Math.min(Math.max(0, 300 - ((int) (System.currentTimeMillis() - this.mLastOpenTime))), 300) : 0, z, false);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishRefresh(boolean z) {
        return finishRefresh(z ? Math.min(Math.max(0, 300 - ((int) (System.currentTimeMillis() - this.mLastOpenTime))), 300) : 0, z, !z ? Boolean.FALSE : null);
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishLoadMore(int i2, boolean z, boolean z2) {
        postDelayed(new h(z, z2), i2 <= 0 ? 1L : i2);
        return this;
    }

    @Override // e.l.a.a.b.j
    public e.l.a.a.b.j finishRefresh(int i2, boolean z, Boolean bool) {
        postDelayed(new g(bool, z), i2 <= 0 ? 1L : i2);
        return this;
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public static class LayoutParams extends ViewGroup.MarginLayoutParams {
        public int backgroundColor;
        public SpinnerStyle spinnerStyle;

        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
            this.backgroundColor = 0;
            this.spinnerStyle = null;
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.SmartRefreshLayout_Layout);
            this.backgroundColor = obtainStyledAttributes.getColor(R.styleable.SmartRefreshLayout_Layout_layout_srlBackgroundColor, this.backgroundColor);
            if (obtainStyledAttributes.hasValue(R.styleable.SmartRefreshLayout_Layout_layout_srlSpinnerStyle)) {
                this.spinnerStyle = SpinnerStyle.values()[obtainStyledAttributes.getInt(R.styleable.SmartRefreshLayout_Layout_layout_srlSpinnerStyle, SpinnerStyle.Translate.ordinal())];
            }
            obtainStyledAttributes.recycle();
        }

        public LayoutParams(int i2, int i3) {
            super(i2, i3);
            this.backgroundColor = 0;
            this.spinnerStyle = null;
        }
    }
}
