package com.ss.android.socialbase.downloader.monitor;

import android.net.Uri;
import android.text.TextUtils;
import androidx.annotation.Nullable;
import com.ss.android.downloadlib.constants.EventConstants;
import com.ss.android.socialbase.downloader.constants.DBDefinition;
import com.ss.android.socialbase.downloader.constants.DownloadErrorCode;
import com.ss.android.socialbase.downloader.constants.DownloadStatus;
import com.ss.android.socialbase.downloader.constants.MonitorConstants;
import com.ss.android.socialbase.downloader.depend.AbsDownloadMonitorDepend;
import com.ss.android.socialbase.downloader.depend.IDownloadDepend;
import com.ss.android.socialbase.downloader.depend.IDownloadMonitorDepend;
import com.ss.android.socialbase.downloader.downloader.DownloadComponentManager;
import com.ss.android.socialbase.downloader.downloader.IMonitorConfig;
import com.ss.android.socialbase.downloader.exception.BaseException;
import com.ss.android.socialbase.downloader.exception.DownloadTTNetException;
import com.ss.android.socialbase.downloader.model.DownloadInfo;
import com.ss.android.socialbase.downloader.model.DownloadTask;
import com.ss.android.socialbase.downloader.network.AbsDownloadHttpConnection;
import com.ss.android.socialbase.downloader.network.IDefaultDownloadHttpConnection;
import com.ss.android.socialbase.downloader.network.IDownloadHeadHttpConnection;
import com.ss.android.socialbase.downloader.network.IDownloadHttpConnection;
import com.ss.android.socialbase.downloader.segment.Segment;
import com.ss.android.socialbase.downloader.setting.DownloadSetting;
import com.ss.android.socialbase.downloader.setting.DownloadSettingKeys;
import com.ss.android.socialbase.downloader.utils.DownloadUtils;
import java.io.IOException;
import java.util.List;
import java.util.concurrent.TimeUnit;
import org.json.JSONException;
import org.json.JSONObject;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class DownloadMonitorHelper {
    public static final String DEFAULT_MONITOR_SCENE = "default";

    public static JSONObject getMonitorJson(String str, DownloadInfo downloadInfo, BaseException baseException, int i2) {
        String str2;
        String str3;
        String str4;
        int i3;
        String str5;
        String str6;
        String str7;
        JSONObject jSONObject = null;
        try {
            JSONObject jSONObject2 = new JSONObject();
            try {
                IMonitorConfig monitorConfig = DownloadComponentManager.getMonitorConfig();
                if (monitorConfig != null) {
                    str2 = monitorConfig.getDeviceId();
                    str3 = parseDevicePostfix(str2);
                    str4 = monitorConfig.getAppId();
                    i3 = monitorConfig.getUpdateVersion();
                } else {
                    str2 = "";
                    str3 = str2;
                    str4 = str3;
                    i3 = 0;
                }
                String requestLog = (baseException == null || !(baseException instanceof DownloadTTNetException)) ? "" : ((DownloadTTNetException) baseException).getRequestLog();
                jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_PAGE, str);
                jSONObject2.put("app_id", str4);
                jSONObject2.put("device_id", str2);
                jSONObject2.put(MonitorConstants.EXTRA_DEVICE_ID_POSTFIX, str3);
                jSONObject2.put(MonitorConstants.EXTRA_UPDATE_VERSION, i3);
                jSONObject2.put("download_status", i2);
                if (downloadInfo != null) {
                    jSONObject2.put(DownloadSettingKeys.SETTING_TAG, DownloadSetting.obtain(downloadInfo.getId()).optString(DownloadSettingKeys.SETTING_TAG));
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_ID, downloadInfo.getId());
                    jSONObject2.put("name", downloadInfo.getName());
                    jSONObject2.put("url", downloadInfo.getUrl());
                    jSONObject2.put("save_path", downloadInfo.getSavePath());
                    jSONObject2.put("download_time", downloadInfo.getDownloadTime());
                    jSONObject2.put("cur_bytes", downloadInfo.getCurBytes());
                    jSONObject2.put("total_bytes", downloadInfo.getTotalBytes());
                    jSONObject2.put("network_quality", downloadInfo.getNetworkQuality());
                    int i4 = 1;
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_ONLY_WIFI, downloadInfo.isOnlyWifi() ? 1 : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_NEED_HTTPS_DEGRADE, downloadInfo.isNeedHttpsToHttpRetry() ? 1 : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_HTTPS_DEGRADE_RETRY_USED, downloadInfo.isHttpsToHttpRetryUsed() ? 1 : 0);
                    jSONObject2.put("md5", downloadInfo.getMd5() == null ? "" : downloadInfo.getMd5());
                    jSONObject2.put("chunk_count", downloadInfo.getChunkCount());
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_IS_FORCE, downloadInfo.isForce() ? 1 : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_RETRY_COUNT, downloadInfo.getRetryCount());
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_CUR_RETRY_TIME, downloadInfo.getCurRetryTime());
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_NEED_RETRY_DELAY, downloadInfo.isNeedRetryDelay() ? 1 : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_NEED_REUSE_FIRST_CONNECTION, downloadInfo.isNeedReuseFirstConnection() ? 1 : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_DEFAULT_HTTP_SERVICE_BACKUP, downloadInfo.isNeedDefaultHttpServiceBackUp() ? 1 : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_RETRY_DELAY_STATUS, downloadInfo.getRetryDelayStatus().ordinal());
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_BACKUP_URL_USED, downloadInfo.isBackUpUrlUsed() ? 1 : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_BYTE_ERROR_RETRY_STATUS, downloadInfo.getByteInvalidRetryStatus().ordinal());
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_FORBIDDEN_HANDLER_STATUS, downloadInfo.getAsyncHandleStatus().ordinal());
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_NEED_INDEPENDENT_PROCESS, downloadInfo.isNeedIndependentProcess() ? 1 : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_HEAD_CONNECTION_ERROR_MSG, downloadInfo.getHeadConnectionException() != null ? downloadInfo.getHeadConnectionException() : "");
                    jSONObject2.put("extra", downloadInfo.getExtra() != null ? downloadInfo.getExtra() : "");
                    if (!downloadInfo.isAddListenerToSameTask()) {
                        i4 = 0;
                    }
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_ADD_LISTENER_TO_SAME_TASK, i4);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_BACKUP_URL_COUNT, downloadInfo.getBackUpUrls() != null ? downloadInfo.getBackUpUrls().size() : 0);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_CUR_BACKUP_URL_INDEX, downloadInfo.getBackUpUrls() != null ? downloadInfo.getCurBackUpUrlIndex() : -1);
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_FORBIDDEN_URLS, downloadInfo.getForbiddenBackupUrls() != null ? downloadInfo.getForbiddenBackupUrls().toString() : "");
                    jSONObject2.put(MonitorConstants.EXTRA_DOWNLOAD_TASK_ID, TextUtils.isEmpty(downloadInfo.getTaskId()) ? "" : downloadInfo.getTaskId());
                    String url = downloadInfo.getUrl();
                    if (TextUtils.isEmpty(url)) {
                        str5 = "";
                        str6 = str5;
                        str7 = str6;
                    } else {
                        Uri parse = Uri.parse(url);
                        str6 = parse.getHost();
                        str7 = parse.getPath();
                        str5 = parse.getLastPathSegment();
                        if (!TextUtils.isEmpty(str7) && !TextUtils.isEmpty(str5)) {
                            try {
                                str7 = str7.substring(0, str7.length() - str5.length());
                            } catch (Throwable th) {
                                th.printStackTrace();
                            }
                        }
                    }
                    jSONObject2.put(MonitorConstants.URL_HOST, str6);
                    jSONObject2.put(MonitorConstants.URL_PATH, str7);
                    jSONObject2.put(MonitorConstants.URL_LAST_PATH_SEGMENT, str5);
                }
                jSONObject2.put("error_code", baseException != null ? baseException.getErrorCode() : 0);
                jSONObject2.put("error_msg", baseException != null ? baseException.getErrorMessage() : "");
                jSONObject2.put(MonitorConstants.REQUEST_LOG, requestLog);
                return jSONObject2;
            } catch (JSONException e2) {
                e = e2;
                jSONObject = jSONObject2;
                e.printStackTrace();
                return jSONObject;
            }
        } catch (JSONException e3) {
            e = e3;
        }
    }

    public static boolean isMonitorStatus(int[] iArr, int i2) {
        if (iArr != null && iArr.length > 0) {
            for (int i3 : iArr) {
                if (i2 == i3) {
                    return true;
                }
            }
        }
        return false;
    }

    /* JADX WARN: Can't wrap try/catch for region: R(24:11|(4:68|69|70|(16:72|73|14|(2:49|(1:(2:57|(1:59)(2:60|61)))(1:54))|17|18|(2:22|23)|26|27|28|(1:30)|31|32|(1:44)|35|(2:39|41)(1:38)))|13|14|(0)|49|(1:51)|(0)|17|18|(3:20|22|23)|26|27|28|(0)|31|32|(0)|42|44|35|(0)|39|41) */
    /* JADX WARN: Code restructure failed: missing block: B:55:0x0114, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:56:0x0115, code lost:
        r0.printStackTrace();
     */
    /* JADX WARN: Removed duplicated region for block: B:33:0x0058 A[Catch: all -> 0x013a, TRY_LEAVE, TryCatch #3 {all -> 0x013a, blocks: (B:18:0x002f, B:20:0x0033, B:44:0x007f, B:46:0x0095, B:49:0x00a8, B:50:0x00ad, B:52:0x00e9, B:53:0x00fa, B:66:0x012e, B:60:0x0120, B:62:0x0126, B:56:0x0115, B:26:0x0047, B:28:0x004d, B:33:0x0058, B:36:0x0065, B:40:0x006b, B:42:0x0077, B:13:0x0025), top: B:76:0x0025, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:52:0x00e9 A[Catch: JSONException -> 0x0114, all -> 0x013a, TryCatch #0 {JSONException -> 0x0114, blocks: (B:50:0x00ad, B:52:0x00e9, B:53:0x00fa), top: B:72:0x00ad, outer: #3 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static void monitorDownloadConnect(@Nullable IDownloadHeadHttpConnection iDownloadHeadHttpConnection, String str, String str2, long j2, String str3, int i2, IOException iOException, DownloadInfo downloadInfo) {
        DownloadSetting obtain;
        int optInt;
        String hostIp;
        String errorMessage;
        int httpStatusCode;
        String path;
        String lastPathSegment;
        JSONObject jSONObject;
        IDownloadMonitorListener downloadMonitorListener;
        if (downloadInfo == null || (optInt = (obtain = DownloadSetting.obtain(downloadInfo.getId())).optInt(DownloadSettingKeys.MONITOR_DOWNLOAD_CONNECT, 0)) <= 0 || TextUtils.isEmpty(str)) {
            return;
        }
        int i3 = -1;
        if (iDownloadHeadHttpConnection != null) {
            try {
                i3 = iDownloadHeadHttpConnection.getResponseCode();
                if (iDownloadHeadHttpConnection instanceof AbsDownloadHttpConnection) {
                    hostIp = ((AbsDownloadHttpConnection) iDownloadHeadHttpConnection).getHostIp();
                    String str4 = "";
                    if (i3 >= 200 || i3 >= 400) {
                        if (downloadInfo.getCurRetryTime() == 0 && ((httpStatusCode = downloadInfo.getHttpStatusCode()) < 200 || httpStatusCode >= 400)) {
                            return;
                        }
                        if (iOException != null) {
                            if (DownloadUtils.isNetworkConnected(DownloadComponentManager.getAppContext())) {
                                try {
                                    DownloadUtils.parseException(iOException, "");
                                } catch (BaseException e2) {
                                    i3 = e2.getErrorCode();
                                    errorMessage = e2.getErrorMessage();
                                    if (e2 instanceof DownloadTTNetException) {
                                        str4 = ((DownloadTTNetException) e2).getRequestLog();
                                    }
                                }
                            } else {
                                i3 = DownloadErrorCode.ERROR_NETWORK_NOT_AVAILABLE;
                            }
                        }
                    }
                    errorMessage = null;
                    Uri parse = Uri.parse(str);
                    String host = parse.getHost();
                    path = parse.getPath();
                    lastPathSegment = parse.getLastPathSegment();
                    if (!TextUtils.isEmpty(path) && !TextUtils.isEmpty(lastPathSegment)) {
                        try {
                            path = path.substring(0, path.length() - lastPathSegment.length());
                        } catch (Throwable unused) {
                        }
                    }
                    jSONObject = new JSONObject();
                    jSONObject.put(DownloadSettingKeys.SETTING_TAG, obtain.optString(DownloadSettingKeys.SETTING_TAG));
                    jSONObject.put(MonitorConstants.URL_HOST, host);
                    jSONObject.putOpt(MonitorConstants.HOST_IP, str2);
                    jSONObject.putOpt(MonitorConstants.HOST_REAL_IP, hostIp);
                    jSONObject.put(MonitorConstants.URL_PATH, path);
                    jSONObject.put(MonitorConstants.URL_LAST_PATH_SEGMENT, lastPathSegment);
                    jSONObject.put(MonitorConstants.NET_LIB, i2);
                    jSONObject.put(MonitorConstants.CONNECT_TYPE, str3);
                    jSONObject.put("status_code", i3);
                    jSONObject.put(MonitorConstants.REQUEST_LOG, str4);
                    if (errorMessage != null) {
                        jSONObject.put("error_msg", DownloadUtils.getFixLengthString(errorMessage, obtain.optInt(DownloadSettingKeys.KEY_EXCEPTION_MSG_LENGTH, 500)));
                    }
                    jSONObject.put(MonitorConstants.CONNECT_TIME, j2);
                    jSONObject.put(MonitorConstants.PKG_NAME, downloadInfo.getPackageName());
                    jSONObject.put("name", downloadInfo.getTitle());
                    if ((optInt != 1 || optInt == 3) && (downloadMonitorListener = DownloadComponentManager.getDownloadMonitorListener()) != null) {
                        downloadMonitorListener.monitorEvent(MonitorConstants.DOWNLOAD_CONNECT, jSONObject, null, null);
                    }
                    if (optInt != 2 || optInt == 3) {
                        DownloadComponentManager.getEventListener().onEvent(downloadInfo.getId(), MonitorConstants.DOWNLOAD_CONNECT, jSONObject);
                    }
                    return;
                }
            }
        }
        hostIp = null;
        String str42 = "";
        if (i3 >= 200) {
        }
        if (downloadInfo.getCurRetryTime() == 0) {
        }
        if (iOException != null) {
        }
        errorMessage = null;
        Uri parse2 = Uri.parse(str);
        String host2 = parse2.getHost();
        path = parse2.getPath();
        lastPathSegment = parse2.getLastPathSegment();
        if (!TextUtils.isEmpty(path)) {
            path = path.substring(0, path.length() - lastPathSegment.length());
        }
        jSONObject = new JSONObject();
        jSONObject.put(DownloadSettingKeys.SETTING_TAG, obtain.optString(DownloadSettingKeys.SETTING_TAG));
        jSONObject.put(MonitorConstants.URL_HOST, host2);
        jSONObject.putOpt(MonitorConstants.HOST_IP, str2);
        jSONObject.putOpt(MonitorConstants.HOST_REAL_IP, hostIp);
        jSONObject.put(MonitorConstants.URL_PATH, path);
        jSONObject.put(MonitorConstants.URL_LAST_PATH_SEGMENT, lastPathSegment);
        jSONObject.put(MonitorConstants.NET_LIB, i2);
        jSONObject.put(MonitorConstants.CONNECT_TYPE, str3);
        jSONObject.put("status_code", i3);
        jSONObject.put(MonitorConstants.REQUEST_LOG, str42);
        if (errorMessage != null) {
        }
        jSONObject.put(MonitorConstants.CONNECT_TIME, j2);
        jSONObject.put(MonitorConstants.PKG_NAME, downloadInfo.getPackageName());
        jSONObject.put("name", downloadInfo.getTitle());
        if (optInt != 1) {
        }
        downloadMonitorListener.monitorEvent(MonitorConstants.DOWNLOAD_CONNECT, jSONObject, null, null);
        if (optInt != 2) {
        }
        DownloadComponentManager.getEventListener().onEvent(downloadInfo.getId(), MonitorConstants.DOWNLOAD_CONNECT, jSONObject);
    }

    public static void monitorDownloadIO(DownloadSetting downloadSetting, DownloadInfo downloadInfo, String str, IDownloadHttpConnection iDownloadHttpConnection, boolean z, boolean z2, BaseException baseException, long j2, long j3, boolean z3, long j4, long j5, long j6, JSONObject jSONObject) {
        monitorIO(MonitorConstants.DOWNLOAD_IO, downloadSetting.optInt(DownloadSettingKeys.MONITOR_DOWNLOAD_IO), downloadSetting, downloadInfo, str, null, null, iDownloadHttpConnection, z, z2, baseException, j2, j3, z3, j4, j5, j6, null);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:28:0x0070 A[Catch: all -> 0x01a9, TryCatch #1 {all -> 0x01a9, blocks: (B:7:0x0016, B:9:0x002d, B:26:0x0065, B:28:0x0070, B:32:0x0077, B:34:0x0083, B:35:0x008d, B:39:0x009a, B:41:0x009e, B:42:0x00a4, B:44:0x00a8, B:48:0x00c4, B:50:0x00d7, B:52:0x0111, B:53:0x0122, B:55:0x0134, B:59:0x0149, B:61:0x0158, B:63:0x0167, B:64:0x016a, B:76:0x019d, B:69:0x0189, B:71:0x018f, B:20:0x004d, B:24:0x005e, B:23:0x005a), top: B:83:0x0016 }] */
    /* JADX WARN: Removed duplicated region for block: B:46:0x00b5  */
    /* JADX WARN: Removed duplicated region for block: B:52:0x0111 A[Catch: all -> 0x01a9, TryCatch #1 {all -> 0x01a9, blocks: (B:7:0x0016, B:9:0x002d, B:26:0x0065, B:28:0x0070, B:32:0x0077, B:34:0x0083, B:35:0x008d, B:39:0x009a, B:41:0x009e, B:42:0x00a4, B:44:0x00a8, B:48:0x00c4, B:50:0x00d7, B:52:0x0111, B:53:0x0122, B:55:0x0134, B:59:0x0149, B:61:0x0158, B:63:0x0167, B:64:0x016a, B:76:0x019d, B:69:0x0189, B:71:0x018f, B:20:0x004d, B:24:0x005e, B:23:0x005a), top: B:83:0x0016 }] */
    /* JADX WARN: Removed duplicated region for block: B:55:0x0134 A[Catch: all -> 0x01a9, TryCatch #1 {all -> 0x01a9, blocks: (B:7:0x0016, B:9:0x002d, B:26:0x0065, B:28:0x0070, B:32:0x0077, B:34:0x0083, B:35:0x008d, B:39:0x009a, B:41:0x009e, B:42:0x00a4, B:44:0x00a8, B:48:0x00c4, B:50:0x00d7, B:52:0x0111, B:53:0x0122, B:55:0x0134, B:59:0x0149, B:61:0x0158, B:63:0x0167, B:64:0x016a, B:76:0x019d, B:69:0x0189, B:71:0x018f, B:20:0x004d, B:24:0x005e, B:23:0x005a), top: B:83:0x0016 }] */
    /* JADX WARN: Removed duplicated region for block: B:57:0x013d  */
    /* JADX WARN: Removed duplicated region for block: B:71:0x018f A[Catch: all -> 0x01a9, TryCatch #1 {all -> 0x01a9, blocks: (B:7:0x0016, B:9:0x002d, B:26:0x0065, B:28:0x0070, B:32:0x0077, B:34:0x0083, B:35:0x008d, B:39:0x009a, B:41:0x009e, B:42:0x00a4, B:44:0x00a8, B:48:0x00c4, B:50:0x00d7, B:52:0x0111, B:53:0x0122, B:55:0x0134, B:59:0x0149, B:61:0x0158, B:63:0x0167, B:64:0x016a, B:76:0x019d, B:69:0x0189, B:71:0x018f, B:20:0x004d, B:24:0x005e, B:23:0x005a), top: B:83:0x0016 }] */
    /* JADX WARN: Removed duplicated region for block: B:72:0x0196  */
    /* JADX WARN: Removed duplicated region for block: B:75:0x019b A[ADDED_TO_REGION] */
    /* JADX WARN: Type inference failed for: r17v3 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static void monitorIO(String str, int i2, DownloadSetting downloadSetting, DownloadInfo downloadInfo, String str2, String str3, String str4, IDownloadHttpConnection iDownloadHttpConnection, boolean z, boolean z2, BaseException baseException, long j2, long j3, boolean z3, long j4, long j5, long j6, JSONObject jSONObject) {
        int i3;
        String errorMessage;
        long j7;
        String str5;
        int i4;
        int i5;
        double d2;
        IDownloadMonitorListener downloadMonitorListener;
        String str6;
        int i6;
        if (i2 <= 0 || j3 <= 0) {
            return;
        }
        try {
            Uri parse = Uri.parse(str2);
            String host = parse.getHost();
            String path = parse.getPath();
            String lastPathSegment = parse.getLastPathSegment();
            if (!TextUtils.isEmpty(path) && !TextUtils.isEmpty(lastPathSegment)) {
                try {
                    path = path.substring(0, path.length() - lastPathSegment.length());
                } catch (Throwable unused) {
                }
            }
            if (z) {
                i3 = 1;
            } else if (z2) {
                i3 = 2;
            } else if (baseException != null) {
                i3 = !DownloadUtils.isNetworkConnected(DownloadComponentManager.getAppContext()) ? DownloadErrorCode.ERROR_NETWORK_NOT_AVAILABLE : baseException.getErrorCode();
                errorMessage = baseException.getErrorMessage();
                JSONObject jSONObject2 = new JSONObject();
                if (iDownloadHttpConnection == null) {
                    i4 = iDownloadHttpConnection instanceof IDefaultDownloadHttpConnection ? 0 : 1;
                    String responseHeaderField = iDownloadHttpConnection.getResponseHeaderField(DownloadUtils.X_CACHE);
                    int contains = TextUtils.isEmpty(responseHeaderField) ? -1 : responseHeaderField.toLowerCase().contains("hit");
                    if (downloadSetting.optInt(DownloadSettingKeys.MONITOR_SLA, 1) == 1 && !z && !z2 && (iDownloadHttpConnection instanceof AbsDownloadHttpConnection)) {
                        ((AbsDownloadHttpConnection) iDownloadHttpConnection).monitorNetworkInfo(jSONObject2, true);
                    }
                    j7 = j2;
                    str5 = iDownloadHttpConnection instanceof AbsDownloadHttpConnection ? ((AbsDownloadHttpConnection) iDownloadHttpConnection).getRequestLog() : "";
                    i5 = contains;
                } else {
                    j7 = j2;
                    str5 = "";
                    i4 = -1;
                    i5 = -1;
                }
                double d3 = j7;
                Double.isNaN(d3);
                double d4 = d3 / 1048576.0d;
                double d5 = j3;
                double nanos = TimeUnit.SECONDS.toNanos(1L);
                Double.isNaN(d5);
                Double.isNaN(nanos);
                d2 = d5 / nanos;
                jSONObject2.put(DownloadSettingKeys.SETTING_TAG, downloadSetting.optString(DownloadSettingKeys.SETTING_TAG));
                jSONObject2.put(MonitorConstants.URL_HOST, host);
                jSONObject2.putOpt(MonitorConstants.HOST_IP, str3);
                jSONObject2.putOpt(MonitorConstants.HOST_REAL_IP, str4);
                jSONObject2.put(MonitorConstants.URL_PATH, path);
                jSONObject2.put(MonitorConstants.URL_LAST_PATH_SEGMENT, lastPathSegment);
                jSONObject2.put(MonitorConstants.NET_LIB, i4);
                jSONObject2.put(MonitorConstants.HIT_CDN_CACHE, i5);
                jSONObject2.put("status_code", i3);
                jSONObject2.put(MonitorConstants.REQUEST_LOG, str5);
                if (errorMessage != null) {
                    jSONObject2.put("error_msg", DownloadUtils.getFixLengthString(errorMessage, downloadSetting.optInt(DownloadSettingKeys.KEY_EXCEPTION_MSG_LENGTH, 500)));
                }
                jSONObject2.put(MonitorConstants.DOWNLOAD_SEC, d2);
                jSONObject2.put(MonitorConstants.DOWNLOAD_MB, d4);
                if (d2 > 0.0d) {
                    jSONObject2.put("download_speed", d4 / d2);
                }
                if (z3) {
                    double d6 = j4;
                    Double.isNaN(d6);
                    Double.isNaN(d5);
                    jSONObject2.put(MonitorConstants.RW_READ_TIME, d6 / d5);
                    double d7 = j5;
                    Double.isNaN(d7);
                    Double.isNaN(d5);
                    jSONObject2.put(MonitorConstants.RW_WRITE_TIME, d7 / d5);
                    double d8 = j6;
                    Double.isNaN(d8);
                    Double.isNaN(d5);
                    jSONObject2.put(MonitorConstants.RW_SYNC_TIME, d8 / d5);
                }
                jSONObject2.put(MonitorConstants.PKG_NAME, downloadInfo.getPackageName());
                jSONObject2.put("name", downloadInfo.getTitle());
                if (i2 != 1 && i2 != 3) {
                    i6 = 2;
                    str6 = str;
                    if (i2 != i6 || i2 == 3) {
                        DownloadComponentManager.getEventListener().onEvent(downloadInfo.getId(), str6, jSONObject2);
                    }
                    return;
                }
                downloadMonitorListener = DownloadComponentManager.getDownloadMonitorListener();
                if (downloadMonitorListener == null) {
                    str6 = str;
                    downloadMonitorListener.monitorEvent(str6, jSONObject2, null, null);
                } else {
                    str6 = str;
                }
                i6 = 2;
                if (i2 != i6) {
                }
                DownloadComponentManager.getEventListener().onEvent(downloadInfo.getId(), str6, jSONObject2);
            } else {
                i3 = 0;
            }
            errorMessage = null;
            JSONObject jSONObject22 = new JSONObject();
            if (iDownloadHttpConnection == null) {
            }
            double d32 = j7;
            Double.isNaN(d32);
            double d42 = d32 / 1048576.0d;
            double d52 = j3;
            double nanos2 = TimeUnit.SECONDS.toNanos(1L);
            Double.isNaN(d52);
            Double.isNaN(nanos2);
            d2 = d52 / nanos2;
            jSONObject22.put(DownloadSettingKeys.SETTING_TAG, downloadSetting.optString(DownloadSettingKeys.SETTING_TAG));
            jSONObject22.put(MonitorConstants.URL_HOST, host);
            jSONObject22.putOpt(MonitorConstants.HOST_IP, str3);
            jSONObject22.putOpt(MonitorConstants.HOST_REAL_IP, str4);
            jSONObject22.put(MonitorConstants.URL_PATH, path);
            jSONObject22.put(MonitorConstants.URL_LAST_PATH_SEGMENT, lastPathSegment);
            jSONObject22.put(MonitorConstants.NET_LIB, i4);
            jSONObject22.put(MonitorConstants.HIT_CDN_CACHE, i5);
            jSONObject22.put("status_code", i3);
            jSONObject22.put(MonitorConstants.REQUEST_LOG, str5);
            if (errorMessage != null) {
            }
            jSONObject22.put(MonitorConstants.DOWNLOAD_SEC, d2);
            jSONObject22.put(MonitorConstants.DOWNLOAD_MB, d42);
            if (d2 > 0.0d) {
            }
            if (z3) {
            }
            jSONObject22.put(MonitorConstants.PKG_NAME, downloadInfo.getPackageName());
            jSONObject22.put("name", downloadInfo.getTitle());
            if (i2 != 1) {
                i6 = 2;
                str6 = str;
                if (i2 != i6) {
                }
                DownloadComponentManager.getEventListener().onEvent(downloadInfo.getId(), str6, jSONObject22);
            }
            downloadMonitorListener = DownloadComponentManager.getDownloadMonitorListener();
            if (downloadMonitorListener == null) {
            }
            i6 = 2;
            if (i2 != i6) {
            }
            DownloadComponentManager.getEventListener().onEvent(downloadInfo.getId(), str6, jSONObject22);
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    public static void monitorSegmentIO(DownloadSetting downloadSetting, DownloadInfo downloadInfo, String str, String str2, String str3, boolean z, IDownloadHttpConnection iDownloadHttpConnection, BaseException baseException, long j2, long j3) {
        monitorIO(MonitorConstants.SEGMENT_IO, downloadSetting.optInt(DownloadSettingKeys.MONITOR_SEGMENT_IO), downloadSetting, downloadInfo, str, str2, str3, iDownloadHttpConnection, z, false, baseException, j2, j3, false, -1L, -1L, -1L, null);
    }

    public static void monitorSegmentsError(DownloadInfo downloadInfo, List<Segment> list) {
        try {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put(DBDefinition.SEGMENT_TABLE_NAME, Segment.toString(list));
            jSONObject.put("cur_bytes", downloadInfo.getCurBytes());
            jSONObject.put("total_bytes", downloadInfo.getTotalBytes());
            InnerEventListener eventListener = DownloadComponentManager.getEventListener();
            if (eventListener != null) {
                eventListener.onEvent(downloadInfo.getId(), "segments_error", jSONObject);
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    public static void monitorSend(DownloadTask downloadTask, BaseException baseException, int i2) {
        if (downloadTask == null) {
            return;
        }
        try {
            DownloadInfo downloadInfo = downloadTask.getDownloadInfo();
            if (downloadInfo == null) {
                return;
            }
            IDownloadMonitorDepend monitorDepend = downloadTask.getMonitorDepend();
            boolean isMonitorStatus = DownloadStatus.isMonitorStatus(i2);
            if (!isMonitorStatus && !(isMonitorStatus = isMonitorStatus(downloadInfo.getExtraMonitorStatus(), i2)) && monitorDepend != null && (monitorDepend instanceof AbsDownloadMonitorDepend)) {
                isMonitorStatus = isMonitorStatus(((AbsDownloadMonitorDepend) monitorDepend).getAdditionalMonitorStatus(), i2);
            }
            if (isMonitorStatus) {
                IDownloadDepend depend = downloadTask.getDepend();
                if (depend != null) {
                    depend.monitorLogSend(downloadInfo, baseException, i2);
                }
                monitorSendWithTaskMonitor(monitorDepend, downloadInfo, baseException, i2);
                monitorSendWithGlobalSdkMonitor(DownloadComponentManager.getDownloadMonitorListener(), downloadInfo, baseException, i2);
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    public static void monitorSendWithGlobalSdkMonitor(IDownloadMonitorListener iDownloadMonitorListener, DownloadInfo downloadInfo, BaseException baseException, int i2) {
        if (iDownloadMonitorListener == null || !downloadInfo.isNeedSDKMonitor() || TextUtils.isEmpty(downloadInfo.getMonitorScene())) {
            return;
        }
        try {
            JSONObject monitorJson = getMonitorJson(downloadInfo.getMonitorScene(), downloadInfo, baseException, i2);
            if (monitorJson == null) {
                monitorJson = new JSONObject();
            }
            if (i2 == -1) {
                monitorJson.put("status", baseException.getErrorCode());
                iDownloadMonitorListener.monitorEvent(EventConstants.Label.DOWNLOAD_FAILED, monitorJson, null, null);
                return;
            }
            putMonitorJsonStatus(i2, monitorJson, downloadInfo);
            iDownloadMonitorListener.monitorEvent("download_common", monitorJson, null, null);
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    public static void monitorSendWithTaskMonitor(IDownloadMonitorDepend iDownloadMonitorDepend, DownloadInfo downloadInfo, BaseException baseException, int i2) {
        if (iDownloadMonitorDepend == null) {
            return;
        }
        try {
            String eventPage = iDownloadMonitorDepend.getEventPage();
            if (TextUtils.isEmpty(eventPage)) {
                eventPage = "default";
            }
            JSONObject monitorJson = getMonitorJson(eventPage, downloadInfo, baseException, i2);
            if (monitorJson == null) {
                monitorJson = new JSONObject();
            }
            iDownloadMonitorDepend.monitorLogSend(monitorJson);
        } catch (Throwable unused) {
        }
    }

    public static String parseDevicePostfix(String str) {
        try {
            return TextUtils.isDigitsOnly(str) ? String.valueOf(Long.valueOf(str).longValue() % 100) : "";
        } catch (Exception e2) {
            e2.printStackTrace();
            return "";
        }
    }

    public static void putMonitorJsonStatus(int i2, JSONObject jSONObject, DownloadInfo downloadInfo) throws JSONException {
        String str;
        if (i2 == -5) {
            str = "download_uncomplete";
        } else if (i2 == -4) {
            str = EventConstants.Label.DOWNLOAD_CANCEL;
        } else if (i2 != -3) {
            str = i2 != -2 ? i2 != 0 ? i2 != 2 ? i2 != 6 ? "" : "download_first_start" : "download_start" : "download_create" : "download_pause";
        } else {
            double downloadSpeed = downloadInfo.getDownloadSpeed();
            if (downloadSpeed >= 0.0d) {
                jSONObject.put("download_speed", downloadSpeed);
            }
            str = "download_success";
        }
        jSONObject.put("status", str);
    }
}
