package com.ss.android.socialbase.downloader.network;

import android.net.Uri;
import android.os.Handler;
import com.ss.android.socialbase.downloader.downloader.DownloadComponentManager;
import com.ss.android.socialbase.downloader.network.connectionpool.DownloadPreconnecter;
import com.ss.android.socialbase.downloader.setting.DownloadSetting;
import com.ss.android.socialbase.downloader.setting.DownloadSettingKeys;
import com.ss.android.socialbase.downloader.thread.DownloadWatchDog;
import com.ss.android.socialbase.downloader.utils.LruCache;
import java.net.InetAddress;
import java.util.List;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class DownloadDnsManager {
    public final LruCache<String, DnsRecord> cache;
    public final Handler cpuHandler;
    public final Handler networkHandler;

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public interface Callback {
        void onDnsResolved(String str, List<InetAddress> list);
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public static class DnsRecord {
        public long timestamp;
        public List<InetAddress> value;

        public DnsRecord() {
        }
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public static class Holder {
        public static final DownloadDnsManager INSTANCE = new DownloadDnsManager();
    }

    public static DownloadDnsManager getInstance() {
        return Holder.INSTANCE;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Code restructure failed: missing block: B:34:0x0085, code lost:
        r10 = r2.value;
     */
    /* JADX WARN: Removed duplicated region for block: B:37:0x008e A[Catch: all -> 0x0095, TRY_LEAVE, TryCatch #2 {all -> 0x0095, blocks: (B:2:0x0000, B:3:0x000a, B:7:0x0016, B:10:0x0034, B:12:0x003a, B:14:0x0052, B:21:0x0063, B:29:0x0078, B:32:0x007f, B:35:0x0087, B:37:0x008e, B:34:0x0085, B:23:0x0069, B:24:0x006d, B:4:0x000b, B:5:0x0013, B:16:0x0058), top: B:45:0x0000 }] */
    /* JADX WARN: Removed duplicated region for block: B:47:? A[RETURN, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void resolveDns(final String str, final Callback callback, long j2) {
        final DnsRecord dnsRecord;
        IDownloadDns downloadDns;
        try {
            String host = Uri.parse(str).getHost();
            synchronized (this.cache) {
                dnsRecord = this.cache.get(host);
            }
            if (dnsRecord != null) {
                if (System.currentTimeMillis() - dnsRecord.timestamp < DownloadSetting.obtainGlobal().optInt(DownloadSettingKeys.DNS_EXPIRE_MIN, 10) * 60 * 1000) {
                    if (callback != null) {
                        callback.onDnsResolved(str, dnsRecord.value);
                        return;
                    }
                    return;
                }
            }
            Runnable runnable = new Runnable() { // from class: com.ss.android.socialbase.downloader.network.DownloadDnsManager.2
                @Override // java.lang.Runnable
                public void run() {
                    Callback callback2 = callback;
                    if (callback2 != null) {
                        String str2 = str;
                        DnsRecord dnsRecord2 = dnsRecord;
                        callback2.onDnsResolved(str2, dnsRecord2 == null ? null : dnsRecord2.value);
                    }
                }
            };
            this.cpuHandler.postDelayed(runnable, j2);
            List<InetAddress> list = null;
            if (DownloadSetting.obtainGlobal().optInt(DownloadSettingKeys.USE_HOST_DNS, 1) == 1 && (downloadDns = DownloadComponentManager.getDownloadDns()) != null) {
                list = downloadDns.lookup(host);
            }
            if (list == null || list.isEmpty()) {
                list = DownloadComponentManager.getDefaultDownloadDns().lookup(host);
            }
            if (list != null && !list.isEmpty()) {
                updateIpAddressToCache(host, list);
                this.cpuHandler.removeCallbacks(runnable);
                if (callback == null) {
                    callback.onDnsResolved(str, list);
                    return;
                }
                return;
            }
            this.cpuHandler.removeCallbacks(runnable);
            if (callback == null) {
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private void updateIpAddressToCache(String str, List<InetAddress> list) {
        synchronized (this.cache) {
            DnsRecord dnsRecord = this.cache.get(str);
            if (dnsRecord == null) {
                dnsRecord = new DnsRecord();
                this.cache.put(str, dnsRecord);
            }
            dnsRecord.value = list;
            dnsRecord.timestamp = System.currentTimeMillis();
        }
    }

    public void resolveDnsAsync(final String str, final Callback callback, final long j2) {
        this.networkHandler.post(new Runnable() { // from class: com.ss.android.socialbase.downloader.network.DownloadDnsManager.1
            @Override // java.lang.Runnable
            public void run() {
                DownloadDnsManager.this.resolveDns(str, callback, j2);
            }
        });
    }

    public DownloadDnsManager() {
        this.cache = new LruCache<>(4, 16, false);
        this.networkHandler = new Handler(DownloadPreconnecter.getLooper());
        this.cpuHandler = new Handler(DownloadWatchDog.getThreadLooper());
    }
}
