package com.ss.android.socialbase.downloader.reader;

import android.os.Process;
import com.ss.android.socialbase.downloader.constants.DownloadErrorCode;
import com.ss.android.socialbase.downloader.downloader.DownloadComponentManager;
import com.ss.android.socialbase.downloader.exception.BaseException;
import com.ss.android.socialbase.downloader.segment.Buffer;
import com.ss.android.socialbase.downloader.segment.StreamClosedException;
import com.ss.android.socialbase.downloader.utils.DownloadUtils;
import java.io.InputStream;
import java.util.concurrent.Future;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class AsyncStreamReader implements IStreamReader {
    public static final String TAG = "AsyncStreamReader";
    public int bufferCount;
    public final int bufferSize;
    public volatile boolean closed;
    public final InputStream inputStream;
    public final int maxBufferCount;
    public volatile Future rFuture;
    public Buffer rHead;
    public Buffer rSafe;
    public Buffer rTail;
    public volatile boolean terminated;
    public volatile Throwable throwable;
    public Buffer wHead;
    public Buffer wSafe;
    public Buffer wTail;
    public final Object rLock = new Object();
    public final Object wLock = new Object();
    public final Runnable rRunnable = new Runnable() { // from class: com.ss.android.socialbase.downloader.reader.AsyncStreamReader.1
        @Override // java.lang.Runnable
        public void run() {
            Buffer dequeueReadBuffer;
            Process.setThreadPriority(10);
            do {
                try {
                    dequeueReadBuffer = AsyncStreamReader.this.dequeueReadBuffer();
                    dequeueReadBuffer.size = AsyncStreamReader.this.inputStream.read(dequeueReadBuffer.data);
                    AsyncStreamReader.this.enqueueWriteBuffer(dequeueReadBuffer);
                } catch (Throwable th) {
                    try {
                        AsyncStreamReader.this.throwable = th;
                        th.printStackTrace();
                        synchronized (AsyncStreamReader.this.wLock) {
                            AsyncStreamReader.this.terminated = true;
                            AsyncStreamReader.this.wLock.notify();
                            DownloadUtils.safeClose(AsyncStreamReader.this.inputStream);
                            return;
                        }
                    } catch (Throwable th2) {
                        synchronized (AsyncStreamReader.this.wLock) {
                            AsyncStreamReader.this.terminated = true;
                            AsyncStreamReader.this.wLock.notify();
                            DownloadUtils.safeClose(AsyncStreamReader.this.inputStream);
                            throw th2;
                        }
                    }
                }
            } while (dequeueReadBuffer.size != -1);
            synchronized (AsyncStreamReader.this.wLock) {
                AsyncStreamReader.this.terminated = true;
                AsyncStreamReader.this.wLock.notify();
            }
            DownloadUtils.safeClose(AsyncStreamReader.this.inputStream);
        }
    };

    public AsyncStreamReader(InputStream inputStream, int i2, int i3) throws Throwable {
        this.inputStream = inputStream;
        this.bufferSize = i2;
        if (i3 < 1) {
            i3 = 1;
        } else if (i3 > 64) {
            i3 = 64;
        }
        this.maxBufferCount = i3;
        start();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public Buffer dequeueReadBuffer() throws StreamClosedException, InterruptedException {
        Buffer buffer = this.rSafe;
        if (buffer != null) {
            if (!this.closed) {
                this.rSafe = buffer.next;
                buffer.next = null;
                return buffer;
            }
            throw new StreamClosedException("");
        }
        synchronized (this.rLock) {
            if (!this.closed) {
                Buffer buffer2 = this.rHead;
                if (buffer2 == null && this.bufferCount < this.maxBufferCount) {
                    this.bufferCount++;
                    return new Buffer(this.bufferSize);
                }
                while (buffer2 == null) {
                    this.rLock.wait();
                    if (!this.closed) {
                        buffer2 = this.rHead;
                    } else {
                        throw new StreamClosedException("");
                    }
                }
                this.rSafe = buffer2.next;
                this.rTail = null;
                this.rHead = null;
                buffer2.next = null;
                return buffer2;
            }
            throw new StreamClosedException("");
        }
    }

    private Buffer dequeueWriteBuffer() throws BaseException, InterruptedException {
        Buffer buffer;
        Buffer buffer2 = this.wSafe;
        if (buffer2 != null) {
            this.wSafe = buffer2.next;
            buffer2.next = null;
            return buffer2;
        }
        synchronized (this.wLock) {
            buffer = this.wHead;
            if (buffer == null) {
                do {
                    if (this.terminated) {
                        handleTerminated();
                    }
                    this.wLock.wait();
                    buffer = this.wHead;
                } while (buffer == null);
                this.wSafe = buffer.next;
                this.wTail = null;
                this.wHead = null;
                buffer.next = null;
            } else {
                this.wSafe = buffer.next;
                this.wTail = null;
                this.wHead = null;
                buffer.next = null;
            }
        }
        return buffer;
    }

    private void enqueueReadBuffer(Buffer buffer) {
        synchronized (this.rLock) {
            Buffer buffer2 = this.rTail;
            if (buffer2 == null) {
                this.rTail = buffer;
                this.rHead = buffer;
                this.rLock.notify();
            } else {
                buffer2.next = buffer;
                this.rTail = buffer;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void enqueueWriteBuffer(Buffer buffer) {
        synchronized (this.wLock) {
            Buffer buffer2 = this.wTail;
            if (buffer2 == null) {
                this.wTail = buffer;
                this.wHead = buffer;
                this.wLock.notify();
            } else {
                buffer2.next = buffer;
                this.wTail = buffer;
            }
        }
    }

    private void handleTerminated() throws BaseException {
        Throwable th = this.throwable;
        if (th != null) {
            if (th instanceof StreamClosedException) {
                throw new BaseException((int) DownloadErrorCode.ERROR_STREAM_CLOSED, "async reader closed!");
            }
            DownloadUtils.parseException(th, "async_read");
        }
        throw new BaseException((int) DownloadErrorCode.ERROR_STREAM_TERMINATED, "async reader terminated!");
    }

    private void start() throws Throwable {
        this.rFuture = DownloadComponentManager.getChunkDownloadThreadExecutorService().submit(this.rRunnable);
    }

    @Override // com.ss.android.socialbase.downloader.reader.IStreamReader
    public void close() {
        synchronized (this.rLock) {
            this.closed = true;
            this.rLock.notify();
        }
        Future future = this.rFuture;
        if (future != null) {
            try {
                future.cancel(true);
            } catch (Throwable unused) {
            }
            this.rFuture = null;
        }
    }

    @Override // com.ss.android.socialbase.downloader.reader.IStreamReader
    public Buffer read() throws BaseException, InterruptedException {
        return dequeueWriteBuffer();
    }

    @Override // com.ss.android.socialbase.downloader.reader.IStreamReader
    public void recycle(Buffer buffer) {
        enqueueReadBuffer(buffer);
    }
}
