package com.ss.android.socialbase.downloader.segment;

import androidx.annotation.NonNull;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class BufferQueue implements IBufferPool, IInput, IOutput {
    public static final int MIN_BUFFER_COUNT = 64;
    public static final int MIN_BUFFER_SIZE = 8192;
    public int bufferCount;
    public final int bufferSize;
    public volatile boolean closed;
    public final int maxBufferCount;
    public Buffer rHead;
    public Buffer rSafe;
    public Buffer rTail;
    public Buffer wHead;
    public Buffer wTail;
    public final Object wLock = new Object();
    public final Object rLock = new Object();

    public BufferQueue(int i2, int i3) {
        i2 = i2 < 64 ? 64 : i2;
        i3 = i3 < 8192 ? 8192 : i3;
        this.maxBufferCount = i2;
        this.bufferSize = i3;
    }

    public void close() {
        this.closed = true;
        synchronized (this.wLock) {
            this.wLock.notifyAll();
        }
        synchronized (this.rLock) {
            this.rLock.notifyAll();
        }
    }

    @Override // com.ss.android.socialbase.downloader.segment.IBufferPool
    @NonNull
    public Buffer obtain() throws StreamClosedException, InterruptedException {
        synchronized (this.wLock) {
            if (!this.closed) {
                Buffer buffer = this.wHead;
                if (buffer == null) {
                    if (this.bufferCount < this.maxBufferCount) {
                        this.bufferCount++;
                        return new Buffer(this.bufferSize);
                    }
                    do {
                        this.wLock.wait();
                        if (!this.closed) {
                            buffer = this.wHead;
                        } else {
                            throw new StreamClosedException("obtain");
                        }
                    } while (buffer == null);
                }
                this.wHead = buffer.next;
                if (buffer == this.wTail) {
                    this.wTail = null;
                }
                buffer.next = null;
                return buffer;
            }
            throw new StreamClosedException("obtain");
        }
    }

    @Override // com.ss.android.socialbase.downloader.segment.IInput
    @NonNull
    public Buffer read() throws StreamClosedException, InterruptedException {
        Buffer buffer;
        Buffer buffer2 = this.rSafe;
        if (buffer2 != null) {
            this.rSafe = buffer2.next;
            buffer2.next = null;
            return buffer2;
        }
        synchronized (this.rLock) {
            buffer = this.rHead;
            while (buffer == null) {
                if (!this.closed) {
                    this.rLock.wait();
                    buffer = this.rHead;
                } else {
                    throw new StreamClosedException("read");
                }
            }
            this.rSafe = buffer.next;
            this.rTail = null;
            this.rHead = null;
            buffer.next = null;
        }
        return buffer;
    }

    @Override // com.ss.android.socialbase.downloader.segment.IBufferPool
    public void recycle(@NonNull Buffer buffer) {
        synchronized (this.wLock) {
            Buffer buffer2 = this.wTail;
            if (buffer2 == null) {
                this.wTail = buffer;
                this.wHead = buffer;
            } else {
                buffer2.next = buffer;
                this.wTail = buffer;
            }
            this.wLock.notify();
        }
    }

    @Override // com.ss.android.socialbase.downloader.segment.IOutput
    public void write(@NonNull Buffer buffer) {
        synchronized (this.rLock) {
            Buffer buffer2 = this.rTail;
            if (buffer2 == null) {
                this.rTail = buffer;
                this.rHead = buffer;
                this.rLock.notify();
            } else {
                buffer2.next = buffer;
                this.rTail = buffer;
            }
        }
    }
}
