package com.ss.android.socialbase.downloader.thread;

import android.annotation.SuppressLint;
import android.os.Process;
import com.ss.android.socialbase.downloader.constants.DownloadErrorCode;
import com.ss.android.socialbase.downloader.downloader.DownloadComponentManager;
import com.ss.android.socialbase.downloader.downloader.DownloadResponseHandler;
import com.ss.android.socialbase.downloader.downloader.IDownloadCache;
import com.ss.android.socialbase.downloader.exception.BaseException;
import com.ss.android.socialbase.downloader.exception.RetryCheckStatus;
import com.ss.android.socialbase.downloader.model.DownloadChunk;
import com.ss.android.socialbase.downloader.model.DownloadInfo;
import com.ss.android.socialbase.downloader.model.DownloadTask;
import com.ss.android.socialbase.downloader.model.HttpHeader;
import com.ss.android.socialbase.downloader.network.IDownloadHttpConnection;
import com.ss.android.socialbase.downloader.utils.DownloadExpSwitchCode;
import com.ss.android.socialbase.downloader.utils.DownloadUtils;
import java.io.IOException;
import java.util.List;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class DownloadChunkRunnable implements Runnable {
    public static final String TAG = DownloadChunkRunnable.class.getSimpleName();
    public final IDownloadRunnableCallback callback;
    public volatile boolean canceled;
    public DownloadChunk curDownloadChunk;
    public IDownloadCache downloadCache;
    public DownloadChunk downloadChunk;
    public DownloadInfo downloadInfo;
    public DownloadResponseHandler downloadResponseHandler;
    public final DownloadTask downloadTask;
    public IDownloadHttpConnection httpConnection;
    public boolean isHttpConnectionInject;
    public volatile boolean paused;

    public DownloadChunkRunnable(DownloadChunk downloadChunk, DownloadTask downloadTask, IDownloadRunnableCallback iDownloadRunnableCallback) {
        this.isHttpConnectionInject = false;
        this.downloadChunk = downloadChunk;
        this.downloadTask = downloadTask;
        if (downloadTask != null) {
            this.downloadInfo = downloadTask.getDownloadInfo();
        }
        this.callback = iDownloadRunnableCallback;
        this.downloadCache = DownloadComponentManager.getDownloadCache();
        this.downloadChunk.setChunkRunnable(this);
    }

    private void closeConnection() {
        IDownloadHttpConnection iDownloadHttpConnection = this.httpConnection;
        if (iDownloadHttpConnection != null) {
            iDownloadHttpConnection.end();
            this.httpConnection = null;
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:139:0x01e4 A[Catch: all -> 0x02a9, TRY_ENTER, TryCatch #3 {all -> 0x02a9, blocks: (B:135:0x01da, B:139:0x01e4, B:141:0x01ea, B:144:0x01f3, B:146:0x01fb, B:148:0x0201, B:152:0x020c, B:154:0x0210, B:156:0x0218, B:158:0x0229, B:168:0x0251, B:170:0x0257, B:172:0x0264, B:176:0x026c, B:171:0x025e, B:162:0x0238, B:163:0x0244, B:178:0x0277, B:180:0x027f, B:182:0x0287, B:184:0x028f, B:186:0x0297, B:189:0x02a0, B:122:0x01bc, B:126:0x01c6, B:129:0x01cd), top: B:199:0x01da, inners: #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:170:0x0257 A[Catch: all -> 0x02a9, TryCatch #3 {all -> 0x02a9, blocks: (B:135:0x01da, B:139:0x01e4, B:141:0x01ea, B:144:0x01f3, B:146:0x01fb, B:148:0x0201, B:152:0x020c, B:154:0x0210, B:156:0x0218, B:158:0x0229, B:168:0x0251, B:170:0x0257, B:172:0x0264, B:176:0x026c, B:171:0x025e, B:162:0x0238, B:163:0x0244, B:178:0x0277, B:180:0x027f, B:182:0x0287, B:184:0x028f, B:186:0x0297, B:189:0x02a0, B:122:0x01bc, B:126:0x01c6, B:129:0x01cd), top: B:199:0x01da, inners: #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:171:0x025e A[Catch: all -> 0x02a9, TryCatch #3 {all -> 0x02a9, blocks: (B:135:0x01da, B:139:0x01e4, B:141:0x01ea, B:144:0x01f3, B:146:0x01fb, B:148:0x0201, B:152:0x020c, B:154:0x0210, B:156:0x0218, B:158:0x0229, B:168:0x0251, B:170:0x0257, B:172:0x0264, B:176:0x026c, B:171:0x025e, B:162:0x0238, B:163:0x0244, B:178:0x0277, B:180:0x027f, B:182:0x0287, B:184:0x028f, B:186:0x0297, B:189:0x02a0, B:122:0x01bc, B:126:0x01c6, B:129:0x01cd), top: B:199:0x01da, inners: #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:176:0x026c A[Catch: all -> 0x02a9, TRY_ENTER, TRY_LEAVE, TryCatch #3 {all -> 0x02a9, blocks: (B:135:0x01da, B:139:0x01e4, B:141:0x01ea, B:144:0x01f3, B:146:0x01fb, B:148:0x0201, B:152:0x020c, B:154:0x0210, B:156:0x0218, B:158:0x0229, B:168:0x0251, B:170:0x0257, B:172:0x0264, B:176:0x026c, B:171:0x025e, B:162:0x0238, B:163:0x0244, B:178:0x0277, B:180:0x027f, B:182:0x0287, B:184:0x028f, B:186:0x0297, B:189:0x02a0, B:122:0x01bc, B:126:0x01c6, B:129:0x01cd), top: B:199:0x01da, inners: #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:224:0x0268 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:226:0x01e0 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:229:0x00ff A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:66:0x0103 A[Catch: all -> 0x01ba, BaseException -> 0x01d6, TRY_ENTER, TryCatch #14 {all -> 0x01ba, blocks: (B:22:0x004f, B:26:0x0059, B:30:0x0064, B:35:0x00b3, B:37:0x00b7, B:45:0x00ce, B:62:0x00f9, B:66:0x0103, B:68:0x0107, B:79:0x0137, B:76:0x012f, B:78:0x0136, B:51:0x00dd, B:53:0x00e1), top: B:213:0x004f }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private boolean downloadChunkInner(DownloadChunk downloadChunk) {
        long j2;
        boolean z;
        long j3;
        RetryCheckStatus onRetry;
        int responseCode;
        DownloadChunk firstReuseChunk;
        while (true) {
            DownloadChunk downloadChunk2 = (downloadChunk.isHostChunk() && downloadChunk.hasChunkDivided() && (firstReuseChunk = downloadChunk.getFirstReuseChunk()) != null && firstReuseChunk.getChunkIndex() == downloadChunk.getChunkIndex()) ? firstReuseChunk : null;
            if (downloadChunk2 != null && downloadChunk2.hasNoBytesDownload()) {
                return true;
            }
            long currentOffset = downloadChunk.getCurrentOffset();
            long endOffset = downloadChunk.getEndOffset();
            long currentOffset2 = downloadChunk.getCurrentOffset();
            if (downloadChunk2 != null) {
                currentOffset2 = downloadChunk2.getCurrentOffset();
                currentOffset = downloadChunk2.getCurrentOffset();
                endOffset = downloadChunk2.getEndOffset();
            }
            long j4 = currentOffset;
            long j5 = endOffset;
            long j6 = 0;
            boolean z2 = false;
            try {
                try {
                    if (isStoppedStatus()) {
                        return false;
                    }
                    String url = getUrl();
                    boolean z3 = this.httpConnection != null;
                    this.isHttpConnectionInject = z3;
                    downloadChunk.setReuseingFirstConnection(z3);
                    try {
                        try {
                            try {
                                try {
                                    if (!this.isHttpConnectionInject) {
                                        List<HttpHeader> addRangeHeader = DownloadUtils.addRangeHeader(this.downloadInfo.getExtraHeaders(), this.downloadInfo.geteTag(), j4, j5);
                                        addRangeHeader.add(new HttpHeader("Chunk-Index", String.valueOf(downloadChunk.getChunkIndex())));
                                        DownloadUtils.addThrottleNetSpeed(addRangeHeader, this.downloadInfo);
                                        DownloadUtils.addTTNetProtectTimeout(addRangeHeader, this.downloadInfo);
                                        this.httpConnection = DownloadComponentManager.downloadWithConnection(this.downloadInfo.isNeedDefaultHttpServiceBackUp(), this.downloadInfo.getMaxBytes(), url, addRangeHeader);
                                    }
                                    if (this.httpConnection != null && this.callback != null) {
                                        try {
                                            int responseCode2 = this.httpConnection.getResponseCode();
                                            if (responseCode2 < 200 || responseCode2 >= 300) {
                                                this.callback.setHttpResponseStatus(this.httpConnection);
                                            }
                                        } catch (Throwable th) {
                                            th = th;
                                            th.printStackTrace();
                                            if (isStoppedStatus()) {
                                            }
                                        }
                                    }
                                } catch (BaseException e2) {
                                    e = e2;
                                    j2 = currentOffset2;
                                    z = false;
                                    try {
                                        if (isStoppedStatus()) {
                                            return true;
                                        }
                                        if (DownloadUtils.isResponseCodeError(e)) {
                                            this.callback.onAllChunkRetryWithReset(e, z);
                                            return z;
                                        } else if (this.callback.canRetry(e)) {
                                            if (DownloadUtils.isHttpDataDirtyError(e)) {
                                                this.callback.onAllChunkRetryWithReset(e, true);
                                                return z;
                                            }
                                            if (z2) {
                                                if (this.downloadResponseHandler != null) {
                                                    if (DownloadExpSwitchCode.isSwitchEnable(32)) {
                                                        j3 = this.downloadResponseHandler.getCurOffset() - this.downloadResponseHandler.getLastSyncBytes();
                                                        if (j3 > 0) {
                                                            revertDownloadChunk(downloadChunk, this.downloadResponseHandler.getLastSyncBytes());
                                                        } else if (j3 < 0) {
                                                        }
                                                        if (!DownloadExpSwitchCode.isSwitchEnable(16)) {
                                                            onRetry = this.callback.onSingleChunkRetry(downloadChunk, e, j3);
                                                        } else {
                                                            onRetry = this.callback.onRetry(e, j3);
                                                        }
                                                        if (onRetry != RetryCheckStatus.RETURN) {
                                                            return z;
                                                        }
                                                        downloadChunk.setReuseingFirstConnection(z);
                                                        closeConnection();
                                                    } else {
                                                        j6 = this.downloadResponseHandler.getCurOffset() - j2;
                                                        revertDownloadChunk(downloadChunk, j2);
                                                    }
                                                } else {
                                                    this.callback.onError(e);
                                                    return z;
                                                }
                                            }
                                            j3 = j6;
                                            if (!DownloadExpSwitchCode.isSwitchEnable(16)) {
                                            }
                                            if (onRetry != RetryCheckStatus.RETURN) {
                                            }
                                        } else if (this.downloadInfo.isNeedChunkDowngradeRetry() && !this.downloadInfo.isChunkDowngradeRetryUsed() && this.downloadInfo.getChunkCount() > 1 && DownloadUtils.canChunkDowngradeRetry(e, this.downloadInfo)) {
                                            this.callback.onChunkDowngradeRetry(e);
                                            return z;
                                        } else {
                                            this.callback.onError(e);
                                            return z;
                                        }
                                    } finally {
                                        closeConnection();
                                    }
                                }
                            } catch (BaseException e3) {
                                e = e3;
                                z2 = false;
                                if (isStoppedStatus()) {
                                }
                            }
                        } catch (BaseException e4) {
                            try {
                                throw e4;
                            } catch (Throwable th2) {
                                th = th2;
                                Throwable th3 = th;
                                if (this.httpConnection != null) {
                                    try {
                                        responseCode = this.httpConnection.getResponseCode();
                                        if (responseCode >= 200) {
                                        }
                                        this.callback.setHttpResponseStatus(this.httpConnection);
                                    } catch (Throwable th4) {
                                        th4.printStackTrace();
                                    }
                                }
                                throw th3;
                            }
                        } catch (Throwable th5) {
                            try {
                                DownloadUtils.parseException(th5, "ChunkRunnableConnection");
                                if (this.httpConnection != null && this.callback != null) {
                                    try {
                                        int responseCode3 = this.httpConnection.getResponseCode();
                                        if (responseCode3 < 200 || responseCode3 >= 300) {
                                            this.callback.setHttpResponseStatus(this.httpConnection);
                                        }
                                    } catch (Throwable th6) {
                                        th = th6;
                                        th.printStackTrace();
                                        if (isStoppedStatus()) {
                                        }
                                    }
                                }
                            } catch (Throwable th7) {
                                th = th7;
                                Throwable th32 = th;
                                if (this.httpConnection != null && this.callback != null) {
                                    responseCode = this.httpConnection.getResponseCode();
                                    if (responseCode >= 200 || responseCode >= 300) {
                                        this.callback.setHttpResponseStatus(this.httpConnection);
                                    }
                                }
                                throw th32;
                            }
                        }
                        if (isStoppedStatus()) {
                            return false;
                        }
                        if (this.httpConnection != null) {
                            if (!this.isHttpConnectionInject) {
                                try {
                                    int responseCode4 = this.httpConnection.getResponseCode();
                                    if (!DownloadUtils.isResponseCodeValid(responseCode4)) {
                                        throw new BaseException(1002, String.format("Http response error , code is : %s ", String.valueOf(responseCode4)));
                                        break;
                                    }
                                } catch (BaseException e5) {
                                    throw e5;
                                } catch (Throwable th8) {
                                    DownloadUtils.parseException(th8, "ChunkRunnableGetResponseCode");
                                }
                            }
                            z = false;
                            j2 = currentOffset2;
                            this.downloadResponseHandler = new DownloadResponseHandler(this.downloadInfo, url, this.httpConnection, downloadChunk, this.callback);
                            if (downloadChunk2 != null) {
                                long retainLength = downloadChunk2.getRetainLength(false);
                                if (j5 != 0 && j5 >= j4) {
                                    retainLength = (j5 - j4) + 1;
                                }
                                this.downloadResponseHandler.setChunkOffset(downloadChunk2.getCurrentOffset(), downloadChunk2.getEndOffset(), retainLength);
                            }
                            try {
                                this.downloadResponseHandler.handleResponse();
                                return true;
                            } catch (BaseException e6) {
                                e = e6;
                                z2 = true;
                                if (isStoppedStatus()) {
                                }
                            }
                        } else {
                            throw new BaseException((int) DownloadErrorCode.ERROR_NO_CONNECTION, new IOException("download can't continue, chunk connection is null"));
                        }
                    } catch (Throwable th9) {
                        th = th9;
                        if (isStoppedStatus()) {
                            return true;
                        }
                        try {
                            DownloadUtils.parseException(th, "downloadChunkInner");
                        } catch (BaseException e7) {
                            this.callback.onError(e7);
                        }
                        return z;
                    }
                } catch (Throwable th10) {
                    th = th10;
                    z = false;
                }
            } catch (BaseException e8) {
                e = e8;
                j2 = currentOffset2;
                z = false;
            }
        }
    }

    private String getUrl() {
        return this.downloadInfo.getConnectionUrl();
    }

    private boolean isStoppedStatus() {
        return this.paused || this.canceled;
    }

    private void revertDownloadChunk(DownloadChunk downloadChunk, long j2) {
        DownloadChunk firstReuseChunk = downloadChunk.isHostChunk() ? downloadChunk.getFirstReuseChunk() : downloadChunk;
        if (firstReuseChunk != null) {
            if (firstReuseChunk.canRefreshCurOffsetForReuseChunk()) {
                this.downloadCache.updateDownloadChunk(firstReuseChunk.getId(), firstReuseChunk.getHostChunkIndex(), j2);
            }
            firstReuseChunk.setCurrentOffset(j2);
            this.downloadCache.updateSubDownloadChunk(firstReuseChunk.getId(), firstReuseChunk.getChunkIndex(), firstReuseChunk.getHostChunkIndex(), j2);
        } else if (downloadChunk.isHostChunk()) {
            this.downloadCache.updateDownloadChunk(downloadChunk.getId(), downloadChunk.getChunkIndex(), j2);
        }
    }

    public void cancel() {
        this.canceled = true;
        DownloadResponseHandler downloadResponseHandler = this.downloadResponseHandler;
        if (downloadResponseHandler != null) {
            downloadResponseHandler.cancel();
        }
    }

    public int getChunkIndex() {
        return this.downloadChunk.getChunkIndex();
    }

    public void pause() {
        this.paused = true;
        DownloadResponseHandler downloadResponseHandler = this.downloadResponseHandler;
        if (downloadResponseHandler != null) {
            downloadResponseHandler.pause();
        }
    }

    public void refreshResponseHandleOffset(long j2, long j3) {
        DownloadResponseHandler downloadResponseHandler = this.downloadResponseHandler;
        if (downloadResponseHandler == null) {
            return;
        }
        downloadResponseHandler.setEndOffset(j2, j3);
    }

    /* JADX WARN: Code restructure failed: missing block: B:6:0x0017, code lost:
        r3.curDownloadChunk.setDownloading(false);
     */
    @Override // java.lang.Runnable
    @SuppressLint({"DefaultLocale"})
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void run() {
        Process.setThreadPriority(10);
        this.curDownloadChunk = this.downloadChunk;
        while (true) {
            try {
                this.curDownloadChunk.setChunkRunnable(this);
                if (!downloadChunkInner(this.curDownloadChunk)) {
                    break;
                }
                this.curDownloadChunk.setDownloading(false);
                if (!isStoppedStatus()) {
                    this.curDownloadChunk = this.callback.getUnCompletedSubChunk(this.curDownloadChunk.getChunkIndex());
                    if (isStoppedStatus() || this.curDownloadChunk == null) {
                        break;
                    }
                    Thread.sleep(50L);
                } else {
                    break;
                }
            } finally {
                DownloadChunk downloadChunk = this.curDownloadChunk;
                if (downloadChunk != null) {
                    downloadChunk.setDownloading(false);
                }
                closeConnection();
                this.callback.onCompleted(this);
            }
        }
    }

    public DownloadChunkRunnable(DownloadChunk downloadChunk, DownloadTask downloadTask, IDownloadHttpConnection iDownloadHttpConnection, IDownloadRunnableCallback iDownloadRunnableCallback) {
        this(downloadChunk, downloadTask, iDownloadRunnableCallback);
        this.httpConnection = iDownloadHttpConnection;
    }
}
