package com.ss.android.ttmd5;

import android.support.v4.media.session.PlaybackStateCompat;
import j.l0;
import java.io.File;
import java.io.IOException;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.security.MessageDigest;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class TTMd5 {
    public static final int DEFAULT_SAMPLE_COUNT = 9;
    public static final int DEFAULT_SAMPLE_SIZE = 8192;
    public static final char[] HEX_CHARS = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
    public static final String PROTOCOL = "ttmd5";
    public static final String TAG = "TTMd5";
    public static final int VERSION_MAIN = 1;
    public static final int VERSION_SUB = 1;

    /* compiled from: AAA */
    @Retention(RetentionPolicy.SOURCE)
    /* loaded from: classes.dex */
    public @interface CHECK_MD5_STATUS {
        public static final int FILE_NOT_EXIST = 5;
        public static final int GET_FILE_MD5_ERROR = 6;
        public static final int MD5_EMPTY = 2;
        public static final int MD5_MATCH = 0;
        public static final int MD5_NOT_MATCH = 1;
        public static final int TTMD5_TAG_PARSER_ERROR = 4;
        public static final int TTMD5_VERSION_NOT_SUPPORT = 3;
        public static final int UNKNOWN_ERROR = 99;
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public static class TTMd5Args {
        public String realMd5;
        public int sampleCount;
        public long sampleSize;
        public int versionMain;
        public int versionSub;

        public TTMd5Args() {
        }
    }

    public static String _ttmd5(File file, int i2, long j2) throws Exception {
        return _ttmd5(new FileRandomAccess(file), i2, j2);
    }

    public static int checkMd5(String str, File file) {
        return checkMd5(str, file, null);
    }

    public static long decryptNum(String str) throws RuntimeException {
        return (Long.parseLong(str, 16) - 31) >> 4;
    }

    public static String encryptionNum(long j2) {
        return Long.toHexString((j2 << 4) + 31);
    }

    public static String generateTTMd5Tag(int i2, long j2) {
        return "ttmd5:1:1:" + encryptionNum(i2) + "g" + encryptionNum(j2);
    }

    public static String md5(File file) {
        return ttmd5(file, -1, -1L);
    }

    public static TTMd5Args parserTTMd5Args(String str) throws Exception {
        if (str.startsWith("ttmd5:")) {
            String[] split = str.split(";");
            String[] split2 = split[0].split(":");
            TTMd5Args tTMd5Args = new TTMd5Args();
            tTMd5Args.versionMain = Integer.parseInt(split2[1]);
            if (tTMd5Args.versionMain > 1) {
                return tTMd5Args;
            }
            tTMd5Args.versionSub = Integer.parseInt(split2[2]);
            String[] split3 = split2[3].split("g");
            tTMd5Args.sampleCount = (int) decryptNum(split3[0]);
            tTMd5Args.sampleSize = decryptNum(split3[1]);
            tTMd5Args.realMd5 = split[1];
            return tTMd5Args;
        }
        return null;
    }

    public static String toHexString(byte[] bArr) {
        if (bArr != null) {
            int length = bArr.length;
            int i2 = length * 2;
            char[] cArr = new char[i2];
            int i3 = 0;
            for (int i4 = 0; i4 < length; i4++) {
                int i5 = bArr[i4 + 0] & l0.MAX_VALUE;
                int i6 = i3 + 1;
                char[] cArr2 = HEX_CHARS;
                cArr[i3] = cArr2[i5 >> 4];
                i3 = i6 + 1;
                cArr[i6] = cArr2[i5 & 15];
            }
            return new String(cArr, 0, i2);
        }
        throw new NullPointerException("bytes is null");
    }

    public static String ttmd5(File file) {
        return ttmd5(file, 9, (long) PlaybackStateCompat.ACTION_PLAY_FROM_URI);
    }

    public static void updateSample(IRandomAccess iRandomAccess, MessageDigest messageDigest, byte[] bArr, long j2, long j3) throws IOException {
        iRandomAccess.seek(j2, j3);
        long j4 = 0;
        while (j4 < j3) {
            int read = iRandomAccess.read(bArr, 0, (int) Math.min(j3 - j4, bArr.length));
            if (read > 0) {
                messageDigest.update(bArr, 0, read);
                j4 += read;
            } else {
                throw new IOException("updateSample unexpected readCount <= 0, readCount = " + read + ", readTotalCount = " + j4 + ", sampleSize = " + j3);
            }
        }
    }

    /* JADX WARN: Can't wrap try/catch for region: R(13:5|6|(6:13|14|(3:16|(1:18)|19)|(1:21)|22|(4:31|32|33|34)(3:26|27|28))|38|14|(0)|(0)|22|(1:24)|31|32|33|34) */
    /* JADX WARN: Removed duplicated region for block: B:17:0x0040 A[Catch: all -> 0x009c, TryCatch #2 {all -> 0x009c, blocks: (B:6:0x000d, B:10:0x001a, B:15:0x002e, B:17:0x0040, B:19:0x004d, B:21:0x0064, B:22:0x006e, B:28:0x0080), top: B:43:0x000d }] */
    /* JADX WARN: Removed duplicated region for block: B:21:0x0064 A[Catch: all -> 0x009c, TryCatch #2 {all -> 0x009c, blocks: (B:6:0x000d, B:10:0x001a, B:15:0x002e, B:17:0x0040, B:19:0x004d, B:21:0x0064, B:22:0x006e, B:28:0x0080), top: B:43:0x000d }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static String _ttmd5(IRandomAccess iRandomAccess, int i2, long j2) throws Exception {
        long j3;
        String hexString;
        int i3 = i2;
        MessageDigest messageDigest = MessageDigest.getInstance("MD5");
        if (messageDigest == null) {
            return "";
        }
        try {
            long length = iRandomAccess.length();
            if (i3 > 0 && j2 > 0 && i3 * j2 <= (8 * length) / 10) {
                j3 = j2;
                byte[] bArr = new byte[8192];
                long j4 = 0;
                updateSample(iRandomAccess, messageDigest, bArr, 0L, j3);
                if (i3 > 2) {
                    int i4 = i3 - 1;
                    long j5 = (length - (i3 * j3)) / i4;
                    int i5 = 1;
                    while (i5 < i4) {
                        j4 += j3 + j5;
                        updateSample(iRandomAccess, messageDigest, bArr, j4, j3);
                        i5++;
                        i4 = i4;
                    }
                }
                if (i3 > 1) {
                    updateSample(iRandomAccess, messageDigest, bArr, length - j3, j3);
                }
                hexString = toHexString(messageDigest.digest());
                if (i3 != 1 && j3 == length) {
                    try {
                        iRandomAccess.close();
                    } catch (Throwable unused) {
                    }
                    return hexString;
                }
                String str = generateTTMd5Tag(i3, j3) + ";" + hexString;
                iRandomAccess.close();
                return str;
            }
            j3 = length;
            i3 = 1;
            byte[] bArr2 = new byte[8192];
            long j42 = 0;
            updateSample(iRandomAccess, messageDigest, bArr2, 0L, j3);
            if (i3 > 2) {
            }
            if (i3 > 1) {
            }
            hexString = toHexString(messageDigest.digest());
            if (i3 != 1) {
            }
            String str2 = generateTTMd5Tag(i3, j3) + ";" + hexString;
            iRandomAccess.close();
            return str2;
        } catch (Throwable th) {
            try {
                iRandomAccess.close();
            } catch (Throwable unused2) {
            }
            throw th;
        }
    }

    public static int checkMd5(String str, File file, IRandomAccess iRandomAccess) {
        String _ttmd5;
        if (str == null || str.length() == 0) {
            return 2;
        }
        try {
            if (iRandomAccess != null) {
                if (iRandomAccess.length() <= 0) {
                    try {
                        iRandomAccess.close();
                    } catch (Throwable unused) {
                    }
                    return 5;
                }
            } else if (file == null || !file.exists()) {
                return 5;
            }
            int i2 = -1;
            long j2 = -1;
            try {
                TTMd5Args parserTTMd5Args = parserTTMd5Args(str);
                if (parserTTMd5Args != null) {
                    if (parserTTMd5Args.versionMain > 1) {
                        return 3;
                    }
                    i2 = parserTTMd5Args.sampleCount;
                    j2 = parserTTMd5Args.sampleSize;
                }
                TTMd5Args tTMd5Args = null;
                if (iRandomAccess != null) {
                    _ttmd5 = _ttmd5(iRandomAccess, i2, j2);
                } else {
                    _ttmd5 = _ttmd5(file, i2, j2);
                }
                if (_ttmd5 != null && _ttmd5.length() != 0) {
                    if (parserTTMd5Args != null && (parserTTMd5Args.versionMain != 1 || parserTTMd5Args.versionSub != 1)) {
                        if (parserTTMd5Args.realMd5 != null) {
                            try {
                                tTMd5Args = parserTTMd5Args(_ttmd5);
                            } catch (Throwable unused2) {
                            }
                            if (tTMd5Args != null && parserTTMd5Args.sampleCount == tTMd5Args.sampleCount && parserTTMd5Args.sampleSize == tTMd5Args.sampleSize && parserTTMd5Args.realMd5.equals(tTMd5Args.realMd5)) {
                                return 0;
                            }
                        }
                    }
                    return _ttmd5.equals(str) ? 0 : 1;
                }
                return 6;
            } catch (Throwable unused3) {
                return 4;
            }
        } catch (Throwable unused4) {
            return 99;
        }
    }

    public static String ttmd5(File file, int i2) {
        return ttmd5(file, i2, (long) PlaybackStateCompat.ACTION_PLAY_FROM_URI);
    }

    public static String ttmd5(File file, int i2, long j2) {
        if (file != null) {
            try {
                if (file.exists()) {
                    return _ttmd5(file, i2, j2);
                }
            } catch (Throwable th) {
                th.printStackTrace();
                return "";
            }
        }
        return "";
    }

    public static String ttmd5(IRandomAccess iRandomAccess) {
        return ttmd5(iRandomAccess, 9, (long) PlaybackStateCompat.ACTION_PLAY_FROM_URI);
    }

    public static String ttmd5(IRandomAccess iRandomAccess, int i2) {
        return ttmd5(iRandomAccess, i2, (long) PlaybackStateCompat.ACTION_PLAY_FROM_URI);
    }

    public static String ttmd5(IRandomAccess iRandomAccess, int i2, long j2) {
        if (iRandomAccess == null) {
            return "";
        }
        try {
            return _ttmd5(iRandomAccess, i2, j2);
        } catch (Throwable th) {
            th.printStackTrace();
            return "";
        }
    }

    public static int checkMd5(File file, File file2) {
        if (file == null || file2 == null) {
            return 5;
        }
        try {
            if (file.exists() && file2.exists()) {
                if (file == file2) {
                    return 0;
                }
                return _ttmd5(file, 9, (long) PlaybackStateCompat.ACTION_PLAY_FROM_URI).equals(_ttmd5(file2, 9, (long) PlaybackStateCompat.ACTION_PLAY_FROM_URI)) ? 0 : 1;
            }
            return 5;
        } catch (Throwable th) {
            th.printStackTrace();
            return 99;
        }
    }
}
