package de.robv.android.xposed;

import android.os.Environment;
import androidx.multidex.MultiDexExtractor;
import e.d.a.i.e;
import g.a.a.a.a.d;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.nio.charset.StandardCharsets;
import java.security.DigestException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.zip.Adler32;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class DexCreator {
    public static File DALVIK_CACHE = new File(Environment.getDataDirectory(), "dalvik-cache");

    public static ByteBuffer create(String str, Class<?> cls) throws IOException {
        return ByteBuffer.wrap(create("xposed.dummy." + str + "SuperClass", cls.getName()));
    }

    public static File ensure(String str, Class<?> cls, Class<?> cls2) throws IOException {
        if (cls2.isAssignableFrom(cls)) {
            try {
                return ensure("xposed.dummy." + str + "SuperClass", cls);
            } catch (IOException e2) {
                throw new IOException("Failed to create a superclass for " + str, e2);
            }
        }
        throw new ClassCastException("Cannot initialize " + str + " because " + cls + " does not extend " + cls2);
    }

    public static File getDefaultFile(String str) {
        File file = DALVIK_CACHE;
        return new File(file, "dreamland_" + str.substring(str.lastIndexOf(46) + 1) + MultiDexExtractor.DEX_SUFFIX);
    }

    public static boolean matches(byte[] bArr, String str, String str2) throws IOException {
        boolean z = str.compareTo(str2) < 0;
        byte[] stringToBytes = stringToBytes(e.PARAMETER_LEVEL_LONG + str.replace(d.PACKAGE_SEPARATOR_CHAR, '/') + ";");
        byte[] stringToBytes2 = stringToBytes(e.PARAMETER_LEVEL_LONG + str2.replace(d.PACKAGE_SEPARATOR_CHAR, '/') + ";");
        int i2 = 160;
        if (stringToBytes.length + 160 + stringToBytes2.length >= bArr.length) {
            return false;
        }
        byte[] bArr2 = z ? stringToBytes : stringToBytes2;
        int length = bArr2.length;
        int i3 = 0;
        while (i3 < length) {
            int i4 = i2 + 1;
            if (bArr[i2] != bArr2[i3]) {
                return false;
            }
            i3++;
            i2 = i4;
        }
        if (z) {
            stringToBytes = stringToBytes2;
        }
        int length2 = stringToBytes.length;
        int i5 = 0;
        while (i5 < length2) {
            int i6 = i2 + 1;
            if (bArr[i2] != stringToBytes[i5]) {
                return false;
            }
            i5++;
            i2 = i6;
        }
        return true;
    }

    public static byte[] stringToBytes(String str) throws IOException {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        writeUleb128(byteArrayOutputStream, str.length());
        byteArrayOutputStream.write(str.getBytes(StandardCharsets.UTF_8));
        byteArrayOutputStream.write(0);
        return byteArrayOutputStream.toByteArray();
    }

    public static void updateChecksum(byte[] bArr) {
        Adler32 adler32 = new Adler32();
        adler32.update(bArr, 12, bArr.length - 12);
        int value = (int) adler32.getValue();
        bArr[8] = (byte) (value & 255);
        bArr[9] = (byte) ((value >> 8) & 255);
        bArr[10] = (byte) ((value >> 16) & 255);
        bArr[11] = (byte) ((value >> 24) & 255);
    }

    public static void updateSignature(byte[] bArr) {
        try {
            MessageDigest messageDigest = MessageDigest.getInstance("SHA-1");
            messageDigest.update(bArr, 32, bArr.length - 32);
            messageDigest.digest(bArr, 12, 20);
        } catch (DigestException | NoSuchAlgorithmException e2) {
            throw new RuntimeException(e2);
        }
    }

    public static void writeInt(OutputStream outputStream, int i2) throws IOException {
        outputStream.write(i2);
        outputStream.write(i2 >> 8);
        outputStream.write(i2 >> 16);
        outputStream.write(i2 >> 24);
    }

    public static void writeMapItem(OutputStream outputStream, int i2, int i3, int i4) throws IOException {
        writeInt(outputStream, i2);
        writeInt(outputStream, i3);
        writeInt(outputStream, i4);
    }

    public static void writeUleb128(OutputStream outputStream, int i2) throws IOException {
        while (i2 > 127) {
            outputStream.write((i2 & 127) | 128);
            i2 >>>= 7;
        }
        outputStream.write(i2);
    }

    public static byte[] create(String str, String str2) throws IOException {
        int i2 = str.compareTo(str2) < 0 ? 1 : 0;
        byte[] stringToBytes = stringToBytes(e.PARAMETER_LEVEL_LONG + str.replace(d.PACKAGE_SEPARATOR_CHAR, '/') + ";");
        byte[] stringToBytes2 = stringToBytes(e.PARAMETER_LEVEL_LONG + str2.replace(d.PACKAGE_SEPARATOR_CHAR, '/') + ";");
        int length = stringToBytes.length + stringToBytes2.length;
        int i3 = (-length) & 3;
        int i4 = length + i3;
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byteArrayOutputStream.write("dex\n035\u0000".getBytes());
        byteArrayOutputStream.write(new byte[24]);
        writeInt(byteArrayOutputStream, i4 + 252);
        writeInt(byteArrayOutputStream, 112);
        writeInt(byteArrayOutputStream, 305419896);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 0);
        int i5 = i4 + 164;
        writeInt(byteArrayOutputStream, i5);
        writeInt(byteArrayOutputStream, 2);
        writeInt(byteArrayOutputStream, 112);
        writeInt(byteArrayOutputStream, 2);
        writeInt(byteArrayOutputStream, 120);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 1);
        writeInt(byteArrayOutputStream, 128);
        writeInt(byteArrayOutputStream, i4 + 92);
        writeInt(byteArrayOutputStream, 160);
        writeInt(byteArrayOutputStream, 160);
        writeInt(byteArrayOutputStream, (i2 != 0 ? stringToBytes.length : stringToBytes2.length) + 160);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 1);
        writeInt(byteArrayOutputStream, i2 ^ 1);
        writeInt(byteArrayOutputStream, 1);
        writeInt(byteArrayOutputStream, i2);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, -1);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 0);
        byteArrayOutputStream.write(i2 != 0 ? stringToBytes : stringToBytes2);
        if (i2 != 0) {
            stringToBytes = stringToBytes2;
        }
        byteArrayOutputStream.write(stringToBytes);
        byteArrayOutputStream.write(new byte[i3]);
        writeInt(byteArrayOutputStream, 0);
        writeInt(byteArrayOutputStream, 7);
        writeMapItem(byteArrayOutputStream, 0, 1, 0);
        writeMapItem(byteArrayOutputStream, 1, 2, 112);
        writeMapItem(byteArrayOutputStream, 2, 2, 120);
        writeMapItem(byteArrayOutputStream, 6, 1, 128);
        writeMapItem(byteArrayOutputStream, 8194, 2, 160);
        writeMapItem(byteArrayOutputStream, 4099, 1, i4 + 160);
        writeMapItem(byteArrayOutputStream, 4096, 1, i5);
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        updateSignature(byteArray);
        updateChecksum(byteArray);
        return byteArray;
    }

    public static File ensure(String str, Class<?> cls) throws IOException {
        return ensure(getDefaultFile(str), str, cls.getName());
    }

    public static File ensure(File file, String str, String str2) throws IOException {
        try {
        } catch (IOException unused) {
            file.delete();
        }
        if (matches(XposedHelpers.inputStreamToByteArray(new FileInputStream(file)), str, str2)) {
            return file;
        }
        file.delete();
        byte[] create = create(str, str2);
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        fileOutputStream.write(create);
        fileOutputStream.close();
        return file;
    }
}
