package de.robv.android.xposed.callbacks;

import android.os.Bundle;
import de.robv.android.xposed.XposedBridge;
import java.io.Serializable;
/* compiled from: AAA */
/* loaded from: classes.dex */
public abstract class XCallback implements Comparable<XCallback> {
    public static final int PRIORITY_DEFAULT = 50;
    public static final int PRIORITY_HIGHEST = 10000;
    public static final int PRIORITY_LOWEST = -10000;
    public final int priority;

    @Deprecated
    public XCallback() {
        this.priority = 50;
    }

    public static void callAll(Param param) {
        if (param.callbacks == null) {
            throw new IllegalStateException("This object was not created for use with callAll");
        }
        int i2 = 0;
        while (true) {
            Object[] objArr = param.callbacks;
            if (i2 >= objArr.length) {
                return;
            }
            try {
                ((XCallback) objArr[i2]).call(param);
            } catch (Throwable th) {
                XposedBridge.log(th);
            }
            i2++;
        }
    }

    public void call(Param param) throws Throwable {
    }

    /* compiled from: AAA */
    /* loaded from: classes.dex */
    public static abstract class Param {
        public final Object[] callbacks;
        public Bundle extra;

        /* compiled from: AAA */
        /* loaded from: classes.dex */
        public static class SerializeWrapper implements Serializable {
            public static final long serialVersionUID = 1;
            public final Object object;

            public SerializeWrapper(Object obj) {
                this.object = obj;
            }
        }

        @Deprecated
        public Param() {
            this.callbacks = null;
        }

        public synchronized Bundle getExtra() {
            if (this.extra == null) {
                this.extra = new Bundle();
            }
            return this.extra;
        }

        public Object getObjectExtra(String str) {
            Serializable serializable = getExtra().getSerializable(str);
            if (serializable instanceof SerializeWrapper) {
                return ((SerializeWrapper) serializable).object;
            }
            return null;
        }

        public void setObjectExtra(String str, Object obj) {
            getExtra().putSerializable(str, new SerializeWrapper(obj));
        }

        public Param(XposedBridge.CopyOnWriteSortedSet<? extends XCallback> copyOnWriteSortedSet) {
            this.callbacks = copyOnWriteSortedSet.getSnapshot();
        }
    }

    @Override // java.lang.Comparable
    public int compareTo(XCallback xCallback) {
        if (this == xCallback) {
            return 0;
        }
        int i2 = xCallback.priority;
        int i3 = this.priority;
        return i2 != i3 ? i2 - i3 : System.identityHashCode(this) < System.identityHashCode(xCallback) ? -1 : 1;
    }

    public XCallback(int i2) {
        this.priority = i2;
    }
}
