package joke.library.hermes;

import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.util.Log;
import java.lang.reflect.Proxy;
import joke.library.hermes.HermesService;
import joke.library.hermes.internal.Channel;
import joke.library.hermes.internal.HermesInvocationHandler;
import joke.library.hermes.internal.Reply;
import joke.library.hermes.sender.Sender;
import joke.library.hermes.sender.SenderDesignator;
import joke.library.hermes.util.HermesException;
import joke.library.hermes.util.HermesGc;
import joke.library.hermes.util.TypeCenter;
import joke.library.hermes.util.TypeUtils;
import joke.library.hermes.wrapper.ObjectWrapper;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class Hermes {
    public static final String TAG = "HERMES";
    public static final TypeCenter TYPE_CENTER = TypeCenter.getInstance();
    public static final Channel CHANNEL = Channel.getInstance();
    public static final HermesGc HERMES_GC = HermesGc.getInstance();
    public static Context sContext = null;

    public static void checkBound(Class<? extends HermesService> cls) {
        if (!CHANNEL.getBound(cls)) {
            throw new IllegalStateException("Service Unavailable: You have not connected the service or the connection is not completed. You can set HermesListener to receive a callback when the connection is completed.");
        }
    }

    public static void checkInit() {
        if (sContext == null) {
            throw new IllegalStateException("Hermes has not been initialized.");
        }
    }

    public static void connect(Context context) {
        connectApp(context, (String) null, HermesService.HermesService0.class);
    }

    public static void connectApp(Context context, String str) {
        connectApp(context, str, HermesService.HermesService0.class);
    }

    public static void disconnect(Context context) {
        disconnect(context, HermesService.HermesService0.class);
    }

    public static Context getContext() {
        return sContext;
    }

    public static <T> T getInstance(Class<T> cls, Object... objArr) {
        return (T) getInstanceInService(HermesService.HermesService0.class, cls, objArr);
    }

    public static <T> T getInstanceInService(Class<? extends HermesService> cls, Class<T> cls2, Object... objArr) {
        return (T) getInstanceWithMethodNameInService(cls, cls2, "", objArr);
    }

    public static <T> T getInstanceWithMethodName(Class<T> cls, String str, Object... objArr) {
        return (T) getInstanceWithMethodNameInService(HermesService.HermesService0.class, cls, str, objArr);
    }

    public static <T> T getInstanceWithMethodNameInService(Class<? extends HermesService> cls, Class<T> cls2, String str, Object... objArr) {
        TypeUtils.validateServiceInterface(cls2);
        checkBound(cls);
        ObjectWrapper objectWrapper = new ObjectWrapper(cls2, 1);
        Sender postOffice = SenderDesignator.getPostOffice(cls, 1, objectWrapper);
        int i2 = 0;
        if (objArr == null) {
            objArr = new Object[0];
        }
        int length = objArr.length;
        Object[] objArr2 = new Object[length + 1];
        objArr2[0] = str;
        while (i2 < length) {
            int i3 = i2 + 1;
            objArr2[i3] = objArr[i2];
            i2 = i3;
        }
        try {
            Reply send = postOffice.send(null, objArr2);
            if (send != null && !send.success()) {
                Log.e(TAG, "Error occurs during getting instance. Error code: " + send.getErrorCode());
                Log.e(TAG, "Error message: " + send.getMessage());
                return null;
            }
            objectWrapper.setType(3);
            return (T) getProxy(cls, objectWrapper);
        } catch (HermesException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public static <T> T getProxy(Class<? extends HermesService> cls, ObjectWrapper objectWrapper) {
        Class<?> objectClass = objectWrapper.getObjectClass();
        T t = (T) Proxy.newProxyInstance(objectClass.getClassLoader(), new Class[]{objectClass}, new HermesInvocationHandler(cls, objectWrapper));
        HERMES_GC.register(cls, t, Long.valueOf(objectWrapper.getTimeStamp()));
        return t;
    }

    public static <T> T getUtilityClass(Class<T> cls) {
        return (T) getUtilityClassInService(HermesService.HermesService0.class, cls);
    }

    public static <T> T getUtilityClassInService(Class<? extends HermesService> cls, Class<T> cls2) {
        TypeUtils.validateServiceInterface(cls2);
        checkBound(cls);
        ObjectWrapper objectWrapper = new ObjectWrapper(cls2, 5);
        try {
            Reply send = SenderDesignator.getPostOffice(cls, 2, objectWrapper).send(null, null);
            if (send != null && !send.success()) {
                Log.e(TAG, "Error occurs during getting utility class. Error code: " + send.getErrorCode());
                Log.e(TAG, "Error message: " + send.getMessage());
                return null;
            }
            objectWrapper.setType(4);
            return (T) getProxy(cls, objectWrapper);
        } catch (HermesException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public static void init(Context context) {
        if (sContext != null) {
            return;
        }
        if (context instanceof Application) {
            sContext = context;
        } else {
            sContext = context.getApplicationContext();
        }
    }

    public static boolean isConnected() {
        return isConnected(HermesService.HermesService0.class);
    }

    public static <T> T newInstance(Class<T> cls, Object... objArr) {
        return (T) newInstanceInService(HermesService.HermesService0.class, cls, objArr);
    }

    public static <T> T newInstanceInService(Class<? extends HermesService> cls, Class<T> cls2, Object... objArr) {
        TypeUtils.validateServiceInterface(cls2);
        checkBound(cls);
        ObjectWrapper objectWrapper = new ObjectWrapper(cls2, 0);
        try {
            Reply send = SenderDesignator.getPostOffice(cls, 0, objectWrapper).send(null, objArr);
            if (send != null && !send.success()) {
                Log.e(TAG, "Error occurs during creating instance. Error code: " + send.getErrorCode());
                Log.e(TAG, "Error message: " + send.getMessage());
                return null;
            }
            objectWrapper.setType(3);
            return (T) getProxy(cls, objectWrapper);
        } catch (HermesException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public static void register(Object obj) {
        register(obj.getClass());
    }

    public static void setHermesListener(HermesListener hermesListener) {
        CHANNEL.setHermesListener(hermesListener);
    }

    public static void connect(Context context, Class<? extends HermesService> cls) {
        connectApp(context, (String) null, cls);
    }

    public static void connectApp(Context context, String str, Class<? extends HermesService> cls) {
        init(context);
        CHANNEL.bind(context.getApplicationContext(), str, cls);
    }

    public static void disconnect(Context context, Class<? extends HermesService> cls) {
        CHANNEL.unbind(context.getApplicationContext(), cls);
    }

    public static boolean isConnected(Class<? extends HermesService> cls) {
        return CHANNEL.isConnected(cls);
    }

    public static void register(Class<?> cls) {
        checkInit();
        TYPE_CENTER.register(cls);
    }

    public static void connectApp(Intent intent, Context context, Class<? extends HermesService> cls) {
        init(context);
        CHANNEL.bind(context.getApplicationContext(), intent, cls);
    }
}
