package joke.library.hermes.internal;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.Process;
import android.os.RemoteException;
import android.text.TextUtils;
import android.util.Log;
import androidx.core.util.Pair;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import joke.library.hermes.HermesListener;
import joke.library.hermes.HermesService;
import joke.library.hermes.internal.IHermesService;
import joke.library.hermes.internal.IHermesServiceCallback;
import joke.library.hermes.util.CallbackManager;
import joke.library.hermes.util.CodeUtils;
import joke.library.hermes.util.HermesException;
import joke.library.hermes.util.TypeCenter;
import joke.library.hermes.wrapper.ParameterWrapper;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class Channel {
    public static final String TAG = "CHANNEL";
    public static volatile Channel sInstance;
    public static final CallbackManager CALLBACK_MANAGER = CallbackManager.getInstance();
    public static final TypeCenter TYPE_CENTER = TypeCenter.getInstance();
    public final ConcurrentHashMap<Class<? extends HermesService>, IHermesService> mHermesServices = new ConcurrentHashMap<>();
    public final ConcurrentHashMap<Class<? extends HermesService>, HermesServiceConnection> mHermesServiceConnections = new ConcurrentHashMap<>();
    public final ConcurrentHashMap<Class<? extends HermesService>, Boolean> mBindings = new ConcurrentHashMap<>();
    public final ConcurrentHashMap<Class<? extends HermesService>, Boolean> mBounds = new ConcurrentHashMap<>();
    public HermesListener mListener = null;
    public Handler mUiHandler = new Handler(Looper.getMainLooper());
    public IHermesServiceCallback mHermesServiceCallback = new IHermesServiceCallback.Stub() { // from class: joke.library.hermes.internal.Channel.1
        private Object[] getParameters(ParameterWrapper[] parameterWrapperArr) throws HermesException {
            if (parameterWrapperArr == null) {
                parameterWrapperArr = new ParameterWrapper[0];
            }
            int length = parameterWrapperArr.length;
            Object[] objArr = new Object[length];
            for (int i2 = 0; i2 < length; i2++) {
                ParameterWrapper parameterWrapper = parameterWrapperArr[i2];
                if (parameterWrapper != null) {
                    Class<?> classType = Channel.TYPE_CENTER.getClassType(parameterWrapper);
                    String data = parameterWrapper.getData();
                    if (data == null) {
                        objArr[i2] = null;
                    } else {
                        objArr[i2] = CodeUtils.decode(data, classType);
                    }
                } else {
                    objArr[i2] = null;
                }
            }
            return objArr;
        }

        /* JADX WARN: Removed duplicated region for block: B:32:0x0078  */
        /* JADX WARN: Removed duplicated region for block: B:36:0x0086 A[Catch: HermesException -> 0x00aa, TryCatch #1 {HermesException -> 0x00aa, blocks: (B:10:0x002a, B:12:0x0044, B:17:0x0053, B:34:0x007b, B:36:0x0086, B:37:0x00a9, B:23:0x005d, B:25:0x006c), top: B:41:0x002a }] */
        @Override // joke.library.hermes.internal.IHermesServiceCallback
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public Reply callback(CallbackMail callbackMail) {
            Object invoke;
            Pair<Boolean, Object> callback = Channel.CALLBACK_MANAGER.getCallback(callbackMail.getTimeStamp(), callbackMail.getIndex());
            if (callback == null) {
                return null;
            }
            final Object obj = callback.second;
            if (obj == null) {
                return new Reply(22, "");
            }
            boolean booleanValue = callback.first.booleanValue();
            try {
                final Method method = Channel.TYPE_CENTER.getMethod(obj.getClass(), callbackMail.getMethod());
                final Object[] parameters = getParameters(callbackMail.getParameters());
                if (booleanValue) {
                    if (!(Looper.getMainLooper() == Looper.myLooper())) {
                        Channel.this.mUiHandler.post(new Runnable() { // from class: joke.library.hermes.internal.Channel.1.1
                            @Override // java.lang.Runnable
                            public void run() {
                                try {
                                    method.invoke(obj, parameters);
                                } catch (Exception e2) {
                                    e2.printStackTrace();
                                }
                            }
                        });
                        return null;
                    }
                    try {
                        invoke = method.invoke(obj, parameters);
                    } catch (IllegalAccessException | InvocationTargetException e2) {
                        e = e2;
                        invoke = null;
                        if (e != null) {
                        }
                    }
                } else {
                    try {
                        invoke = method.invoke(obj, parameters);
                    } catch (IllegalAccessException e3) {
                        e = e3;
                        invoke = null;
                        if (e != null) {
                        }
                    } catch (InvocationTargetException e4) {
                        e = e4;
                        invoke = null;
                        if (e != null) {
                        }
                    }
                }
                e = null;
                if (e != null) {
                    if (invoke == null) {
                        return null;
                    }
                    return new Reply(new ParameterWrapper(invoke));
                }
                e.printStackTrace();
                throw new HermesException(18, "Error occurs when invoking method " + method + " on " + obj, e);
            } catch (HermesException e5) {
                e5.printStackTrace();
                return new Reply(e5.getErrorCode(), e5.getErrorMessage());
            }
        }

        @Override // joke.library.hermes.internal.IHermesServiceCallback
        public void gc(List<Long> list, List<Integer> list2) throws RemoteException {
            int size = list.size();
            for (int i2 = 0; i2 < size; i2++) {
                Channel.CALLBACK_MANAGER.removeCallback(list.get(i2).longValue(), list2.get(i2).intValue());
            }
        }
    };

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public class HermesServiceConnection implements ServiceConnection {
        public Class<? extends HermesService> mClass;

        public HermesServiceConnection(Class<? extends HermesService> cls) {
            this.mClass = cls;
        }

        @Override // android.content.ServiceConnection
        public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            synchronized (Channel.this) {
                Channel.this.mBounds.put(this.mClass, true);
                Channel.this.mBindings.put(this.mClass, false);
                IHermesService asInterface = IHermesService.Stub.asInterface(iBinder);
                Channel.this.mHermesServices.put(this.mClass, asInterface);
                try {
                    asInterface.register(Channel.this.mHermesServiceCallback, Process.myPid());
                } catch (RemoteException e2) {
                    e2.printStackTrace();
                    Log.e(Channel.TAG, "Remote Exception: Check whether the process you are communicating with is still alive.");
                    return;
                }
            }
            if (Channel.this.mListener != null) {
                Channel.this.mListener.onHermesConnected(this.mClass);
            }
        }

        @Override // android.content.ServiceConnection
        public void onServiceDisconnected(ComponentName componentName) {
            synchronized (Channel.this) {
                Channel.this.mHermesServices.remove(this.mClass);
                Channel.this.mBounds.put(this.mClass, false);
                Channel.this.mBindings.put(this.mClass, false);
            }
            if (Channel.this.mListener != null) {
                Channel.this.mListener.onHermesDisconnected(this.mClass);
            }
        }
    }

    public static Channel getInstance() {
        if (sInstance == null) {
            synchronized (Channel.class) {
                if (sInstance == null) {
                    sInstance = new Channel();
                }
            }
        }
        return sInstance;
    }

    public void bind(Context context, String str, Class<? extends HermesService> cls) {
        Intent intent;
        HermesListener hermesListener;
        synchronized (this) {
            if (getBound(cls)) {
                return;
            }
            Boolean bool = this.mBindings.get(cls);
            if (bool == null || !bool.booleanValue()) {
                this.mBindings.put(cls, true);
                HermesServiceConnection hermesServiceConnection = new HermesServiceConnection(cls);
                this.mHermesServiceConnections.put(cls, hermesServiceConnection);
                if (TextUtils.isEmpty(str)) {
                    intent = new Intent(context, cls);
                } else {
                    Intent intent2 = new Intent();
                    intent2.setClassName(str, cls.getName());
                    intent = intent2;
                }
                if (context.bindService(intent, hermesServiceConnection, 1) || (hermesListener = this.mListener) == null) {
                    return;
                }
                hermesListener.onHermesConnectedFail();
            }
        }
    }

    public void gc(Class<? extends HermesService> cls, List<Long> list) {
        IHermesService iHermesService = this.mHermesServices.get(cls);
        if (iHermesService == null) {
            Log.e(TAG, "Service Unavailable: Check whether you have disconnected the service before a process dies.");
            return;
        }
        try {
            iHermesService.gc(list);
        } catch (RemoteException e2) {
            e2.printStackTrace();
        }
    }

    public boolean getBound(Class<? extends HermesService> cls) {
        Boolean bool = this.mBounds.get(cls);
        return bool != null && bool.booleanValue();
    }

    public boolean isConnected(Class<? extends HermesService> cls) {
        IHermesService iHermesService = this.mHermesServices.get(cls);
        return iHermesService != null && iHermesService.asBinder().pingBinder();
    }

    public Reply send(Class<? extends HermesService> cls, Mail mail) {
        IHermesService iHermesService = this.mHermesServices.get(cls);
        try {
            if (iHermesService == null) {
                return new Reply(2, "Service Unavailable: Check whether you have connected Hermes.");
            }
            return iHermesService.send(mail);
        } catch (RemoteException unused) {
            return new Reply(1, "Remote Exception: Check whether the process you are communicating with is still alive.");
        }
    }

    public void setHermesListener(HermesListener hermesListener) {
        this.mListener = hermesListener;
    }

    public void unbind(Context context, Class<? extends HermesService> cls) {
        synchronized (this) {
            Boolean bool = this.mBounds.get(cls);
            Boolean bool2 = this.mBindings.get(cls);
            if (bool2 != null && bool2.booleanValue()) {
                this.mBindings.put(cls, false);
            }
            if (bool != null && bool.booleanValue()) {
                HermesServiceConnection hermesServiceConnection = this.mHermesServiceConnections.get(cls);
                if (hermesServiceConnection != null) {
                    context.unbindService(hermesServiceConnection);
                }
                this.mBounds.put(cls, false);
            }
        }
    }

    public void bind(Context context, Intent intent, Class<? extends HermesService> cls) {
        synchronized (this) {
            if (getBound(cls)) {
                return;
            }
            Boolean bool = this.mBindings.get(cls);
            if (bool == null || !bool.booleanValue()) {
                this.mBindings.put(cls, true);
                HermesServiceConnection hermesServiceConnection = new HermesServiceConnection(cls);
                this.mHermesServiceConnections.put(cls, hermesServiceConnection);
                boolean bindService = context.bindService(intent, hermesServiceConnection, 1);
                Log.w("hermes", "绑定服务==" + bindService);
            }
        }
    }
}
