package joke.library.hermes.receiver;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import joke.library.hermes.util.HermesException;
import joke.library.hermes.util.TypeUtils;
import joke.library.hermes.wrapper.MethodWrapper;
import joke.library.hermes.wrapper.ObjectWrapper;
import joke.library.hermes.wrapper.ParameterWrapper;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class InstanceGettingReceiver extends Receiver {
    public Method mMethod;
    public Class<?> mObjectClass;

    public InstanceGettingReceiver(ObjectWrapper objectWrapper) throws HermesException {
        super(objectWrapper);
        Class<?> classType = Receiver.TYPE_CENTER.getClassType(objectWrapper);
        TypeUtils.validateAccessible(classType);
        this.mObjectClass = classType;
    }

    @Override // joke.library.hermes.receiver.Receiver
    public Object invokeMethod() throws HermesException {
        try {
            Receiver.OBJECT_CENTER.putObject(getObjectTimeStamp(), this.mMethod.invoke(null, getParameters()));
            return null;
        } catch (IllegalAccessException | InvocationTargetException e2) {
            e2.printStackTrace();
            throw new HermesException(18, "Error occurs when invoking method " + this.mMethod + " to get an instance of " + this.mObjectClass.getName(), e2);
        }
    }

    @Override // joke.library.hermes.receiver.Receiver
    public void setMethod(MethodWrapper methodWrapper, ParameterWrapper[] parameterWrapperArr) throws HermesException {
        int length = parameterWrapperArr.length;
        Class[] clsArr = new Class[length];
        for (int i2 = 0; i2 < length; i2++) {
            clsArr[i2] = Receiver.TYPE_CENTER.getClassType(parameterWrapperArr[i2]);
        }
        Method methodForGettingInstance = TypeUtils.getMethodForGettingInstance(this.mObjectClass, methodWrapper.getName(), clsArr);
        if (Modifier.isStatic(methodForGettingInstance.getModifiers())) {
            TypeUtils.validateAccessible(methodForGettingInstance);
            this.mMethod = methodForGettingInstance;
            return;
        }
        throw new HermesException(21, "Method " + methodForGettingInstance.getName() + " of class " + this.mObjectClass.getName() + " is not static. Only the static method can be invoked to get an instance.");
    }
}
