package joke.library.hermes.sender;

import android.content.Context;
import java.lang.annotation.Annotation;
import java.lang.reflect.Method;
import joke.library.hermes.HermesService;
import joke.library.hermes.annotation.Background;
import joke.library.hermes.annotation.WeakRef;
import joke.library.hermes.internal.Channel;
import joke.library.hermes.internal.Mail;
import joke.library.hermes.internal.Reply;
import joke.library.hermes.util.CallbackManager;
import joke.library.hermes.util.HermesException;
import joke.library.hermes.util.TimeStampGenerator;
import joke.library.hermes.util.TypeCenter;
import joke.library.hermes.util.TypeUtils;
import joke.library.hermes.wrapper.MethodWrapper;
import joke.library.hermes.wrapper.ObjectWrapper;
import joke.library.hermes.wrapper.ParameterWrapper;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public abstract class Sender {
    public MethodWrapper mMethod;
    public ObjectWrapper mObject;
    public ParameterWrapper[] mParameters;
    public Class<? extends HermesService> mService;
    public long mTimeStamp;
    public static final TypeCenter TYPE_CENTER = TypeCenter.getInstance();
    public static final Channel CHANNEL = Channel.getInstance();
    public static final CallbackManager CALLBACK_MANAGER = CallbackManager.getInstance();

    public Sender(Class<? extends HermesService> cls, ObjectWrapper objectWrapper) {
        this.mService = cls;
        this.mObject = objectWrapper;
    }

    private final ParameterWrapper[] getParameterWrappers(Method method, Object[] objArr) throws HermesException {
        int length = objArr.length;
        ParameterWrapper[] parameterWrapperArr = new ParameterWrapper[length];
        int i2 = 0;
        if (method != null) {
            Class<?>[] parameterTypes = method.getParameterTypes();
            Annotation[][] parameterAnnotations = method.getParameterAnnotations();
            while (i2 < length) {
                if (parameterTypes[i2].isInterface()) {
                    Object obj = objArr[i2];
                    if (obj != null) {
                        parameterWrapperArr[i2] = new ParameterWrapper(parameterTypes[i2], null);
                    } else {
                        parameterWrapperArr[i2] = new ParameterWrapper((Object) null);
                    }
                    if (parameterAnnotations[i2] != null && obj != null) {
                        CALLBACK_MANAGER.addCallback(this.mTimeStamp, i2, obj, TypeUtils.arrayContainsAnnotation(parameterAnnotations[i2], WeakRef.class), !TypeUtils.arrayContainsAnnotation(parameterAnnotations[i2], Background.class));
                    }
                } else if (Context.class.isAssignableFrom(parameterTypes[i2])) {
                    parameterWrapperArr[i2] = new ParameterWrapper(TypeUtils.getContextClass(parameterTypes[i2]), null);
                } else {
                    parameterWrapperArr[i2] = new ParameterWrapper(objArr[i2]);
                }
                i2++;
            }
        } else {
            while (i2 < length) {
                parameterWrapperArr[i2] = new ParameterWrapper(objArr[i2]);
                i2++;
            }
        }
        return parameterWrapperArr;
    }

    private void registerCallbackMethodParameterTypes(Class<?> cls) {
        for (Method method : cls.getMethods()) {
            for (Class<?> cls2 : method.getParameterTypes()) {
                TYPE_CENTER.register(cls2);
            }
        }
    }

    private void registerClass(Method method) throws HermesException {
        Class<?>[] parameterTypes;
        if (method == null) {
            return;
        }
        for (Class<?> cls : method.getParameterTypes()) {
            if (cls.isInterface()) {
                TYPE_CENTER.register(cls);
                registerCallbackMethodParameterTypes(cls);
            }
        }
        TYPE_CENTER.register(method.getReturnType());
    }

    public abstract MethodWrapper getMethodWrapper(Method method, ParameterWrapper[] parameterWrapperArr) throws HermesException;

    public ObjectWrapper getObject() {
        return this.mObject;
    }

    public final synchronized Reply send(Method method, Object[] objArr) throws HermesException {
        Mail mail;
        this.mTimeStamp = TimeStampGenerator.getTimeStamp();
        if (objArr == null) {
            objArr = new Object[0];
        }
        ParameterWrapper[] parameterWrappers = getParameterWrappers(method, objArr);
        MethodWrapper methodWrapper = getMethodWrapper(method, parameterWrappers);
        registerClass(method);
        setParameterWrappers(parameterWrappers);
        mail = new Mail(this.mTimeStamp, this.mObject, methodWrapper, this.mParameters);
        this.mMethod = methodWrapper;
        return CHANNEL.send(this.mService, mail);
    }

    public void setParameterWrappers(ParameterWrapper[] parameterWrapperArr) {
        this.mParameters = parameterWrapperArr;
    }
}
