package joke.library.hermes.util;

import android.app.Activity;
import android.app.Application;
import android.app.IntentService;
import android.app.Service;
import android.content.Context;
import android.util.Log;
import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.FragmentActivity;
import com.baidu.mobads.sdk.api.IAdInterListener;
import com.joke.chongya.basecommons.view.loading.util.VectorCommand;
import e.b.a.a.f.b;
import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.HashSet;
import joke.library.hermes.annotation.ClassId;
import joke.library.hermes.annotation.GetInstance;
import joke.library.hermes.annotation.MethodId;
import joke.library.hermes.annotation.WithinProcess;
import joke.library.hermes.wrapper.MethodWrapper;
import joke.library.hermes.wrapper.ParameterWrapper;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class TypeUtils {
    public static final HashSet<Class<?>> CONTEXT_CLASSES = new HashSet<Class<?>>() { // from class: joke.library.hermes.util.TypeUtils.1
        {
            add(Context.class);
            add(Activity.class);
            add(AppCompatActivity.class);
            add(Application.class);
            add(FragmentActivity.class);
            add(IntentService.class);
            add(Service.class);
        }
    };

    public static boolean arrayContainsAnnotation(Annotation[] annotationArr, Class<? extends Annotation> cls) {
        if (annotationArr != null && cls != null) {
            for (Annotation annotation : annotationArr) {
                if (cls.isInstance(annotation)) {
                    return true;
                }
            }
        }
        return false;
    }

    public static boolean classAssignable(Class<?>[] clsArr, Class<?>[] clsArr2) {
        if (clsArr.length != clsArr2.length) {
            return false;
        }
        int length = clsArr2.length;
        for (int i2 = 0; i2 < length; i2++) {
            if (clsArr2[i2] != null && !primitiveMatch(clsArr[i2], clsArr2[i2]) && !clsArr[i2].isAssignableFrom(clsArr2[i2])) {
                return false;
            }
        }
        return true;
    }

    public static String getClassId(Class<?> cls) {
        ClassId classId = (ClassId) cls.getAnnotation(ClassId.class);
        if (classId != null) {
            return classId.value();
        }
        return cls.getName();
    }

    public static String getClassName(Class<?> cls) {
        return cls == Boolean.class ? "boolean" : cls == Byte.class ? "byte" : cls == Character.class ? "char" : cls == Short.class ? "short" : cls == Integer.class ? IAdInterListener.AdProdType.PRODUCT_INTERSTITIAL : cls == Long.class ? "long" : cls == Float.class ? "float" : cls == Double.class ? "double" : cls == Void.class ? "void" : cls.getName();
    }

    public static Constructor<?> getConstructor(Class<?> cls, Class<?>[] clsArr) throws HermesException {
        Constructor<?>[] constructors;
        Constructor<?> constructor = null;
        for (Constructor<?> constructor2 : cls.getConstructors()) {
            if (classAssignable(constructor2.getParameterTypes(), clsArr)) {
                if (constructor != null) {
                    throw new HermesException(14, "The class " + cls.getName() + " has too many constructors whose  parameter types match the required types.");
                }
                constructor = constructor2;
            }
        }
        if (constructor != null) {
            return constructor;
        }
        throw new HermesException(15, "The class " + cls.getName() + " do not have a constructor whose  parameter types match the required types.");
    }

    public static Class<?> getContextClass(Class<?> cls) {
        for (Class<?> cls2 = cls; cls2 != Object.class; cls2 = cls2.getSuperclass()) {
            if (CONTEXT_CLASSES.contains(cls2)) {
                return cls2;
            }
        }
        while (cls != Object.class) {
            Log.w("lxy_context", cls.getName() + "::" + cls.getClass().getName());
            cls = cls.getSuperclass();
        }
        throw new IllegalArgumentException();
    }

    public static Method getMethod(Class<?> cls, String str, Class<?>[] clsArr, Class<?> cls2) throws HermesException {
        Method[] methods;
        Method method = null;
        for (Method method2 : cls.getMethods()) {
            if (method2.getName().equals(str) && classAssignable(method2.getParameterTypes(), clsArr)) {
                if (method != null) {
                    throw new HermesException(8, "There are more than one method named " + str + " of the class " + cls.getName() + " matching the parameters!");
                }
                method = method2;
            }
        }
        if (method == null || method.getReturnType() == cls2) {
            return method;
        }
        throw new HermesException(10, "The method named " + str + " of the class " + cls.getName() + " matches the parameter types but not the return type. The return type is " + method.getReturnType().getName() + " but the required type is " + cls2.getName() + ". The method in the local interface must exactly match the method in the remote class.");
    }

    public static Method getMethodForGettingInstance(Class<?> cls, String str, Class<?>[] clsArr) throws HermesException {
        Method[] methods;
        Method method = null;
        for (Method method2 : cls.getMethods()) {
            String name = method2.getName();
            if (((str.equals("") && (name.equals("getInstance") || method2.isAnnotationPresent(GetInstance.class))) || (!str.equals("") && name.equals(str))) && classAssignable(method2.getParameterTypes(), clsArr)) {
                if (method != null) {
                    throw new HermesException(11, "When getting instance, there are more than one method named " + str + " of the class " + cls.getName() + " matching the parameters!");
                }
                method = method2;
            }
        }
        if (method != null) {
            if (method.getReturnType() == cls) {
                return method;
            }
            throw new HermesException(12, "When getting instance, the method named " + str + " of the class " + cls.getName() + " matches the parameter types but not the return type. The return type is " + method.getReturnType().getName() + " but the required type is " + cls.getName() + b.DOT);
        }
        throw new HermesException(13, "When getting instance, the method named " + str + " of the class " + cls.getName() + " is not found. The class must have a method for getting instance.");
    }

    public static String getMethodId(Method method) {
        MethodId methodId = (MethodId) method.getAnnotation(MethodId.class);
        if (methodId != null) {
            return methodId.value();
        }
        return method.getName() + '(' + getMethodParameters(method.getParameterTypes()) + ')';
    }

    public static String getMethodParameters(Class<?>[] clsArr) {
        StringBuilder sb = new StringBuilder();
        int length = clsArr.length;
        if (length == 0) {
            return sb.toString();
        }
        sb.append(getClassName(clsArr[0]));
        for (int i2 = 1; i2 < length; i2++) {
            sb.append(VectorCommand.SVG_ARG_DELIMITER);
            sb.append(getClassName(clsArr[i2]));
        }
        return sb.toString();
    }

    public static void methodMatch(Method method, MethodWrapper methodWrapper) throws HermesException {
        methodParameterTypeMatch(method, methodWrapper);
        methodReturnTypeMatch(method, methodWrapper);
    }

    public static void methodParameterTypeMatch(Method method, MethodWrapper methodWrapper) throws HermesException {
        Class<?>[] classTypes = TypeCenter.getInstance().getClassTypes(methodWrapper.getParameterTypes());
        Class<?>[] parameterTypes = method.getParameterTypes();
        if (classTypes.length == parameterTypes.length) {
            int length = classTypes.length;
            for (int i2 = 0; i2 < length; i2++) {
                if (!classTypes[i2].isPrimitive() && !parameterTypes[i2].isPrimitive()) {
                    if (classTypes[i2] != parameterTypes[i2] && !primitiveMatch(classTypes[i2], parameterTypes[i2])) {
                        throw new HermesException(9, "The parameter type of method " + method + " do not match at index " + i2 + b.DOT);
                    }
                } else if (!primitiveMatch(classTypes[i2], parameterTypes[i2])) {
                    throw new HermesException(9, "The parameter type of method " + method + " do not match at index " + i2 + b.DOT);
                }
            }
            return;
        }
        throw new HermesException(9, "The number of method parameters do not match. Method " + method + " has " + parameterTypes.length + " parameters. The required method has " + classTypes.length + " parameters.");
    }

    public static void methodReturnTypeMatch(Method method, MethodWrapper methodWrapper) throws HermesException {
        Class<?> returnType = method.getReturnType();
        Class<?> classType = TypeCenter.getInstance().getClassType(methodWrapper.getReturnType());
        if (!returnType.isPrimitive() && !classType.isPrimitive()) {
            if (classType == returnType || primitiveMatch(returnType, classType)) {
                return;
            }
            throw new HermesException(10, "The return type of methods do not match. Method " + method + " return type: " + returnType.getName() + ". The required is " + classType.getName());
        } else if (primitiveMatch(returnType, classType)) {
        } else {
            throw new HermesException(10, "The return type of methods do not match. Method " + method + " return type: " + returnType.getName() + ". The required is " + classType.getName());
        }
    }

    public static ParameterWrapper[] objectToWrapper(Object[] objArr) throws HermesException {
        if (objArr == null) {
            objArr = new Object[0];
        }
        int length = objArr.length;
        ParameterWrapper[] parameterWrapperArr = new ParameterWrapper[length];
        for (int i2 = 0; i2 < length; i2++) {
            try {
                parameterWrapperArr[i2] = new ParameterWrapper(objArr[i2]);
            } catch (HermesException e2) {
                e2.printStackTrace();
                int errorCode = e2.getErrorCode();
                throw new HermesException(errorCode, "Error happens at parameter encoding, and parameter index is " + i2 + ". See the stack trace for more information.", e2);
            }
        }
        return parameterWrapperArr;
    }

    public static boolean primitiveMatch(Class<?> cls, Class<?> cls2) {
        if (cls.isPrimitive() || cls2.isPrimitive()) {
            if (cls == cls2) {
                return true;
            }
            if (cls.isPrimitive()) {
                return primitiveMatch(cls2, cls);
            }
            if (cls == Boolean.class && cls2 == Boolean.TYPE) {
                return true;
            }
            if (cls == Byte.class && cls2 == Byte.TYPE) {
                return true;
            }
            if (cls == Character.class && cls2 == Character.TYPE) {
                return true;
            }
            if (cls == Short.class && cls2 == Short.TYPE) {
                return true;
            }
            if (cls == Integer.class && cls2 == Integer.TYPE) {
                return true;
            }
            if (cls == Long.class && cls2 == Long.TYPE) {
                return true;
            }
            if (cls == Float.class && cls2 == Float.TYPE) {
                return true;
            }
            if (cls == Double.class && cls2 == Double.TYPE) {
                return true;
            }
            return cls == Void.class && cls2 == Void.TYPE;
        }
        return false;
    }

    public static void validateAccessible(Class<?> cls) throws HermesException {
        if (cls.isAnnotationPresent(WithinProcess.class)) {
            throw new HermesException(19, "Class " + cls.getName() + " has a WithProcess annotation on it, so it cannot be accessed from outside the process.");
        }
    }

    public static void validateClass(Class<?> cls) {
        if (cls != null) {
            if (cls.isPrimitive() || cls.isInterface()) {
                return;
            }
            if (!cls.isAnnotationPresent(WithinProcess.class)) {
                if (!cls.isAnonymousClass()) {
                    if (!cls.isLocalClass()) {
                        if (!Context.class.isAssignableFrom(cls) && Modifier.isAbstract(cls.getModifiers())) {
                            throw new IllegalArgumentException("Error occurs when registering class " + cls.getName() + ". Abstract class cannot be accessed from outside the process.");
                        }
                        return;
                    }
                    throw new IllegalArgumentException("Error occurs when registering class " + cls.getName() + ". Local class cannot be accessed from outside the process.");
                }
                throw new IllegalArgumentException("Error occurs when registering class " + cls.getName() + ". Anonymous class cannot be accessed from outside the process.");
            }
            throw new IllegalArgumentException("Error occurs when registering class " + cls.getName() + ". Class with a WithinProcess annotation presented on it cannot be accessed from outside the process.");
        }
        throw new IllegalArgumentException("Class object is null.");
    }

    public static void validateServiceInterface(Class<?> cls) {
        if (cls != null) {
            if (!cls.isInterface()) {
                throw new IllegalArgumentException("Only interfaces can be passed as the parameters.");
            }
            return;
        }
        throw new IllegalArgumentException("Class object is null.");
    }

    public static void validateAccessible(Method method) throws HermesException {
        if (method.isAnnotationPresent(WithinProcess.class)) {
            throw new HermesException(20, "Method " + method.getName() + " of class " + method.getDeclaringClass().getName() + " has a WithProcess annotation on it, so it cannot be accessed from outside the process.");
        }
    }

    public static void validateAccessible(Constructor<?> constructor) throws HermesException {
        if (constructor.isAnnotationPresent(WithinProcess.class)) {
            throw new HermesException(20, "Constructor " + constructor.getName() + " of class " + constructor.getDeclaringClass().getName() + " has a WithProcess annotation on it, so it cannot be accessed from outside the process.");
        }
    }
}
