package jp.wasabeef.glide.transformations;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
import android.graphics.Shader;
import androidx.annotation.NonNull;
import com.bumptech.glide.load.Key;
import com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool;
import java.security.MessageDigest;
/* compiled from: AAA */
/* loaded from: classes3.dex */
public class RoundedCornersTransformation extends i.a.a.a.a {
    public static final String ID = "jp.wasabeef.glide.transformations.RoundedCornersTransformation.1";
    public static final int VERSION = 1;
    public CornerType cornerType;
    public int diameter;
    public int margin;
    public int radius;

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public enum CornerType {
        ALL,
        TOP_LEFT,
        TOP_RIGHT,
        BOTTOM_LEFT,
        BOTTOM_RIGHT,
        TOP,
        BOTTOM,
        LEFT,
        RIGHT,
        OTHER_TOP_LEFT,
        OTHER_TOP_RIGHT,
        OTHER_BOTTOM_LEFT,
        OTHER_BOTTOM_RIGHT,
        DIAGONAL_FROM_TOP_LEFT,
        DIAGONAL_FROM_TOP_RIGHT
    }

    /* compiled from: AAA */
    /* loaded from: classes3.dex */
    public static /* synthetic */ class a {
        public static final /* synthetic */ int[] $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType;

        static {
            int[] iArr = new int[CornerType.values().length];
            $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType = iArr;
            try {
                iArr[CornerType.ALL.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.TOP_LEFT.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.TOP_RIGHT.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.BOTTOM_LEFT.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.BOTTOM_RIGHT.ordinal()] = 5;
            } catch (NoSuchFieldError unused5) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.TOP.ordinal()] = 6;
            } catch (NoSuchFieldError unused6) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.BOTTOM.ordinal()] = 7;
            } catch (NoSuchFieldError unused7) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.LEFT.ordinal()] = 8;
            } catch (NoSuchFieldError unused8) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.RIGHT.ordinal()] = 9;
            } catch (NoSuchFieldError unused9) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.OTHER_TOP_LEFT.ordinal()] = 10;
            } catch (NoSuchFieldError unused10) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.OTHER_TOP_RIGHT.ordinal()] = 11;
            } catch (NoSuchFieldError unused11) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.OTHER_BOTTOM_LEFT.ordinal()] = 12;
            } catch (NoSuchFieldError unused12) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.OTHER_BOTTOM_RIGHT.ordinal()] = 13;
            } catch (NoSuchFieldError unused13) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.DIAGONAL_FROM_TOP_LEFT.ordinal()] = 14;
            } catch (NoSuchFieldError unused14) {
            }
            try {
                $SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[CornerType.DIAGONAL_FROM_TOP_RIGHT.ordinal()] = 15;
            } catch (NoSuchFieldError unused15) {
            }
        }
    }

    public RoundedCornersTransformation(int i2, int i3) {
        this(i2, i3, CornerType.ALL);
    }

    private void drawBottomLeftRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        int i3 = this.diameter;
        RectF rectF = new RectF(i2, f3 - i3, i2 + i3, f3);
        int i4 = this.radius;
        canvas.drawRoundRect(rectF, i4, i4, paint);
        int i5 = this.margin;
        canvas.drawRect(new RectF(i5, i5, i5 + this.diameter, f3 - this.radius), paint);
        int i6 = this.margin;
        canvas.drawRect(new RectF(this.radius + i6, i6, f2, f3), paint);
    }

    private void drawBottomRightRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.diameter;
        RectF rectF = new RectF(f2 - i2, f3 - i2, f2, f3);
        int i3 = this.radius;
        canvas.drawRoundRect(rectF, i3, i3, paint);
        int i4 = this.margin;
        canvas.drawRect(new RectF(i4, i4, f2 - this.radius, f3), paint);
        int i5 = this.radius;
        canvas.drawRect(new RectF(f2 - i5, this.margin, f2, f3 - i5), paint);
    }

    private void drawBottomRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        RectF rectF = new RectF(this.margin, f3 - this.diameter, f2, f3);
        int i2 = this.radius;
        canvas.drawRoundRect(rectF, i2, i2, paint);
        int i3 = this.margin;
        canvas.drawRect(new RectF(i3, i3, f2, f3 - this.radius), paint);
    }

    private void drawDiagonalFromTopLeftRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        int i3 = this.diameter;
        RectF rectF = new RectF(i2, i2, i2 + i3, i2 + i3);
        int i4 = this.radius;
        canvas.drawRoundRect(rectF, i4, i4, paint);
        int i5 = this.diameter;
        RectF rectF2 = new RectF(f2 - i5, f3 - i5, f2, f3);
        int i6 = this.radius;
        canvas.drawRoundRect(rectF2, i6, i6, paint);
        int i7 = this.margin;
        canvas.drawRect(new RectF(i7, i7 + this.radius, f2 - this.diameter, f3), paint);
        int i8 = this.margin;
        canvas.drawRect(new RectF(this.diameter + i8, i8, f2, f3 - this.radius), paint);
    }

    private void drawDiagonalFromTopRightRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.diameter;
        int i3 = this.margin;
        RectF rectF = new RectF(f2 - i2, i3, f2, i3 + i2);
        int i4 = this.radius;
        canvas.drawRoundRect(rectF, i4, i4, paint);
        int i5 = this.margin;
        int i6 = this.diameter;
        RectF rectF2 = new RectF(i5, f3 - i6, i5 + i6, f3);
        int i7 = this.radius;
        canvas.drawRoundRect(rectF2, i7, i7, paint);
        int i8 = this.margin;
        int i9 = this.radius;
        canvas.drawRect(new RectF(i8, i8, f2 - i9, f3 - i9), paint);
        int i10 = this.margin;
        int i11 = this.radius;
        canvas.drawRect(new RectF(i10 + i11, i10 + i11, f2, f3), paint);
    }

    private void drawLeftRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        RectF rectF = new RectF(i2, i2, i2 + this.diameter, f3);
        int i3 = this.radius;
        canvas.drawRoundRect(rectF, i3, i3, paint);
        int i4 = this.margin;
        canvas.drawRect(new RectF(this.radius + i4, i4, f2, f3), paint);
    }

    private void drawOtherBottomLeftRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        RectF rectF = new RectF(i2, i2, f2, i2 + this.diameter);
        int i3 = this.radius;
        canvas.drawRoundRect(rectF, i3, i3, paint);
        RectF rectF2 = new RectF(f2 - this.diameter, this.margin, f2, f3);
        int i4 = this.radius;
        canvas.drawRoundRect(rectF2, i4, i4, paint);
        int i5 = this.margin;
        int i6 = this.radius;
        canvas.drawRect(new RectF(i5, i5 + i6, f2 - i6, f3), paint);
    }

    private void drawOtherBottomRightRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        RectF rectF = new RectF(i2, i2, f2, i2 + this.diameter);
        int i3 = this.radius;
        canvas.drawRoundRect(rectF, i3, i3, paint);
        int i4 = this.margin;
        RectF rectF2 = new RectF(i4, i4, i4 + this.diameter, f3);
        int i5 = this.radius;
        canvas.drawRoundRect(rectF2, i5, i5, paint);
        int i6 = this.margin;
        int i7 = this.radius;
        canvas.drawRect(new RectF(i6 + i7, i6 + i7, f2, f3), paint);
    }

    private void drawOtherTopLeftRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        RectF rectF = new RectF(this.margin, f3 - this.diameter, f2, f3);
        int i2 = this.radius;
        canvas.drawRoundRect(rectF, i2, i2, paint);
        RectF rectF2 = new RectF(f2 - this.diameter, this.margin, f2, f3);
        int i3 = this.radius;
        canvas.drawRoundRect(rectF2, i3, i3, paint);
        int i4 = this.margin;
        int i5 = this.radius;
        canvas.drawRect(new RectF(i4, i4, f2 - i5, f3 - i5), paint);
    }

    private void drawOtherTopRightRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        RectF rectF = new RectF(i2, i2, i2 + this.diameter, f3);
        int i3 = this.radius;
        canvas.drawRoundRect(rectF, i3, i3, paint);
        RectF rectF2 = new RectF(this.margin, f3 - this.diameter, f2, f3);
        int i4 = this.radius;
        canvas.drawRoundRect(rectF2, i4, i4, paint);
        int i5 = this.margin;
        int i6 = this.radius;
        canvas.drawRect(new RectF(i5 + i6, i5, f2, f3 - i6), paint);
    }

    private void drawRightRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        RectF rectF = new RectF(f2 - this.diameter, this.margin, f2, f3);
        int i2 = this.radius;
        canvas.drawRoundRect(rectF, i2, i2, paint);
        int i3 = this.margin;
        canvas.drawRect(new RectF(i3, i3, f2 - this.radius, f3), paint);
    }

    private void drawRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        float f4 = f2 - i2;
        float f5 = f3 - i2;
        switch (a.$SwitchMap$jp$wasabeef$glide$transformations$RoundedCornersTransformation$CornerType[this.cornerType.ordinal()]) {
            case 1:
                int i3 = this.margin;
                RectF rectF = new RectF(i3, i3, f4, f5);
                int i4 = this.radius;
                canvas.drawRoundRect(rectF, i4, i4, paint);
                return;
            case 2:
                drawTopLeftRoundRect(canvas, paint, f4, f5);
                return;
            case 3:
                drawTopRightRoundRect(canvas, paint, f4, f5);
                return;
            case 4:
                drawBottomLeftRoundRect(canvas, paint, f4, f5);
                return;
            case 5:
                drawBottomRightRoundRect(canvas, paint, f4, f5);
                return;
            case 6:
                drawTopRoundRect(canvas, paint, f4, f5);
                return;
            case 7:
                drawBottomRoundRect(canvas, paint, f4, f5);
                return;
            case 8:
                drawLeftRoundRect(canvas, paint, f4, f5);
                return;
            case 9:
                drawRightRoundRect(canvas, paint, f4, f5);
                return;
            case 10:
                drawOtherTopLeftRoundRect(canvas, paint, f4, f5);
                return;
            case 11:
                drawOtherTopRightRoundRect(canvas, paint, f4, f5);
                return;
            case 12:
                drawOtherBottomLeftRoundRect(canvas, paint, f4, f5);
                return;
            case 13:
                drawOtherBottomRightRoundRect(canvas, paint, f4, f5);
                return;
            case 14:
                drawDiagonalFromTopLeftRoundRect(canvas, paint, f4, f5);
                return;
            case 15:
                drawDiagonalFromTopRightRoundRect(canvas, paint, f4, f5);
                return;
            default:
                int i5 = this.margin;
                RectF rectF2 = new RectF(i5, i5, f4, f5);
                int i6 = this.radius;
                canvas.drawRoundRect(rectF2, i6, i6, paint);
                return;
        }
    }

    private void drawTopLeftRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        int i3 = this.diameter;
        RectF rectF = new RectF(i2, i2, i2 + i3, i2 + i3);
        int i4 = this.radius;
        canvas.drawRoundRect(rectF, i4, i4, paint);
        int i5 = this.margin;
        int i6 = this.radius;
        canvas.drawRect(new RectF(i5, i5 + i6, i5 + i6, f3), paint);
        int i7 = this.margin;
        canvas.drawRect(new RectF(this.radius + i7, i7, f2, f3), paint);
    }

    private void drawTopRightRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.diameter;
        int i3 = this.margin;
        RectF rectF = new RectF(f2 - i2, i3, f2, i3 + i2);
        int i4 = this.radius;
        canvas.drawRoundRect(rectF, i4, i4, paint);
        int i5 = this.margin;
        canvas.drawRect(new RectF(i5, i5, f2 - this.radius, f3), paint);
        int i6 = this.radius;
        canvas.drawRect(new RectF(f2 - i6, this.margin + i6, f2, f3), paint);
    }

    private void drawTopRoundRect(Canvas canvas, Paint paint, float f2, float f3) {
        int i2 = this.margin;
        RectF rectF = new RectF(i2, i2, f2, i2 + this.diameter);
        int i3 = this.radius;
        canvas.drawRoundRect(rectF, i3, i3, paint);
        int i4 = this.margin;
        canvas.drawRect(new RectF(i4, i4 + this.radius, f2, f3), paint);
    }

    @Override // i.a.a.a.a, com.bumptech.glide.load.Key
    public boolean equals(Object obj) {
        if (obj instanceof RoundedCornersTransformation) {
            RoundedCornersTransformation roundedCornersTransformation = (RoundedCornersTransformation) obj;
            if (roundedCornersTransformation.radius == this.radius && roundedCornersTransformation.diameter == this.diameter && roundedCornersTransformation.margin == this.margin && roundedCornersTransformation.cornerType == this.cornerType) {
                return true;
            }
        }
        return false;
    }

    @Override // i.a.a.a.a, com.bumptech.glide.load.Key
    public int hashCode() {
        return 425235636 + (this.radius * 10000) + (this.diameter * 1000) + (this.margin * 100) + (this.cornerType.ordinal() * 10);
    }

    public String toString() {
        return "RoundedTransformation(radius=" + this.radius + ", margin=" + this.margin + ", diameter=" + this.diameter + ", cornerType=" + this.cornerType.name() + ")";
    }

    @Override // i.a.a.a.a
    public Bitmap transform(@NonNull Context context, @NonNull BitmapPool bitmapPool, @NonNull Bitmap bitmap, int i2, int i3) {
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        Bitmap bitmap2 = bitmapPool.get(width, height, Bitmap.Config.ARGB_8888);
        bitmap2.setHasAlpha(true);
        setCanvasBitmapDensity(bitmap, bitmap2);
        Canvas canvas = new Canvas(bitmap2);
        Paint paint = new Paint();
        paint.setAntiAlias(true);
        Shader.TileMode tileMode = Shader.TileMode.CLAMP;
        paint.setShader(new BitmapShader(bitmap, tileMode, tileMode));
        drawRoundRect(canvas, paint, width, height);
        return bitmap2;
    }

    @Override // i.a.a.a.a, com.bumptech.glide.load.Key
    public void updateDiskCacheKey(@NonNull MessageDigest messageDigest) {
        messageDigest.update((ID + this.radius + this.diameter + this.margin + this.cornerType).getBytes(Key.CHARSET));
    }

    public RoundedCornersTransformation(int i2, int i3, CornerType cornerType) {
        this.radius = i2;
        this.diameter = i2 * 2;
        this.margin = i3;
        this.cornerType = cornerType;
    }
}
