package top.niunaijun.blackreflection;

import java.lang.annotation.Annotation;
import java.lang.ref.WeakReference;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.util.HashMap;
import java.util.Map;
import java.util.WeakHashMap;
import top.niunaijun.blackreflection.annotation.BClass;
import top.niunaijun.blackreflection.annotation.BClassName;
import top.niunaijun.blackreflection.annotation.BClassNameNotProcess;
import top.niunaijun.blackreflection.annotation.BConstructor;
import top.niunaijun.blackreflection.annotation.BConstructorNotProcess;
import top.niunaijun.blackreflection.annotation.BField;
import top.niunaijun.blackreflection.annotation.BFieldCheckNotProcess;
import top.niunaijun.blackreflection.annotation.BFieldNotProcess;
import top.niunaijun.blackreflection.annotation.BFieldSetNotProcess;
import top.niunaijun.blackreflection.annotation.BMethodCheckNotProcess;
import top.niunaijun.blackreflection.annotation.BParamClass;
import top.niunaijun.blackreflection.annotation.BParamClassName;
import top.niunaijun.blackreflection.utils.Reflector;
/* compiled from: AAA */
/* loaded from: classes.dex */
public class BlackReflection {
    public static boolean CACHE = false;
    public static boolean DEBUG = false;
    public static final Map<Class<?>, Object> sProxyCache = new HashMap();
    public static final WeakHashMap<Object, Map<Class<?>, Object>> sCallerProxyCache = new WeakHashMap<>();

    public static <T> T create(Class<T> cls, Object obj, final boolean z) {
        try {
            T t = (T) getProxy(cls, obj, z);
            if (t != null) {
                return t;
            }
            final WeakReference weakReference = obj == null ? null : new WeakReference(obj);
            final Class<?> classNameByBlackClass = getClassNameByBlackClass(cls);
            T t2 = (T) Proxy.newProxyInstance(cls.getClassLoader(), new Class[]{cls}, new InvocationHandler() { // from class: top.niunaijun.blackreflection.BlackReflection.1
                @Override // java.lang.reflect.InvocationHandler
                public Object invoke(Object obj2, Method method, Object[] objArr) throws Throwable {
                    String name = method.getName();
                    Class<?> returnType = method.getReturnType();
                    try {
                        boolean z2 = weakReference == null;
                        Object obj3 = z2 ? null : weakReference.get();
                        BField bField = (BField) method.getAnnotation(BField.class);
                        BFieldNotProcess bFieldNotProcess = (BFieldNotProcess) method.getAnnotation(BFieldNotProcess.class);
                        if (bField == null && bFieldNotProcess == null) {
                            if (((BFieldSetNotProcess) method.getAnnotation(BFieldSetNotProcess.class)) != null) {
                                Reflector field = Reflector.on(classNameByBlackClass).field(name.substring(5));
                                if (z2) {
                                    field.set(objArr[0]);
                                } else if (obj3 == null) {
                                    return 0;
                                } else {
                                    field.set(obj3, objArr[0]);
                                }
                                return 0;
                            } else if (((BFieldCheckNotProcess) method.getAnnotation(BFieldCheckNotProcess.class)) == null) {
                                Class<?>[] paramClass = BlackReflection.getParamClass(method);
                                if (((BMethodCheckNotProcess) method.getAnnotation(BMethodCheckNotProcess.class)) != null) {
                                    try {
                                        return Reflector.on(classNameByBlackClass).method(name.substring(7), paramClass).getMethod();
                                    } catch (Throwable unused) {
                                        return null;
                                    }
                                }
                                BConstructor bConstructor = (BConstructor) method.getAnnotation(BConstructor.class);
                                BConstructorNotProcess bConstructorNotProcess = (BConstructorNotProcess) method.getAnnotation(BConstructorNotProcess.class);
                                if (bConstructor == null && bConstructorNotProcess == null) {
                                    Reflector method2 = Reflector.on(classNameByBlackClass).method(name, paramClass);
                                    if (z2) {
                                        return method2.call(objArr);
                                    }
                                    if (obj3 == null) {
                                        return BlackReflection.generateNullValue(returnType);
                                    }
                                    return method2.callByCaller(obj3, objArr);
                                }
                                return Reflector.on(classNameByBlackClass).constructor(paramClass).newInstance(objArr);
                            } else {
                                try {
                                    return Reflector.on(classNameByBlackClass).field(name.substring(7)).getField();
                                } catch (Throwable unused2) {
                                    return null;
                                }
                            }
                        }
                        Reflector field2 = Reflector.on(classNameByBlackClass).field(name);
                        if (z2) {
                            return field2.get();
                        }
                        if (obj3 == null) {
                            return BlackReflection.generateNullValue(returnType);
                        }
                        return field2.get(obj3);
                    } catch (Throwable th) {
                        if (BlackReflection.DEBUG) {
                            if (th.getCause() != null) {
                                th.getCause().printStackTrace();
                            } else {
                                th.printStackTrace();
                            }
                        }
                        if (!(th instanceof BlackNullPointerException)) {
                            if (!z) {
                                return BlackReflection.generateNullValue(returnType);
                            }
                            throw th;
                        }
                        throw new NullPointerException(th.getMessage());
                    }
                }
            });
            if (obj == null) {
                sProxyCache.put(cls, t2);
            } else {
                Map<Class<?>, Object> map = sCallerProxyCache.get(obj);
                if (map == null) {
                    map = new HashMap<>();
                    sCallerProxyCache.put(obj, map);
                }
                map.put(cls, t2);
            }
            return t2;
        } catch (ClassNotFoundException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public static Object generateNullValue(Class<?> cls) {
        if (cls == Void.TYPE) {
            return 0;
        }
        if (cls.isPrimitive()) {
            throw new BlackNullPointerException("value is null!");
        }
        return null;
    }

    public static Class<?> getClassNameByBlackClass(Class<?> cls) throws ClassNotFoundException {
        BClass bClass = (BClass) cls.getAnnotation(BClass.class);
        BClassName bClassName = (BClassName) cls.getAnnotation(BClassName.class);
        BClassNameNotProcess bClassNameNotProcess = (BClassNameNotProcess) cls.getAnnotation(BClassNameNotProcess.class);
        if (bClass == null && bClassName == null && bClassNameNotProcess == null) {
            throw new RuntimeException("Not found @BlackClass or @BlackStrClass");
        }
        if (bClass != null) {
            return bClass.value();
        }
        if (bClassName != null) {
            return Class.forName(bClassName.value());
        }
        return Class.forName(bClassNameNotProcess.value());
    }

    public static Class<?>[] getParamClass(Method method) throws Throwable {
        boolean z;
        Annotation[][] parameterAnnotations = method.getParameterAnnotations();
        Class<?>[] parameterTypes = method.getParameterTypes();
        Class<?>[] clsArr = new Class[parameterTypes.length];
        for (int i2 = 0; i2 < parameterTypes.length; i2++) {
            Annotation[] annotationArr = parameterAnnotations[i2];
            int length = annotationArr.length;
            int i3 = 0;
            while (true) {
                z = true;
                if (i3 >= length) {
                    z = false;
                    break;
                }
                Annotation annotation = annotationArr[i3];
                if (annotation instanceof BParamClassName) {
                    clsArr[i2] = Class.forName(((BParamClassName) annotation).value());
                    break;
                } else if (annotation instanceof BParamClass) {
                    clsArr[i2] = ((BParamClass) annotation).value();
                    break;
                } else {
                    i3++;
                }
            }
            if (!z) {
                clsArr[i2] = parameterTypes[i2];
            }
        }
        return clsArr;
    }

    public static <T> T getProxy(Class<T> cls, Object obj, boolean z) {
        T t;
        if (CACHE && !z) {
            try {
                if (obj == null) {
                    T t2 = (T) sProxyCache.get(cls);
                    if (t2 != null) {
                        return t2;
                    }
                } else {
                    Map<Class<?>, Object> map = sCallerProxyCache.get(obj);
                    if (map != null && (t = (T) map.get(cls)) != null) {
                        return t;
                    }
                }
            } catch (Throwable unused) {
            }
        }
        return null;
    }
}
